@@ -1,4 +1,4 @@
-const baseConfig = require('../../../tools/cdk-build-tools/config/jest.config');
+const baseConfig = require('cdk-build-tools/config/jest.config');
 module.exports = {
   ...baseConfig,
   coverageThreshold: {
