@@ -27,10 +27,8 @@ class CfnSkill(
 ):
     """A CloudFormation ``Alexa::ASK::Skill``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html
-    cloudformationResource:
-    :cloudformationResource:: Alexa::ASK::Skill
+    :cloudformationResource: Alexa::ASK::Skill
     """
 
     def __init__(
@@ -38,8 +36,8 @@ class CfnSkill(
         scope: _Construct_f50a3f53,
         id: builtins.str,
         *,
-        authentication_configuration: typing.Union["AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
-        skill_package: typing.Union["SkillPackageProperty", _IResolvable_9ceae33e],
+        authentication_configuration: typing.Union["CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
+        skill_package: typing.Union["CfnSkill.SkillPackageProperty", _IResolvable_9ceae33e],
         vendor_id: builtins.str,
     ) -> None:
         """Create a new ``Alexa::ASK::Skill``.
@@ -60,11 +58,10 @@ class CfnSkill(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -94,10 +91,9 @@ class CfnSkill(
     @jsii.member(jsii_name="authenticationConfiguration")
     def authentication_configuration(
         self,
-    ) -> typing.Union["AuthenticationConfigurationProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e]:
         """``Alexa::ASK::Skill.AuthenticationConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html#cfn-ask-skill-authenticationconfiguration
         """
         return jsii.get(self, "authenticationConfiguration")
@@ -105,7 +101,7 @@ class CfnSkill(
     @authentication_configuration.setter # type: ignore
     def authentication_configuration(
         self,
-        value: typing.Union["AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "authenticationConfiguration", value)
 
@@ -113,10 +109,9 @@ class CfnSkill(
     @jsii.member(jsii_name="skillPackage")
     def skill_package(
         self,
-    ) -> typing.Union["SkillPackageProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnSkill.SkillPackageProperty", _IResolvable_9ceae33e]:
         """``Alexa::ASK::Skill.SkillPackage``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html#cfn-ask-skill-skillpackage
         """
         return jsii.get(self, "skillPackage")
@@ -124,7 +119,7 @@ class CfnSkill(
     @skill_package.setter # type: ignore
     def skill_package(
         self,
-        value: typing.Union["SkillPackageProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnSkill.SkillPackageProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "skillPackage", value)
 
@@ -133,7 +128,6 @@ class CfnSkill(
     def vendor_id(self) -> builtins.str:
         """``Alexa::ASK::Skill.VendorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html#cfn-ask-skill-vendorid
         """
         return jsii.get(self, "vendorId")
@@ -164,7 +158,6 @@ class CfnSkill(
             :param client_secret: ``CfnSkill.AuthenticationConfigurationProperty.ClientSecret``.
             :param refresh_token: ``CfnSkill.AuthenticationConfigurationProperty.RefreshToken``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-authenticationconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -177,7 +170,6 @@ class CfnSkill(
         def client_id(self) -> builtins.str:
             """``CfnSkill.AuthenticationConfigurationProperty.ClientId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-authenticationconfiguration.html#cfn-ask-skill-authenticationconfiguration-clientid
             """
             result = self._values.get("client_id")
@@ -188,7 +180,6 @@ class CfnSkill(
         def client_secret(self) -> builtins.str:
             """``CfnSkill.AuthenticationConfigurationProperty.ClientSecret``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-authenticationconfiguration.html#cfn-ask-skill-authenticationconfiguration-clientsecret
             """
             result = self._values.get("client_secret")
@@ -199,7 +190,6 @@ class CfnSkill(
         def refresh_token(self) -> builtins.str:
             """``CfnSkill.AuthenticationConfigurationProperty.RefreshToken``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-authenticationconfiguration.html#cfn-ask-skill-authenticationconfiguration-refreshtoken
             """
             result = self._values.get("refresh_token")
@@ -227,7 +217,6 @@ class CfnSkill(
             """
             :param manifest: ``CfnSkill.OverridesProperty.Manifest``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-overrides.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -238,7 +227,6 @@ class CfnSkill(
         def manifest(self) -> typing.Any:
             """``CfnSkill.OverridesProperty.Manifest``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-overrides.html#cfn-ask-skill-overrides-manifest
             """
             result = self._values.get("manifest")
@@ -283,7 +271,6 @@ class CfnSkill(
             :param s3_bucket_role: ``CfnSkill.SkillPackageProperty.S3BucketRole``.
             :param s3_object_version: ``CfnSkill.SkillPackageProperty.S3ObjectVersion``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -301,7 +288,6 @@ class CfnSkill(
         def s3_bucket(self) -> builtins.str:
             """``CfnSkill.SkillPackageProperty.S3Bucket``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-s3bucket
             """
             result = self._values.get("s3_bucket")
@@ -312,7 +298,6 @@ class CfnSkill(
         def s3_key(self) -> builtins.str:
             """``CfnSkill.SkillPackageProperty.S3Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-s3key
             """
             result = self._values.get("s3_key")
@@ -325,7 +310,6 @@ class CfnSkill(
         ) -> typing.Optional[typing.Union["CfnSkill.OverridesProperty", _IResolvable_9ceae33e]]:
             """``CfnSkill.SkillPackageProperty.Overrides``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-overrides
             """
             result = self._values.get("overrides")
@@ -335,7 +319,6 @@ class CfnSkill(
         def s3_bucket_role(self) -> typing.Optional[builtins.str]:
             """``CfnSkill.SkillPackageProperty.S3BucketRole``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-s3bucketrole
             """
             result = self._values.get("s3_bucket_role")
@@ -345,7 +328,6 @@ class CfnSkill(
         def s3_object_version(self) -> typing.Optional[builtins.str]:
             """``CfnSkill.SkillPackageProperty.S3ObjectVersion``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ask-skill-skillpackage.html#cfn-ask-skill-skillpackage-s3objectversion
             """
             result = self._values.get("s3_object_version")
@@ -376,8 +358,8 @@ class CfnSkillProps:
     def __init__(
         self,
         *,
-        authentication_configuration: typing.Union["CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e],
-        skill_package: typing.Union["CfnSkill.SkillPackageProperty", _IResolvable_9ceae33e],
+        authentication_configuration: typing.Union[CfnSkill.AuthenticationConfigurationProperty, _IResolvable_9ceae33e],
+        skill_package: typing.Union[CfnSkill.SkillPackageProperty, _IResolvable_9ceae33e],
         vendor_id: builtins.str,
     ) -> None:
         """Properties for defining a ``Alexa::ASK::Skill``.
@@ -386,7 +368,6 @@ class CfnSkillProps:
         :param skill_package: ``Alexa::ASK::Skill.SkillPackage``.
         :param vendor_id: ``Alexa::ASK::Skill.VendorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -398,10 +379,9 @@ class CfnSkillProps:
     @builtins.property
     def authentication_configuration(
         self,
-    ) -> typing.Union["CfnSkill.AuthenticationConfigurationProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnSkill.AuthenticationConfigurationProperty, _IResolvable_9ceae33e]:
         """``Alexa::ASK::Skill.AuthenticationConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html#cfn-ask-skill-authenticationconfiguration
         """
         result = self._values.get("authentication_configuration")
@@ -411,10 +391,9 @@ class CfnSkillProps:
     @builtins.property
     def skill_package(
         self,
-    ) -> typing.Union["CfnSkill.SkillPackageProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnSkill.SkillPackageProperty, _IResolvable_9ceae33e]:
         """``Alexa::ASK::Skill.SkillPackage``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html#cfn-ask-skill-skillpackage
         """
         result = self._values.get("skill_package")
@@ -425,7 +404,6 @@ class CfnSkillProps:
     def vendor_id(self) -> builtins.str:
         """``Alexa::ASK::Skill.VendorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ask-skill.html#cfn-ask-skill-vendorid
         """
         result = self._values.get("vendor_id")
