@@ -41,7 +41,7 @@ class PipelineDeployStackAction(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.app_delivery.PipelineDeployStackAction",
 ):
-    """A class to deploy a stack that is part of a CDK App, using CodePipeline.
+    """(experimental) A class to deploy a stack that is part of a CDK App, using CodePipeline.
 
     This composite Action takes care of preparing and executing a CloudFormation ChangeSet.
 
@@ -49,7 +49,6 @@ class PipelineDeployStackAction(
     requires the deployed stack is in the same account and region where the
     CodePipeline is hosted.
 
-    stability
     :stability: experimental
     """
 
@@ -68,18 +67,17 @@ class PipelineDeployStackAction(
         role: typing.Optional[_IRole_e69bbae4] = None,
     ) -> None:
         """
-        :param admin_permissions: Whether to grant admin permissions to CloudFormation while deploying this template. Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you don't specify any alternatives. The default role that will be created for you will have admin (i.e., ``*``) permissions on all resources, and the deployment will have named IAM capabilities (i.e., able to create all IAM resources). This is a shorthand that you can use if you fully trust the templates that are deployed in this pipeline. If you want more fine-grained permissions, use ``addToRolePolicy`` and ``capabilities`` to control what the CloudFormation deployment is allowed to do.
-        :param input: The CodePipeline artifact that holds the synthesized app, which is the contents of the ``<directory>`` when running ``cdk synth -o <directory>``.
-        :param stack: The CDK stack to be deployed.
-        :param capabilities: Acknowledge certain changes made as part of deployment. For stacks that contain certain resources, explicit acknowledgement that AWS CloudFormation might create or update those resources. For example, you must specify AnonymousIAM if your stack template contains AWS Identity and Access Management (IAM) resources. For more information Default: [AnonymousIAM, AutoExpand], unless ``adminPermissions`` is true
-        :param change_set_name: The name to use when creating a ChangeSet for the stack. Default: CDK-CodePipeline-ChangeSet
-        :param create_change_set_action_name: The name of the CodePipeline action creating the ChangeSet. Default: 'ChangeSet'
-        :param create_change_set_run_order: The runOrder for the CodePipeline action creating the ChangeSet. Default: 1
-        :param execute_change_set_action_name: The name of the CodePipeline action creating the ChangeSet. Default: 'Execute'
-        :param execute_change_set_run_order: The runOrder for the CodePipeline action executing the ChangeSet. Default: ``createChangeSetRunOrder + 1``
-        :param role: IAM role to assume when deploying changes. If not specified, a fresh role is created. The role is created with zero permissions unless ``adminPermissions`` is true, in which case the role will have admin permissions. Default: A fresh role with admin or no permissions (depending on the value of ``adminPermissions``).
+        :param admin_permissions: (experimental) Whether to grant admin permissions to CloudFormation while deploying this template. Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you don't specify any alternatives. The default role that will be created for you will have admin (i.e., ``*``) permissions on all resources, and the deployment will have named IAM capabilities (i.e., able to create all IAM resources). This is a shorthand that you can use if you fully trust the templates that are deployed in this pipeline. If you want more fine-grained permissions, use ``addToRolePolicy`` and ``capabilities`` to control what the CloudFormation deployment is allowed to do.
+        :param input: (experimental) The CodePipeline artifact that holds the synthesized app, which is the contents of the ``<directory>`` when running ``cdk synth -o <directory>``.
+        :param stack: (experimental) The CDK stack to be deployed.
+        :param capabilities: (experimental) Acknowledge certain changes made as part of deployment. For stacks that contain certain resources, explicit acknowledgement that AWS CloudFormation might create or update those resources. For example, you must specify AnonymousIAM if your stack template contains AWS Identity and Access Management (IAM) resources. For more information Default: [AnonymousIAM, AutoExpand], unless ``adminPermissions`` is true
+        :param change_set_name: (experimental) The name to use when creating a ChangeSet for the stack. Default: CDK-CodePipeline-ChangeSet
+        :param create_change_set_action_name: (experimental) The name of the CodePipeline action creating the ChangeSet. Default: 'ChangeSet'
+        :param create_change_set_run_order: (experimental) The runOrder for the CodePipeline action creating the ChangeSet. Default: 1
+        :param execute_change_set_action_name: (experimental) The name of the CodePipeline action creating the ChangeSet. Default: 'Execute'
+        :param execute_change_set_run_order: (experimental) The runOrder for the CodePipeline action executing the ChangeSet. Default: ``createChangeSetRunOrder + 1``
+        :param role: (experimental) IAM role to assume when deploying changes. If not specified, a fresh role is created. The role is created with zero permissions unless ``adminPermissions`` is true, in which case the role will have admin permissions. Default: A fresh role with admin or no permissions (depending on the value of ``adminPermissions``).
 
-        stability
         :stability: experimental
         """
         props = PipelineDeployStackActionProps(
@@ -102,7 +100,7 @@ class PipelineDeployStackAction(
         self,
         statement: _PolicyStatement_f75dc775,
     ) -> None:
-        """Add policy statements to the role deploying the stack.
+        """(experimental) Add policy statements to the role deploying the stack.
 
         This role is passed to CloudFormation and must have the IAM permissions
         necessary to deploy the stack or you can grant this role ``adminPermissions``
@@ -112,7 +110,6 @@ class PipelineDeployStackAction(
 
         :param statement: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "addToDeploymentRolePolicy", [statement])
@@ -132,7 +129,6 @@ class PipelineDeployStackAction(
         :param bucket: 
         :param role: 
 
-        stability
         :stability: experimental
         """
         options = _ActionBindOptions_530c352f(bucket=bucket, role=role)
@@ -156,15 +152,14 @@ class PipelineDeployStackAction(
         """
         :param name: -
         :param target: -
-        :param description: A description of the rule's purpose. Default: - No description.
-        :param enabled: Indicates whether the rule is enabled. Default: true
-        :param event_bus: The event bus to associate with this rule. Default: - The default event bus.
-        :param event_pattern: Describes which events EventBridge routes to the specified target. These routed events are matched events. For more information, see Events and Event Patterns in the Amazon EventBridge User Guide. Default: - None.
-        :param rule_name: A name for the rule. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the rule name. For more information, see Name Type.
-        :param schedule: The schedule or rate (frequency) that determines when EventBridge runs the rule. For more information, see Schedule Expression Syntax for Rules in the Amazon EventBridge User Guide. Default: - None.
-        :param targets: Targets to invoke when this rule matches an event. Input will be the full matched event. If you wish to specify custom target input, use ``addTarget(target[, inputOptions])``. Default: - No targets.
+        :param description: (experimental) A description of the rule's purpose. Default: - No description.
+        :param enabled: (experimental) Indicates whether the rule is enabled. Default: true
+        :param event_bus: (experimental) The event bus to associate with this rule. Default: - The default event bus.
+        :param event_pattern: (experimental) Describes which events EventBridge routes to the specified target. These routed events are matched events. For more information, see Events and Event Patterns in the Amazon EventBridge User Guide. Default: - None.
+        :param rule_name: (experimental) A name for the rule. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the rule name. For more information, see Name Type.
+        :param schedule: (experimental) The schedule or rate (frequency) that determines when EventBridge runs the rule. For more information, see Schedule Expression Syntax for Rules in the Amazon EventBridge User Guide. Default: - None.
+        :param targets: (experimental) Targets to invoke when this rule matches an event. Input will be the full matched event. If you wish to specify custom target input, use ``addTarget(target[, inputOptions])``. Default: - No targets.
 
-        stability
         :stability: experimental
         """
         options = _RuleProps_d60f0abf(
@@ -183,7 +178,6 @@ class PipelineDeployStackAction(
     @jsii.member(jsii_name="actionProperties")
     def action_properties(self) -> _ActionProperties_8f5d7a9d:
         """
-        stability
         :stability: experimental
         """
         return jsii.get(self, "actionProperties")
@@ -192,7 +186,6 @@ class PipelineDeployStackAction(
     @jsii.member(jsii_name="deploymentRole")
     def deployment_role(self) -> _IRole_e69bbae4:
         """
-        stability
         :stability: experimental
         """
         return jsii.get(self, "deploymentRole")
@@ -230,18 +223,17 @@ class PipelineDeployStackActionProps:
         role: typing.Optional[_IRole_e69bbae4] = None,
     ) -> None:
         """
-        :param admin_permissions: Whether to grant admin permissions to CloudFormation while deploying this template. Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you don't specify any alternatives. The default role that will be created for you will have admin (i.e., ``*``) permissions on all resources, and the deployment will have named IAM capabilities (i.e., able to create all IAM resources). This is a shorthand that you can use if you fully trust the templates that are deployed in this pipeline. If you want more fine-grained permissions, use ``addToRolePolicy`` and ``capabilities`` to control what the CloudFormation deployment is allowed to do.
-        :param input: The CodePipeline artifact that holds the synthesized app, which is the contents of the ``<directory>`` when running ``cdk synth -o <directory>``.
-        :param stack: The CDK stack to be deployed.
-        :param capabilities: Acknowledge certain changes made as part of deployment. For stacks that contain certain resources, explicit acknowledgement that AWS CloudFormation might create or update those resources. For example, you must specify AnonymousIAM if your stack template contains AWS Identity and Access Management (IAM) resources. For more information Default: [AnonymousIAM, AutoExpand], unless ``adminPermissions`` is true
-        :param change_set_name: The name to use when creating a ChangeSet for the stack. Default: CDK-CodePipeline-ChangeSet
-        :param create_change_set_action_name: The name of the CodePipeline action creating the ChangeSet. Default: 'ChangeSet'
-        :param create_change_set_run_order: The runOrder for the CodePipeline action creating the ChangeSet. Default: 1
-        :param execute_change_set_action_name: The name of the CodePipeline action creating the ChangeSet. Default: 'Execute'
-        :param execute_change_set_run_order: The runOrder for the CodePipeline action executing the ChangeSet. Default: ``createChangeSetRunOrder + 1``
-        :param role: IAM role to assume when deploying changes. If not specified, a fresh role is created. The role is created with zero permissions unless ``adminPermissions`` is true, in which case the role will have admin permissions. Default: A fresh role with admin or no permissions (depending on the value of ``adminPermissions``).
+        :param admin_permissions: (experimental) Whether to grant admin permissions to CloudFormation while deploying this template. Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you don't specify any alternatives. The default role that will be created for you will have admin (i.e., ``*``) permissions on all resources, and the deployment will have named IAM capabilities (i.e., able to create all IAM resources). This is a shorthand that you can use if you fully trust the templates that are deployed in this pipeline. If you want more fine-grained permissions, use ``addToRolePolicy`` and ``capabilities`` to control what the CloudFormation deployment is allowed to do.
+        :param input: (experimental) The CodePipeline artifact that holds the synthesized app, which is the contents of the ``<directory>`` when running ``cdk synth -o <directory>``.
+        :param stack: (experimental) The CDK stack to be deployed.
+        :param capabilities: (experimental) Acknowledge certain changes made as part of deployment. For stacks that contain certain resources, explicit acknowledgement that AWS CloudFormation might create or update those resources. For example, you must specify AnonymousIAM if your stack template contains AWS Identity and Access Management (IAM) resources. For more information Default: [AnonymousIAM, AutoExpand], unless ``adminPermissions`` is true
+        :param change_set_name: (experimental) The name to use when creating a ChangeSet for the stack. Default: CDK-CodePipeline-ChangeSet
+        :param create_change_set_action_name: (experimental) The name of the CodePipeline action creating the ChangeSet. Default: 'ChangeSet'
+        :param create_change_set_run_order: (experimental) The runOrder for the CodePipeline action creating the ChangeSet. Default: 1
+        :param execute_change_set_action_name: (experimental) The name of the CodePipeline action creating the ChangeSet. Default: 'Execute'
+        :param execute_change_set_run_order: (experimental) The runOrder for the CodePipeline action executing the ChangeSet. Default: ``createChangeSetRunOrder + 1``
+        :param role: (experimental) IAM role to assume when deploying changes. If not specified, a fresh role is created. The role is created with zero permissions unless ``adminPermissions`` is true, in which case the role will have admin permissions. Default: A fresh role with admin or no permissions (depending on the value of ``adminPermissions``).
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -266,7 +258,7 @@ class PipelineDeployStackActionProps:
 
     @builtins.property
     def admin_permissions(self) -> builtins.bool:
-        """Whether to grant admin permissions to CloudFormation while deploying this template.
+        """(experimental) Whether to grant admin permissions to CloudFormation while deploying this template.
 
         Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you
         don't specify any alternatives.
@@ -280,7 +272,6 @@ class PipelineDeployStackActionProps:
         use ``addToRolePolicy`` and ``capabilities`` to control what the CloudFormation
         deployment is allowed to do.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("admin_permissions")
@@ -289,9 +280,8 @@ class PipelineDeployStackActionProps:
 
     @builtins.property
     def input(self) -> _Artifact_af6d98e9:
-        """The CodePipeline artifact that holds the synthesized app, which is the contents of the ``<directory>`` when running ``cdk synth -o <directory>``.
+        """(experimental) The CodePipeline artifact that holds the synthesized app, which is the contents of the ``<directory>`` when running ``cdk synth -o <directory>``.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("input")
@@ -300,9 +290,8 @@ class PipelineDeployStackActionProps:
 
     @builtins.property
     def stack(self) -> _Stack_05f4505a:
-        """The CDK stack to be deployed.
+        """(experimental) The CDK stack to be deployed.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("stack")
@@ -313,19 +302,16 @@ class PipelineDeployStackActionProps:
     def capabilities(
         self,
     ) -> typing.Optional[typing.List[_CloudFormationCapabilities_979dd343]]:
-        """Acknowledge certain changes made as part of deployment.
+        """(experimental) Acknowledge certain changes made as part of deployment.
 
         For stacks that contain certain resources, explicit acknowledgement that AWS CloudFormation
         might create or update those resources. For example, you must specify AnonymousIAM if your
         stack template contains AWS Identity and Access Management (IAM) resources. For more
         information
 
-        default
         :default: [AnonymousIAM, AutoExpand], unless ``adminPermissions`` is true
 
-        see
         :see: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-capabilities
-        stability
         :stability: experimental
         """
         result = self._values.get("capabilities")
@@ -333,12 +319,10 @@ class PipelineDeployStackActionProps:
 
     @builtins.property
     def change_set_name(self) -> typing.Optional[builtins.str]:
-        """The name to use when creating a ChangeSet for the stack.
+        """(experimental) The name to use when creating a ChangeSet for the stack.
 
-        default
         :default: CDK-CodePipeline-ChangeSet
 
-        stability
         :stability: experimental
         """
         result = self._values.get("change_set_name")
@@ -346,12 +330,10 @@ class PipelineDeployStackActionProps:
 
     @builtins.property
     def create_change_set_action_name(self) -> typing.Optional[builtins.str]:
-        """The name of the CodePipeline action creating the ChangeSet.
+        """(experimental) The name of the CodePipeline action creating the ChangeSet.
 
-        default
         :default: 'ChangeSet'
 
-        stability
         :stability: experimental
         """
         result = self._values.get("create_change_set_action_name")
@@ -359,12 +341,10 @@ class PipelineDeployStackActionProps:
 
     @builtins.property
     def create_change_set_run_order(self) -> typing.Optional[jsii.Number]:
-        """The runOrder for the CodePipeline action creating the ChangeSet.
+        """(experimental) The runOrder for the CodePipeline action creating the ChangeSet.
 
-        default
         :default: 1
 
-        stability
         :stability: experimental
         """
         result = self._values.get("create_change_set_run_order")
@@ -372,12 +352,10 @@ class PipelineDeployStackActionProps:
 
     @builtins.property
     def execute_change_set_action_name(self) -> typing.Optional[builtins.str]:
-        """The name of the CodePipeline action creating the ChangeSet.
+        """(experimental) The name of the CodePipeline action creating the ChangeSet.
 
-        default
         :default: 'Execute'
 
-        stability
         :stability: experimental
         """
         result = self._values.get("execute_change_set_action_name")
@@ -385,12 +363,10 @@ class PipelineDeployStackActionProps:
 
     @builtins.property
     def execute_change_set_run_order(self) -> typing.Optional[jsii.Number]:
-        """The runOrder for the CodePipeline action executing the ChangeSet.
+        """(experimental) The runOrder for the CodePipeline action executing the ChangeSet.
 
-        default
         :default: ``createChangeSetRunOrder + 1``
 
-        stability
         :stability: experimental
         """
         result = self._values.get("execute_change_set_run_order")
@@ -398,16 +374,14 @@ class PipelineDeployStackActionProps:
 
     @builtins.property
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
-        """IAM role to assume when deploying changes.
+        """(experimental) IAM role to assume when deploying changes.
 
         If not specified, a fresh role is created. The role is created with zero
         permissions unless ``adminPermissions`` is true, in which case the role will have
         admin permissions.
 
-        default
         :default: A fresh role with admin or no permissions (depending on the value of ``adminPermissions``).
 
-        stability
         :stability: experimental
         """
         result = self._values.get("role")
