@@ -25,15 +25,13 @@ class CopyOptions:
         exclude: typing.Optional[typing.List[builtins.str]] = None,
         follow: typing.Optional["FollowMode"] = None,
     ) -> None:
-        """Obtains applied when copying directories into the staging location.
+        """(deprecated) Obtains applied when copying directories into the staging location.
 
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
 
-        deprecated
         :deprecated: see ``core.CopyOptions``
 
-        stability
         :stability: deprecated
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -44,12 +42,10 @@ class CopyOptions:
 
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
-        """Glob patterns to exclude from the copy.
+        """(deprecated) Glob patterns to exclude from the copy.
 
-        default
         :default: nothing is excluded
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("exclude")
@@ -57,12 +53,10 @@ class CopyOptions:
 
     @builtins.property
     def follow(self) -> typing.Optional["FollowMode"]:
-        """A strategy for how to handle symlinks.
+        """(deprecated) A strategy for how to handle symlinks.
 
-        default
         :default: Never
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("follow")
@@ -93,16 +87,14 @@ class FingerprintOptions(CopyOptions):
         follow: typing.Optional["FollowMode"] = None,
         extra_hash: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Options related to calculating source hash.
+        """(deprecated) Options related to calculating source hash.
 
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
-        :param extra_hash: Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
+        :param extra_hash: (deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
 
-        deprecated
         :deprecated: see ``core.FingerprintOptions``
 
-        stability
         :stability: deprecated
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -115,12 +107,10 @@ class FingerprintOptions(CopyOptions):
 
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
-        """Glob patterns to exclude from the copy.
+        """(deprecated) Glob patterns to exclude from the copy.
 
-        default
         :default: nothing is excluded
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("exclude")
@@ -128,12 +118,10 @@ class FingerprintOptions(CopyOptions):
 
     @builtins.property
     def follow(self) -> typing.Optional["FollowMode"]:
-        """A strategy for how to handle symlinks.
+        """(deprecated) A strategy for how to handle symlinks.
 
-        default
         :default: Never
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("follow")
@@ -141,12 +129,10 @@ class FingerprintOptions(CopyOptions):
 
     @builtins.property
     def extra_hash(self) -> typing.Optional[builtins.str]:
-        """Extra information to encode into the fingerprint (e.g. build instructions and other inputs).
+        """(deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs).
 
-        default
         :default: - hash is only based on source content
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("extra_hash")
@@ -166,35 +152,30 @@ class FingerprintOptions(CopyOptions):
 
 @jsii.enum(jsii_type="monocdk-experiment.assets.FollowMode")
 class FollowMode(enum.Enum):
-    """Symlink follow mode.
+    """(deprecated) Symlink follow mode.
 
-    deprecated
     :deprecated: see ``core.SymlinkFollowMode``
 
-    stability
     :stability: deprecated
     """
 
     NEVER = "NEVER"
-    """Never follow symlinks.
+    """(deprecated) Never follow symlinks.
 
-    stability
     :stability: deprecated
     """
     ALWAYS = "ALWAYS"
-    """Materialize all symlinks, whether they are internal or external to the source directory.
+    """(deprecated) Materialize all symlinks, whether they are internal or external to the source directory.
 
-    stability
     :stability: deprecated
     """
     EXTERNAL = "EXTERNAL"
-    """Only follows symlinks that are external to the source directory.
+    """(deprecated) Only follows symlinks that are external to the source directory.
 
-    stability
     :stability: deprecated
     """
     BLOCK_EXTERNAL = "BLOCK_EXTERNAL"
-    """Forbids source from having any symlinks pointing outside of the source tree.
+    """(deprecated) Forbids source from having any symlinks pointing outside of the source tree.
 
     This is the safest mode of operation as it ensures that copy operations
     won't materialize files from the user's file system. Internal symlinks are
@@ -202,19 +183,16 @@ class FollowMode(enum.Enum):
 
     If the copy operation runs into an external symlink, it will fail.
 
-    stability
     :stability: deprecated
     """
 
 
 @jsii.interface(jsii_type="monocdk-experiment.assets.IAsset")
 class IAsset(typing_extensions.Protocol):
-    """Common interface for all assets.
+    """(deprecated) Common interface for all assets.
 
-    deprecated
     :deprecated: use ``core.IAsset``
 
-    stability
     :stability: deprecated
     """
 
@@ -225,25 +203,22 @@ class IAsset(typing_extensions.Protocol):
     @builtins.property # type: ignore
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
-        """A hash of the source of this asset, which is available at construction time.
+        """(deprecated) A hash of the source of this asset, which is available at construction time.
 
         As this is a plain
         string, it can be used in construct IDs in order to enforce creation of a new resource when
         the content hash has changed.
 
-        stability
         :stability: deprecated
         """
         ...
 
 
 class _IAssetProxy:
-    """Common interface for all assets.
+    """(deprecated) Common interface for all assets.
 
-    deprecated
     :deprecated: use ``core.IAsset``
 
-    stability
     :stability: deprecated
     """
 
@@ -252,13 +227,12 @@ class _IAssetProxy:
     @builtins.property # type: ignore
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
-        """A hash of the source of this asset, which is available at construction time.
+        """(deprecated) A hash of the source of this asset, which is available at construction time.
 
         As this is a plain
         string, it can be used in construct IDs in order to enforce creation of a new resource when
         the content hash has changed.
 
-        stability
         :stability: deprecated
         """
         return jsii.get(self, "sourceHash")
@@ -269,12 +243,10 @@ class Staging(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.assets.Staging",
 ):
-    """Deprecated.
+    """(deprecated) Deprecated.
 
-    deprecated
     :deprecated: use ``core.AssetStaging``
 
-    stability
     :stability: deprecated
     """
 
@@ -286,17 +258,16 @@ class Staging(
         source_path: builtins.str,
         extra_hash: typing.Optional[builtins.str] = None,
         exclude: typing.Optional[typing.List[builtins.str]] = None,
-        follow: typing.Optional["FollowMode"] = None,
+        follow: typing.Optional[FollowMode] = None,
     ) -> None:
         """
         :param scope: -
         :param id: -
-        :param source_path: Local file or directory to stage.
-        :param extra_hash: Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
+        :param source_path: (deprecated) Local file or directory to stage.
+        :param extra_hash: (deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
 
-        stability
         :stability: deprecated
         """
         props = StagingProps(
@@ -324,21 +295,19 @@ class StagingProps(FingerprintOptions):
         self,
         *,
         exclude: typing.Optional[typing.List[builtins.str]] = None,
-        follow: typing.Optional["FollowMode"] = None,
+        follow: typing.Optional[FollowMode] = None,
         extra_hash: typing.Optional[builtins.str] = None,
         source_path: builtins.str,
     ) -> None:
-        """Deprecated.
+        """(deprecated) Deprecated.
 
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
-        :param extra_hash: Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
-        :param source_path: Local file or directory to stage.
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
+        :param extra_hash: (deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
+        :param source_path: (deprecated) Local file or directory to stage.
 
-        deprecated
         :deprecated: use ``core.AssetStagingProps``
 
-        stability
         :stability: deprecated
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -353,25 +322,21 @@ class StagingProps(FingerprintOptions):
 
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
-        """Glob patterns to exclude from the copy.
+        """(deprecated) Glob patterns to exclude from the copy.
 
-        default
         :default: nothing is excluded
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("exclude")
         return result
 
     @builtins.property
-    def follow(self) -> typing.Optional["FollowMode"]:
-        """A strategy for how to handle symlinks.
+    def follow(self) -> typing.Optional[FollowMode]:
+        """(deprecated) A strategy for how to handle symlinks.
 
-        default
         :default: Never
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("follow")
@@ -379,12 +344,10 @@ class StagingProps(FingerprintOptions):
 
     @builtins.property
     def extra_hash(self) -> typing.Optional[builtins.str]:
-        """Extra information to encode into the fingerprint (e.g. build instructions and other inputs).
+        """(deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs).
 
-        default
         :default: - hash is only based on source content
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("extra_hash")
@@ -392,9 +355,8 @@ class StagingProps(FingerprintOptions):
 
     @builtins.property
     def source_path(self) -> builtins.str:
-        """Local file or directory to stage.
+        """(deprecated) Local file or directory to stage.
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("source_path")
