@@ -29,10 +29,8 @@ class CfnCertificate(
 ):
     """A CloudFormation ``AWS::ACMPCA::Certificate``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::ACMPCA::Certificate
+    :cloudformationResource: AWS::ACMPCA::Certificate
     """
 
     def __init__(
@@ -43,7 +41,7 @@ class CfnCertificate(
         certificate_authority_arn: builtins.str,
         certificate_signing_request: builtins.str,
         signing_algorithm: builtins.str,
-        validity: typing.Union["ValidityProperty", _IResolvable_9ceae33e],
+        validity: typing.Union["CfnCertificate.ValidityProperty", _IResolvable_9ceae33e],
         template_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::ACMPCA::Certificate``.
@@ -68,11 +66,10 @@ class CfnCertificate(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -97,8 +94,7 @@ class CfnCertificate(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -106,8 +102,7 @@ class CfnCertificate(
     @jsii.member(jsii_name="attrCertificate")
     def attr_certificate(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Certificate
+        :cloudformationAttribute: Certificate
         """
         return jsii.get(self, "attrCertificate")
 
@@ -121,7 +116,6 @@ class CfnCertificate(
     def certificate_authority_arn(self) -> builtins.str:
         """``AWS::ACMPCA::Certificate.CertificateAuthorityArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-certificateauthorityarn
         """
         return jsii.get(self, "certificateAuthorityArn")
@@ -135,7 +129,6 @@ class CfnCertificate(
     def certificate_signing_request(self) -> builtins.str:
         """``AWS::ACMPCA::Certificate.CertificateSigningRequest``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-certificatesigningrequest
         """
         return jsii.get(self, "certificateSigningRequest")
@@ -149,7 +142,6 @@ class CfnCertificate(
     def signing_algorithm(self) -> builtins.str:
         """``AWS::ACMPCA::Certificate.SigningAlgorithm``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-signingalgorithm
         """
         return jsii.get(self, "signingAlgorithm")
@@ -160,10 +152,11 @@ class CfnCertificate(
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="validity")
-    def validity(self) -> typing.Union["ValidityProperty", _IResolvable_9ceae33e]:
+    def validity(
+        self,
+    ) -> typing.Union["CfnCertificate.ValidityProperty", _IResolvable_9ceae33e]:
         """``AWS::ACMPCA::Certificate.Validity``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-validity
         """
         return jsii.get(self, "validity")
@@ -171,7 +164,7 @@ class CfnCertificate(
     @validity.setter # type: ignore
     def validity(
         self,
-        value: typing.Union["ValidityProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnCertificate.ValidityProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "validity", value)
 
@@ -180,7 +173,6 @@ class CfnCertificate(
     def template_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::ACMPCA::Certificate.TemplateArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-templatearn
         """
         return jsii.get(self, "templateArn")
@@ -200,7 +192,6 @@ class CfnCertificate(
             :param type: ``CfnCertificate.ValidityProperty.Type``.
             :param value: ``CfnCertificate.ValidityProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificate-validity.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -212,7 +203,6 @@ class CfnCertificate(
         def type(self) -> builtins.str:
             """``CfnCertificate.ValidityProperty.Type``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificate-validity.html#cfn-acmpca-certificate-validity-type
             """
             result = self._values.get("type")
@@ -223,7 +213,6 @@ class CfnCertificate(
         def value(self) -> jsii.Number:
             """``CfnCertificate.ValidityProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificate-validity.html#cfn-acmpca-certificate-validity-value
             """
             result = self._values.get("value")
@@ -250,10 +239,8 @@ class CfnCertificateAuthority(
 ):
     """A CloudFormation ``AWS::ACMPCA::CertificateAuthority``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::ACMPCA::CertificateAuthority
+    :cloudformationResource: AWS::ACMPCA::CertificateAuthority
     """
 
     def __init__(
@@ -263,9 +250,9 @@ class CfnCertificateAuthority(
         *,
         key_algorithm: builtins.str,
         signing_algorithm: builtins.str,
-        subject: typing.Union["SubjectProperty", _IResolvable_9ceae33e],
+        subject: typing.Union["CfnCertificateAuthority.SubjectProperty", _IResolvable_9ceae33e],
         type: builtins.str,
-        revocation_configuration: typing.Optional[typing.Union["RevocationConfigurationProperty", _IResolvable_9ceae33e]] = None,
+        revocation_configuration: typing.Optional[typing.Union["CfnCertificateAuthority.RevocationConfigurationProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::ACMPCA::CertificateAuthority``.
@@ -292,11 +279,10 @@ class CfnCertificateAuthority(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -321,8 +307,7 @@ class CfnCertificateAuthority(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -330,8 +315,7 @@ class CfnCertificateAuthority(
     @jsii.member(jsii_name="attrCertificateSigningRequest")
     def attr_certificate_signing_request(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: CertificateSigningRequest
+        :cloudformationAttribute: CertificateSigningRequest
         """
         return jsii.get(self, "attrCertificateSigningRequest")
 
@@ -345,7 +329,6 @@ class CfnCertificateAuthority(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::ACMPCA::CertificateAuthority.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-tags
         """
         return jsii.get(self, "tags")
@@ -355,7 +338,6 @@ class CfnCertificateAuthority(
     def key_algorithm(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthority.KeyAlgorithm``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-keyalgorithm
         """
         return jsii.get(self, "keyAlgorithm")
@@ -369,7 +351,6 @@ class CfnCertificateAuthority(
     def signing_algorithm(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthority.SigningAlgorithm``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-signingalgorithm
         """
         return jsii.get(self, "signingAlgorithm")
@@ -380,10 +361,11 @@ class CfnCertificateAuthority(
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="subject")
-    def subject(self) -> typing.Union["SubjectProperty", _IResolvable_9ceae33e]:
+    def subject(
+        self,
+    ) -> typing.Union["CfnCertificateAuthority.SubjectProperty", _IResolvable_9ceae33e]:
         """``AWS::ACMPCA::CertificateAuthority.Subject``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-subject
         """
         return jsii.get(self, "subject")
@@ -391,7 +373,7 @@ class CfnCertificateAuthority(
     @subject.setter # type: ignore
     def subject(
         self,
-        value: typing.Union["SubjectProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnCertificateAuthority.SubjectProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "subject", value)
 
@@ -400,7 +382,6 @@ class CfnCertificateAuthority(
     def type(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthority.Type``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-type
         """
         return jsii.get(self, "type")
@@ -413,10 +394,9 @@ class CfnCertificateAuthority(
     @jsii.member(jsii_name="revocationConfiguration")
     def revocation_configuration(
         self,
-    ) -> typing.Optional[typing.Union["RevocationConfigurationProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnCertificateAuthority.RevocationConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::ACMPCA::CertificateAuthority.RevocationConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-revocationconfiguration
         """
         return jsii.get(self, "revocationConfiguration")
@@ -424,7 +404,7 @@ class CfnCertificateAuthority(
     @revocation_configuration.setter # type: ignore
     def revocation_configuration(
         self,
-        value: typing.Optional[typing.Union["RevocationConfigurationProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnCertificateAuthority.RevocationConfigurationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "revocationConfiguration", value)
 
@@ -453,7 +433,6 @@ class CfnCertificateAuthority(
             :param expiration_in_days: ``CfnCertificateAuthority.CrlConfigurationProperty.ExpirationInDays``.
             :param s3_bucket_name: ``CfnCertificateAuthority.CrlConfigurationProperty.S3BucketName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-crlconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -470,7 +449,6 @@ class CfnCertificateAuthority(
         def custom_cname(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.CrlConfigurationProperty.CustomCname``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-crlconfiguration.html#cfn-acmpca-certificateauthority-crlconfiguration-customcname
             """
             result = self._values.get("custom_cname")
@@ -482,7 +460,6 @@ class CfnCertificateAuthority(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnCertificateAuthority.CrlConfigurationProperty.Enabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-crlconfiguration.html#cfn-acmpca-certificateauthority-crlconfiguration-enabled
             """
             result = self._values.get("enabled")
@@ -492,7 +469,6 @@ class CfnCertificateAuthority(
         def expiration_in_days(self) -> typing.Optional[jsii.Number]:
             """``CfnCertificateAuthority.CrlConfigurationProperty.ExpirationInDays``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-crlconfiguration.html#cfn-acmpca-certificateauthority-crlconfiguration-expirationindays
             """
             result = self._values.get("expiration_in_days")
@@ -502,7 +478,6 @@ class CfnCertificateAuthority(
         def s3_bucket_name(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.CrlConfigurationProperty.S3BucketName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-crlconfiguration.html#cfn-acmpca-certificateauthority-crlconfiguration-s3bucketname
             """
             result = self._values.get("s3_bucket_name")
@@ -533,7 +508,6 @@ class CfnCertificateAuthority(
             """
             :param crl_configuration: ``CfnCertificateAuthority.RevocationConfigurationProperty.CrlConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-revocationconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -546,7 +520,6 @@ class CfnCertificateAuthority(
         ) -> typing.Optional[typing.Union["CfnCertificateAuthority.CrlConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnCertificateAuthority.RevocationConfigurationProperty.CrlConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-revocationconfiguration.html#cfn-acmpca-certificateauthority-revocationconfiguration-crlconfiguration
             """
             result = self._values.get("crl_configuration")
@@ -618,7 +591,6 @@ class CfnCertificateAuthority(
             :param surname: ``CfnCertificateAuthority.SubjectProperty.Surname``.
             :param title: ``CfnCertificateAuthority.SubjectProperty.Title``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -655,7 +627,6 @@ class CfnCertificateAuthority(
         def common_name(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.CommonName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-commonname
             """
             result = self._values.get("common_name")
@@ -665,7 +636,6 @@ class CfnCertificateAuthority(
         def country(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.Country``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-country
             """
             result = self._values.get("country")
@@ -675,7 +645,6 @@ class CfnCertificateAuthority(
         def distinguished_name_qualifier(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.DistinguishedNameQualifier``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-distinguishednamequalifier
             """
             result = self._values.get("distinguished_name_qualifier")
@@ -685,7 +654,6 @@ class CfnCertificateAuthority(
         def generation_qualifier(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.GenerationQualifier``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-generationqualifier
             """
             result = self._values.get("generation_qualifier")
@@ -695,7 +663,6 @@ class CfnCertificateAuthority(
         def given_name(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.GivenName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-givenname
             """
             result = self._values.get("given_name")
@@ -705,7 +672,6 @@ class CfnCertificateAuthority(
         def initials(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.Initials``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-initials
             """
             result = self._values.get("initials")
@@ -715,7 +681,6 @@ class CfnCertificateAuthority(
         def locality(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.Locality``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-locality
             """
             result = self._values.get("locality")
@@ -725,7 +690,6 @@ class CfnCertificateAuthority(
         def organization(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.Organization``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-organization
             """
             result = self._values.get("organization")
@@ -735,7 +699,6 @@ class CfnCertificateAuthority(
         def organizational_unit(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.OrganizationalUnit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-organizationalunit
             """
             result = self._values.get("organizational_unit")
@@ -745,7 +708,6 @@ class CfnCertificateAuthority(
         def pseudonym(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.Pseudonym``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-pseudonym
             """
             result = self._values.get("pseudonym")
@@ -755,7 +717,6 @@ class CfnCertificateAuthority(
         def serial_number(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.SerialNumber``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-serialnumber
             """
             result = self._values.get("serial_number")
@@ -765,7 +726,6 @@ class CfnCertificateAuthority(
         def state(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.State``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-state
             """
             result = self._values.get("state")
@@ -775,7 +735,6 @@ class CfnCertificateAuthority(
         def surname(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.Surname``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-surname
             """
             result = self._values.get("surname")
@@ -785,7 +744,6 @@ class CfnCertificateAuthority(
         def title(self) -> typing.Optional[builtins.str]:
             """``CfnCertificateAuthority.SubjectProperty.Title``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-acmpca-certificateauthority-subject.html#cfn-acmpca-certificateauthority-subject-title
             """
             result = self._values.get("title")
@@ -811,10 +769,8 @@ class CfnCertificateAuthorityActivation(
 ):
     """A CloudFormation ``AWS::ACMPCA::CertificateAuthorityActivation``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::ACMPCA::CertificateAuthorityActivation
+    :cloudformationResource: AWS::ACMPCA::CertificateAuthorityActivation
     """
 
     def __init__(
@@ -847,11 +803,10 @@ class CfnCertificateAuthorityActivation(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -876,8 +831,7 @@ class CfnCertificateAuthorityActivation(
     @jsii.member(jsii_name="attrCompleteCertificateChain")
     def attr_complete_certificate_chain(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: CompleteCertificateChain
+        :cloudformationAttribute: CompleteCertificateChain
         """
         return jsii.get(self, "attrCompleteCertificateChain")
 
@@ -891,7 +845,6 @@ class CfnCertificateAuthorityActivation(
     def certificate(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthorityActivation.Certificate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html#cfn-acmpca-certificateauthorityactivation-certificate
         """
         return jsii.get(self, "certificate")
@@ -905,7 +858,6 @@ class CfnCertificateAuthorityActivation(
     def certificate_authority_arn(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthorityActivation.CertificateAuthorityArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html#cfn-acmpca-certificateauthorityactivation-certificateauthorityarn
         """
         return jsii.get(self, "certificateAuthorityArn")
@@ -919,7 +871,6 @@ class CfnCertificateAuthorityActivation(
     def certificate_chain(self) -> typing.Optional[builtins.str]:
         """``AWS::ACMPCA::CertificateAuthorityActivation.CertificateChain``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html#cfn-acmpca-certificateauthorityactivation-certificatechain
         """
         return jsii.get(self, "certificateChain")
@@ -933,7 +884,6 @@ class CfnCertificateAuthorityActivation(
     def status(self) -> typing.Optional[builtins.str]:
         """``AWS::ACMPCA::CertificateAuthorityActivation.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html#cfn-acmpca-certificateauthorityactivation-status
         """
         return jsii.get(self, "status")
@@ -969,7 +919,6 @@ class CfnCertificateAuthorityActivationProps:
         :param certificate_chain: ``AWS::ACMPCA::CertificateAuthorityActivation.CertificateChain``.
         :param status: ``AWS::ACMPCA::CertificateAuthorityActivation.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -985,7 +934,6 @@ class CfnCertificateAuthorityActivationProps:
     def certificate(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthorityActivation.Certificate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html#cfn-acmpca-certificateauthorityactivation-certificate
         """
         result = self._values.get("certificate")
@@ -996,7 +944,6 @@ class CfnCertificateAuthorityActivationProps:
     def certificate_authority_arn(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthorityActivation.CertificateAuthorityArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html#cfn-acmpca-certificateauthorityactivation-certificateauthorityarn
         """
         result = self._values.get("certificate_authority_arn")
@@ -1007,7 +954,6 @@ class CfnCertificateAuthorityActivationProps:
     def certificate_chain(self) -> typing.Optional[builtins.str]:
         """``AWS::ACMPCA::CertificateAuthorityActivation.CertificateChain``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html#cfn-acmpca-certificateauthorityactivation-certificatechain
         """
         result = self._values.get("certificate_chain")
@@ -1017,7 +963,6 @@ class CfnCertificateAuthorityActivationProps:
     def status(self) -> typing.Optional[builtins.str]:
         """``AWS::ACMPCA::CertificateAuthorityActivation.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthorityactivation.html#cfn-acmpca-certificateauthorityactivation-status
         """
         result = self._values.get("status")
@@ -1053,9 +998,9 @@ class CfnCertificateAuthorityProps:
         *,
         key_algorithm: builtins.str,
         signing_algorithm: builtins.str,
-        subject: typing.Union["CfnCertificateAuthority.SubjectProperty", _IResolvable_9ceae33e],
+        subject: typing.Union[CfnCertificateAuthority.SubjectProperty, _IResolvable_9ceae33e],
         type: builtins.str,
-        revocation_configuration: typing.Optional[typing.Union["CfnCertificateAuthority.RevocationConfigurationProperty", _IResolvable_9ceae33e]] = None,
+        revocation_configuration: typing.Optional[typing.Union[CfnCertificateAuthority.RevocationConfigurationProperty, _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::ACMPCA::CertificateAuthority``.
@@ -1067,7 +1012,6 @@ class CfnCertificateAuthorityProps:
         :param revocation_configuration: ``AWS::ACMPCA::CertificateAuthority.RevocationConfiguration``.
         :param tags: ``AWS::ACMPCA::CertificateAuthority.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1085,7 +1029,6 @@ class CfnCertificateAuthorityProps:
     def key_algorithm(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthority.KeyAlgorithm``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-keyalgorithm
         """
         result = self._values.get("key_algorithm")
@@ -1096,7 +1039,6 @@ class CfnCertificateAuthorityProps:
     def signing_algorithm(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthority.SigningAlgorithm``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-signingalgorithm
         """
         result = self._values.get("signing_algorithm")
@@ -1106,10 +1048,9 @@ class CfnCertificateAuthorityProps:
     @builtins.property
     def subject(
         self,
-    ) -> typing.Union["CfnCertificateAuthority.SubjectProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnCertificateAuthority.SubjectProperty, _IResolvable_9ceae33e]:
         """``AWS::ACMPCA::CertificateAuthority.Subject``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-subject
         """
         result = self._values.get("subject")
@@ -1120,7 +1061,6 @@ class CfnCertificateAuthorityProps:
     def type(self) -> builtins.str:
         """``AWS::ACMPCA::CertificateAuthority.Type``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-type
         """
         result = self._values.get("type")
@@ -1130,10 +1070,9 @@ class CfnCertificateAuthorityProps:
     @builtins.property
     def revocation_configuration(
         self,
-    ) -> typing.Optional[typing.Union["CfnCertificateAuthority.RevocationConfigurationProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnCertificateAuthority.RevocationConfigurationProperty, _IResolvable_9ceae33e]]:
         """``AWS::ACMPCA::CertificateAuthority.RevocationConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-revocationconfiguration
         """
         result = self._values.get("revocation_configuration")
@@ -1143,7 +1082,6 @@ class CfnCertificateAuthorityProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::ACMPCA::CertificateAuthority.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificateauthority.html#cfn-acmpca-certificateauthority-tags
         """
         result = self._values.get("tags")
@@ -1179,7 +1117,7 @@ class CfnCertificateProps:
         certificate_authority_arn: builtins.str,
         certificate_signing_request: builtins.str,
         signing_algorithm: builtins.str,
-        validity: typing.Union["CfnCertificate.ValidityProperty", _IResolvable_9ceae33e],
+        validity: typing.Union[CfnCertificate.ValidityProperty, _IResolvable_9ceae33e],
         template_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::ACMPCA::Certificate``.
@@ -1190,7 +1128,6 @@ class CfnCertificateProps:
         :param validity: ``AWS::ACMPCA::Certificate.Validity``.
         :param template_arn: ``AWS::ACMPCA::Certificate.TemplateArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1206,7 +1143,6 @@ class CfnCertificateProps:
     def certificate_authority_arn(self) -> builtins.str:
         """``AWS::ACMPCA::Certificate.CertificateAuthorityArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-certificateauthorityarn
         """
         result = self._values.get("certificate_authority_arn")
@@ -1217,7 +1153,6 @@ class CfnCertificateProps:
     def certificate_signing_request(self) -> builtins.str:
         """``AWS::ACMPCA::Certificate.CertificateSigningRequest``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-certificatesigningrequest
         """
         result = self._values.get("certificate_signing_request")
@@ -1228,7 +1163,6 @@ class CfnCertificateProps:
     def signing_algorithm(self) -> builtins.str:
         """``AWS::ACMPCA::Certificate.SigningAlgorithm``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-signingalgorithm
         """
         result = self._values.get("signing_algorithm")
@@ -1238,10 +1172,9 @@ class CfnCertificateProps:
     @builtins.property
     def validity(
         self,
-    ) -> typing.Union["CfnCertificate.ValidityProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnCertificate.ValidityProperty, _IResolvable_9ceae33e]:
         """``AWS::ACMPCA::Certificate.Validity``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-validity
         """
         result = self._values.get("validity")
@@ -1252,7 +1185,6 @@ class CfnCertificateProps:
     def template_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::ACMPCA::Certificate.TemplateArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-acmpca-certificate.html#cfn-acmpca-certificate-templatearn
         """
         result = self._values.get("template_arn")
