@@ -29,10 +29,8 @@ class CfnDataCatalog(
 ):
     """A CloudFormation ``AWS::Athena::DataCatalog``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Athena::DataCatalog
+    :cloudformationResource: AWS::Athena::DataCatalog
     """
 
     def __init__(
@@ -44,7 +42,7 @@ class CfnDataCatalog(
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, builtins.str]]] = None,
-        tags: typing.Optional["TagsProperty"] = None,
+        tags: typing.Optional["CfnDataCatalog.TagsProperty"] = None,
     ) -> None:
         """Create a new ``AWS::Athena::DataCatalog``.
 
@@ -68,11 +66,10 @@ class CfnDataCatalog(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -103,7 +100,6 @@ class CfnDataCatalog(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::Athena::DataCatalog.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-tags
         """
         return jsii.get(self, "tags")
@@ -113,7 +109,6 @@ class CfnDataCatalog(
     def name(self) -> builtins.str:
         """``AWS::Athena::DataCatalog.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-name
         """
         return jsii.get(self, "name")
@@ -127,7 +122,6 @@ class CfnDataCatalog(
     def type(self) -> builtins.str:
         """``AWS::Athena::DataCatalog.Type``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-type
         """
         return jsii.get(self, "type")
@@ -141,7 +135,6 @@ class CfnDataCatalog(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::DataCatalog.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-description
         """
         return jsii.get(self, "description")
@@ -157,7 +150,6 @@ class CfnDataCatalog(
     ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, builtins.str]]]:
         """``AWS::Athena::DataCatalog.Parameters``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-parameters
         """
         return jsii.get(self, "parameters")
@@ -183,7 +175,6 @@ class CfnDataCatalog(
             """
             :param tags: ``CfnDataCatalog.TagsProperty.Tags``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-datacatalog-tags.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -194,7 +185,6 @@ class CfnDataCatalog(
         def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
             """``CfnDataCatalog.TagsProperty.Tags``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-datacatalog-tags.html#cfn-athena-datacatalog-tags-tags
             """
             result = self._values.get("tags")
@@ -231,7 +221,7 @@ class CfnDataCatalogProps:
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, builtins.str]]] = None,
-        tags: typing.Optional["CfnDataCatalog.TagsProperty"] = None,
+        tags: typing.Optional[CfnDataCatalog.TagsProperty] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::DataCatalog``.
 
@@ -241,7 +231,6 @@ class CfnDataCatalogProps:
         :param parameters: ``AWS::Athena::DataCatalog.Parameters``.
         :param tags: ``AWS::Athena::DataCatalog.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html
         """
         if isinstance(tags, dict):
@@ -261,7 +250,6 @@ class CfnDataCatalogProps:
     def name(self) -> builtins.str:
         """``AWS::Athena::DataCatalog.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-name
         """
         result = self._values.get("name")
@@ -272,7 +260,6 @@ class CfnDataCatalogProps:
     def type(self) -> builtins.str:
         """``AWS::Athena::DataCatalog.Type``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-type
         """
         result = self._values.get("type")
@@ -283,7 +270,6 @@ class CfnDataCatalogProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::DataCatalog.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-description
         """
         result = self._values.get("description")
@@ -295,17 +281,15 @@ class CfnDataCatalogProps:
     ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, builtins.str]]]:
         """``AWS::Athena::DataCatalog.Parameters``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-parameters
         """
         result = self._values.get("parameters")
         return result
 
     @builtins.property
-    def tags(self) -> typing.Optional["CfnDataCatalog.TagsProperty"]:
+    def tags(self) -> typing.Optional[CfnDataCatalog.TagsProperty]:
         """``AWS::Athena::DataCatalog.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-tags
         """
         result = self._values.get("tags")
@@ -331,10 +315,8 @@ class CfnNamedQuery(
 ):
     """A CloudFormation ``AWS::Athena::NamedQuery``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Athena::NamedQuery
+    :cloudformationResource: AWS::Athena::NamedQuery
     """
 
     def __init__(
@@ -367,11 +349,10 @@ class CfnNamedQuery(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -396,8 +377,7 @@ class CfnNamedQuery(
     @jsii.member(jsii_name="attrNamedQueryId")
     def attr_named_query_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: NamedQueryId
+        :cloudformationAttribute: NamedQueryId
         """
         return jsii.get(self, "attrNamedQueryId")
 
@@ -411,7 +391,6 @@ class CfnNamedQuery(
     def database(self) -> builtins.str:
         """``AWS::Athena::NamedQuery.Database``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-database
         """
         return jsii.get(self, "database")
@@ -425,7 +404,6 @@ class CfnNamedQuery(
     def query_string(self) -> builtins.str:
         """``AWS::Athena::NamedQuery.QueryString``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-querystring
         """
         return jsii.get(self, "queryString")
@@ -439,7 +417,6 @@ class CfnNamedQuery(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::NamedQuery.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-description
         """
         return jsii.get(self, "description")
@@ -453,7 +430,6 @@ class CfnNamedQuery(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::NamedQuery.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-name
         """
         return jsii.get(self, "name")
@@ -489,7 +465,6 @@ class CfnNamedQueryProps:
         :param description: ``AWS::Athena::NamedQuery.Description``.
         :param name: ``AWS::Athena::NamedQuery.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -505,7 +480,6 @@ class CfnNamedQueryProps:
     def database(self) -> builtins.str:
         """``AWS::Athena::NamedQuery.Database``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-database
         """
         result = self._values.get("database")
@@ -516,7 +490,6 @@ class CfnNamedQueryProps:
     def query_string(self) -> builtins.str:
         """``AWS::Athena::NamedQuery.QueryString``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-querystring
         """
         result = self._values.get("query_string")
@@ -527,7 +500,6 @@ class CfnNamedQueryProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::NamedQuery.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-description
         """
         result = self._values.get("description")
@@ -537,7 +509,6 @@ class CfnNamedQueryProps:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::NamedQuery.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-name
         """
         result = self._values.get("name")
@@ -563,10 +534,8 @@ class CfnWorkGroup(
 ):
     """A CloudFormation ``AWS::Athena::WorkGroup``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Athena::WorkGroup
+    :cloudformationResource: AWS::Athena::WorkGroup
     """
 
     def __init__(
@@ -579,8 +548,8 @@ class CfnWorkGroup(
         recursive_delete_option: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         state: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
-        work_group_configuration: typing.Optional[typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]] = None,
-        work_group_configuration_updates: typing.Optional[typing.Union["WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]] = None,
+        work_group_configuration: typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e]] = None,
+        work_group_configuration_updates: typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::Athena::WorkGroup``.
 
@@ -608,11 +577,10 @@ class CfnWorkGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -637,8 +605,7 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="attrCreationTime")
     def attr_creation_time(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: CreationTime
+        :cloudformationAttribute: CreationTime
         """
         return jsii.get(self, "attrCreationTime")
 
@@ -652,7 +619,6 @@ class CfnWorkGroup(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::Athena::WorkGroup.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-tags
         """
         return jsii.get(self, "tags")
@@ -662,7 +628,6 @@ class CfnWorkGroup(
     def name(self) -> builtins.str:
         """``AWS::Athena::WorkGroup.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-name
         """
         return jsii.get(self, "name")
@@ -676,7 +641,6 @@ class CfnWorkGroup(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::WorkGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-description
         """
         return jsii.get(self, "description")
@@ -692,7 +656,6 @@ class CfnWorkGroup(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.RecursiveDeleteOption``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-recursivedeleteoption
         """
         return jsii.get(self, "recursiveDeleteOption")
@@ -709,7 +672,6 @@ class CfnWorkGroup(
     def state(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::WorkGroup.State``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-state
         """
         return jsii.get(self, "state")
@@ -722,10 +684,9 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="workGroupConfiguration")
     def work_group_configuration(
         self,
-    ) -> typing.Optional[typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-workgroupconfiguration
         """
         return jsii.get(self, "workGroupConfiguration")
@@ -733,7 +694,7 @@ class CfnWorkGroup(
     @work_group_configuration.setter # type: ignore
     def work_group_configuration(
         self,
-        value: typing.Optional[typing.Union["WorkGroupConfigurationProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "workGroupConfiguration", value)
 
@@ -741,10 +702,9 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="workGroupConfigurationUpdates")
     def work_group_configuration_updates(
         self,
-    ) -> typing.Optional[typing.Union["WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-workgroupconfigurationupdates
         """
         return jsii.get(self, "workGroupConfigurationUpdates")
@@ -752,7 +712,7 @@ class CfnWorkGroup(
     @work_group_configuration_updates.setter # type: ignore
     def work_group_configuration_updates(
         self,
-        value: typing.Optional[typing.Union["WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "workGroupConfigurationUpdates", value)
 
@@ -772,7 +732,6 @@ class CfnWorkGroup(
             :param encryption_option: ``CfnWorkGroup.EncryptionConfigurationProperty.EncryptionOption``.
             :param kms_key: ``CfnWorkGroup.EncryptionConfigurationProperty.KmsKey``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-encryptionconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -785,7 +744,6 @@ class CfnWorkGroup(
         def encryption_option(self) -> builtins.str:
             """``CfnWorkGroup.EncryptionConfigurationProperty.EncryptionOption``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-encryptionconfiguration.html#cfn-athena-workgroup-encryptionconfiguration-encryptionoption
             """
             result = self._values.get("encryption_option")
@@ -796,7 +754,6 @@ class CfnWorkGroup(
         def kms_key(self) -> typing.Optional[builtins.str]:
             """``CfnWorkGroup.EncryptionConfigurationProperty.KmsKey``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-encryptionconfiguration.html#cfn-athena-workgroup-encryptionconfiguration-kmskey
             """
             result = self._values.get("kms_key")
@@ -832,7 +789,6 @@ class CfnWorkGroup(
             :param encryption_configuration: ``CfnWorkGroup.ResultConfigurationProperty.EncryptionConfiguration``.
             :param output_location: ``CfnWorkGroup.ResultConfigurationProperty.OutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -847,7 +803,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union["CfnWorkGroup.EncryptionConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.ResultConfigurationProperty.EncryptionConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfiguration.html#cfn-athena-workgroup-resultconfiguration-encryptionconfiguration
             """
             result = self._values.get("encryption_configuration")
@@ -857,7 +812,6 @@ class CfnWorkGroup(
         def output_location(self) -> typing.Optional[builtins.str]:
             """``CfnWorkGroup.ResultConfigurationProperty.OutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfiguration.html#cfn-athena-workgroup-resultconfiguration-outputlocation
             """
             result = self._values.get("output_location")
@@ -899,7 +853,6 @@ class CfnWorkGroup(
             :param remove_encryption_configuration: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveEncryptionConfiguration``.
             :param remove_output_location: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveOutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -918,7 +871,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union["CfnWorkGroup.EncryptionConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.EncryptionConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html#cfn-athena-workgroup-resultconfigurationupdates-encryptionconfiguration
             """
             result = self._values.get("encryption_configuration")
@@ -928,7 +880,6 @@ class CfnWorkGroup(
         def output_location(self) -> typing.Optional[builtins.str]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.OutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html#cfn-athena-workgroup-resultconfigurationupdates-outputlocation
             """
             result = self._values.get("output_location")
@@ -940,7 +891,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveEncryptionConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html#cfn-athena-workgroup-resultconfigurationupdates-removeencryptionconfiguration
             """
             result = self._values.get("remove_encryption_configuration")
@@ -952,7 +902,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveOutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html#cfn-athena-workgroup-resultconfigurationupdates-removeoutputlocation
             """
             result = self._values.get("remove_output_location")
@@ -997,7 +946,6 @@ class CfnWorkGroup(
             :param requester_pays_enabled: ``CfnWorkGroup.WorkGroupConfigurationProperty.RequesterPaysEnabled``.
             :param result_configuration: ``CfnWorkGroup.WorkGroupConfigurationProperty.ResultConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -1016,7 +964,6 @@ class CfnWorkGroup(
         def bytes_scanned_cutoff_per_query(self) -> typing.Optional[jsii.Number]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.BytesScannedCutoffPerQuery``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-bytesscannedcutoffperquery
             """
             result = self._values.get("bytes_scanned_cutoff_per_query")
@@ -1028,7 +975,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.EnforceWorkGroupConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-enforceworkgroupconfiguration
             """
             result = self._values.get("enforce_work_group_configuration")
@@ -1040,7 +986,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.PublishCloudWatchMetricsEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-publishcloudwatchmetricsenabled
             """
             result = self._values.get("publish_cloud_watch_metrics_enabled")
@@ -1052,7 +997,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.RequesterPaysEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-requesterpaysenabled
             """
             result = self._values.get("requester_pays_enabled")
@@ -1064,7 +1008,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union["CfnWorkGroup.ResultConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.ResultConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-resultconfiguration
             """
             result = self._values.get("result_configuration")
@@ -1112,7 +1055,6 @@ class CfnWorkGroup(
             :param requester_pays_enabled: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RequesterPaysEnabled``.
             :param result_configuration_updates: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.ResultConfigurationUpdates``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -1133,7 +1075,6 @@ class CfnWorkGroup(
         def bytes_scanned_cutoff_per_query(self) -> typing.Optional[jsii.Number]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.BytesScannedCutoffPerQuery``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-bytesscannedcutoffperquery
             """
             result = self._values.get("bytes_scanned_cutoff_per_query")
@@ -1145,7 +1086,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.EnforceWorkGroupConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-enforceworkgroupconfiguration
             """
             result = self._values.get("enforce_work_group_configuration")
@@ -1157,7 +1097,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.PublishCloudWatchMetricsEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-publishcloudwatchmetricsenabled
             """
             result = self._values.get("publish_cloud_watch_metrics_enabled")
@@ -1169,7 +1108,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RemoveBytesScannedCutoffPerQuery``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-removebytesscannedcutoffperquery
             """
             result = self._values.get("remove_bytes_scanned_cutoff_per_query")
@@ -1181,7 +1119,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RequesterPaysEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-requesterpaysenabled
             """
             result = self._values.get("requester_pays_enabled")
@@ -1193,7 +1130,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union["CfnWorkGroup.ResultConfigurationUpdatesProperty", _IResolvable_9ceae33e]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.ResultConfigurationUpdates``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-resultconfigurationupdates
             """
             result = self._values.get("result_configuration_updates")
@@ -1233,8 +1169,8 @@ class CfnWorkGroupProps:
         recursive_delete_option: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         state: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
-        work_group_configuration: typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e]] = None,
-        work_group_configuration_updates: typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]] = None,
+        work_group_configuration: typing.Optional[typing.Union[CfnWorkGroup.WorkGroupConfigurationProperty, _IResolvable_9ceae33e]] = None,
+        work_group_configuration_updates: typing.Optional[typing.Union[CfnWorkGroup.WorkGroupConfigurationUpdatesProperty, _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::WorkGroup``.
 
@@ -1246,7 +1182,6 @@ class CfnWorkGroupProps:
         :param work_group_configuration: ``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
         :param work_group_configuration_updates: ``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1269,7 +1204,6 @@ class CfnWorkGroupProps:
     def name(self) -> builtins.str:
         """``AWS::Athena::WorkGroup.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-name
         """
         result = self._values.get("name")
@@ -1280,7 +1214,6 @@ class CfnWorkGroupProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::WorkGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-description
         """
         result = self._values.get("description")
@@ -1292,7 +1225,6 @@ class CfnWorkGroupProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.RecursiveDeleteOption``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-recursivedeleteoption
         """
         result = self._values.get("recursive_delete_option")
@@ -1302,7 +1234,6 @@ class CfnWorkGroupProps:
     def state(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::WorkGroup.State``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-state
         """
         result = self._values.get("state")
@@ -1314,7 +1245,6 @@ class CfnWorkGroupProps:
     ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
         """``AWS::Athena::WorkGroup.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-tags
         """
         result = self._values.get("tags")
@@ -1323,10 +1253,9 @@ class CfnWorkGroupProps:
     @builtins.property
     def work_group_configuration(
         self,
-    ) -> typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnWorkGroup.WorkGroupConfigurationProperty, _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-workgroupconfiguration
         """
         result = self._values.get("work_group_configuration")
@@ -1335,10 +1264,9 @@ class CfnWorkGroupProps:
     @builtins.property
     def work_group_configuration_updates(
         self,
-    ) -> typing.Optional[typing.Union["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnWorkGroup.WorkGroupConfigurationUpdatesProperty, _IResolvable_9ceae33e]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-workgroupconfigurationupdates
         """
         result = self._values.get("work_group_configuration_updates")
