@@ -27,11 +27,10 @@ class FunctionHook(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_autoscaling_hooktargets.FunctionHook",
 ):
-    """Use a Lambda Function as a hook target.
+    """(experimental) Use a Lambda Function as a hook target.
 
     Internally creates a Topic to make the connection.
 
-    stability
     :stability: experimental
     """
 
@@ -44,7 +43,6 @@ class FunctionHook(
         :param fn: Function to invoke in response to a lifecycle event.
         :param encryption_key: If provided, this key is used to encrypt the contents of the SNS topic.
 
-        stability
         :stability: experimental
         """
         jsii.create(FunctionHook, self, [fn, encryption_key])
@@ -55,12 +53,11 @@ class FunctionHook(
         scope: _Construct_f50a3f53,
         lifecycle_hook: _ILifecycleHook_04206686,
     ) -> _LifecycleHookTargetConfig_83c58429:
-        """Called when this object is used as the target of a lifecycle hook.
+        """(experimental) Called when this object is used as the target of a lifecycle hook.
 
         :param scope: -
         :param lifecycle_hook: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [scope, lifecycle_hook])
@@ -71,9 +68,8 @@ class QueueHook(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_autoscaling_hooktargets.QueueHook",
 ):
-    """Use an SQS queue as a hook target.
+    """(experimental) Use an SQS queue as a hook target.
 
-    stability
     :stability: experimental
     """
 
@@ -81,7 +77,6 @@ class QueueHook(
         """
         :param queue: -
 
-        stability
         :stability: experimental
         """
         jsii.create(QueueHook, self, [queue])
@@ -92,12 +87,11 @@ class QueueHook(
         _scope: _Construct_f50a3f53,
         lifecycle_hook: _ILifecycleHook_04206686,
     ) -> _LifecycleHookTargetConfig_83c58429:
-        """Called when this object is used as the target of a lifecycle hook.
+        """(experimental) Called when this object is used as the target of a lifecycle hook.
 
         :param _scope: -
         :param lifecycle_hook: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_scope, lifecycle_hook])
@@ -108,9 +102,8 @@ class TopicHook(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_autoscaling_hooktargets.TopicHook",
 ):
-    """Use an SNS topic as a hook target.
+    """(experimental) Use an SNS topic as a hook target.
 
-    stability
     :stability: experimental
     """
 
@@ -118,7 +111,6 @@ class TopicHook(
         """
         :param topic: -
 
-        stability
         :stability: experimental
         """
         jsii.create(TopicHook, self, [topic])
@@ -129,12 +121,11 @@ class TopicHook(
         _scope: _Construct_f50a3f53,
         lifecycle_hook: _ILifecycleHook_04206686,
     ) -> _LifecycleHookTargetConfig_83c58429:
-        """Called when this object is used as the target of a lifecycle hook.
+        """(experimental) Called when this object is used as the target of a lifecycle hook.
 
         :param _scope: -
         :param lifecycle_hook: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_scope, lifecycle_hook])
