@@ -27,10 +27,8 @@ class CfnScalingPlan(
 ):
     """A CloudFormation ``AWS::AutoScalingPlans::ScalingPlan``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::AutoScalingPlans::ScalingPlan
+    :cloudformationResource: AWS::AutoScalingPlans::ScalingPlan
     """
 
     def __init__(
@@ -38,8 +36,8 @@ class CfnScalingPlan(
         scope: _Construct_f50a3f53,
         id: builtins.str,
         *,
-        application_source: typing.Union["ApplicationSourceProperty", _IResolvable_9ceae33e],
-        scaling_instructions: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ScalingInstructionProperty", _IResolvable_9ceae33e]]],
+        application_source: typing.Union["CfnScalingPlan.ApplicationSourceProperty", _IResolvable_9ceae33e],
+        scaling_instructions: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.ScalingInstructionProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         """Create a new ``AWS::AutoScalingPlans::ScalingPlan``.
 
@@ -57,11 +55,10 @@ class CfnScalingPlan(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -86,8 +83,7 @@ class CfnScalingPlan(
     @jsii.member(jsii_name="attrScalingPlanName")
     def attr_scaling_plan_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ScalingPlanName
+        :cloudformationAttribute: ScalingPlanName
         """
         return jsii.get(self, "attrScalingPlanName")
 
@@ -95,8 +91,7 @@ class CfnScalingPlan(
     @jsii.member(jsii_name="attrScalingPlanVersion")
     def attr_scaling_plan_version(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ScalingPlanVersion
+        :cloudformationAttribute: ScalingPlanVersion
         """
         return jsii.get(self, "attrScalingPlanVersion")
 
@@ -109,10 +104,9 @@ class CfnScalingPlan(
     @jsii.member(jsii_name="applicationSource")
     def application_source(
         self,
-    ) -> typing.Union["ApplicationSourceProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnScalingPlan.ApplicationSourceProperty", _IResolvable_9ceae33e]:
         """``AWS::AutoScalingPlans::ScalingPlan.ApplicationSource``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-applicationsource
         """
         return jsii.get(self, "applicationSource")
@@ -120,7 +114,7 @@ class CfnScalingPlan(
     @application_source.setter # type: ignore
     def application_source(
         self,
-        value: typing.Union["ApplicationSourceProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnScalingPlan.ApplicationSourceProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "applicationSource", value)
 
@@ -128,10 +122,9 @@ class CfnScalingPlan(
     @jsii.member(jsii_name="scalingInstructions")
     def scaling_instructions(
         self,
-    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ScalingInstructionProperty", _IResolvable_9ceae33e]]]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.ScalingInstructionProperty", _IResolvable_9ceae33e]]]:
         """``AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-scalinginstructions
         """
         return jsii.get(self, "scalingInstructions")
@@ -139,7 +132,7 @@ class CfnScalingPlan(
     @scaling_instructions.setter # type: ignore
     def scaling_instructions(
         self,
-        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ScalingInstructionProperty", _IResolvable_9ceae33e]]],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.ScalingInstructionProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "scalingInstructions", value)
 
@@ -162,7 +155,6 @@ class CfnScalingPlan(
             :param cloud_formation_stack_arn: ``CfnScalingPlan.ApplicationSourceProperty.CloudFormationStackARN``.
             :param tag_filters: ``CfnScalingPlan.ApplicationSourceProperty.TagFilters``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-applicationsource.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -175,7 +167,6 @@ class CfnScalingPlan(
         def cloud_formation_stack_arn(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.ApplicationSourceProperty.CloudFormationStackARN``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-applicationsource.html#cfn-autoscalingplans-scalingplan-applicationsource-cloudformationstackarn
             """
             result = self._values.get("cloud_formation_stack_arn")
@@ -187,7 +178,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.TagFilterProperty", _IResolvable_9ceae33e]]]]:
             """``CfnScalingPlan.ApplicationSourceProperty.TagFilters``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-applicationsource.html#cfn-autoscalingplans-scalingplan-applicationsource-tagfilters
             """
             result = self._values.get("tag_filters")
@@ -232,7 +222,6 @@ class CfnScalingPlan(
             :param dimensions: ``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Dimensions``.
             :param unit: ``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -249,7 +238,6 @@ class CfnScalingPlan(
         def metric_name(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.MetricName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-metricname
             """
             result = self._values.get("metric_name")
@@ -260,7 +248,6 @@ class CfnScalingPlan(
         def namespace(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Namespace``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-namespace
             """
             result = self._values.get("namespace")
@@ -271,7 +258,6 @@ class CfnScalingPlan(
         def statistic(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Statistic``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-statistic
             """
             result = self._values.get("statistic")
@@ -284,7 +270,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.MetricDimensionProperty", _IResolvable_9ceae33e]]]]:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Dimensions``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-dimensions
             """
             result = self._values.get("dimensions")
@@ -294,7 +279,6 @@ class CfnScalingPlan(
         def unit(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-unit
             """
             result = self._values.get("unit")
@@ -339,7 +323,6 @@ class CfnScalingPlan(
             :param dimensions: ``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Dimensions``.
             :param unit: ``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -356,7 +339,6 @@ class CfnScalingPlan(
         def metric_name(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.MetricName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-metricname
             """
             result = self._values.get("metric_name")
@@ -367,7 +349,6 @@ class CfnScalingPlan(
         def namespace(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Namespace``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-namespace
             """
             result = self._values.get("namespace")
@@ -378,7 +359,6 @@ class CfnScalingPlan(
         def statistic(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Statistic``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-statistic
             """
             result = self._values.get("statistic")
@@ -391,7 +371,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.MetricDimensionProperty", _IResolvable_9ceae33e]]]]:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Dimensions``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-dimensions
             """
             result = self._values.get("dimensions")
@@ -401,7 +380,6 @@ class CfnScalingPlan(
         def unit(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-unit
             """
             result = self._values.get("unit")
@@ -429,7 +407,6 @@ class CfnScalingPlan(
             :param name: ``CfnScalingPlan.MetricDimensionProperty.Name``.
             :param value: ``CfnScalingPlan.MetricDimensionProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-metricdimension.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -441,7 +418,6 @@ class CfnScalingPlan(
         def name(self) -> builtins.str:
             """``CfnScalingPlan.MetricDimensionProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-metricdimension.html#cfn-autoscalingplans-scalingplan-metricdimension-name
             """
             result = self._values.get("name")
@@ -452,7 +428,6 @@ class CfnScalingPlan(
         def value(self) -> builtins.str:
             """``CfnScalingPlan.MetricDimensionProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-metricdimension.html#cfn-autoscalingplans-scalingplan-metricdimension-value
             """
             result = self._values.get("value")
@@ -489,7 +464,6 @@ class CfnScalingPlan(
             :param predefined_load_metric_type: ``CfnScalingPlan.PredefinedLoadMetricSpecificationProperty.PredefinedLoadMetricType``.
             :param resource_label: ``CfnScalingPlan.PredefinedLoadMetricSpecificationProperty.ResourceLabel``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedloadmetricspecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -502,7 +476,6 @@ class CfnScalingPlan(
         def predefined_load_metric_type(self) -> builtins.str:
             """``CfnScalingPlan.PredefinedLoadMetricSpecificationProperty.PredefinedLoadMetricType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-predefinedloadmetricspecification-predefinedloadmetrictype
             """
             result = self._values.get("predefined_load_metric_type")
@@ -513,7 +486,6 @@ class CfnScalingPlan(
         def resource_label(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.PredefinedLoadMetricSpecificationProperty.ResourceLabel``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-predefinedloadmetricspecification-resourcelabel
             """
             result = self._values.get("resource_label")
@@ -549,7 +521,6 @@ class CfnScalingPlan(
             :param predefined_scaling_metric_type: ``CfnScalingPlan.PredefinedScalingMetricSpecificationProperty.PredefinedScalingMetricType``.
             :param resource_label: ``CfnScalingPlan.PredefinedScalingMetricSpecificationProperty.ResourceLabel``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedscalingmetricspecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -562,7 +533,6 @@ class CfnScalingPlan(
         def predefined_scaling_metric_type(self) -> builtins.str:
             """``CfnScalingPlan.PredefinedScalingMetricSpecificationProperty.PredefinedScalingMetricType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-predefinedscalingmetricspecification-predefinedscalingmetrictype
             """
             result = self._values.get("predefined_scaling_metric_type")
@@ -573,7 +543,6 @@ class CfnScalingPlan(
         def resource_label(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.PredefinedScalingMetricSpecificationProperty.ResourceLabel``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-predefinedscalingmetricspecification-resourcelabel
             """
             result = self._values.get("resource_label")
@@ -645,7 +614,6 @@ class CfnScalingPlan(
             :param scaling_policy_update_behavior: ``CfnScalingPlan.ScalingInstructionProperty.ScalingPolicyUpdateBehavior``.
             :param scheduled_action_buffer_time: ``CfnScalingPlan.ScalingInstructionProperty.ScheduledActionBufferTime``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -677,7 +645,6 @@ class CfnScalingPlan(
         def max_capacity(self) -> jsii.Number:
             """``CfnScalingPlan.ScalingInstructionProperty.MaxCapacity``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-maxcapacity
             """
             result = self._values.get("max_capacity")
@@ -688,7 +655,6 @@ class CfnScalingPlan(
         def min_capacity(self) -> jsii.Number:
             """``CfnScalingPlan.ScalingInstructionProperty.MinCapacity``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-mincapacity
             """
             result = self._values.get("min_capacity")
@@ -699,7 +665,6 @@ class CfnScalingPlan(
         def resource_id(self) -> builtins.str:
             """``CfnScalingPlan.ScalingInstructionProperty.ResourceId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-resourceid
             """
             result = self._values.get("resource_id")
@@ -710,7 +675,6 @@ class CfnScalingPlan(
         def scalable_dimension(self) -> builtins.str:
             """``CfnScalingPlan.ScalingInstructionProperty.ScalableDimension``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-scalabledimension
             """
             result = self._values.get("scalable_dimension")
@@ -721,7 +685,6 @@ class CfnScalingPlan(
         def service_namespace(self) -> builtins.str:
             """``CfnScalingPlan.ScalingInstructionProperty.ServiceNamespace``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-servicenamespace
             """
             result = self._values.get("service_namespace")
@@ -734,7 +697,6 @@ class CfnScalingPlan(
         ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.TargetTrackingConfigurationProperty", _IResolvable_9ceae33e]]]:
             """``CfnScalingPlan.ScalingInstructionProperty.TargetTrackingConfigurations``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-targettrackingconfigurations
             """
             result = self._values.get("target_tracking_configurations")
@@ -747,7 +709,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union["CfnScalingPlan.CustomizedLoadMetricSpecificationProperty", _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.ScalingInstructionProperty.CustomizedLoadMetricSpecification``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-customizedloadmetricspecification
             """
             result = self._values.get("customized_load_metric_specification")
@@ -759,7 +720,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.ScalingInstructionProperty.DisableDynamicScaling``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-disabledynamicscaling
             """
             result = self._values.get("disable_dynamic_scaling")
@@ -771,7 +731,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union["CfnScalingPlan.PredefinedLoadMetricSpecificationProperty", _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.ScalingInstructionProperty.PredefinedLoadMetricSpecification``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-predefinedloadmetricspecification
             """
             result = self._values.get("predefined_load_metric_specification")
@@ -783,7 +742,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.ScalingInstructionProperty.PredictiveScalingMaxCapacityBehavior``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-predictivescalingmaxcapacitybehavior
             """
             result = self._values.get("predictive_scaling_max_capacity_behavior")
@@ -795,7 +753,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.ScalingInstructionProperty.PredictiveScalingMaxCapacityBuffer``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-predictivescalingmaxcapacitybuffer
             """
             result = self._values.get("predictive_scaling_max_capacity_buffer")
@@ -805,7 +762,6 @@ class CfnScalingPlan(
         def predictive_scaling_mode(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.ScalingInstructionProperty.PredictiveScalingMode``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-predictivescalingmode
             """
             result = self._values.get("predictive_scaling_mode")
@@ -815,7 +771,6 @@ class CfnScalingPlan(
         def scaling_policy_update_behavior(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.ScalingInstructionProperty.ScalingPolicyUpdateBehavior``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-scalingpolicyupdatebehavior
             """
             result = self._values.get("scaling_policy_update_behavior")
@@ -825,7 +780,6 @@ class CfnScalingPlan(
         def scheduled_action_buffer_time(self) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.ScalingInstructionProperty.ScheduledActionBufferTime``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-scheduledactionbuffertime
             """
             result = self._values.get("scheduled_action_buffer_time")
@@ -858,7 +812,6 @@ class CfnScalingPlan(
             :param key: ``CfnScalingPlan.TagFilterProperty.Key``.
             :param values: ``CfnScalingPlan.TagFilterProperty.Values``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-tagfilter.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -871,7 +824,6 @@ class CfnScalingPlan(
         def key(self) -> builtins.str:
             """``CfnScalingPlan.TagFilterProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-tagfilter.html#cfn-autoscalingplans-scalingplan-tagfilter-key
             """
             result = self._values.get("key")
@@ -882,7 +834,6 @@ class CfnScalingPlan(
         def values(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnScalingPlan.TagFilterProperty.Values``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-tagfilter.html#cfn-autoscalingplans-scalingplan-tagfilter-values
             """
             result = self._values.get("values")
@@ -933,7 +884,6 @@ class CfnScalingPlan(
             :param scale_in_cooldown: ``CfnScalingPlan.TargetTrackingConfigurationProperty.ScaleInCooldown``.
             :param scale_out_cooldown: ``CfnScalingPlan.TargetTrackingConfigurationProperty.ScaleOutCooldown``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -956,7 +906,6 @@ class CfnScalingPlan(
         def target_value(self) -> jsii.Number:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.TargetValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-targetvalue
             """
             result = self._values.get("target_value")
@@ -969,7 +918,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union["CfnScalingPlan.CustomizedScalingMetricSpecificationProperty", _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.CustomizedScalingMetricSpecification``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-customizedscalingmetricspecification
             """
             result = self._values.get("customized_scaling_metric_specification")
@@ -981,7 +929,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.DisableScaleIn``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-disablescalein
             """
             result = self._values.get("disable_scale_in")
@@ -991,7 +938,6 @@ class CfnScalingPlan(
         def estimated_instance_warmup(self) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.EstimatedInstanceWarmup``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-estimatedinstancewarmup
             """
             result = self._values.get("estimated_instance_warmup")
@@ -1003,7 +949,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union["CfnScalingPlan.PredefinedScalingMetricSpecificationProperty", _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.PredefinedScalingMetricSpecification``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-predefinedscalingmetricspecification
             """
             result = self._values.get("predefined_scaling_metric_specification")
@@ -1013,7 +958,6 @@ class CfnScalingPlan(
         def scale_in_cooldown(self) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.ScaleInCooldown``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-scaleincooldown
             """
             result = self._values.get("scale_in_cooldown")
@@ -1023,7 +967,6 @@ class CfnScalingPlan(
         def scale_out_cooldown(self) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.ScaleOutCooldown``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-scaleoutcooldown
             """
             result = self._values.get("scale_out_cooldown")
@@ -1053,15 +996,14 @@ class CfnScalingPlanProps:
     def __init__(
         self,
         *,
-        application_source: typing.Union["CfnScalingPlan.ApplicationSourceProperty", _IResolvable_9ceae33e],
-        scaling_instructions: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.ScalingInstructionProperty", _IResolvable_9ceae33e]]],
+        application_source: typing.Union[CfnScalingPlan.ApplicationSourceProperty, _IResolvable_9ceae33e],
+        scaling_instructions: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnScalingPlan.ScalingInstructionProperty, _IResolvable_9ceae33e]]],
     ) -> None:
         """Properties for defining a ``AWS::AutoScalingPlans::ScalingPlan``.
 
         :param application_source: ``AWS::AutoScalingPlans::ScalingPlan.ApplicationSource``.
         :param scaling_instructions: ``AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1072,10 +1014,9 @@ class CfnScalingPlanProps:
     @builtins.property
     def application_source(
         self,
-    ) -> typing.Union["CfnScalingPlan.ApplicationSourceProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnScalingPlan.ApplicationSourceProperty, _IResolvable_9ceae33e]:
         """``AWS::AutoScalingPlans::ScalingPlan.ApplicationSource``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-applicationsource
         """
         result = self._values.get("application_source")
@@ -1085,10 +1026,9 @@ class CfnScalingPlanProps:
     @builtins.property
     def scaling_instructions(
         self,
-    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.ScalingInstructionProperty", _IResolvable_9ceae33e]]]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnScalingPlan.ScalingInstructionProperty, _IResolvable_9ceae33e]]]:
         """``AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-scalinginstructions
         """
         result = self._values.get("scaling_instructions")
