@@ -27,10 +27,8 @@ class CfnBudget(
 ):
     """A CloudFormation ``AWS::Budgets::Budget``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Budgets::Budget
+    :cloudformationResource: AWS::Budgets::Budget
     """
 
     def __init__(
@@ -38,8 +36,8 @@ class CfnBudget(
         scope: _Construct_f50a3f53,
         id: builtins.str,
         *,
-        budget: typing.Union["BudgetDataProperty", _IResolvable_9ceae33e],
-        notifications_with_subscribers: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]] = None,
+        budget: typing.Union["CfnBudget.BudgetDataProperty", _IResolvable_9ceae33e],
+        notifications_with_subscribers: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::Budgets::Budget``.
 
@@ -57,11 +55,10 @@ class CfnBudget(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -89,10 +86,11 @@ class CfnBudget(
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="budget")
-    def budget(self) -> typing.Union["BudgetDataProperty", _IResolvable_9ceae33e]:
+    def budget(
+        self,
+    ) -> typing.Union["CfnBudget.BudgetDataProperty", _IResolvable_9ceae33e]:
         """``AWS::Budgets::Budget.Budget``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html#cfn-budgets-budget-budget
         """
         return jsii.get(self, "budget")
@@ -100,7 +98,7 @@ class CfnBudget(
     @budget.setter # type: ignore
     def budget(
         self,
-        value: typing.Union["BudgetDataProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnBudget.BudgetDataProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "budget", value)
 
@@ -108,10 +106,9 @@ class CfnBudget(
     @jsii.member(jsii_name="notificationsWithSubscribers")
     def notifications_with_subscribers(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Budgets::Budget.NotificationsWithSubscribers``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html#cfn-budgets-budget-notificationswithsubscribers
         """
         return jsii.get(self, "notificationsWithSubscribers")
@@ -119,7 +116,7 @@ class CfnBudget(
     @notifications_with_subscribers.setter # type: ignore
     def notifications_with_subscribers(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "notificationsWithSubscribers", value)
 
@@ -160,7 +157,6 @@ class CfnBudget(
             :param planned_budget_limits: ``CfnBudget.BudgetDataProperty.PlannedBudgetLimits``.
             :param time_period: ``CfnBudget.BudgetDataProperty.TimePeriod``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -184,7 +180,6 @@ class CfnBudget(
         def budget_type(self) -> builtins.str:
             """``CfnBudget.BudgetDataProperty.BudgetType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-budgettype
             """
             result = self._values.get("budget_type")
@@ -195,7 +190,6 @@ class CfnBudget(
         def time_unit(self) -> builtins.str:
             """``CfnBudget.BudgetDataProperty.TimeUnit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-timeunit
             """
             result = self._values.get("time_unit")
@@ -208,7 +202,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union["CfnBudget.SpendProperty", _IResolvable_9ceae33e]]:
             """``CfnBudget.BudgetDataProperty.BudgetLimit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-budgetlimit
             """
             result = self._values.get("budget_limit")
@@ -218,7 +211,6 @@ class CfnBudget(
         def budget_name(self) -> typing.Optional[builtins.str]:
             """``CfnBudget.BudgetDataProperty.BudgetName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-budgetname
             """
             result = self._values.get("budget_name")
@@ -228,7 +220,6 @@ class CfnBudget(
         def cost_filters(self) -> typing.Any:
             """``CfnBudget.BudgetDataProperty.CostFilters``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-costfilters
             """
             result = self._values.get("cost_filters")
@@ -240,7 +231,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union["CfnBudget.CostTypesProperty", _IResolvable_9ceae33e]]:
             """``CfnBudget.BudgetDataProperty.CostTypes``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-costtypes
             """
             result = self._values.get("cost_types")
@@ -250,7 +240,6 @@ class CfnBudget(
         def planned_budget_limits(self) -> typing.Any:
             """``CfnBudget.BudgetDataProperty.PlannedBudgetLimits``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-plannedbudgetlimits
             """
             result = self._values.get("planned_budget_limits")
@@ -262,7 +251,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union["CfnBudget.TimePeriodProperty", _IResolvable_9ceae33e]]:
             """``CfnBudget.BudgetDataProperty.TimePeriod``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-timeperiod
             """
             result = self._values.get("time_period")
@@ -325,7 +313,6 @@ class CfnBudget(
             :param use_amortized: ``CfnBudget.CostTypesProperty.UseAmortized``.
             :param use_blended: ``CfnBudget.CostTypesProperty.UseBlended``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -358,7 +345,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeCredit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includecredit
             """
             result = self._values.get("include_credit")
@@ -370,7 +356,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeDiscount``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includediscount
             """
             result = self._values.get("include_discount")
@@ -382,7 +367,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeOtherSubscription``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includeothersubscription
             """
             result = self._values.get("include_other_subscription")
@@ -394,7 +378,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeRecurring``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includerecurring
             """
             result = self._values.get("include_recurring")
@@ -406,7 +389,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeRefund``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includerefund
             """
             result = self._values.get("include_refund")
@@ -418,7 +400,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeSubscription``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includesubscription
             """
             result = self._values.get("include_subscription")
@@ -430,7 +411,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeSupport``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includesupport
             """
             result = self._values.get("include_support")
@@ -442,7 +422,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeTax``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includetax
             """
             result = self._values.get("include_tax")
@@ -454,7 +433,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeUpfront``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includeupfront
             """
             result = self._values.get("include_upfront")
@@ -466,7 +444,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.UseAmortized``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-useamortized
             """
             result = self._values.get("use_amortized")
@@ -478,7 +455,6 @@ class CfnBudget(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.UseBlended``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-useblended
             """
             result = self._values.get("use_blended")
@@ -520,7 +496,6 @@ class CfnBudget(
             :param threshold: ``CfnBudget.NotificationProperty.Threshold``.
             :param threshold_type: ``CfnBudget.NotificationProperty.ThresholdType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -535,7 +510,6 @@ class CfnBudget(
         def comparison_operator(self) -> builtins.str:
             """``CfnBudget.NotificationProperty.ComparisonOperator``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html#cfn-budgets-budget-notification-comparisonoperator
             """
             result = self._values.get("comparison_operator")
@@ -546,7 +520,6 @@ class CfnBudget(
         def notification_type(self) -> builtins.str:
             """``CfnBudget.NotificationProperty.NotificationType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html#cfn-budgets-budget-notification-notificationtype
             """
             result = self._values.get("notification_type")
@@ -557,7 +530,6 @@ class CfnBudget(
         def threshold(self) -> jsii.Number:
             """``CfnBudget.NotificationProperty.Threshold``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html#cfn-budgets-budget-notification-threshold
             """
             result = self._values.get("threshold")
@@ -568,7 +540,6 @@ class CfnBudget(
         def threshold_type(self) -> typing.Optional[builtins.str]:
             """``CfnBudget.NotificationProperty.ThresholdType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html#cfn-budgets-budget-notification-thresholdtype
             """
             result = self._values.get("threshold_type")
@@ -601,7 +572,6 @@ class CfnBudget(
             :param notification: ``CfnBudget.NotificationWithSubscribersProperty.Notification``.
             :param subscribers: ``CfnBudget.NotificationWithSubscribersProperty.Subscribers``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notificationwithsubscribers.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -615,7 +585,6 @@ class CfnBudget(
         ) -> typing.Union["CfnBudget.NotificationProperty", _IResolvable_9ceae33e]:
             """``CfnBudget.NotificationWithSubscribersProperty.Notification``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notificationwithsubscribers.html#cfn-budgets-budget-notificationwithsubscribers-notification
             """
             result = self._values.get("notification")
@@ -628,7 +597,6 @@ class CfnBudget(
         ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.SubscriberProperty", _IResolvable_9ceae33e]]]:
             """``CfnBudget.NotificationWithSubscribersProperty.Subscribers``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notificationwithsubscribers.html#cfn-budgets-budget-notificationwithsubscribers-subscribers
             """
             result = self._values.get("subscribers")
@@ -657,7 +625,6 @@ class CfnBudget(
             :param amount: ``CfnBudget.SpendProperty.Amount``.
             :param unit: ``CfnBudget.SpendProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-spend.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -669,7 +636,6 @@ class CfnBudget(
         def amount(self) -> jsii.Number:
             """``CfnBudget.SpendProperty.Amount``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-spend.html#cfn-budgets-budget-spend-amount
             """
             result = self._values.get("amount")
@@ -680,7 +646,6 @@ class CfnBudget(
         def unit(self) -> builtins.str:
             """``CfnBudget.SpendProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-spend.html#cfn-budgets-budget-spend-unit
             """
             result = self._values.get("unit")
@@ -714,7 +679,6 @@ class CfnBudget(
             :param address: ``CfnBudget.SubscriberProperty.Address``.
             :param subscription_type: ``CfnBudget.SubscriberProperty.SubscriptionType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-subscriber.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -726,7 +690,6 @@ class CfnBudget(
         def address(self) -> builtins.str:
             """``CfnBudget.SubscriberProperty.Address``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-subscriber.html#cfn-budgets-budget-subscriber-address
             """
             result = self._values.get("address")
@@ -737,7 +700,6 @@ class CfnBudget(
         def subscription_type(self) -> builtins.str:
             """``CfnBudget.SubscriberProperty.SubscriptionType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-subscriber.html#cfn-budgets-budget-subscriber-subscriptiontype
             """
             result = self._values.get("subscription_type")
@@ -771,7 +733,6 @@ class CfnBudget(
             :param end: ``CfnBudget.TimePeriodProperty.End``.
             :param start: ``CfnBudget.TimePeriodProperty.Start``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-timeperiod.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -784,7 +745,6 @@ class CfnBudget(
         def end(self) -> typing.Optional[builtins.str]:
             """``CfnBudget.TimePeriodProperty.End``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-timeperiod.html#cfn-budgets-budget-timeperiod-end
             """
             result = self._values.get("end")
@@ -794,7 +754,6 @@ class CfnBudget(
         def start(self) -> typing.Optional[builtins.str]:
             """``CfnBudget.TimePeriodProperty.Start``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-timeperiod.html#cfn-budgets-budget-timeperiod-start
             """
             result = self._values.get("start")
@@ -824,15 +783,14 @@ class CfnBudgetProps:
     def __init__(
         self,
         *,
-        budget: typing.Union["CfnBudget.BudgetDataProperty", _IResolvable_9ceae33e],
-        notifications_with_subscribers: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]] = None,
+        budget: typing.Union[CfnBudget.BudgetDataProperty, _IResolvable_9ceae33e],
+        notifications_with_subscribers: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnBudget.NotificationWithSubscribersProperty, _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Budgets::Budget``.
 
         :param budget: ``AWS::Budgets::Budget.Budget``.
         :param notifications_with_subscribers: ``AWS::Budgets::Budget.NotificationsWithSubscribers``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -844,10 +802,9 @@ class CfnBudgetProps:
     @builtins.property
     def budget(
         self,
-    ) -> typing.Union["CfnBudget.BudgetDataProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnBudget.BudgetDataProperty, _IResolvable_9ceae33e]:
         """``AWS::Budgets::Budget.Budget``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html#cfn-budgets-budget-budget
         """
         result = self._values.get("budget")
@@ -857,10 +814,9 @@ class CfnBudgetProps:
     @builtins.property
     def notifications_with_subscribers(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnBudget.NotificationWithSubscribersProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::Budgets::Budget.NotificationsWithSubscribers``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html#cfn-budgets-budget-notificationswithsubscribers
         """
         result = self._values.get("notifications_with_subscribers")
