@@ -27,10 +27,8 @@ class CfnKeyspace(
 ):
     """A CloudFormation ``AWS::Cassandra::Keyspace``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-keyspace.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Cassandra::Keyspace
+    :cloudformationResource: AWS::Cassandra::Keyspace
     """
 
     def __init__(
@@ -52,11 +50,10 @@ class CfnKeyspace(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -87,7 +84,6 @@ class CfnKeyspace(
     def keyspace_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cassandra::Keyspace.KeyspaceName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-keyspace.html#cfn-cassandra-keyspace-keyspacename
         """
         return jsii.get(self, "keyspaceName")
@@ -108,7 +104,6 @@ class CfnKeyspaceProps:
 
         :param keyspace_name: ``AWS::Cassandra::Keyspace.KeyspaceName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-keyspace.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -119,7 +114,6 @@ class CfnKeyspaceProps:
     def keyspace_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cassandra::Keyspace.KeyspaceName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-keyspace.html#cfn-cassandra-keyspace-keyspacename
         """
         result = self._values.get("keyspace_name")
@@ -145,10 +139,8 @@ class CfnTable(
 ):
     """A CloudFormation ``AWS::Cassandra::Table``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Cassandra::Table
+    :cloudformationResource: AWS::Cassandra::Table
     """
 
     def __init__(
@@ -157,10 +149,10 @@ class CfnTable(
         id: builtins.str,
         *,
         keyspace_name: builtins.str,
-        partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]],
-        billing_mode: typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]] = None,
-        clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]] = None,
-        regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]] = None,
+        partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]],
+        billing_mode: typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]] = None,
+        clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]] = None,
+        regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]] = None,
         table_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::Cassandra::Table``.
@@ -187,11 +179,10 @@ class CfnTable(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -222,7 +213,6 @@ class CfnTable(
     def keyspace_name(self) -> builtins.str:
         """``AWS::Cassandra::Table.KeyspaceName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-keyspacename
         """
         return jsii.get(self, "keyspaceName")
@@ -235,10 +225,9 @@ class CfnTable(
     @jsii.member(jsii_name="partitionKeyColumns")
     def partition_key_columns(
         self,
-    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]:
         """``AWS::Cassandra::Table.PartitionKeyColumns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-partitionkeycolumns
         """
         return jsii.get(self, "partitionKeyColumns")
@@ -246,7 +235,7 @@ class CfnTable(
     @partition_key_columns.setter # type: ignore
     def partition_key_columns(
         self,
-        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "partitionKeyColumns", value)
 
@@ -254,10 +243,9 @@ class CfnTable(
     @jsii.member(jsii_name="billingMode")
     def billing_mode(
         self,
-    ) -> typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]]:
         """``AWS::Cassandra::Table.BillingMode``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-billingmode
         """
         return jsii.get(self, "billingMode")
@@ -265,7 +253,7 @@ class CfnTable(
     @billing_mode.setter # type: ignore
     def billing_mode(
         self,
-        value: typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "billingMode", value)
 
@@ -273,10 +261,9 @@ class CfnTable(
     @jsii.member(jsii_name="clusteringKeyColumns")
     def clustering_key_columns(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Cassandra::Table.ClusteringKeyColumns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-clusteringkeycolumns
         """
         return jsii.get(self, "clusteringKeyColumns")
@@ -284,7 +271,7 @@ class CfnTable(
     @clustering_key_columns.setter # type: ignore
     def clustering_key_columns(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "clusteringKeyColumns", value)
 
@@ -292,10 +279,9 @@ class CfnTable(
     @jsii.member(jsii_name="regularColumns")
     def regular_columns(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Cassandra::Table.RegularColumns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-regularcolumns
         """
         return jsii.get(self, "regularColumns")
@@ -303,7 +289,7 @@ class CfnTable(
     @regular_columns.setter # type: ignore
     def regular_columns(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "regularColumns", value)
 
@@ -312,7 +298,6 @@ class CfnTable(
     def table_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cassandra::Table.TableName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-tablename
         """
         return jsii.get(self, "tableName")
@@ -340,7 +325,6 @@ class CfnTable(
             :param mode: ``CfnTable.BillingModeProperty.Mode``.
             :param provisioned_throughput: ``CfnTable.BillingModeProperty.ProvisionedThroughput``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -353,7 +337,6 @@ class CfnTable(
         def mode(self) -> builtins.str:
             """``CfnTable.BillingModeProperty.Mode``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html#cfn-cassandra-table-billingmode-mode
             """
             result = self._values.get("mode")
@@ -366,7 +349,6 @@ class CfnTable(
         ) -> typing.Optional[typing.Union["CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e]]:
             """``CfnTable.BillingModeProperty.ProvisionedThroughput``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html#cfn-cassandra-table-billingmode-provisionedthroughput
             """
             result = self._values.get("provisioned_throughput")
@@ -399,7 +381,6 @@ class CfnTable(
             :param column: ``CfnTable.ClusteringKeyColumnProperty.Column``.
             :param order_by: ``CfnTable.ClusteringKeyColumnProperty.OrderBy``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -414,7 +395,6 @@ class CfnTable(
         ) -> typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]:
             """``CfnTable.ClusteringKeyColumnProperty.Column``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html#cfn-cassandra-table-clusteringkeycolumn-column
             """
             result = self._values.get("column")
@@ -425,7 +405,6 @@ class CfnTable(
         def order_by(self) -> typing.Optional[builtins.str]:
             """``CfnTable.ClusteringKeyColumnProperty.OrderBy``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html#cfn-cassandra-table-clusteringkeycolumn-orderby
             """
             result = self._values.get("order_by")
@@ -458,7 +437,6 @@ class CfnTable(
             :param column_name: ``CfnTable.ColumnProperty.ColumnName``.
             :param column_type: ``CfnTable.ColumnProperty.ColumnType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -470,7 +448,6 @@ class CfnTable(
         def column_name(self) -> builtins.str:
             """``CfnTable.ColumnProperty.ColumnName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html#cfn-cassandra-table-column-columnname
             """
             result = self._values.get("column_name")
@@ -481,7 +458,6 @@ class CfnTable(
         def column_type(self) -> builtins.str:
             """``CfnTable.ColumnProperty.ColumnType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html#cfn-cassandra-table-column-columntype
             """
             result = self._values.get("column_type")
@@ -518,7 +494,6 @@ class CfnTable(
             :param read_capacity_units: ``CfnTable.ProvisionedThroughputProperty.ReadCapacityUnits``.
             :param write_capacity_units: ``CfnTable.ProvisionedThroughputProperty.WriteCapacityUnits``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -530,7 +505,6 @@ class CfnTable(
         def read_capacity_units(self) -> jsii.Number:
             """``CfnTable.ProvisionedThroughputProperty.ReadCapacityUnits``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html#cfn-cassandra-table-provisionedthroughput-readcapacityunits
             """
             result = self._values.get("read_capacity_units")
@@ -541,7 +515,6 @@ class CfnTable(
         def write_capacity_units(self) -> jsii.Number:
             """``CfnTable.ProvisionedThroughputProperty.WriteCapacityUnits``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html#cfn-cassandra-table-provisionedthroughput-writecapacityunits
             """
             result = self._values.get("write_capacity_units")
@@ -577,10 +550,10 @@ class CfnTableProps:
         self,
         *,
         keyspace_name: builtins.str,
-        partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]],
-        billing_mode: typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]] = None,
-        clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]] = None,
-        regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]] = None,
+        partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnTable.ColumnProperty, _IResolvable_9ceae33e]]],
+        billing_mode: typing.Optional[typing.Union[CfnTable.BillingModeProperty, _IResolvable_9ceae33e]] = None,
+        clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnTable.ClusteringKeyColumnProperty, _IResolvable_9ceae33e]]]] = None,
+        regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnTable.ColumnProperty, _IResolvable_9ceae33e]]]] = None,
         table_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::Cassandra::Table``.
@@ -592,7 +565,6 @@ class CfnTableProps:
         :param regular_columns: ``AWS::Cassandra::Table.RegularColumns``.
         :param table_name: ``AWS::Cassandra::Table.TableName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -612,7 +584,6 @@ class CfnTableProps:
     def keyspace_name(self) -> builtins.str:
         """``AWS::Cassandra::Table.KeyspaceName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-keyspacename
         """
         result = self._values.get("keyspace_name")
@@ -622,10 +593,9 @@ class CfnTableProps:
     @builtins.property
     def partition_key_columns(
         self,
-    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnTable.ColumnProperty, _IResolvable_9ceae33e]]]:
         """``AWS::Cassandra::Table.PartitionKeyColumns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-partitionkeycolumns
         """
         result = self._values.get("partition_key_columns")
@@ -635,10 +605,9 @@ class CfnTableProps:
     @builtins.property
     def billing_mode(
         self,
-    ) -> typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnTable.BillingModeProperty, _IResolvable_9ceae33e]]:
         """``AWS::Cassandra::Table.BillingMode``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-billingmode
         """
         result = self._values.get("billing_mode")
@@ -647,10 +616,9 @@ class CfnTableProps:
     @builtins.property
     def clustering_key_columns(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnTable.ClusteringKeyColumnProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::Cassandra::Table.ClusteringKeyColumns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-clusteringkeycolumns
         """
         result = self._values.get("clustering_key_columns")
@@ -659,10 +627,9 @@ class CfnTableProps:
     @builtins.property
     def regular_columns(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnTable.ColumnProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::Cassandra::Table.RegularColumns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-regularcolumns
         """
         result = self._values.get("regular_columns")
@@ -672,7 +639,6 @@ class CfnTableProps:
     def table_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cassandra::Table.TableName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html#cfn-cassandra-table-tablename
         """
         result = self._values.get("table_name")
