@@ -38,10 +38,8 @@ class CfnEnvironmentEC2(
 ):
     """A CloudFormation ``AWS::Cloud9::EnvironmentEC2``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Cloud9::EnvironmentEC2
+    :cloudformationResource: AWS::Cloud9::EnvironmentEC2
     """
 
     def __init__(
@@ -55,7 +53,7 @@ class CfnEnvironmentEC2(
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         owner_arn: typing.Optional[builtins.str] = None,
-        repositories: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]]]] = None,
+        repositories: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e]]]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -89,11 +87,10 @@ class CfnEnvironmentEC2(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -118,8 +115,7 @@ class CfnEnvironmentEC2(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -127,8 +123,7 @@ class CfnEnvironmentEC2(
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Name
+        :cloudformationAttribute: Name
         """
         return jsii.get(self, "attrName")
 
@@ -142,7 +137,6 @@ class CfnEnvironmentEC2(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::Cloud9::EnvironmentEC2.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-tags
         """
         return jsii.get(self, "tags")
@@ -152,7 +146,6 @@ class CfnEnvironmentEC2(
     def instance_type(self) -> builtins.str:
         """``AWS::Cloud9::EnvironmentEC2.InstanceType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-instancetype
         """
         return jsii.get(self, "instanceType")
@@ -166,7 +159,6 @@ class CfnEnvironmentEC2(
     def automatic_stop_time_minutes(self) -> typing.Optional[jsii.Number]:
         """``AWS::Cloud9::EnvironmentEC2.AutomaticStopTimeMinutes``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-automaticstoptimeminutes
         """
         return jsii.get(self, "automaticStopTimeMinutes")
@@ -180,7 +172,6 @@ class CfnEnvironmentEC2(
     def connection_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.ConnectionType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-connectiontype
         """
         return jsii.get(self, "connectionType")
@@ -194,7 +185,6 @@ class CfnEnvironmentEC2(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-description
         """
         return jsii.get(self, "description")
@@ -208,7 +198,6 @@ class CfnEnvironmentEC2(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-name
         """
         return jsii.get(self, "name")
@@ -222,7 +211,6 @@ class CfnEnvironmentEC2(
     def owner_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.OwnerArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-ownerarn
         """
         return jsii.get(self, "ownerArn")
@@ -235,10 +223,9 @@ class CfnEnvironmentEC2(
     @jsii.member(jsii_name="repositories")
     def repositories(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Cloud9::EnvironmentEC2.Repositories``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
         """
         return jsii.get(self, "repositories")
@@ -246,7 +233,7 @@ class CfnEnvironmentEC2(
     @repositories.setter # type: ignore
     def repositories(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "repositories", value)
 
@@ -255,7 +242,6 @@ class CfnEnvironmentEC2(
     def subnet_id(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.SubnetId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-subnetid
         """
         return jsii.get(self, "subnetId")
@@ -283,7 +269,6 @@ class CfnEnvironmentEC2(
             :param path_component: ``CfnEnvironmentEC2.RepositoryProperty.PathComponent``.
             :param repository_url: ``CfnEnvironmentEC2.RepositoryProperty.RepositoryUrl``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -295,7 +280,6 @@ class CfnEnvironmentEC2(
         def path_component(self) -> builtins.str:
             """``CfnEnvironmentEC2.RepositoryProperty.PathComponent``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
             """
             result = self._values.get("path_component")
@@ -306,7 +290,6 @@ class CfnEnvironmentEC2(
         def repository_url(self) -> builtins.str:
             """``CfnEnvironmentEC2.RepositoryProperty.RepositoryUrl``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
             """
             result = self._values.get("repository_url")
@@ -350,7 +333,7 @@ class CfnEnvironmentEC2Props:
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         owner_arn: typing.Optional[builtins.str] = None,
-        repositories: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e]]]] = None,
+        repositories: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, _IResolvable_9ceae33e]]]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -366,7 +349,6 @@ class CfnEnvironmentEC2Props:
         :param subnet_id: ``AWS::Cloud9::EnvironmentEC2.SubnetId``.
         :param tags: ``AWS::Cloud9::EnvironmentEC2.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -393,7 +375,6 @@ class CfnEnvironmentEC2Props:
     def instance_type(self) -> builtins.str:
         """``AWS::Cloud9::EnvironmentEC2.InstanceType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-instancetype
         """
         result = self._values.get("instance_type")
@@ -404,7 +385,6 @@ class CfnEnvironmentEC2Props:
     def automatic_stop_time_minutes(self) -> typing.Optional[jsii.Number]:
         """``AWS::Cloud9::EnvironmentEC2.AutomaticStopTimeMinutes``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-automaticstoptimeminutes
         """
         result = self._values.get("automatic_stop_time_minutes")
@@ -414,7 +394,6 @@ class CfnEnvironmentEC2Props:
     def connection_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.ConnectionType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-connectiontype
         """
         result = self._values.get("connection_type")
@@ -424,7 +403,6 @@ class CfnEnvironmentEC2Props:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-description
         """
         result = self._values.get("description")
@@ -434,7 +412,6 @@ class CfnEnvironmentEC2Props:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-name
         """
         result = self._values.get("name")
@@ -444,7 +421,6 @@ class CfnEnvironmentEC2Props:
     def owner_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.OwnerArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-ownerarn
         """
         result = self._values.get("owner_arn")
@@ -453,10 +429,9 @@ class CfnEnvironmentEC2Props:
     @builtins.property
     def repositories(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::Cloud9::EnvironmentEC2.Repositories``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
         """
         result = self._values.get("repositories")
@@ -466,7 +441,6 @@ class CfnEnvironmentEC2Props:
     def subnet_id(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.SubnetId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-subnetid
         """
         result = self._values.get("subnet_id")
@@ -476,7 +450,6 @@ class CfnEnvironmentEC2Props:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::Cloud9::EnvironmentEC2.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-tags
         """
         result = self._values.get("tags")
@@ -498,9 +471,8 @@ class CloneRepository(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_cloud9.CloneRepository",
 ):
-    """The class for different repository providers.
+    """(experimental) The class for different repository providers.
 
-    stability
     :stability: experimental
     """
 
@@ -511,12 +483,11 @@ class CloneRepository(
         repository: _IRepository_91f381de,
         path: builtins.str,
     ) -> "CloneRepository":
-        """import repository to cloud9 environment from AWS CodeCommit.
+        """(experimental) import repository to cloud9 environment from AWS CodeCommit.
 
         :param repository: the codecommit repository to clone from.
         :param path: the target path in cloud9 environment.
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "fromCodeCommit", [repository, path])
@@ -525,7 +496,6 @@ class CloneRepository(
     @jsii.member(jsii_name="pathComponent")
     def path_component(self) -> builtins.str:
         """
-        stability
         :stability: experimental
         """
         return jsii.get(self, "pathComponent")
@@ -534,7 +504,6 @@ class CloneRepository(
     @jsii.member(jsii_name="repositoryUrl")
     def repository_url(self) -> builtins.str:
         """
-        stability
         :stability: experimental
         """
         return jsii.get(self, "repositoryUrl")
@@ -557,22 +526,21 @@ class Ec2EnvironmentProps:
         self,
         *,
         vpc: _IVpc_3795853f,
-        cloned_repositories: typing.Optional[typing.List["CloneRepository"]] = None,
+        cloned_repositories: typing.Optional[typing.List[CloneRepository]] = None,
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[_InstanceType_85a97b30] = None,
         subnet_selection: typing.Optional[_SubnetSelection_36a13cd6] = None,
     ) -> None:
-        """Properties for Ec2Environment.
+        """(experimental) Properties for Ec2Environment.
 
-        :param vpc: The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
-        :param cloned_repositories: The AWS CodeCommit repository to be cloned. Default: - do not clone any repository
-        :param description: Description of the environment. Default: - no description
-        :param ec2_environment_name: Name of the environment. Default: - automatically generated name
-        :param instance_type: The type of instance to connect to the environment. Default: - t2.micro
-        :param subnet_selection: The subnetSelection of the VPC that AWS Cloud9 will use to communicate with the Amazon EC2 instance. Default: - all public subnets of the VPC are selected.
+        :param vpc: (experimental) The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
+        :param cloned_repositories: (experimental) The AWS CodeCommit repository to be cloned. Default: - do not clone any repository
+        :param description: (experimental) Description of the environment. Default: - no description
+        :param ec2_environment_name: (experimental) Name of the environment. Default: - automatically generated name
+        :param instance_type: (experimental) The type of instance to connect to the environment. Default: - t2.micro
+        :param subnet_selection: (experimental) The subnetSelection of the VPC that AWS Cloud9 will use to communicate with the Amazon EC2 instance. Default: - all public subnets of the VPC are selected.
 
-        stability
         :stability: experimental
         """
         if isinstance(subnet_selection, dict):
@@ -593,9 +561,8 @@ class Ec2EnvironmentProps:
 
     @builtins.property
     def vpc(self) -> _IVpc_3795853f:
-        """The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
+        """(experimental) The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("vpc")
@@ -603,13 +570,11 @@ class Ec2EnvironmentProps:
         return result
 
     @builtins.property
-    def cloned_repositories(self) -> typing.Optional[typing.List["CloneRepository"]]:
-        """The AWS CodeCommit repository to be cloned.
+    def cloned_repositories(self) -> typing.Optional[typing.List[CloneRepository]]:
+        """(experimental) The AWS CodeCommit repository to be cloned.
 
-        default
         :default: - do not clone any repository
 
-        stability
         :stability: experimental
         """
         result = self._values.get("cloned_repositories")
@@ -617,12 +582,10 @@ class Ec2EnvironmentProps:
 
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
-        """Description of the environment.
+        """(experimental) Description of the environment.
 
-        default
         :default: - no description
 
-        stability
         :stability: experimental
         """
         result = self._values.get("description")
@@ -630,12 +593,10 @@ class Ec2EnvironmentProps:
 
     @builtins.property
     def ec2_environment_name(self) -> typing.Optional[builtins.str]:
-        """Name of the environment.
+        """(experimental) Name of the environment.
 
-        default
         :default: - automatically generated name
 
-        stability
         :stability: experimental
         """
         result = self._values.get("ec2_environment_name")
@@ -643,12 +604,10 @@ class Ec2EnvironmentProps:
 
     @builtins.property
     def instance_type(self) -> typing.Optional[_InstanceType_85a97b30]:
-        """The type of instance to connect to the environment.
+        """(experimental) The type of instance to connect to the environment.
 
-        default
         :default: - t2.micro
 
-        stability
         :stability: experimental
         """
         result = self._values.get("instance_type")
@@ -656,12 +615,10 @@ class Ec2EnvironmentProps:
 
     @builtins.property
     def subnet_selection(self) -> typing.Optional[_SubnetSelection_36a13cd6]:
-        """The subnetSelection of the VPC that AWS Cloud9 will use to communicate with the Amazon EC2 instance.
+        """(experimental) The subnetSelection of the VPC that AWS Cloud9 will use to communicate with the Amazon EC2 instance.
 
-        default
         :default: - all public subnets of the VPC are selected.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("subnet_selection")
@@ -681,9 +638,8 @@ class Ec2EnvironmentProps:
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_cloud9.IEc2Environment")
 class IEc2Environment(_IResource_72f7ee7e, typing_extensions.Protocol):
-    """A Cloud9 Environment.
+    """(experimental) A Cloud9 Environment.
 
-    stability
     :stability: experimental
     """
 
@@ -694,24 +650,20 @@ class IEc2Environment(_IResource_72f7ee7e, typing_extensions.Protocol):
     @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> builtins.str:
-        """The arn of the EnvironmentEc2.
+        """(experimental) The arn of the EnvironmentEc2.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: environmentE2Arn
+        :attribute: environmentE2Arn
         """
         ...
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentName")
     def ec2_environment_name(self) -> builtins.str:
-        """The name of the EnvironmentEc2.
+        """(experimental) The name of the EnvironmentEc2.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: environmentEc2Name
+        :attribute: environmentEc2Name
         """
         ...
 
@@ -719,9 +671,8 @@ class IEc2Environment(_IResource_72f7ee7e, typing_extensions.Protocol):
 class _IEc2EnvironmentProxy(
     jsii.proxy_for(_IResource_72f7ee7e) # type: ignore
 ):
-    """A Cloud9 Environment.
+    """(experimental) A Cloud9 Environment.
 
-    stability
     :stability: experimental
     """
 
@@ -730,24 +681,20 @@ class _IEc2EnvironmentProxy(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> builtins.str:
-        """The arn of the EnvironmentEc2.
+        """(experimental) The arn of the EnvironmentEc2.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: environmentE2Arn
+        :attribute: environmentE2Arn
         """
         return jsii.get(self, "ec2EnvironmentArn")
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentName")
     def ec2_environment_name(self) -> builtins.str:
-        """The name of the EnvironmentEc2.
+        """(experimental) The name of the EnvironmentEc2.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: environmentEc2Name
+        :attribute: environmentEc2Name
         """
         return jsii.get(self, "ec2EnvironmentName")
 
@@ -758,12 +705,10 @@ class Ec2Environment(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_cloud9.Ec2Environment",
 ):
-    """A Cloud9 Environment with Amazon EC2.
+    """(experimental) A Cloud9 Environment with Amazon EC2.
 
-    stability
     :stability: experimental
-    resource:
-    :resource:: AWS::Cloud9::EnvironmentEC2
+    :resource: AWS::Cloud9::EnvironmentEC2
     """
 
     def __init__(
@@ -772,7 +717,7 @@ class Ec2Environment(
         id: builtins.str,
         *,
         vpc: _IVpc_3795853f,
-        cloned_repositories: typing.Optional[typing.List["CloneRepository"]] = None,
+        cloned_repositories: typing.Optional[typing.List[CloneRepository]] = None,
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[_InstanceType_85a97b30] = None,
@@ -781,14 +726,13 @@ class Ec2Environment(
         """
         :param scope: -
         :param id: -
-        :param vpc: The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
-        :param cloned_repositories: The AWS CodeCommit repository to be cloned. Default: - do not clone any repository
-        :param description: Description of the environment. Default: - no description
-        :param ec2_environment_name: Name of the environment. Default: - automatically generated name
-        :param instance_type: The type of instance to connect to the environment. Default: - t2.micro
-        :param subnet_selection: The subnetSelection of the VPC that AWS Cloud9 will use to communicate with the Amazon EC2 instance. Default: - all public subnets of the VPC are selected.
+        :param vpc: (experimental) The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
+        :param cloned_repositories: (experimental) The AWS CodeCommit repository to be cloned. Default: - do not clone any repository
+        :param description: (experimental) Description of the environment. Default: - no description
+        :param ec2_environment_name: (experimental) Name of the environment. Default: - automatically generated name
+        :param instance_type: (experimental) The type of instance to connect to the environment. Default: - t2.micro
+        :param subnet_selection: (experimental) The subnetSelection of the VPC that AWS Cloud9 will use to communicate with the Amazon EC2 instance. Default: - all public subnets of the VPC are selected.
 
-        stability
         :stability: experimental
         """
         props = Ec2EnvironmentProps(
@@ -809,14 +753,13 @@ class Ec2Environment(
         scope: constructs.Construct,
         id: builtins.str,
         ec2_environment_name: builtins.str,
-    ) -> "IEc2Environment":
-        """import from EnvironmentEc2Name.
+    ) -> IEc2Environment:
+        """(experimental) import from EnvironmentEc2Name.
 
         :param scope: -
         :param id: -
         :param ec2_environment_name: -
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "fromEc2EnvironmentName", [scope, id, ec2_environment_name])
@@ -824,33 +767,28 @@ class Ec2Environment(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> builtins.str:
-        """The environment ARN of this Cloud9 environment.
+        """(experimental) The environment ARN of this Cloud9 environment.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         return jsii.get(self, "ec2EnvironmentArn")
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentName")
     def ec2_environment_name(self) -> builtins.str:
-        """The environment name of this Cloud9 environment.
+        """(experimental) The environment name of this Cloud9 environment.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         return jsii.get(self, "ec2EnvironmentName")
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="environmentId")
     def environment_id(self) -> builtins.str:
-        """The environment ID of this Cloud9 environment.
+        """(experimental) The environment ID of this Cloud9 environment.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "environmentId")
@@ -858,9 +796,8 @@ class Ec2Environment(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="ideUrl")
     def ide_url(self) -> builtins.str:
-        """The complete IDE URL of this Cloud9 environment.
+        """(experimental) The complete IDE URL of this Cloud9 environment.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "ideUrl")
@@ -868,9 +805,8 @@ class Ec2Environment(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> _IVpc_3795853f:
-        """VPC ID.
+        """(experimental) VPC ID.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "vpc")
