@@ -29,9 +29,8 @@ class HttpOrigin(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_cloudfront_origins.HttpOrigin",
 ):
-    """An Origin for an HTTP server or S3 bucket configured for website hosting.
+    """(experimental) An Origin for an HTTP server or S3 bucket configured for website hosting.
 
-    stability
     :stability: experimental
     """
 
@@ -51,17 +50,16 @@ class HttpOrigin(
     ) -> None:
         """
         :param domain_name: -
-        :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
-        :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
-        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
-        :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
-        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
-        :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
-        :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
-        :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
+        :param http_port: (experimental) The HTTP port that CloudFront uses to connect to the origin. Default: 80
+        :param https_port: (experimental) The HTTPS port that CloudFront uses to connect to the origin. Default: 443
+        :param keepalive_timeout: (experimental) Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
+        :param protocol_policy: (experimental) Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
+        :param read_timeout: (experimental) Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
+        :param connection_attempts: (experimental) The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
+        :param connection_timeout: (experimental) The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
+        :param custom_headers: (experimental) A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
+        :param origin_path: (experimental) An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
 
-        stability
         :stability: experimental
         """
         props = HttpOriginProps(
@@ -83,7 +81,6 @@ class HttpOrigin(
         self,
     ) -> typing.Optional[_CfnDistribution_3a5e7b5c.CustomOriginConfigProperty]:
         """
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "renderCustomOriginConfig", [])
@@ -118,19 +115,18 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         protocol_policy: typing.Optional[_OriginProtocolPolicy_d2d28ec7] = None,
         read_timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
-        """Properties for an Origin backed by an S3 website-configured bucket, load balancer, or custom HTTP server.
+        """(experimental) Properties for an Origin backed by an S3 website-configured bucket, load balancer, or custom HTTP server.
 
-        :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
-        :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
-        :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
-        :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
-        :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
-        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
-        :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
-        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
+        :param connection_attempts: (experimental) The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
+        :param connection_timeout: (experimental) The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
+        :param custom_headers: (experimental) A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
+        :param origin_path: (experimental) An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
+        :param http_port: (experimental) The HTTP port that CloudFront uses to connect to the origin. Default: 80
+        :param https_port: (experimental) The HTTPS port that CloudFront uses to connect to the origin. Default: 443
+        :param keepalive_timeout: (experimental) Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
+        :param protocol_policy: (experimental) Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
+        :param read_timeout: (experimental) Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -155,14 +151,12 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
 
     @builtins.property
     def connection_attempts(self) -> typing.Optional[jsii.Number]:
-        """The number of times that CloudFront attempts to connect to the origin;
+        """(experimental) The number of times that CloudFront attempts to connect to the origin;
 
         valid values are 1, 2, or 3 attempts.
 
-        default
         :default: 3
 
-        stability
         :stability: experimental
         """
         result = self._values.get("connection_attempts")
@@ -170,14 +164,12 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
 
     @builtins.property
     def connection_timeout(self) -> typing.Optional[_Duration_5170c158]:
-        """The number of seconds that CloudFront waits when trying to establish a connection to the origin.
+        """(experimental) The number of seconds that CloudFront waits when trying to establish a connection to the origin.
 
         Valid values are 1-10 seconds, inclusive.
 
-        default
         :default: Duration.seconds(10)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("connection_timeout")
@@ -187,12 +179,10 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
     def custom_headers(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
-        """A list of HTTP header names and values that CloudFront adds to requests it sends to the origin.
+        """(experimental) A list of HTTP header names and values that CloudFront adds to requests it sends to the origin.
 
-        default
         :default: {}
 
-        stability
         :stability: experimental
         """
         result = self._values.get("custom_headers")
@@ -200,14 +190,12 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
 
     @builtins.property
     def origin_path(self) -> typing.Optional[builtins.str]:
-        """An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
+        """(experimental) An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
 
         Must begin, but not end, with '/' (e.g., '/production/images').
 
-        default
         :default: '/'
 
-        stability
         :stability: experimental
         """
         result = self._values.get("origin_path")
@@ -215,12 +203,10 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
 
     @builtins.property
     def http_port(self) -> typing.Optional[jsii.Number]:
-        """The HTTP port that CloudFront uses to connect to the origin.
+        """(experimental) The HTTP port that CloudFront uses to connect to the origin.
 
-        default
         :default: 80
 
-        stability
         :stability: experimental
         """
         result = self._values.get("http_port")
@@ -228,12 +214,10 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
 
     @builtins.property
     def https_port(self) -> typing.Optional[jsii.Number]:
-        """The HTTPS port that CloudFront uses to connect to the origin.
+        """(experimental) The HTTPS port that CloudFront uses to connect to the origin.
 
-        default
         :default: 443
 
-        stability
         :stability: experimental
         """
         result = self._values.get("https_port")
@@ -241,14 +225,12 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
 
     @builtins.property
     def keepalive_timeout(self) -> typing.Optional[_Duration_5170c158]:
-        """Specifies how long, in seconds, CloudFront persists its connection to the origin.
+        """(experimental) Specifies how long, in seconds, CloudFront persists its connection to the origin.
 
         The valid range is from 1 to 60 seconds, inclusive.
 
-        default
         :default: Duration.seconds(5)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("keepalive_timeout")
@@ -256,12 +238,10 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
 
     @builtins.property
     def protocol_policy(self) -> typing.Optional[_OriginProtocolPolicy_d2d28ec7]:
-        """Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.
+        """(experimental) Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.
 
-        default
         :default: OriginProtocolPolicy.HTTPS_ONLY
 
-        stability
         :stability: experimental
         """
         result = self._values.get("protocol_policy")
@@ -269,14 +249,12 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
 
     @builtins.property
     def read_timeout(self) -> typing.Optional[_Duration_5170c158]:
-        """Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout.
+        """(experimental) Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout.
 
         The valid range is from 1 to 60 seconds, inclusive.
 
-        default
         :default: Duration.seconds(30)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("read_timeout")
@@ -299,9 +277,8 @@ class LoadBalancerV2Origin(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_cloudfront_origins.LoadBalancerV2Origin",
 ):
-    """An Origin for a v2 load balancer.
+    """(experimental) An Origin for a v2 load balancer.
 
-    stability
     :stability: experimental
     """
 
@@ -321,17 +298,16 @@ class LoadBalancerV2Origin(
     ) -> None:
         """
         :param load_balancer: -
-        :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
-        :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
-        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
-        :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
-        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
-        :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
-        :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
-        :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
+        :param http_port: (experimental) The HTTP port that CloudFront uses to connect to the origin. Default: 80
+        :param https_port: (experimental) The HTTPS port that CloudFront uses to connect to the origin. Default: 443
+        :param keepalive_timeout: (experimental) Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
+        :param protocol_policy: (experimental) Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
+        :param read_timeout: (experimental) Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
+        :param connection_attempts: (experimental) The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
+        :param connection_timeout: (experimental) The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
+        :param custom_headers: (experimental) A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
+        :param origin_path: (experimental) An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
 
-        stability
         :stability: experimental
         """
         props = LoadBalancerV2OriginProps(
@@ -378,19 +354,18 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         protocol_policy: typing.Optional[_OriginProtocolPolicy_d2d28ec7] = None,
         read_timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
-        """Properties for an Origin backed by a v2 load balancer.
+        """(experimental) Properties for an Origin backed by a v2 load balancer.
 
-        :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
-        :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
-        :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
-        :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
-        :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
-        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
-        :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
-        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
+        :param connection_attempts: (experimental) The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
+        :param connection_timeout: (experimental) The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
+        :param custom_headers: (experimental) A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
+        :param origin_path: (experimental) An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
+        :param http_port: (experimental) The HTTP port that CloudFront uses to connect to the origin. Default: 80
+        :param https_port: (experimental) The HTTPS port that CloudFront uses to connect to the origin. Default: 443
+        :param keepalive_timeout: (experimental) Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
+        :param protocol_policy: (experimental) Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
+        :param read_timeout: (experimental) Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -415,14 +390,12 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
 
     @builtins.property
     def connection_attempts(self) -> typing.Optional[jsii.Number]:
-        """The number of times that CloudFront attempts to connect to the origin;
+        """(experimental) The number of times that CloudFront attempts to connect to the origin;
 
         valid values are 1, 2, or 3 attempts.
 
-        default
         :default: 3
 
-        stability
         :stability: experimental
         """
         result = self._values.get("connection_attempts")
@@ -430,14 +403,12 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
 
     @builtins.property
     def connection_timeout(self) -> typing.Optional[_Duration_5170c158]:
-        """The number of seconds that CloudFront waits when trying to establish a connection to the origin.
+        """(experimental) The number of seconds that CloudFront waits when trying to establish a connection to the origin.
 
         Valid values are 1-10 seconds, inclusive.
 
-        default
         :default: Duration.seconds(10)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("connection_timeout")
@@ -447,12 +418,10 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
     def custom_headers(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
-        """A list of HTTP header names and values that CloudFront adds to requests it sends to the origin.
+        """(experimental) A list of HTTP header names and values that CloudFront adds to requests it sends to the origin.
 
-        default
         :default: {}
 
-        stability
         :stability: experimental
         """
         result = self._values.get("custom_headers")
@@ -460,14 +429,12 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
 
     @builtins.property
     def origin_path(self) -> typing.Optional[builtins.str]:
-        """An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
+        """(experimental) An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
 
         Must begin, but not end, with '/' (e.g., '/production/images').
 
-        default
         :default: '/'
 
-        stability
         :stability: experimental
         """
         result = self._values.get("origin_path")
@@ -475,12 +442,10 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
 
     @builtins.property
     def http_port(self) -> typing.Optional[jsii.Number]:
-        """The HTTP port that CloudFront uses to connect to the origin.
+        """(experimental) The HTTP port that CloudFront uses to connect to the origin.
 
-        default
         :default: 80
 
-        stability
         :stability: experimental
         """
         result = self._values.get("http_port")
@@ -488,12 +453,10 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
 
     @builtins.property
     def https_port(self) -> typing.Optional[jsii.Number]:
-        """The HTTPS port that CloudFront uses to connect to the origin.
+        """(experimental) The HTTPS port that CloudFront uses to connect to the origin.
 
-        default
         :default: 443
 
-        stability
         :stability: experimental
         """
         result = self._values.get("https_port")
@@ -501,14 +464,12 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
 
     @builtins.property
     def keepalive_timeout(self) -> typing.Optional[_Duration_5170c158]:
-        """Specifies how long, in seconds, CloudFront persists its connection to the origin.
+        """(experimental) Specifies how long, in seconds, CloudFront persists its connection to the origin.
 
         The valid range is from 1 to 60 seconds, inclusive.
 
-        default
         :default: Duration.seconds(5)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("keepalive_timeout")
@@ -516,12 +477,10 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
 
     @builtins.property
     def protocol_policy(self) -> typing.Optional[_OriginProtocolPolicy_d2d28ec7]:
-        """Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.
+        """(experimental) Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.
 
-        default
         :default: OriginProtocolPolicy.HTTPS_ONLY
 
-        stability
         :stability: experimental
         """
         result = self._values.get("protocol_policy")
@@ -529,14 +488,12 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
 
     @builtins.property
     def read_timeout(self) -> typing.Optional[_Duration_5170c158]:
-        """Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout.
+        """(experimental) Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout.
 
         The valid range is from 1 to 60 seconds, inclusive.
 
-        default
         :default: Duration.seconds(30)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("read_timeout")
@@ -559,12 +516,11 @@ class OriginGroup(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_cloudfront_origins.OriginGroup",
 ):
-    """An Origin that represents a group.
+    """(experimental) An Origin that represents a group.
 
     Consists of a primary Origin,
     and a fallback Origin called when the primary returns one of the provided HTTP status codes.
 
-    stability
     :stability: experimental
     """
 
@@ -576,11 +532,10 @@ class OriginGroup(
         fallback_status_codes: typing.Optional[typing.List[jsii.Number]] = None,
     ) -> None:
         """
-        :param fallback_origin: The fallback origin that should serve requests when the primary fails.
-        :param primary_origin: The primary origin that should serve requests for this group.
-        :param fallback_status_codes: The list of HTTP status codes that, when returned from the primary origin, would cause querying the fallback origin. Default: - 500, 502, 503 and 504
+        :param fallback_origin: (experimental) The fallback origin that should serve requests when the primary fails.
+        :param primary_origin: (experimental) The primary origin that should serve requests for this group.
+        :param fallback_status_codes: (experimental) The list of HTTP status codes that, when returned from the primary origin, would cause querying the fallback origin. Default: - 500, 502, 503 and 504
 
-        stability
         :stability: experimental
         """
         props = OriginGroupProps(
@@ -598,12 +553,11 @@ class OriginGroup(
         *,
         origin_id: builtins.str,
     ) -> _OriginBindConfig_86e63cf0:
-        """The method called when a given Origin is added (for the first time) to a Distribution.
+        """(experimental) The method called when a given Origin is added (for the first time) to a Distribution.
 
         :param scope: -
-        :param origin_id: The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
+        :param origin_id: (experimental) The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
 
-        stability
         :stability: experimental
         """
         options = _OriginBindOptions_5b2ffb69(origin_id=origin_id)
@@ -628,13 +582,12 @@ class OriginGroupProps:
         primary_origin: _IOrigin_ceac1980,
         fallback_status_codes: typing.Optional[typing.List[jsii.Number]] = None,
     ) -> None:
-        """Construction properties for {@link OriginGroup}.
+        """(experimental) Construction properties for {@link OriginGroup}.
 
-        :param fallback_origin: The fallback origin that should serve requests when the primary fails.
-        :param primary_origin: The primary origin that should serve requests for this group.
-        :param fallback_status_codes: The list of HTTP status codes that, when returned from the primary origin, would cause querying the fallback origin. Default: - 500, 502, 503 and 504
+        :param fallback_origin: (experimental) The fallback origin that should serve requests when the primary fails.
+        :param primary_origin: (experimental) The primary origin that should serve requests for this group.
+        :param fallback_status_codes: (experimental) The list of HTTP status codes that, when returned from the primary origin, would cause querying the fallback origin. Default: - 500, 502, 503 and 504
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -646,9 +599,8 @@ class OriginGroupProps:
 
     @builtins.property
     def fallback_origin(self) -> _IOrigin_ceac1980:
-        """The fallback origin that should serve requests when the primary fails.
+        """(experimental) The fallback origin that should serve requests when the primary fails.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("fallback_origin")
@@ -657,9 +609,8 @@ class OriginGroupProps:
 
     @builtins.property
     def primary_origin(self) -> _IOrigin_ceac1980:
-        """The primary origin that should serve requests for this group.
+        """(experimental) The primary origin that should serve requests for this group.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("primary_origin")
@@ -668,12 +619,10 @@ class OriginGroupProps:
 
     @builtins.property
     def fallback_status_codes(self) -> typing.Optional[typing.List[jsii.Number]]:
-        """The list of HTTP status codes that, when returned from the primary origin, would cause querying the fallback origin.
+        """(experimental) The list of HTTP status codes that, when returned from the primary origin, would cause querying the fallback origin.
 
-        default
         :default: - 500, 502, 503 and 504
 
-        stability
         :stability: experimental
         """
         result = self._values.get("fallback_status_codes")
@@ -696,13 +645,12 @@ class S3Origin(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_cloudfront_origins.S3Origin",
 ):
-    """An Origin that is backed by an S3 bucket.
+    """(experimental) An Origin that is backed by an S3 bucket.
 
     If the bucket is configured for website hosting, this origin will be configured to use the bucket as an
     HTTP server origin and will use the bucket's configured website redirects and error handling. Otherwise,
     the origin is created as a bucket origin and will use CloudFront's redirect and error handling.
 
-    stability
     :stability: experimental
     """
 
@@ -714,9 +662,8 @@ class S3Origin(
     ) -> None:
         """
         :param bucket: -
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
+        :param origin_path: (experimental) An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
 
-        stability
         :stability: experimental
         """
         props = S3OriginProps(origin_path=origin_path)
@@ -730,12 +677,11 @@ class S3Origin(
         *,
         origin_id: builtins.str,
     ) -> _OriginBindConfig_86e63cf0:
-        """The method called when a given Origin is added (for the first time) to a Distribution.
+        """(experimental) The method called when a given Origin is added (for the first time) to a Distribution.
 
         :param scope: -
-        :param origin_id: The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
+        :param origin_id: (experimental) The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
 
-        stability
         :stability: experimental
         """
         options = _OriginBindOptions_5b2ffb69(origin_id=origin_id)
@@ -750,11 +696,10 @@ class S3Origin(
 )
 class S3OriginProps:
     def __init__(self, *, origin_path: typing.Optional[builtins.str] = None) -> None:
-        """Properties to use to customize an S3 Origin.
+        """(experimental) Properties to use to customize an S3 Origin.
 
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
+        :param origin_path: (experimental) An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -763,14 +708,12 @@ class S3OriginProps:
 
     @builtins.property
     def origin_path(self) -> typing.Optional[builtins.str]:
-        """An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
+        """(experimental) An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
 
         Must begin, but not end, with '/' (e.g., '/production/images').
 
-        default
         :default: '/'
 
-        stability
         :stability: experimental
         """
         result = self._values.get("origin_path")
