@@ -28,9 +28,8 @@ class ApplicationScalingAction(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_cloudwatch_actions.ApplicationScalingAction",
 ):
-    """Use an ApplicationAutoScaling StepScalingAction as an Alarm Action.
+    """(experimental) Use an ApplicationAutoScaling StepScalingAction as an Alarm Action.
 
-    stability
     :stability: experimental
     """
 
@@ -38,7 +37,6 @@ class ApplicationScalingAction(
         """
         :param step_scaling_action: -
 
-        stability
         :stability: experimental
         """
         jsii.create(ApplicationScalingAction, self, [step_scaling_action])
@@ -49,12 +47,11 @@ class ApplicationScalingAction(
         _scope: _Construct_f50a3f53,
         _alarm: _IAlarm_478ec33c,
     ) -> _AlarmActionConfig_280e5eed:
-        """Returns an alarm action configuration to use an ApplicationScaling StepScalingAction as an alarm action.
+        """(experimental) Returns an alarm action configuration to use an ApplicationScaling StepScalingAction as an alarm action.
 
         :param _scope: -
         :param _alarm: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_scope, _alarm])
@@ -65,9 +62,8 @@ class AutoScalingAction(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_cloudwatch_actions.AutoScalingAction",
 ):
-    """Use an AutoScaling StepScalingAction as an Alarm Action.
+    """(experimental) Use an AutoScaling StepScalingAction as an Alarm Action.
 
-    stability
     :stability: experimental
     """
 
@@ -75,7 +71,6 @@ class AutoScalingAction(
         """
         :param step_scaling_action: -
 
-        stability
         :stability: experimental
         """
         jsii.create(AutoScalingAction, self, [step_scaling_action])
@@ -86,12 +81,11 @@ class AutoScalingAction(
         _scope: _Construct_f50a3f53,
         _alarm: _IAlarm_478ec33c,
     ) -> _AlarmActionConfig_280e5eed:
-        """Returns an alarm action configuration to use an AutoScaling StepScalingAction as an alarm action.
+        """(experimental) Returns an alarm action configuration to use an AutoScaling StepScalingAction as an alarm action.
 
         :param _scope: -
         :param _alarm: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_scope, _alarm])
@@ -102,9 +96,8 @@ class SnsAction(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_cloudwatch_actions.SnsAction",
 ):
-    """Use an SNS topic as an alarm action.
+    """(experimental) Use an SNS topic as an alarm action.
 
-    stability
     :stability: experimental
     """
 
@@ -112,7 +105,6 @@ class SnsAction(
         """
         :param topic: -
 
-        stability
         :stability: experimental
         """
         jsii.create(SnsAction, self, [topic])
@@ -123,12 +115,11 @@ class SnsAction(
         _scope: _Construct_f50a3f53,
         _alarm: _IAlarm_478ec33c,
     ) -> _AlarmActionConfig_280e5eed:
-        """Returns an alarm action configuration to use an SNS topic as an alarm action.
+        """(experimental) Returns an alarm action configuration to use an SNS topic as an alarm action.
 
         :param _scope: -
         :param _alarm: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_scope, _alarm])
