@@ -33,10 +33,8 @@ class CfnProfilingGroup(
 ):
     """A CloudFormation ``AWS::CodeGuruProfiler::ProfilingGroup``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::CodeGuruProfiler::ProfilingGroup
+    :cloudformationResource: AWS::CodeGuruProfiler::ProfilingGroup
     """
 
     def __init__(
@@ -46,7 +44,7 @@ class CfnProfilingGroup(
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -72,11 +70,10 @@ class CfnProfilingGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -101,8 +98,7 @@ class CfnProfilingGroup(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -116,7 +112,6 @@ class CfnProfilingGroup(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::CodeGuruProfiler::ProfilingGroup.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-tags
         """
         return jsii.get(self, "tags")
@@ -126,7 +121,6 @@ class CfnProfilingGroup(
     def agent_permissions(self) -> typing.Any:
         """``AWS::CodeGuruProfiler::ProfilingGroup.AgentPermissions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-agentpermissions
         """
         return jsii.get(self, "agentPermissions")
@@ -140,7 +134,6 @@ class CfnProfilingGroup(
     def profiling_group_name(self) -> builtins.str:
         """``AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-profilinggroupname
         """
         return jsii.get(self, "profilingGroupName")
@@ -153,10 +146,9 @@ class CfnProfilingGroup(
     @jsii.member(jsii_name="anomalyDetectionNotificationConfiguration")
     def anomaly_detection_notification_configuration(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
         """
         return jsii.get(self, "anomalyDetectionNotificationConfiguration")
@@ -164,7 +156,7 @@ class CfnProfilingGroup(
     @anomaly_detection_notification_configuration.setter # type: ignore
     def anomaly_detection_notification_configuration(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
 
@@ -173,7 +165,6 @@ class CfnProfilingGroup(
     def compute_platform(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-computeplatform
         """
         return jsii.get(self, "computePlatform")
@@ -198,7 +189,6 @@ class CfnProfilingGroup(
             :param channel_uri: ``CfnProfilingGroup.ChannelProperty.channelUri``.
             :param channel_id: ``CfnProfilingGroup.ChannelProperty.channelId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -211,7 +201,6 @@ class CfnProfilingGroup(
         def channel_uri(self) -> builtins.str:
             """``CfnProfilingGroup.ChannelProperty.channelUri``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html#cfn-codeguruprofiler-profilinggroup-channel-channeluri
             """
             result = self._values.get("channel_uri")
@@ -222,7 +211,6 @@ class CfnProfilingGroup(
         def channel_id(self) -> typing.Optional[builtins.str]:
             """``CfnProfilingGroup.ChannelProperty.channelId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html#cfn-codeguruprofiler-profilinggroup-channel-channelid
             """
             result = self._values.get("channel_id")
@@ -257,7 +245,7 @@ class CfnProfilingGroupProps:
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnProfilingGroup.ChannelProperty, _IResolvable_9ceae33e]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -269,7 +257,6 @@ class CfnProfilingGroupProps:
         :param compute_platform: ``AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform``.
         :param tags: ``AWS::CodeGuruProfiler::ProfilingGroup.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -288,7 +275,6 @@ class CfnProfilingGroupProps:
     def profiling_group_name(self) -> builtins.str:
         """``AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-profilinggroupname
         """
         result = self._values.get("profiling_group_name")
@@ -299,7 +285,6 @@ class CfnProfilingGroupProps:
     def agent_permissions(self) -> typing.Any:
         """``AWS::CodeGuruProfiler::ProfilingGroup.AgentPermissions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-agentpermissions
         """
         result = self._values.get("agent_permissions")
@@ -308,10 +293,9 @@ class CfnProfilingGroupProps:
     @builtins.property
     def anomaly_detection_notification_configuration(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnProfilingGroup.ChannelProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
         """
         result = self._values.get("anomaly_detection_notification_configuration")
@@ -321,7 +305,6 @@ class CfnProfilingGroupProps:
     def compute_platform(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-computeplatform
         """
         result = self._values.get("compute_platform")
@@ -331,7 +314,6 @@ class CfnProfilingGroupProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-tags
         """
         result = self._values.get("tags")
@@ -351,31 +333,27 @@ class CfnProfilingGroupProps:
 
 @jsii.enum(jsii_type="monocdk-experiment.aws_codeguruprofiler.ComputePlatform")
 class ComputePlatform(enum.Enum):
-    """The compute platform of the profiling group.
+    """(experimental) The compute platform of the profiling group.
 
-    stability
     :stability: experimental
     """
 
     AWS_LAMBDA = "AWS_LAMBDA"
-    """Use AWS_LAMBDA if your application runs on AWS Lambda.
+    """(experimental) Use AWS_LAMBDA if your application runs on AWS Lambda.
 
-    stability
     :stability: experimental
     """
     DEFAULT = "DEFAULT"
-    """Use Default if your application runs on a compute platform that is not AWS Lambda, such an Amazon EC2 instance, an on-premises server, or a different platform.
+    """(experimental) Use Default if your application runs on a compute platform that is not AWS Lambda, such an Amazon EC2 instance, an on-premises server, or a different platform.
 
-    stability
     :stability: experimental
     """
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_codeguruprofiler.IProfilingGroup")
 class IProfilingGroup(_IResource_72f7ee7e, typing_extensions.Protocol):
-    """IResource represents a Profiling Group.
+    """(experimental) IResource represents a Profiling Group.
 
-    stability
     :stability: experimental
     """
 
@@ -386,18 +364,16 @@ class IProfilingGroup(_IResource_72f7ee7e, typing_extensions.Protocol):
     @builtins.property # type: ignore
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
-        """A name for the profiling group.
+        """(experimental) A name for the profiling group.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         ...
 
     @jsii.member(jsii_name="grantPublish")
     def grant_publish(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant access to publish profiling information to the Profiling Group to the given identity.
+        """(experimental) Grant access to publish profiling information to the Profiling Group to the given identity.
 
         This will grant the following permissions:
 
@@ -406,14 +382,13 @@ class IProfilingGroup(_IResource_72f7ee7e, typing_extensions.Protocol):
 
         :param grantee: Principal to grant publish rights to.
 
-        stability
         :stability: experimental
         """
         ...
 
     @jsii.member(jsii_name="grantRead")
     def grant_read(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant access to read profiling information from the Profiling Group to the given identity.
+        """(experimental) Grant access to read profiling information from the Profiling Group to the given identity.
 
         This will grant the following permissions:
 
@@ -422,7 +397,6 @@ class IProfilingGroup(_IResource_72f7ee7e, typing_extensions.Protocol):
 
         :param grantee: Principal to grant read rights to.
 
-        stability
         :stability: experimental
         """
         ...
@@ -431,9 +405,8 @@ class IProfilingGroup(_IResource_72f7ee7e, typing_extensions.Protocol):
 class _IProfilingGroupProxy(
     jsii.proxy_for(_IResource_72f7ee7e) # type: ignore
 ):
-    """IResource represents a Profiling Group.
+    """(experimental) IResource represents a Profiling Group.
 
-    stability
     :stability: experimental
     """
 
@@ -442,18 +415,16 @@ class _IProfilingGroupProxy(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
-        """A name for the profiling group.
+        """(experimental) A name for the profiling group.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         return jsii.get(self, "profilingGroupName")
 
     @jsii.member(jsii_name="grantPublish")
     def grant_publish(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant access to publish profiling information to the Profiling Group to the given identity.
+        """(experimental) Grant access to publish profiling information to the Profiling Group to the given identity.
 
         This will grant the following permissions:
 
@@ -462,14 +433,13 @@ class _IProfilingGroupProxy(
 
         :param grantee: Principal to grant publish rights to.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantPublish", [grantee])
 
     @jsii.member(jsii_name="grantRead")
     def grant_read(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant access to read profiling information from the Profiling Group to the given identity.
+        """(experimental) Grant access to read profiling information from the Profiling Group to the given identity.
 
         This will grant the following permissions:
 
@@ -478,7 +448,6 @@ class _IProfilingGroupProxy(
 
         :param grantee: Principal to grant read rights to.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantRead", [grantee])
@@ -490,9 +459,8 @@ class ProfilingGroup(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_codeguruprofiler.ProfilingGroup",
 ):
-    """A new Profiling Group.
+    """(experimental) A new Profiling Group.
 
-    stability
     :stability: experimental
     """
 
@@ -501,16 +469,15 @@ class ProfilingGroup(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        compute_platform: typing.Optional["ComputePlatform"] = None,
+        compute_platform: typing.Optional[ComputePlatform] = None,
         profiling_group_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param scope: -
         :param id: -
-        :param compute_platform: The compute platform of the profiling group. Default: ComputePlatform.DEFAULT
-        :param profiling_group_name: A name for the profiling group. Default: - automatically generated name.
+        :param compute_platform: (experimental) The compute platform of the profiling group. Default: ComputePlatform.DEFAULT
+        :param profiling_group_name: (experimental) A name for the profiling group. Default: - automatically generated name.
 
-        stability
         :stability: experimental
         """
         props = ProfilingGroupProps(
@@ -527,14 +494,13 @@ class ProfilingGroup(
         scope: constructs.Construct,
         id: builtins.str,
         profiling_group_arn: builtins.str,
-    ) -> "IProfilingGroup":
-        """Import an existing Profiling Group provided an ARN.
+    ) -> IProfilingGroup:
+        """(experimental) Import an existing Profiling Group provided an ARN.
 
         :param scope: The parent creating construct.
         :param id: The construct's name.
         :param profiling_group_arn: Profiling Group ARN.
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "fromProfilingGroupArn", [scope, id, profiling_group_arn])
@@ -546,21 +512,20 @@ class ProfilingGroup(
         scope: constructs.Construct,
         id: builtins.str,
         profiling_group_name: builtins.str,
-    ) -> "IProfilingGroup":
-        """Import an existing Profiling Group provided a Profiling Group Name.
+    ) -> IProfilingGroup:
+        """(experimental) Import an existing Profiling Group provided a Profiling Group Name.
 
         :param scope: The parent creating construct.
         :param id: The construct's name.
         :param profiling_group_name: Profiling Group Name.
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "fromProfilingGroupName", [scope, id, profiling_group_name])
 
     @jsii.member(jsii_name="grantPublish")
     def grant_publish(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant access to publish profiling information to the Profiling Group to the given identity.
+        """(experimental) Grant access to publish profiling information to the Profiling Group to the given identity.
 
         This will grant the following permissions:
 
@@ -569,14 +534,13 @@ class ProfilingGroup(
 
         :param grantee: Principal to grant publish rights to.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantPublish", [grantee])
 
     @jsii.member(jsii_name="grantRead")
     def grant_read(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant access to read profiling information from the Profiling Group to the given identity.
+        """(experimental) Grant access to read profiling information from the Profiling Group to the given identity.
 
         This will grant the following permissions:
 
@@ -585,7 +549,6 @@ class ProfilingGroup(
 
         :param grantee: Principal to grant read rights to.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantRead", [grantee])
@@ -593,24 +556,20 @@ class ProfilingGroup(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="profilingGroupArn")
     def profiling_group_arn(self) -> builtins.str:
-        """The ARN of the Profiling Group.
+        """(experimental) The ARN of the Profiling Group.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         return jsii.get(self, "profilingGroupArn")
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
-        """The name of the Profiling Group.
+        """(experimental) The name of the Profiling Group.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         return jsii.get(self, "profilingGroupName")
 
@@ -627,15 +586,14 @@ class ProfilingGroupProps:
     def __init__(
         self,
         *,
-        compute_platform: typing.Optional["ComputePlatform"] = None,
+        compute_platform: typing.Optional[ComputePlatform] = None,
         profiling_group_name: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Properties for creating a new Profiling Group.
+        """(experimental) Properties for creating a new Profiling Group.
 
-        :param compute_platform: The compute platform of the profiling group. Default: ComputePlatform.DEFAULT
-        :param profiling_group_name: A name for the profiling group. Default: - automatically generated name.
+        :param compute_platform: (experimental) The compute platform of the profiling group. Default: ComputePlatform.DEFAULT
+        :param profiling_group_name: (experimental) A name for the profiling group. Default: - automatically generated name.
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -645,13 +603,11 @@ class ProfilingGroupProps:
             self._values["profiling_group_name"] = profiling_group_name
 
     @builtins.property
-    def compute_platform(self) -> typing.Optional["ComputePlatform"]:
-        """The compute platform of the profiling group.
+    def compute_platform(self) -> typing.Optional[ComputePlatform]:
+        """(experimental) The compute platform of the profiling group.
 
-        default
         :default: ComputePlatform.DEFAULT
 
-        stability
         :stability: experimental
         """
         result = self._values.get("compute_platform")
@@ -659,12 +615,10 @@ class ProfilingGroupProps:
 
     @builtins.property
     def profiling_group_name(self) -> typing.Optional[builtins.str]:
-        """A name for the profiling group.
+        """(experimental) A name for the profiling group.
 
-        default
         :default: - automatically generated name.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("profiling_group_name")
