@@ -32,10 +32,8 @@ class CfnGitHubRepository(
 ):
     """A CloudFormation ``AWS::CodeStar::GitHubRepository``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::CodeStar::GitHubRepository
+    :cloudformationResource: AWS::CodeStar::GitHubRepository
     """
 
     def __init__(
@@ -46,7 +44,7 @@ class CfnGitHubRepository(
         repository_access_token: builtins.str,
         repository_name: builtins.str,
         repository_owner: builtins.str,
-        code: typing.Optional[typing.Union["CodeProperty", _IResolvable_9ceae33e]] = None,
+        code: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]] = None,
         enable_issues: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         is_private: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         repository_description: typing.Optional[builtins.str] = None,
@@ -77,11 +75,10 @@ class CfnGitHubRepository(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -112,7 +109,6 @@ class CfnGitHubRepository(
     def repository_access_token(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryAccessToken``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositoryaccesstoken
         """
         return jsii.get(self, "repositoryAccessToken")
@@ -126,7 +122,6 @@ class CfnGitHubRepository(
     def repository_name(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositoryname
         """
         return jsii.get(self, "repositoryName")
@@ -140,7 +135,6 @@ class CfnGitHubRepository(
     def repository_owner(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryOwner``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositoryowner
         """
         return jsii.get(self, "repositoryOwner")
@@ -153,10 +147,9 @@ class CfnGitHubRepository(
     @jsii.member(jsii_name="code")
     def code(
         self,
-    ) -> typing.Optional[typing.Union["CodeProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.Code``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-code
         """
         return jsii.get(self, "code")
@@ -164,7 +157,7 @@ class CfnGitHubRepository(
     @code.setter # type: ignore
     def code(
         self,
-        value: typing.Optional[typing.Union["CodeProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "code", value)
 
@@ -175,7 +168,6 @@ class CfnGitHubRepository(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.EnableIssues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-enableissues
         """
         return jsii.get(self, "enableIssues")
@@ -194,7 +186,6 @@ class CfnGitHubRepository(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.IsPrivate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-isprivate
         """
         return jsii.get(self, "isPrivate")
@@ -211,7 +202,6 @@ class CfnGitHubRepository(
     def repository_description(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStar::GitHubRepository.RepositoryDescription``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositorydescription
         """
         return jsii.get(self, "repositoryDescription")
@@ -234,7 +224,6 @@ class CfnGitHubRepository(
             """
             :param s3: ``CfnGitHubRepository.CodeProperty.S3``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-code.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -247,7 +236,6 @@ class CfnGitHubRepository(
         ) -> typing.Union["CfnGitHubRepository.S3Property", _IResolvable_9ceae33e]:
             """``CfnGitHubRepository.CodeProperty.S3``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-code.html#cfn-codestar-githubrepository-code-s3
             """
             result = self._values.get("s3")
@@ -287,7 +275,6 @@ class CfnGitHubRepository(
             :param key: ``CfnGitHubRepository.S3Property.Key``.
             :param object_version: ``CfnGitHubRepository.S3Property.ObjectVersion``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-s3.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -301,7 +288,6 @@ class CfnGitHubRepository(
         def bucket(self) -> builtins.str:
             """``CfnGitHubRepository.S3Property.Bucket``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-s3.html#cfn-codestar-githubrepository-s3-bucket
             """
             result = self._values.get("bucket")
@@ -312,7 +298,6 @@ class CfnGitHubRepository(
         def key(self) -> builtins.str:
             """``CfnGitHubRepository.S3Property.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-s3.html#cfn-codestar-githubrepository-s3-key
             """
             result = self._values.get("key")
@@ -323,7 +308,6 @@ class CfnGitHubRepository(
         def object_version(self) -> typing.Optional[builtins.str]:
             """``CfnGitHubRepository.S3Property.ObjectVersion``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-s3.html#cfn-codestar-githubrepository-s3-objectversion
             """
             result = self._values.get("object_version")
@@ -361,7 +345,7 @@ class CfnGitHubRepositoryProps:
         repository_access_token: builtins.str,
         repository_name: builtins.str,
         repository_owner: builtins.str,
-        code: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]] = None,
+        code: typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, _IResolvable_9ceae33e]] = None,
         enable_issues: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         is_private: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         repository_description: typing.Optional[builtins.str] = None,
@@ -376,7 +360,6 @@ class CfnGitHubRepositoryProps:
         :param is_private: ``AWS::CodeStar::GitHubRepository.IsPrivate``.
         :param repository_description: ``AWS::CodeStar::GitHubRepository.RepositoryDescription``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -397,7 +380,6 @@ class CfnGitHubRepositoryProps:
     def repository_access_token(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryAccessToken``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositoryaccesstoken
         """
         result = self._values.get("repository_access_token")
@@ -408,7 +390,6 @@ class CfnGitHubRepositoryProps:
     def repository_name(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositoryname
         """
         result = self._values.get("repository_name")
@@ -419,7 +400,6 @@ class CfnGitHubRepositoryProps:
     def repository_owner(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryOwner``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositoryowner
         """
         result = self._values.get("repository_owner")
@@ -429,10 +409,9 @@ class CfnGitHubRepositoryProps:
     @builtins.property
     def code(
         self,
-    ) -> typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.Code``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-code
         """
         result = self._values.get("code")
@@ -444,7 +423,6 @@ class CfnGitHubRepositoryProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.EnableIssues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-enableissues
         """
         result = self._values.get("enable_issues")
@@ -456,7 +434,6 @@ class CfnGitHubRepositoryProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.IsPrivate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-isprivate
         """
         result = self._values.get("is_private")
@@ -466,7 +443,6 @@ class CfnGitHubRepositoryProps:
     def repository_description(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStar::GitHubRepository.RepositoryDescription``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositorydescription
         """
         result = self._values.get("repository_description")
@@ -513,19 +489,18 @@ class GitHubRepositoryProps:
         enable_issues: typing.Optional[builtins.bool] = None,
         visibility: typing.Optional["RepositoryVisibility"] = None,
     ) -> None:
-        """Construction properties of {@link GitHubRepository}.
+        """(experimental) Construction properties of {@link GitHubRepository}.
 
-        :param access_token: The GitHub user's personal access token for the GitHub repository.
-        :param contents_bucket: The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
-        :param contents_key: The S3 object key or file name for the ZIP file.
-        :param owner: The GitHub user name for the owner of the GitHub repository to be created. If this repository should be owned by a GitHub organization, provide its name
-        :param repository_name: The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
-        :param contents_s3_version: The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket. Default: - not specified
-        :param description: A comment or description about the new repository. This description is displayed in GitHub after the repository is created. Default: - no description
-        :param enable_issues: Indicates whether to enable issues for the GitHub repository. You can use GitHub issues to track information and bugs for your repository. Default: true
-        :param visibility: Indicates whether the GitHub repository is a private repository. If so, you choose who can see and commit to this repository. Default: RepositoryVisibility.PUBLIC
+        :param access_token: (experimental) The GitHub user's personal access token for the GitHub repository.
+        :param contents_bucket: (experimental) The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
+        :param contents_key: (experimental) The S3 object key or file name for the ZIP file.
+        :param owner: (experimental) The GitHub user name for the owner of the GitHub repository to be created. If this repository should be owned by a GitHub organization, provide its name
+        :param repository_name: (experimental) The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
+        :param contents_s3_version: (experimental) The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket. Default: - not specified
+        :param description: (experimental) A comment or description about the new repository. This description is displayed in GitHub after the repository is created. Default: - no description
+        :param enable_issues: (experimental) Indicates whether to enable issues for the GitHub repository. You can use GitHub issues to track information and bugs for your repository. Default: true
+        :param visibility: (experimental) Indicates whether the GitHub repository is a private repository. If so, you choose who can see and commit to this repository. Default: RepositoryVisibility.PUBLIC
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -546,9 +521,8 @@ class GitHubRepositoryProps:
 
     @builtins.property
     def access_token(self) -> _SecretValue_99478b8b:
-        """The GitHub user's personal access token for the GitHub repository.
+        """(experimental) The GitHub user's personal access token for the GitHub repository.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("access_token")
@@ -557,9 +531,8 @@ class GitHubRepositoryProps:
 
     @builtins.property
     def contents_bucket(self) -> _IBucket_25bad983:
-        """The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
+        """(experimental) The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("contents_bucket")
@@ -568,9 +541,8 @@ class GitHubRepositoryProps:
 
     @builtins.property
     def contents_key(self) -> builtins.str:
-        """The S3 object key or file name for the ZIP file.
+        """(experimental) The S3 object key or file name for the ZIP file.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("contents_key")
@@ -579,12 +551,11 @@ class GitHubRepositoryProps:
 
     @builtins.property
     def owner(self) -> builtins.str:
-        """The GitHub user name for the owner of the GitHub repository to be created.
+        """(experimental) The GitHub user name for the owner of the GitHub repository to be created.
 
         If this
         repository should be owned by a GitHub organization, provide its name
 
-        stability
         :stability: experimental
         """
         result = self._values.get("owner")
@@ -593,9 +564,8 @@ class GitHubRepositoryProps:
 
     @builtins.property
     def repository_name(self) -> builtins.str:
-        """The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
+        """(experimental) The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("repository_name")
@@ -604,12 +574,10 @@ class GitHubRepositoryProps:
 
     @builtins.property
     def contents_s3_version(self) -> typing.Optional[builtins.str]:
-        """The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket.
+        """(experimental) The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket.
 
-        default
         :default: - not specified
 
-        stability
         :stability: experimental
         """
         result = self._values.get("contents_s3_version")
@@ -617,15 +585,13 @@ class GitHubRepositoryProps:
 
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
-        """A comment or description about the new repository.
+        """(experimental) A comment or description about the new repository.
 
         This description is displayed in GitHub after the repository
         is created.
 
-        default
         :default: - no description
 
-        stability
         :stability: experimental
         """
         result = self._values.get("description")
@@ -633,15 +599,13 @@ class GitHubRepositoryProps:
 
     @builtins.property
     def enable_issues(self) -> typing.Optional[builtins.bool]:
-        """Indicates whether to enable issues for the GitHub repository.
+        """(experimental) Indicates whether to enable issues for the GitHub repository.
 
         You can use GitHub issues to track information
         and bugs for your repository.
 
-        default
         :default: true
 
-        stability
         :stability: experimental
         """
         result = self._values.get("enable_issues")
@@ -649,15 +613,13 @@ class GitHubRepositoryProps:
 
     @builtins.property
     def visibility(self) -> typing.Optional["RepositoryVisibility"]:
-        """Indicates whether the GitHub repository is a private repository.
+        """(experimental) Indicates whether the GitHub repository is a private repository.
 
         If so, you choose who can see and commit to
         this repository.
 
-        default
         :default: RepositoryVisibility.PUBLIC
 
-        stability
         :stability: experimental
         """
         result = self._values.get("visibility")
@@ -677,9 +639,8 @@ class GitHubRepositoryProps:
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_codestar.IGitHubRepository")
 class IGitHubRepository(_IResource_72f7ee7e, typing_extensions.Protocol):
-    """GitHubRepository resource interface.
+    """(experimental) GitHubRepository resource interface.
 
-    stability
     :stability: experimental
     """
 
@@ -690,9 +651,8 @@ class IGitHubRepository(_IResource_72f7ee7e, typing_extensions.Protocol):
     @builtins.property # type: ignore
     @jsii.member(jsii_name="owner")
     def owner(self) -> builtins.str:
-        """the repository owner.
+        """(experimental) the repository owner.
 
-        stability
         :stability: experimental
         """
         ...
@@ -700,9 +660,8 @@ class IGitHubRepository(_IResource_72f7ee7e, typing_extensions.Protocol):
     @builtins.property # type: ignore
     @jsii.member(jsii_name="repo")
     def repo(self) -> builtins.str:
-        """the repository name.
+        """(experimental) the repository name.
 
-        stability
         :stability: experimental
         """
         ...
@@ -711,9 +670,8 @@ class IGitHubRepository(_IResource_72f7ee7e, typing_extensions.Protocol):
 class _IGitHubRepositoryProxy(
     jsii.proxy_for(_IResource_72f7ee7e) # type: ignore
 ):
-    """GitHubRepository resource interface.
+    """(experimental) GitHubRepository resource interface.
 
-    stability
     :stability: experimental
     """
 
@@ -722,9 +680,8 @@ class _IGitHubRepositoryProxy(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="owner")
     def owner(self) -> builtins.str:
-        """the repository owner.
+        """(experimental) the repository owner.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "owner")
@@ -732,9 +689,8 @@ class _IGitHubRepositoryProxy(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="repo")
     def repo(self) -> builtins.str:
-        """the repository name.
+        """(experimental) the repository name.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "repo")
@@ -742,22 +698,19 @@ class _IGitHubRepositoryProxy(
 
 @jsii.enum(jsii_type="monocdk-experiment.aws_codestar.RepositoryVisibility")
 class RepositoryVisibility(enum.Enum):
-    """Visibility of the GitHubRepository.
+    """(experimental) Visibility of the GitHubRepository.
 
-    stability
     :stability: experimental
     """
 
     PRIVATE = "PRIVATE"
-    """private repository.
+    """(experimental) private repository.
 
-    stability
     :stability: experimental
     """
     PUBLIC = "PUBLIC"
-    """public repository.
+    """(experimental) public repository.
 
-    stability
     :stability: experimental
     """
 
@@ -768,9 +721,8 @@ class GitHubRepository(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_codestar.GitHubRepository",
 ):
-    """The GitHubRepository resource.
+    """(experimental) The GitHubRepository resource.
 
-    stability
     :stability: experimental
     """
 
@@ -787,22 +739,21 @@ class GitHubRepository(
         contents_s3_version: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         enable_issues: typing.Optional[builtins.bool] = None,
-        visibility: typing.Optional["RepositoryVisibility"] = None,
+        visibility: typing.Optional[RepositoryVisibility] = None,
     ) -> None:
         """
         :param scope: -
         :param id: -
-        :param access_token: The GitHub user's personal access token for the GitHub repository.
-        :param contents_bucket: The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
-        :param contents_key: The S3 object key or file name for the ZIP file.
-        :param owner: The GitHub user name for the owner of the GitHub repository to be created. If this repository should be owned by a GitHub organization, provide its name
-        :param repository_name: The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
-        :param contents_s3_version: The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket. Default: - not specified
-        :param description: A comment or description about the new repository. This description is displayed in GitHub after the repository is created. Default: - no description
-        :param enable_issues: Indicates whether to enable issues for the GitHub repository. You can use GitHub issues to track information and bugs for your repository. Default: true
-        :param visibility: Indicates whether the GitHub repository is a private repository. If so, you choose who can see and commit to this repository. Default: RepositoryVisibility.PUBLIC
+        :param access_token: (experimental) The GitHub user's personal access token for the GitHub repository.
+        :param contents_bucket: (experimental) The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
+        :param contents_key: (experimental) The S3 object key or file name for the ZIP file.
+        :param owner: (experimental) The GitHub user name for the owner of the GitHub repository to be created. If this repository should be owned by a GitHub organization, provide its name
+        :param repository_name: (experimental) The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
+        :param contents_s3_version: (experimental) The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket. Default: - not specified
+        :param description: (experimental) A comment or description about the new repository. This description is displayed in GitHub after the repository is created. Default: - no description
+        :param enable_issues: (experimental) Indicates whether to enable issues for the GitHub repository. You can use GitHub issues to track information and bugs for your repository. Default: true
+        :param visibility: (experimental) Indicates whether the GitHub repository is a private repository. If so, you choose who can see and commit to this repository. Default: RepositoryVisibility.PUBLIC
 
-        stability
         :stability: experimental
         """
         props = GitHubRepositoryProps(
@@ -822,9 +773,8 @@ class GitHubRepository(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="owner")
     def owner(self) -> builtins.str:
-        """the repository owner.
+        """(experimental) the repository owner.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "owner")
@@ -832,9 +782,8 @@ class GitHubRepository(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="repo")
     def repo(self) -> builtins.str:
-        """the repository name.
+        """(experimental) the repository name.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "repo")
