@@ -27,10 +27,8 @@ class CfnPipeline(
 ):
     """A CloudFormation ``AWS::DataPipeline::Pipeline``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DataPipeline::Pipeline
+    :cloudformationResource: AWS::DataPipeline::Pipeline
     """
 
     def __init__(
@@ -39,12 +37,12 @@ class CfnPipeline(
         id: builtins.str,
         *,
         name: builtins.str,
-        parameter_objects: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterObjectProperty", _IResolvable_9ceae33e]]],
+        parameter_objects: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", _IResolvable_9ceae33e]]],
         activate: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         description: typing.Optional[builtins.str] = None,
-        parameter_values: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterValueProperty", _IResolvable_9ceae33e]]]] = None,
-        pipeline_objects: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineObjectProperty", _IResolvable_9ceae33e]]]] = None,
-        pipeline_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineTagProperty", _IResolvable_9ceae33e]]]] = None,
+        parameter_values: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterValueProperty", _IResolvable_9ceae33e]]]] = None,
+        pipeline_objects: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineObjectProperty", _IResolvable_9ceae33e]]]] = None,
+        pipeline_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineTagProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::DataPipeline::Pipeline``.
 
@@ -72,11 +70,10 @@ class CfnPipeline(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -107,7 +104,6 @@ class CfnPipeline(
     def name(self) -> builtins.str:
         """``AWS::DataPipeline::Pipeline.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
         """
         return jsii.get(self, "name")
@@ -120,10 +116,9 @@ class CfnPipeline(
     @jsii.member(jsii_name="parameterObjects")
     def parameter_objects(
         self,
-    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterObjectProperty", _IResolvable_9ceae33e]]]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", _IResolvable_9ceae33e]]]:
         """``AWS::DataPipeline::Pipeline.ParameterObjects``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
         """
         return jsii.get(self, "parameterObjects")
@@ -131,7 +126,7 @@ class CfnPipeline(
     @parameter_objects.setter # type: ignore
     def parameter_objects(
         self,
-        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterObjectProperty", _IResolvable_9ceae33e]]],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "parameterObjects", value)
 
@@ -142,7 +137,6 @@ class CfnPipeline(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
         """
         return jsii.get(self, "activate")
@@ -159,7 +153,6 @@ class CfnPipeline(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DataPipeline::Pipeline.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
         """
         return jsii.get(self, "description")
@@ -172,10 +165,9 @@ class CfnPipeline(
     @jsii.member(jsii_name="parameterValues")
     def parameter_values(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterValueProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterValueProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::DataPipeline::Pipeline.ParameterValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
         """
         return jsii.get(self, "parameterValues")
@@ -183,7 +175,7 @@ class CfnPipeline(
     @parameter_values.setter # type: ignore
     def parameter_values(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ParameterValueProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterValueProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "parameterValues", value)
 
@@ -191,10 +183,9 @@ class CfnPipeline(
     @jsii.member(jsii_name="pipelineObjects")
     def pipeline_objects(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineObjectProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineObjectProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
         """
         return jsii.get(self, "pipelineObjects")
@@ -202,7 +193,7 @@ class CfnPipeline(
     @pipeline_objects.setter # type: ignore
     def pipeline_objects(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineObjectProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineObjectProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "pipelineObjects", value)
 
@@ -210,10 +201,9 @@ class CfnPipeline(
     @jsii.member(jsii_name="pipelineTags")
     def pipeline_tags(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineTagProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineTagProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
         """
         return jsii.get(self, "pipelineTags")
@@ -221,7 +211,7 @@ class CfnPipeline(
     @pipeline_tags.setter # type: ignore
     def pipeline_tags(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PipelineTagProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineTagProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "pipelineTags", value)
 
@@ -247,7 +237,6 @@ class CfnPipeline(
             :param ref_value: ``CfnPipeline.FieldProperty.RefValue``.
             :param string_value: ``CfnPipeline.FieldProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -262,7 +251,6 @@ class CfnPipeline(
         def key(self) -> builtins.str:
             """``CfnPipeline.FieldProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-key
             """
             result = self._values.get("key")
@@ -273,7 +261,6 @@ class CfnPipeline(
         def ref_value(self) -> typing.Optional[builtins.str]:
             """``CfnPipeline.FieldProperty.RefValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-refvalue
             """
             result = self._values.get("ref_value")
@@ -283,7 +270,6 @@ class CfnPipeline(
         def string_value(self) -> typing.Optional[builtins.str]:
             """``CfnPipeline.FieldProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-stringvalue
             """
             result = self._values.get("string_value")
@@ -311,7 +297,6 @@ class CfnPipeline(
             :param key: ``CfnPipeline.ParameterAttributeProperty.Key``.
             :param string_value: ``CfnPipeline.ParameterAttributeProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -323,7 +308,6 @@ class CfnPipeline(
         def key(self) -> builtins.str:
             """``CfnPipeline.ParameterAttributeProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-key
             """
             result = self._values.get("key")
@@ -334,7 +318,6 @@ class CfnPipeline(
         def string_value(self) -> builtins.str:
             """``CfnPipeline.ParameterAttributeProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-stringvalue
             """
             result = self._values.get("string_value")
@@ -368,7 +351,6 @@ class CfnPipeline(
             :param attributes: ``CfnPipeline.ParameterObjectProperty.Attributes``.
             :param id: ``CfnPipeline.ParameterObjectProperty.Id``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -382,7 +364,6 @@ class CfnPipeline(
         ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterAttributeProperty", _IResolvable_9ceae33e]]]:
             """``CfnPipeline.ParameterObjectProperty.Attributes``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-attributes
             """
             result = self._values.get("attributes")
@@ -393,7 +374,6 @@ class CfnPipeline(
         def id(self) -> builtins.str:
             """``CfnPipeline.ParameterObjectProperty.Id``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-id
             """
             result = self._values.get("id")
@@ -422,7 +402,6 @@ class CfnPipeline(
             :param id: ``CfnPipeline.ParameterValueProperty.Id``.
             :param string_value: ``CfnPipeline.ParameterValueProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -434,7 +413,6 @@ class CfnPipeline(
         def id(self) -> builtins.str:
             """``CfnPipeline.ParameterValueProperty.Id``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-id
             """
             result = self._values.get("id")
@@ -445,7 +423,6 @@ class CfnPipeline(
         def string_value(self) -> builtins.str:
             """``CfnPipeline.ParameterValueProperty.StringValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-stringvalue
             """
             result = self._values.get("string_value")
@@ -481,7 +458,6 @@ class CfnPipeline(
             :param id: ``CfnPipeline.PipelineObjectProperty.Id``.
             :param name: ``CfnPipeline.PipelineObjectProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -496,7 +472,6 @@ class CfnPipeline(
         ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.FieldProperty", _IResolvable_9ceae33e]]]:
             """``CfnPipeline.PipelineObjectProperty.Fields``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-fields
             """
             result = self._values.get("fields")
@@ -507,7 +482,6 @@ class CfnPipeline(
         def id(self) -> builtins.str:
             """``CfnPipeline.PipelineObjectProperty.Id``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-id
             """
             result = self._values.get("id")
@@ -518,7 +492,6 @@ class CfnPipeline(
         def name(self) -> builtins.str:
             """``CfnPipeline.PipelineObjectProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-name
             """
             result = self._values.get("name")
@@ -547,7 +520,6 @@ class CfnPipeline(
             :param key: ``CfnPipeline.PipelineTagProperty.Key``.
             :param value: ``CfnPipeline.PipelineTagProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -559,7 +531,6 @@ class CfnPipeline(
         def key(self) -> builtins.str:
             """``CfnPipeline.PipelineTagProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-key
             """
             result = self._values.get("key")
@@ -570,7 +541,6 @@ class CfnPipeline(
         def value(self) -> builtins.str:
             """``CfnPipeline.PipelineTagProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-value
             """
             result = self._values.get("value")
@@ -607,12 +577,12 @@ class CfnPipelineProps:
         self,
         *,
         name: builtins.str,
-        parameter_objects: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", _IResolvable_9ceae33e]]],
+        parameter_objects: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPipeline.ParameterObjectProperty, _IResolvable_9ceae33e]]],
         activate: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         description: typing.Optional[builtins.str] = None,
-        parameter_values: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterValueProperty", _IResolvable_9ceae33e]]]] = None,
-        pipeline_objects: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineObjectProperty", _IResolvable_9ceae33e]]]] = None,
-        pipeline_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineTagProperty", _IResolvable_9ceae33e]]]] = None,
+        parameter_values: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPipeline.ParameterValueProperty, _IResolvable_9ceae33e]]]] = None,
+        pipeline_objects: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPipeline.PipelineObjectProperty, _IResolvable_9ceae33e]]]] = None,
+        pipeline_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPipeline.PipelineTagProperty, _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::DataPipeline::Pipeline``.
 
@@ -624,7 +594,6 @@ class CfnPipelineProps:
         :param pipeline_objects: ``AWS::DataPipeline::Pipeline.PipelineObjects``.
         :param pipeline_tags: ``AWS::DataPipeline::Pipeline.PipelineTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -646,7 +615,6 @@ class CfnPipelineProps:
     def name(self) -> builtins.str:
         """``AWS::DataPipeline::Pipeline.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
         """
         result = self._values.get("name")
@@ -656,10 +624,9 @@ class CfnPipelineProps:
     @builtins.property
     def parameter_objects(
         self,
-    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", _IResolvable_9ceae33e]]]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPipeline.ParameterObjectProperty, _IResolvable_9ceae33e]]]:
         """``AWS::DataPipeline::Pipeline.ParameterObjects``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
         """
         result = self._values.get("parameter_objects")
@@ -672,7 +639,6 @@ class CfnPipelineProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
         """
         result = self._values.get("activate")
@@ -682,7 +648,6 @@ class CfnPipelineProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DataPipeline::Pipeline.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
         """
         result = self._values.get("description")
@@ -691,10 +656,9 @@ class CfnPipelineProps:
     @builtins.property
     def parameter_values(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.ParameterValueProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPipeline.ParameterValueProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::DataPipeline::Pipeline.ParameterValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
         """
         result = self._values.get("parameter_values")
@@ -703,10 +667,9 @@ class CfnPipelineProps:
     @builtins.property
     def pipeline_objects(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineObjectProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPipeline.PipelineObjectProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
         """
         result = self._values.get("pipeline_objects")
@@ -715,10 +678,9 @@ class CfnPipelineProps:
     @builtins.property
     def pipeline_tags(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPipeline.PipelineTagProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPipeline.PipelineTagProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
         """
         result = self._values.get("pipeline_tags")
