@@ -28,10 +28,8 @@ class CfnCluster(
 ):
     """A CloudFormation ``AWS::DAX::Cluster``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DAX::Cluster
+    :cloudformationResource: AWS::DAX::Cluster
     """
 
     def __init__(
@@ -49,7 +47,7 @@ class CfnCluster(
         parameter_group_name: typing.Optional[builtins.str] = None,
         preferred_maintenance_window: typing.Optional[builtins.str] = None,
         security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
-        sse_specification: typing.Optional[typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]] = None,
+        sse_specification: typing.Optional[typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -91,11 +89,10 @@ class CfnCluster(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -120,8 +117,7 @@ class CfnCluster(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -129,8 +125,7 @@ class CfnCluster(
     @jsii.member(jsii_name="attrClusterDiscoveryEndpoint")
     def attr_cluster_discovery_endpoint(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ClusterDiscoveryEndpoint
+        :cloudformationAttribute: ClusterDiscoveryEndpoint
         """
         return jsii.get(self, "attrClusterDiscoveryEndpoint")
 
@@ -144,7 +139,6 @@ class CfnCluster(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::DAX::Cluster.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-tags
         """
         return jsii.get(self, "tags")
@@ -154,7 +148,6 @@ class CfnCluster(
     def iam_role_arn(self) -> builtins.str:
         """``AWS::DAX::Cluster.IAMRoleARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
         """
         return jsii.get(self, "iamRoleArn")
@@ -168,7 +161,6 @@ class CfnCluster(
     def node_type(self) -> builtins.str:
         """``AWS::DAX::Cluster.NodeType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
         """
         return jsii.get(self, "nodeType")
@@ -182,7 +174,6 @@ class CfnCluster(
     def replication_factor(self) -> jsii.Number:
         """``AWS::DAX::Cluster.ReplicationFactor``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
         """
         return jsii.get(self, "replicationFactor")
@@ -196,7 +187,6 @@ class CfnCluster(
     def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.AvailabilityZones``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-availabilityzones
         """
         return jsii.get(self, "availabilityZones")
@@ -213,7 +203,6 @@ class CfnCluster(
     def cluster_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ClusterName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-clustername
         """
         return jsii.get(self, "clusterName")
@@ -227,7 +216,6 @@ class CfnCluster(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-description
         """
         return jsii.get(self, "description")
@@ -241,7 +229,6 @@ class CfnCluster(
     def notification_topic_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.NotificationTopicARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-notificationtopicarn
         """
         return jsii.get(self, "notificationTopicArn")
@@ -255,7 +242,6 @@ class CfnCluster(
     def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ParameterGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-parametergroupname
         """
         return jsii.get(self, "parameterGroupName")
@@ -269,7 +255,6 @@ class CfnCluster(
     def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.PreferredMaintenanceWindow``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-preferredmaintenancewindow
         """
         return jsii.get(self, "preferredMaintenanceWindow")
@@ -286,7 +271,6 @@ class CfnCluster(
     def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.SecurityGroupIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-securitygroupids
         """
         return jsii.get(self, "securityGroupIds")
@@ -302,10 +286,9 @@ class CfnCluster(
     @jsii.member(jsii_name="sseSpecification")
     def sse_specification(
         self,
-    ) -> typing.Optional[typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-ssespecification
         """
         return jsii.get(self, "sseSpecification")
@@ -313,7 +296,7 @@ class CfnCluster(
     @sse_specification.setter # type: ignore
     def sse_specification(
         self,
-        value: typing.Optional[typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "sseSpecification", value)
 
@@ -322,7 +305,6 @@ class CfnCluster(
     def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-subnetgroupname
         """
         return jsii.get(self, "subnetGroupName")
@@ -345,7 +327,6 @@ class CfnCluster(
             """
             :param sse_enabled: ``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dax-cluster-ssespecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -358,7 +339,6 @@ class CfnCluster(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dax-cluster-ssespecification.html#cfn-dax-cluster-ssespecification-sseenabled
             """
             result = self._values.get("sse_enabled")
@@ -409,7 +389,7 @@ class CfnClusterProps:
         parameter_group_name: typing.Optional[builtins.str] = None,
         preferred_maintenance_window: typing.Optional[builtins.str] = None,
         security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
-        sse_specification: typing.Optional[typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]] = None,
+        sse_specification: typing.Optional[typing.Union[CfnCluster.SSESpecificationProperty, _IResolvable_9ceae33e]] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -429,7 +409,6 @@ class CfnClusterProps:
         :param subnet_group_name: ``AWS::DAX::Cluster.SubnetGroupName``.
         :param tags: ``AWS::DAX::Cluster.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -462,7 +441,6 @@ class CfnClusterProps:
     def iam_role_arn(self) -> builtins.str:
         """``AWS::DAX::Cluster.IAMRoleARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
         """
         result = self._values.get("iam_role_arn")
@@ -473,7 +451,6 @@ class CfnClusterProps:
     def node_type(self) -> builtins.str:
         """``AWS::DAX::Cluster.NodeType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
         """
         result = self._values.get("node_type")
@@ -484,7 +461,6 @@ class CfnClusterProps:
     def replication_factor(self) -> jsii.Number:
         """``AWS::DAX::Cluster.ReplicationFactor``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
         """
         result = self._values.get("replication_factor")
@@ -495,7 +471,6 @@ class CfnClusterProps:
     def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.AvailabilityZones``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-availabilityzones
         """
         result = self._values.get("availability_zones")
@@ -505,7 +480,6 @@ class CfnClusterProps:
     def cluster_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ClusterName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-clustername
         """
         result = self._values.get("cluster_name")
@@ -515,7 +489,6 @@ class CfnClusterProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-description
         """
         result = self._values.get("description")
@@ -525,7 +498,6 @@ class CfnClusterProps:
     def notification_topic_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.NotificationTopicARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-notificationtopicarn
         """
         result = self._values.get("notification_topic_arn")
@@ -535,7 +507,6 @@ class CfnClusterProps:
     def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ParameterGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-parametergroupname
         """
         result = self._values.get("parameter_group_name")
@@ -545,7 +516,6 @@ class CfnClusterProps:
     def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.PreferredMaintenanceWindow``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-preferredmaintenancewindow
         """
         result = self._values.get("preferred_maintenance_window")
@@ -555,7 +525,6 @@ class CfnClusterProps:
     def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.SecurityGroupIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-securitygroupids
         """
         result = self._values.get("security_group_ids")
@@ -564,10 +533,9 @@ class CfnClusterProps:
     @builtins.property
     def sse_specification(
         self,
-    ) -> typing.Optional[typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnCluster.SSESpecificationProperty, _IResolvable_9ceae33e]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-ssespecification
         """
         result = self._values.get("sse_specification")
@@ -577,7 +545,6 @@ class CfnClusterProps:
     def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-subnetgroupname
         """
         result = self._values.get("subnet_group_name")
@@ -587,7 +554,6 @@ class CfnClusterProps:
     def tags(self) -> typing.Any:
         """``AWS::DAX::Cluster.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-tags
         """
         result = self._values.get("tags")
@@ -613,10 +579,8 @@ class CfnParameterGroup(
 ):
     """A CloudFormation ``AWS::DAX::ParameterGroup``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DAX::ParameterGroup
+    :cloudformationResource: AWS::DAX::ParameterGroup
     """
 
     def __init__(
@@ -646,11 +610,10 @@ class CfnParameterGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -681,7 +644,6 @@ class CfnParameterGroup(
     def parameter_name_values(self) -> typing.Any:
         """``AWS::DAX::ParameterGroup.ParameterNameValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parameternamevalues
         """
         return jsii.get(self, "parameterNameValues")
@@ -695,7 +657,6 @@ class CfnParameterGroup(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-description
         """
         return jsii.get(self, "description")
@@ -709,7 +670,6 @@ class CfnParameterGroup(
     def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.ParameterGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parametergroupname
         """
         return jsii.get(self, "parameterGroupName")
@@ -742,7 +702,6 @@ class CfnParameterGroupProps:
         :param parameter_group_name: ``AWS::DAX::ParameterGroup.ParameterGroupName``.
         :param parameter_name_values: ``AWS::DAX::ParameterGroup.ParameterNameValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -757,7 +716,6 @@ class CfnParameterGroupProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-description
         """
         result = self._values.get("description")
@@ -767,7 +725,6 @@ class CfnParameterGroupProps:
     def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.ParameterGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parametergroupname
         """
         result = self._values.get("parameter_group_name")
@@ -777,7 +734,6 @@ class CfnParameterGroupProps:
     def parameter_name_values(self) -> typing.Any:
         """``AWS::DAX::ParameterGroup.ParameterNameValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parameternamevalues
         """
         result = self._values.get("parameter_name_values")
@@ -803,10 +759,8 @@ class CfnSubnetGroup(
 ):
     """A CloudFormation ``AWS::DAX::SubnetGroup``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DAX::SubnetGroup
+    :cloudformationResource: AWS::DAX::SubnetGroup
     """
 
     def __init__(
@@ -836,11 +790,10 @@ class CfnSubnetGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -871,7 +824,6 @@ class CfnSubnetGroup(
     def subnet_ids(self) -> typing.List[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
         """
         return jsii.get(self, "subnetIds")
@@ -885,7 +837,6 @@ class CfnSubnetGroup(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-description
         """
         return jsii.get(self, "description")
@@ -899,7 +850,6 @@ class CfnSubnetGroup(
     def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetgroupname
         """
         return jsii.get(self, "subnetGroupName")
@@ -932,7 +882,6 @@ class CfnSubnetGroupProps:
         :param description: ``AWS::DAX::SubnetGroup.Description``.
         :param subnet_group_name: ``AWS::DAX::SubnetGroup.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -947,7 +896,6 @@ class CfnSubnetGroupProps:
     def subnet_ids(self) -> typing.List[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
         """
         result = self._values.get("subnet_ids")
@@ -958,7 +906,6 @@ class CfnSubnetGroupProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-description
         """
         result = self._values.get("description")
@@ -968,7 +915,6 @@ class CfnSubnetGroupProps:
     def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetgroupname
         """
         result = self._values.get("subnet_group_name")
