@@ -27,10 +27,8 @@ class CfnMicrosoftAD(
 ):
     """A CloudFormation ``AWS::DirectoryService::MicrosoftAD``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DirectoryService::MicrosoftAD
+    :cloudformationResource: AWS::DirectoryService::MicrosoftAD
     """
 
     def __init__(
@@ -40,7 +38,7 @@ class CfnMicrosoftAD(
         *,
         name: builtins.str,
         password: builtins.str,
-        vpc_settings: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e],
+        vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e],
         create_alias: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         edition: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
@@ -72,11 +70,10 @@ class CfnMicrosoftAD(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -101,8 +98,7 @@ class CfnMicrosoftAD(
     @jsii.member(jsii_name="attrAlias")
     def attr_alias(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Alias
+        :cloudformationAttribute: Alias
         """
         return jsii.get(self, "attrAlias")
 
@@ -110,8 +106,7 @@ class CfnMicrosoftAD(
     @jsii.member(jsii_name="attrDnsIpAddresses")
     def attr_dns_ip_addresses(self) -> typing.List[builtins.str]:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: DnsIpAddresses
+        :cloudformationAttribute: DnsIpAddresses
         """
         return jsii.get(self, "attrDnsIpAddresses")
 
@@ -125,7 +120,6 @@ class CfnMicrosoftAD(
     def name(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
         """
         return jsii.get(self, "name")
@@ -139,7 +133,6 @@ class CfnMicrosoftAD(
     def password(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Password``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
         """
         return jsii.get(self, "password")
@@ -152,10 +145,9 @@ class CfnMicrosoftAD(
     @jsii.member(jsii_name="vpcSettings")
     def vpc_settings(
         self,
-    ) -> typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e]:
         """``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
         """
         return jsii.get(self, "vpcSettings")
@@ -163,7 +155,7 @@ class CfnMicrosoftAD(
     @vpc_settings.setter # type: ignore
     def vpc_settings(
         self,
-        value: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "vpcSettings", value)
 
@@ -174,7 +166,6 @@ class CfnMicrosoftAD(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-createalias
         """
         return jsii.get(self, "createAlias")
@@ -191,7 +182,6 @@ class CfnMicrosoftAD(
     def edition(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.Edition``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-edition
         """
         return jsii.get(self, "edition")
@@ -207,7 +197,6 @@ class CfnMicrosoftAD(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-enablesso
         """
         return jsii.get(self, "enableSso")
@@ -224,7 +213,6 @@ class CfnMicrosoftAD(
     def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-shortname
         """
         return jsii.get(self, "shortName")
@@ -249,7 +237,6 @@ class CfnMicrosoftAD(
             :param subnet_ids: ``CfnMicrosoftAD.VpcSettingsProperty.SubnetIds``.
             :param vpc_id: ``CfnMicrosoftAD.VpcSettingsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -261,7 +248,6 @@ class CfnMicrosoftAD(
         def subnet_ids(self) -> typing.List[builtins.str]:
             """``CfnMicrosoftAD.VpcSettingsProperty.SubnetIds``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-subnetids
             """
             result = self._values.get("subnet_ids")
@@ -272,7 +258,6 @@ class CfnMicrosoftAD(
         def vpc_id(self) -> builtins.str:
             """``CfnMicrosoftAD.VpcSettingsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-vpcid
             """
             result = self._values.get("vpc_id")
@@ -310,7 +295,7 @@ class CfnMicrosoftADProps:
         *,
         name: builtins.str,
         password: builtins.str,
-        vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e],
+        vpc_settings: typing.Union[CfnMicrosoftAD.VpcSettingsProperty, _IResolvable_9ceae33e],
         create_alias: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         edition: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
@@ -326,7 +311,6 @@ class CfnMicrosoftADProps:
         :param enable_sso: ``AWS::DirectoryService::MicrosoftAD.EnableSso``.
         :param short_name: ``AWS::DirectoryService::MicrosoftAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -347,7 +331,6 @@ class CfnMicrosoftADProps:
     def name(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
         """
         result = self._values.get("name")
@@ -358,7 +341,6 @@ class CfnMicrosoftADProps:
     def password(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Password``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
         """
         result = self._values.get("password")
@@ -368,10 +350,9 @@ class CfnMicrosoftADProps:
     @builtins.property
     def vpc_settings(
         self,
-    ) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnMicrosoftAD.VpcSettingsProperty, _IResolvable_9ceae33e]:
         """``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
         """
         result = self._values.get("vpc_settings")
@@ -384,7 +365,6 @@ class CfnMicrosoftADProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-createalias
         """
         result = self._values.get("create_alias")
@@ -394,7 +374,6 @@ class CfnMicrosoftADProps:
     def edition(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.Edition``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-edition
         """
         result = self._values.get("edition")
@@ -406,7 +385,6 @@ class CfnMicrosoftADProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-enablesso
         """
         result = self._values.get("enable_sso")
@@ -416,7 +394,6 @@ class CfnMicrosoftADProps:
     def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-shortname
         """
         result = self._values.get("short_name")
@@ -442,10 +419,8 @@ class CfnSimpleAD(
 ):
     """A CloudFormation ``AWS::DirectoryService::SimpleAD``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DirectoryService::SimpleAD
+    :cloudformationResource: AWS::DirectoryService::SimpleAD
     """
 
     def __init__(
@@ -456,7 +431,7 @@ class CfnSimpleAD(
         name: builtins.str,
         password: builtins.str,
         size: builtins.str,
-        vpc_settings: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e],
+        vpc_settings: typing.Union["CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e],
         create_alias: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         description: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
@@ -490,11 +465,10 @@ class CfnSimpleAD(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -519,8 +493,7 @@ class CfnSimpleAD(
     @jsii.member(jsii_name="attrAlias")
     def attr_alias(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Alias
+        :cloudformationAttribute: Alias
         """
         return jsii.get(self, "attrAlias")
 
@@ -528,8 +501,7 @@ class CfnSimpleAD(
     @jsii.member(jsii_name="attrDnsIpAddresses")
     def attr_dns_ip_addresses(self) -> typing.List[builtins.str]:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: DnsIpAddresses
+        :cloudformationAttribute: DnsIpAddresses
         """
         return jsii.get(self, "attrDnsIpAddresses")
 
@@ -543,7 +515,6 @@ class CfnSimpleAD(
     def name(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
         """
         return jsii.get(self, "name")
@@ -557,7 +528,6 @@ class CfnSimpleAD(
     def password(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Password``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
         """
         return jsii.get(self, "password")
@@ -571,7 +541,6 @@ class CfnSimpleAD(
     def size(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Size``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
         """
         return jsii.get(self, "size")
@@ -584,10 +553,9 @@ class CfnSimpleAD(
     @jsii.member(jsii_name="vpcSettings")
     def vpc_settings(
         self,
-    ) -> typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e]:
         """``AWS::DirectoryService::SimpleAD.VpcSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
         """
         return jsii.get(self, "vpcSettings")
@@ -595,7 +563,7 @@ class CfnSimpleAD(
     @vpc_settings.setter # type: ignore
     def vpc_settings(
         self,
-        value: typing.Union["VpcSettingsProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "vpcSettings", value)
 
@@ -606,7 +574,6 @@ class CfnSimpleAD(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-createalias
         """
         return jsii.get(self, "createAlias")
@@ -623,7 +590,6 @@ class CfnSimpleAD(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-description
         """
         return jsii.get(self, "description")
@@ -639,7 +605,6 @@ class CfnSimpleAD(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-enablesso
         """
         return jsii.get(self, "enableSso")
@@ -656,7 +621,6 @@ class CfnSimpleAD(
     def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-shortname
         """
         return jsii.get(self, "shortName")
@@ -681,7 +645,6 @@ class CfnSimpleAD(
             :param subnet_ids: ``CfnSimpleAD.VpcSettingsProperty.SubnetIds``.
             :param vpc_id: ``CfnSimpleAD.VpcSettingsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -693,7 +656,6 @@ class CfnSimpleAD(
         def subnet_ids(self) -> typing.List[builtins.str]:
             """``CfnSimpleAD.VpcSettingsProperty.SubnetIds``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-subnetids
             """
             result = self._values.get("subnet_ids")
@@ -704,7 +666,6 @@ class CfnSimpleAD(
         def vpc_id(self) -> builtins.str:
             """``CfnSimpleAD.VpcSettingsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-vpcid
             """
             result = self._values.get("vpc_id")
@@ -744,7 +705,7 @@ class CfnSimpleADProps:
         name: builtins.str,
         password: builtins.str,
         size: builtins.str,
-        vpc_settings: typing.Union["CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e],
+        vpc_settings: typing.Union[CfnSimpleAD.VpcSettingsProperty, _IResolvable_9ceae33e],
         create_alias: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         description: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
@@ -761,7 +722,6 @@ class CfnSimpleADProps:
         :param enable_sso: ``AWS::DirectoryService::SimpleAD.EnableSso``.
         :param short_name: ``AWS::DirectoryService::SimpleAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -783,7 +743,6 @@ class CfnSimpleADProps:
     def name(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
         """
         result = self._values.get("name")
@@ -794,7 +753,6 @@ class CfnSimpleADProps:
     def password(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Password``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
         """
         result = self._values.get("password")
@@ -805,7 +763,6 @@ class CfnSimpleADProps:
     def size(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Size``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
         """
         result = self._values.get("size")
@@ -815,10 +772,9 @@ class CfnSimpleADProps:
     @builtins.property
     def vpc_settings(
         self,
-    ) -> typing.Union["CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnSimpleAD.VpcSettingsProperty, _IResolvable_9ceae33e]:
         """``AWS::DirectoryService::SimpleAD.VpcSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
         """
         result = self._values.get("vpc_settings")
@@ -831,7 +787,6 @@ class CfnSimpleADProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-createalias
         """
         result = self._values.get("create_alias")
@@ -841,7 +796,6 @@ class CfnSimpleADProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-description
         """
         result = self._values.get("description")
@@ -853,7 +807,6 @@ class CfnSimpleADProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-enablesso
         """
         result = self._values.get("enable_sso")
@@ -863,7 +816,6 @@ class CfnSimpleADProps:
     def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-shortname
         """
         result = self._values.get("short_name")
