@@ -28,10 +28,8 @@ class CfnLifecyclePolicy(
 ):
     """A CloudFormation ``AWS::DLM::LifecyclePolicy``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DLM::LifecyclePolicy
+    :cloudformationResource: AWS::DLM::LifecyclePolicy
     """
 
     def __init__(
@@ -41,7 +39,7 @@ class CfnLifecyclePolicy(
         *,
         description: typing.Optional[builtins.str] = None,
         execution_role_arn: typing.Optional[builtins.str] = None,
-        policy_details: typing.Optional[typing.Union["PolicyDetailsProperty", _IResolvable_9ceae33e]] = None,
+        policy_details: typing.Optional[typing.Union["CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e]] = None,
         state: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::DLM::LifecyclePolicy``.
@@ -64,11 +62,10 @@ class CfnLifecyclePolicy(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -93,8 +90,7 @@ class CfnLifecyclePolicy(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -108,7 +104,6 @@ class CfnLifecyclePolicy(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-description
         """
         return jsii.get(self, "description")
@@ -122,7 +117,6 @@ class CfnLifecyclePolicy(
     def execution_role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.ExecutionRoleArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-executionrolearn
         """
         return jsii.get(self, "executionRoleArn")
@@ -135,10 +129,9 @@ class CfnLifecyclePolicy(
     @jsii.member(jsii_name="policyDetails")
     def policy_details(
         self,
-    ) -> typing.Optional[typing.Union["PolicyDetailsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e]]:
         """``AWS::DLM::LifecyclePolicy.PolicyDetails``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-policydetails
         """
         return jsii.get(self, "policyDetails")
@@ -146,7 +139,7 @@ class CfnLifecyclePolicy(
     @policy_details.setter # type: ignore
     def policy_details(
         self,
-        value: typing.Optional[typing.Union["PolicyDetailsProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "policyDetails", value)
 
@@ -155,7 +148,6 @@ class CfnLifecyclePolicy(
     def state(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.State``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-state
         """
         return jsii.get(self, "state")
@@ -189,7 +181,6 @@ class CfnLifecyclePolicy(
             :param interval_unit: ``CfnLifecyclePolicy.CreateRuleProperty.IntervalUnit``.
             :param times: ``CfnLifecyclePolicy.CreateRuleProperty.Times``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -206,7 +197,6 @@ class CfnLifecyclePolicy(
         def cron_expression(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.CreateRuleProperty.CronExpression``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html#cfn-dlm-lifecyclepolicy-createrule-cronexpression
             """
             result = self._values.get("cron_expression")
@@ -216,7 +206,6 @@ class CfnLifecyclePolicy(
         def interval(self) -> typing.Optional[jsii.Number]:
             """``CfnLifecyclePolicy.CreateRuleProperty.Interval``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html#cfn-dlm-lifecyclepolicy-createrule-interval
             """
             result = self._values.get("interval")
@@ -226,7 +215,6 @@ class CfnLifecyclePolicy(
         def interval_unit(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.CreateRuleProperty.IntervalUnit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html#cfn-dlm-lifecyclepolicy-createrule-intervalunit
             """
             result = self._values.get("interval_unit")
@@ -236,7 +224,6 @@ class CfnLifecyclePolicy(
         def times(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnLifecyclePolicy.CreateRuleProperty.Times``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html#cfn-dlm-lifecyclepolicy-createrule-times
             """
             result = self._values.get("times")
@@ -269,7 +256,6 @@ class CfnLifecyclePolicy(
             :param interval: ``CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty.Interval``.
             :param interval_unit: ``CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty.IntervalUnit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyretainrule.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -281,7 +267,6 @@ class CfnLifecyclePolicy(
         def interval(self) -> jsii.Number:
             """``CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty.Interval``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyretainrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyretainrule-interval
             """
             result = self._values.get("interval")
@@ -292,7 +277,6 @@ class CfnLifecyclePolicy(
         def interval_unit(self) -> builtins.str:
             """``CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty.IntervalUnit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyretainrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyretainrule-intervalunit
             """
             result = self._values.get("interval_unit")
@@ -338,7 +322,6 @@ class CfnLifecyclePolicy(
             :param copy_tags: ``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.CopyTags``.
             :param retain_rule: ``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.RetainRule``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -356,7 +339,6 @@ class CfnLifecyclePolicy(
         def encrypted(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.Encrypted``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-encrypted
             """
             result = self._values.get("encrypted")
@@ -367,7 +349,6 @@ class CfnLifecyclePolicy(
         def target_region(self) -> builtins.str:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.TargetRegion``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-targetregion
             """
             result = self._values.get("target_region")
@@ -378,7 +359,6 @@ class CfnLifecyclePolicy(
         def cmk_arn(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.CmkArn``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-cmkarn
             """
             result = self._values.get("cmk_arn")
@@ -390,7 +370,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.CopyTags``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-copytags
             """
             result = self._values.get("copy_tags")
@@ -402,7 +381,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.CrossRegionCopyRetainRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.CrossRegionCopyRuleProperty.RetainRule``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html#cfn-dlm-lifecyclepolicy-crossregioncopyrule-retainrule
             """
             result = self._values.get("retain_rule")
@@ -444,7 +422,6 @@ class CfnLifecyclePolicy(
             :param interval: ``CfnLifecyclePolicy.FastRestoreRuleProperty.Interval``.
             :param interval_unit: ``CfnLifecyclePolicy.FastRestoreRuleProperty.IntervalUnit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -461,7 +438,6 @@ class CfnLifecyclePolicy(
         def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnLifecyclePolicy.FastRestoreRuleProperty.AvailabilityZones``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html#cfn-dlm-lifecyclepolicy-fastrestorerule-availabilityzones
             """
             result = self._values.get("availability_zones")
@@ -471,7 +447,6 @@ class CfnLifecyclePolicy(
         def count(self) -> typing.Optional[jsii.Number]:
             """``CfnLifecyclePolicy.FastRestoreRuleProperty.Count``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html#cfn-dlm-lifecyclepolicy-fastrestorerule-count
             """
             result = self._values.get("count")
@@ -481,7 +456,6 @@ class CfnLifecyclePolicy(
         def interval(self) -> typing.Optional[jsii.Number]:
             """``CfnLifecyclePolicy.FastRestoreRuleProperty.Interval``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html#cfn-dlm-lifecyclepolicy-fastrestorerule-interval
             """
             result = self._values.get("interval")
@@ -491,7 +465,6 @@ class CfnLifecyclePolicy(
         def interval_unit(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.FastRestoreRuleProperty.IntervalUnit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html#cfn-dlm-lifecyclepolicy-fastrestorerule-intervalunit
             """
             result = self._values.get("interval_unit")
@@ -522,7 +495,6 @@ class CfnLifecyclePolicy(
             """
             :param exclude_boot_volume: ``CfnLifecyclePolicy.ParametersProperty.ExcludeBootVolume``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-parameters.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -535,7 +507,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ParametersProperty.ExcludeBootVolume``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-parameters.html#cfn-dlm-lifecyclepolicy-parameters-excludebootvolume
             """
             result = self._values.get("exclude_boot_volume")
@@ -580,7 +551,6 @@ class CfnLifecyclePolicy(
             :param parameters: ``CfnLifecyclePolicy.PolicyDetailsProperty.Parameters``.
             :param policy_type: ``CfnLifecyclePolicy.PolicyDetailsProperty.PolicyType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -597,7 +567,6 @@ class CfnLifecyclePolicy(
         def resource_types(self) -> typing.List[builtins.str]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.ResourceTypes``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-resourcetypes
             """
             result = self._values.get("resource_types")
@@ -610,7 +579,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLifecyclePolicy.ScheduleProperty", _IResolvable_9ceae33e]]]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.Schedules``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-schedules
             """
             result = self._values.get("schedules")
@@ -623,7 +591,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.TargetTags``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-targettags
             """
             result = self._values.get("target_tags")
@@ -636,7 +603,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.ParametersProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.Parameters``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-parameters
             """
             result = self._values.get("parameters")
@@ -646,7 +612,6 @@ class CfnLifecyclePolicy(
         def policy_type(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.PolicyDetailsProperty.PolicyType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html#cfn-dlm-lifecyclepolicy-policydetails-policytype
             """
             result = self._values.get("policy_type")
@@ -685,7 +650,6 @@ class CfnLifecyclePolicy(
             :param interval: ``CfnLifecyclePolicy.RetainRuleProperty.Interval``.
             :param interval_unit: ``CfnLifecyclePolicy.RetainRuleProperty.IntervalUnit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retainrule.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -700,7 +664,6 @@ class CfnLifecyclePolicy(
         def count(self) -> typing.Optional[jsii.Number]:
             """``CfnLifecyclePolicy.RetainRuleProperty.Count``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retainrule.html#cfn-dlm-lifecyclepolicy-retainrule-count
             """
             result = self._values.get("count")
@@ -710,7 +673,6 @@ class CfnLifecyclePolicy(
         def interval(self) -> typing.Optional[jsii.Number]:
             """``CfnLifecyclePolicy.RetainRuleProperty.Interval``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retainrule.html#cfn-dlm-lifecyclepolicy-retainrule-interval
             """
             result = self._values.get("interval")
@@ -720,7 +682,6 @@ class CfnLifecyclePolicy(
         def interval_unit(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.RetainRuleProperty.IntervalUnit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retainrule.html#cfn-dlm-lifecyclepolicy-retainrule-intervalunit
             """
             result = self._values.get("interval_unit")
@@ -774,7 +735,6 @@ class CfnLifecyclePolicy(
             :param tags_to_add: ``CfnLifecyclePolicy.ScheduleProperty.TagsToAdd``.
             :param variable_tags: ``CfnLifecyclePolicy.ScheduleProperty.VariableTags``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -801,7 +761,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ScheduleProperty.CopyTags``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-copytags
             """
             result = self._values.get("copy_tags")
@@ -813,7 +772,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.CreateRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ScheduleProperty.CreateRule``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-createrule
             """
             result = self._values.get("create_rule")
@@ -825,7 +783,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnLifecyclePolicy.CrossRegionCopyRuleProperty", _IResolvable_9ceae33e]]]]:
             """``CfnLifecyclePolicy.ScheduleProperty.CrossRegionCopyRules``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-crossregioncopyrules
             """
             result = self._values.get("cross_region_copy_rules")
@@ -837,7 +794,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.FastRestoreRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ScheduleProperty.FastRestoreRule``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-fastrestorerule
             """
             result = self._values.get("fast_restore_rule")
@@ -847,7 +803,6 @@ class CfnLifecyclePolicy(
         def name(self) -> typing.Optional[builtins.str]:
             """``CfnLifecyclePolicy.ScheduleProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-name
             """
             result = self._values.get("name")
@@ -859,7 +814,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.RetainRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnLifecyclePolicy.ScheduleProperty.RetainRule``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-retainrule
             """
             result = self._values.get("retain_rule")
@@ -871,7 +825,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
             """``CfnLifecyclePolicy.ScheduleProperty.TagsToAdd``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-tagstoadd
             """
             result = self._values.get("tags_to_add")
@@ -883,7 +836,6 @@ class CfnLifecyclePolicy(
         ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
             """``CfnLifecyclePolicy.ScheduleProperty.VariableTags``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html#cfn-dlm-lifecyclepolicy-schedule-variabletags
             """
             result = self._values.get("variable_tags")
@@ -917,7 +869,7 @@ class CfnLifecyclePolicyProps:
         *,
         description: typing.Optional[builtins.str] = None,
         execution_role_arn: typing.Optional[builtins.str] = None,
-        policy_details: typing.Optional[typing.Union["CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e]] = None,
+        policy_details: typing.Optional[typing.Union[CfnLifecyclePolicy.PolicyDetailsProperty, _IResolvable_9ceae33e]] = None,
         state: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::DLM::LifecyclePolicy``.
@@ -927,7 +879,6 @@ class CfnLifecyclePolicyProps:
         :param policy_details: ``AWS::DLM::LifecyclePolicy.PolicyDetails``.
         :param state: ``AWS::DLM::LifecyclePolicy.State``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -944,7 +895,6 @@ class CfnLifecyclePolicyProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-description
         """
         result = self._values.get("description")
@@ -954,7 +904,6 @@ class CfnLifecyclePolicyProps:
     def execution_role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.ExecutionRoleArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-executionrolearn
         """
         result = self._values.get("execution_role_arn")
@@ -963,10 +912,9 @@ class CfnLifecyclePolicyProps:
     @builtins.property
     def policy_details(
         self,
-    ) -> typing.Optional[typing.Union["CfnLifecyclePolicy.PolicyDetailsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnLifecyclePolicy.PolicyDetailsProperty, _IResolvable_9ceae33e]]:
         """``AWS::DLM::LifecyclePolicy.PolicyDetails``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-policydetails
         """
         result = self._values.get("policy_details")
@@ -976,7 +924,6 @@ class CfnLifecyclePolicyProps:
     def state(self) -> typing.Optional[builtins.str]:
         """``AWS::DLM::LifecyclePolicy.State``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html#cfn-dlm-lifecyclepolicy-state
         """
         result = self._values.get("state")
