@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import Construct as _Construct_f50a3f53
 from ..assets import (
     FingerprintOptions as _FingerprintOptions_8c2e67f4,
@@ -25,17 +26,16 @@ class DockerImageAsset(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_ecr_assets.DockerImageAsset",
 ):
-    """An asset that represents a Docker image.
+    """(experimental) An asset that represents a Docker image.
 
     The image will be created in build time and uploaded to an ECR repository.
 
-    stability
     :stability: experimental
     """
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         directory: builtins.str,
@@ -50,16 +50,15 @@ class DockerImageAsset(
         """
         :param scope: -
         :param id: -
-        :param directory: The directory where the Dockerfile is stored.
-        :param build_args: Build args to pass to the ``docker build`` command. Since Docker build arguments are resolved before deployment, keys and values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or ``queue.queueUrl``). Default: - no build args are passed
-        :param file: Path to the Dockerfile (relative to the directory). Default: 'Dockerfile'
-        :param repository_name: ECR repository name. Specify this property if you need to statically address the image, e.g. from a Kubernetes Pod. Note, this is only the repository name, without the registry and the tag parts. Default: - the default ECR repository for CDK assets
-        :param target: Docker target to build to. Default: - no target
-        :param extra_hash: Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
+        :param directory: (experimental) The directory where the Dockerfile is stored.
+        :param build_args: (experimental) Build args to pass to the ``docker build`` command. Since Docker build arguments are resolved before deployment, keys and values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or ``queue.queueUrl``). Default: - no build args are passed
+        :param file: (experimental) Path to the Dockerfile (relative to the directory). Default: 'Dockerfile'
+        :param repository_name: (deprecated) ECR repository name. Specify this property if you need to statically address the image, e.g. from a Kubernetes Pod. Note, this is only the repository name, without the registry and the tag parts. Default: - the default ECR repository for CDK assets
+        :param target: (experimental) Docker target to build to. Default: - no target
+        :param extra_hash: (deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
 
-        stability
         :stability: experimental
         """
         props = DockerImageAssetProps(
@@ -78,13 +77,12 @@ class DockerImageAsset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
-        """A hash of the source of this asset, which is available at construction time.
+        """(experimental) A hash of the source of this asset, which is available at construction time.
 
         As this is a plain
         string, it can be used in construct IDs in order to enforce creation of a new resource when
         the content hash has changed.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "sourceHash")
@@ -92,12 +90,11 @@ class DockerImageAsset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="imageUri")
     def image_uri(self) -> builtins.str:
-        """The full URI of the image (including a tag).
+        """(experimental) The full URI of the image (including a tag).
 
         Use this reference to pull
         the asset.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "imageUri")
@@ -109,9 +106,8 @@ class DockerImageAsset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="repository")
     def repository(self) -> _IRepository_aa6e452c:
-        """Repository where the image is stored.
+        """(experimental) Repository where the image is stored.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "repository")
@@ -146,17 +142,16 @@ class DockerImageAssetOptions(_FingerprintOptions_8c2e67f4):
         repository_name: typing.Optional[builtins.str] = None,
         target: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Options for DockerImageAsset.
+        """(experimental) Options for DockerImageAsset.
 
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
-        :param extra_hash: Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
-        :param build_args: Build args to pass to the ``docker build`` command. Since Docker build arguments are resolved before deployment, keys and values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or ``queue.queueUrl``). Default: - no build args are passed
-        :param file: Path to the Dockerfile (relative to the directory). Default: 'Dockerfile'
-        :param repository_name: ECR repository name. Specify this property if you need to statically address the image, e.g. from a Kubernetes Pod. Note, this is only the repository name, without the registry and the tag parts. Default: - the default ECR repository for CDK assets
-        :param target: Docker target to build to. Default: - no target
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
+        :param extra_hash: (deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
+        :param build_args: (experimental) Build args to pass to the ``docker build`` command. Since Docker build arguments are resolved before deployment, keys and values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or ``queue.queueUrl``). Default: - no build args are passed
+        :param file: (experimental) Path to the Dockerfile (relative to the directory). Default: 'Dockerfile'
+        :param repository_name: (deprecated) ECR repository name. Specify this property if you need to statically address the image, e.g. from a Kubernetes Pod. Note, this is only the repository name, without the registry and the tag parts. Default: - the default ECR repository for CDK assets
+        :param target: (experimental) Docker target to build to. Default: - no target
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -177,12 +172,10 @@ class DockerImageAssetOptions(_FingerprintOptions_8c2e67f4):
 
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
-        """Glob patterns to exclude from the copy.
+        """(deprecated) Glob patterns to exclude from the copy.
 
-        default
         :default: nothing is excluded
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("exclude")
@@ -190,12 +183,10 @@ class DockerImageAssetOptions(_FingerprintOptions_8c2e67f4):
 
     @builtins.property
     def follow(self) -> typing.Optional[_FollowMode_f74e7125]:
-        """A strategy for how to handle symlinks.
+        """(deprecated) A strategy for how to handle symlinks.
 
-        default
         :default: Never
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("follow")
@@ -203,12 +194,10 @@ class DockerImageAssetOptions(_FingerprintOptions_8c2e67f4):
 
     @builtins.property
     def extra_hash(self) -> typing.Optional[builtins.str]:
-        """Extra information to encode into the fingerprint (e.g. build instructions and other inputs).
+        """(deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs).
 
-        default
         :default: - hash is only based on source content
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("extra_hash")
@@ -216,16 +205,14 @@ class DockerImageAssetOptions(_FingerprintOptions_8c2e67f4):
 
     @builtins.property
     def build_args(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
-        """Build args to pass to the ``docker build`` command.
+        """(experimental) Build args to pass to the ``docker build`` command.
 
         Since Docker build arguments are resolved before deployment, keys and
         values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or
         ``queue.queueUrl``).
 
-        default
         :default: - no build args are passed
 
-        stability
         :stability: experimental
         """
         result = self._values.get("build_args")
@@ -233,12 +220,10 @@ class DockerImageAssetOptions(_FingerprintOptions_8c2e67f4):
 
     @builtins.property
     def file(self) -> typing.Optional[builtins.str]:
-        """Path to the Dockerfile (relative to the directory).
+        """(experimental) Path to the Dockerfile (relative to the directory).
 
-        default
         :default: 'Dockerfile'
 
-        stability
         :stability: experimental
         """
         result = self._values.get("file")
@@ -246,23 +231,20 @@ class DockerImageAssetOptions(_FingerprintOptions_8c2e67f4):
 
     @builtins.property
     def repository_name(self) -> typing.Optional[builtins.str]:
-        """ECR repository name.
+        """(deprecated) ECR repository name.
 
         Specify this property if you need to statically address the image, e.g.
         from a Kubernetes Pod. Note, this is only the repository name, without the
         registry and the tag parts.
 
-        default
         :default: - the default ECR repository for CDK assets
 
-        deprecated
         :deprecated:
 
         to control the location of docker image assets, please override
         ``Stack.addDockerImageAsset``. this feature will be removed in future
         releases.
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("repository_name")
@@ -270,12 +252,10 @@ class DockerImageAssetOptions(_FingerprintOptions_8c2e67f4):
 
     @builtins.property
     def target(self) -> typing.Optional[builtins.str]:
-        """Docker target to build to.
+        """(experimental) Docker target to build to.
 
-        default
         :default: - no target
 
-        stability
         :stability: experimental
         """
         result = self._values.get("target")
@@ -320,18 +300,17 @@ class DockerImageAssetProps(DockerImageAssetOptions):
         target: typing.Optional[builtins.str] = None,
         directory: builtins.str,
     ) -> None:
-        """Props for DockerImageAssets.
+        """(experimental) Props for DockerImageAssets.
 
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
-        :param extra_hash: Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
-        :param build_args: Build args to pass to the ``docker build`` command. Since Docker build arguments are resolved before deployment, keys and values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or ``queue.queueUrl``). Default: - no build args are passed
-        :param file: Path to the Dockerfile (relative to the directory). Default: 'Dockerfile'
-        :param repository_name: ECR repository name. Specify this property if you need to statically address the image, e.g. from a Kubernetes Pod. Note, this is only the repository name, without the registry and the tag parts. Default: - the default ECR repository for CDK assets
-        :param target: Docker target to build to. Default: - no target
-        :param directory: The directory where the Dockerfile is stored.
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
+        :param extra_hash: (deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
+        :param build_args: (experimental) Build args to pass to the ``docker build`` command. Since Docker build arguments are resolved before deployment, keys and values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or ``queue.queueUrl``). Default: - no build args are passed
+        :param file: (experimental) Path to the Dockerfile (relative to the directory). Default: 'Dockerfile'
+        :param repository_name: (deprecated) ECR repository name. Specify this property if you need to statically address the image, e.g. from a Kubernetes Pod. Note, this is only the repository name, without the registry and the tag parts. Default: - the default ECR repository for CDK assets
+        :param target: (experimental) Docker target to build to. Default: - no target
+        :param directory: (experimental) The directory where the Dockerfile is stored.
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -354,12 +333,10 @@ class DockerImageAssetProps(DockerImageAssetOptions):
 
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
-        """Glob patterns to exclude from the copy.
+        """(deprecated) Glob patterns to exclude from the copy.
 
-        default
         :default: nothing is excluded
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("exclude")
@@ -367,12 +344,10 @@ class DockerImageAssetProps(DockerImageAssetOptions):
 
     @builtins.property
     def follow(self) -> typing.Optional[_FollowMode_f74e7125]:
-        """A strategy for how to handle symlinks.
+        """(deprecated) A strategy for how to handle symlinks.
 
-        default
         :default: Never
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("follow")
@@ -380,12 +355,10 @@ class DockerImageAssetProps(DockerImageAssetOptions):
 
     @builtins.property
     def extra_hash(self) -> typing.Optional[builtins.str]:
-        """Extra information to encode into the fingerprint (e.g. build instructions and other inputs).
+        """(deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs).
 
-        default
         :default: - hash is only based on source content
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("extra_hash")
@@ -393,16 +366,14 @@ class DockerImageAssetProps(DockerImageAssetOptions):
 
     @builtins.property
     def build_args(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
-        """Build args to pass to the ``docker build`` command.
+        """(experimental) Build args to pass to the ``docker build`` command.
 
         Since Docker build arguments are resolved before deployment, keys and
         values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or
         ``queue.queueUrl``).
 
-        default
         :default: - no build args are passed
 
-        stability
         :stability: experimental
         """
         result = self._values.get("build_args")
@@ -410,12 +381,10 @@ class DockerImageAssetProps(DockerImageAssetOptions):
 
     @builtins.property
     def file(self) -> typing.Optional[builtins.str]:
-        """Path to the Dockerfile (relative to the directory).
+        """(experimental) Path to the Dockerfile (relative to the directory).
 
-        default
         :default: 'Dockerfile'
 
-        stability
         :stability: experimental
         """
         result = self._values.get("file")
@@ -423,23 +392,20 @@ class DockerImageAssetProps(DockerImageAssetOptions):
 
     @builtins.property
     def repository_name(self) -> typing.Optional[builtins.str]:
-        """ECR repository name.
+        """(deprecated) ECR repository name.
 
         Specify this property if you need to statically address the image, e.g.
         from a Kubernetes Pod. Note, this is only the repository name, without the
         registry and the tag parts.
 
-        default
         :default: - the default ECR repository for CDK assets
 
-        deprecated
         :deprecated:
 
         to control the location of docker image assets, please override
         ``Stack.addDockerImageAsset``. this feature will be removed in future
         releases.
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("repository_name")
@@ -447,12 +413,10 @@ class DockerImageAssetProps(DockerImageAssetOptions):
 
     @builtins.property
     def target(self) -> typing.Optional[builtins.str]:
-        """Docker target to build to.
+        """(experimental) Docker target to build to.
 
-        default
         :default: - no target
 
-        stability
         :stability: experimental
         """
         result = self._values.get("target")
@@ -460,9 +424,8 @@ class DockerImageAssetProps(DockerImageAssetOptions):
 
     @builtins.property
     def directory(self) -> builtins.str:
-        """The directory where the Dockerfile is stored.
+        """(experimental) The directory where the Dockerfile is stored.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("directory")
