@@ -27,9 +27,8 @@ class AuthenticateCognitoAction(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_elasticloadbalancingv2_actions.AuthenticateCognitoAction",
 ):
-    """A Listener Action to authenticate with Cognito.
+    """(experimental) A Listener Action to authenticate with Cognito.
 
-    stability
     :stability: experimental
     """
 
@@ -46,19 +45,18 @@ class AuthenticateCognitoAction(
         session_cookie_name: typing.Optional[builtins.str] = None,
         session_timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
-        """Authenticate using an identity provide (IdP) that is compliant with OpenID Connect (OIDC).
+        """(experimental) Authenticate using an identity provide (IdP) that is compliant with OpenID Connect (OIDC).
 
-        :param next: What action to execute next. Multiple actions form a linked chain; the chain must always terminate in a (weighted)forward, fixedResponse or redirect action.
-        :param user_pool: The Amazon Cognito user pool.
-        :param user_pool_client: The Amazon Cognito user pool client.
-        :param user_pool_domain: The domain prefix or fully-qualified domain name of the Amazon Cognito user pool.
-        :param authentication_request_extra_params: The query parameters (up to 10) to include in the redirect request to the authorization endpoint. Default: - No extra parameters
-        :param on_unauthenticated_request: The behavior if the user is not authenticated. Default: UnauthenticatedAction.AUTHENTICATE
-        :param scope: The set of user claims to be requested from the IdP. To verify which scope values your IdP supports and how to separate multiple values, see the documentation for your IdP. Default: "openid"
-        :param session_cookie_name: The name of the cookie used to maintain session information. Default: "AWSELBAuthSessionCookie"
-        :param session_timeout: The maximum duration of the authentication session. Default: Duration.days(7)
+        :param next: (experimental) What action to execute next. Multiple actions form a linked chain; the chain must always terminate in a (weighted)forward, fixedResponse or redirect action.
+        :param user_pool: (experimental) The Amazon Cognito user pool.
+        :param user_pool_client: (experimental) The Amazon Cognito user pool client.
+        :param user_pool_domain: (experimental) The domain prefix or fully-qualified domain name of the Amazon Cognito user pool.
+        :param authentication_request_extra_params: (experimental) The query parameters (up to 10) to include in the redirect request to the authorization endpoint. Default: - No extra parameters
+        :param on_unauthenticated_request: (experimental) The behavior if the user is not authenticated. Default: UnauthenticatedAction.AUTHENTICATE
+        :param scope: (experimental) The set of user claims to be requested from the IdP. To verify which scope values your IdP supports and how to separate multiple values, see the documentation for your IdP. Default: "openid"
+        :param session_cookie_name: (experimental) The name of the cookie used to maintain session information. Default: "AWSELBAuthSessionCookie"
+        :param session_timeout: (experimental) The maximum duration of the authentication session. Default: Duration.days(7)
 
-        stability
         :stability: experimental
         """
         options = AuthenticateCognitoActionProps(
@@ -105,19 +103,18 @@ class AuthenticateCognitoActionProps:
         session_cookie_name: typing.Optional[builtins.str] = None,
         session_timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
-        """Properties for AuthenticateCognitoAction.
+        """(experimental) Properties for AuthenticateCognitoAction.
 
-        :param next: What action to execute next. Multiple actions form a linked chain; the chain must always terminate in a (weighted)forward, fixedResponse or redirect action.
-        :param user_pool: The Amazon Cognito user pool.
-        :param user_pool_client: The Amazon Cognito user pool client.
-        :param user_pool_domain: The domain prefix or fully-qualified domain name of the Amazon Cognito user pool.
-        :param authentication_request_extra_params: The query parameters (up to 10) to include in the redirect request to the authorization endpoint. Default: - No extra parameters
-        :param on_unauthenticated_request: The behavior if the user is not authenticated. Default: UnauthenticatedAction.AUTHENTICATE
-        :param scope: The set of user claims to be requested from the IdP. To verify which scope values your IdP supports and how to separate multiple values, see the documentation for your IdP. Default: "openid"
-        :param session_cookie_name: The name of the cookie used to maintain session information. Default: "AWSELBAuthSessionCookie"
-        :param session_timeout: The maximum duration of the authentication session. Default: Duration.days(7)
+        :param next: (experimental) What action to execute next. Multiple actions form a linked chain; the chain must always terminate in a (weighted)forward, fixedResponse or redirect action.
+        :param user_pool: (experimental) The Amazon Cognito user pool.
+        :param user_pool_client: (experimental) The Amazon Cognito user pool client.
+        :param user_pool_domain: (experimental) The domain prefix or fully-qualified domain name of the Amazon Cognito user pool.
+        :param authentication_request_extra_params: (experimental) The query parameters (up to 10) to include in the redirect request to the authorization endpoint. Default: - No extra parameters
+        :param on_unauthenticated_request: (experimental) The behavior if the user is not authenticated. Default: UnauthenticatedAction.AUTHENTICATE
+        :param scope: (experimental) The set of user claims to be requested from the IdP. To verify which scope values your IdP supports and how to separate multiple values, see the documentation for your IdP. Default: "openid"
+        :param session_cookie_name: (experimental) The name of the cookie used to maintain session information. Default: "AWSELBAuthSessionCookie"
+        :param session_timeout: (experimental) The maximum duration of the authentication session. Default: Duration.days(7)
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -139,12 +136,11 @@ class AuthenticateCognitoActionProps:
 
     @builtins.property
     def next(self) -> _ListenerAction_941cc841:
-        """What action to execute next.
+        """(experimental) What action to execute next.
 
         Multiple actions form a linked chain; the chain must always terminate in a
         (weighted)forward, fixedResponse or redirect action.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("next")
@@ -153,9 +149,8 @@ class AuthenticateCognitoActionProps:
 
     @builtins.property
     def user_pool(self) -> _IUserPool_e9547b0f:
-        """The Amazon Cognito user pool.
+        """(experimental) The Amazon Cognito user pool.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("user_pool")
@@ -164,9 +159,8 @@ class AuthenticateCognitoActionProps:
 
     @builtins.property
     def user_pool_client(self) -> _IUserPoolClient_fd99c9a8:
-        """The Amazon Cognito user pool client.
+        """(experimental) The Amazon Cognito user pool client.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("user_pool_client")
@@ -175,9 +169,8 @@ class AuthenticateCognitoActionProps:
 
     @builtins.property
     def user_pool_domain(self) -> _IUserPoolDomain_a6fbdcfa:
-        """The domain prefix or fully-qualified domain name of the Amazon Cognito user pool.
+        """(experimental) The domain prefix or fully-qualified domain name of the Amazon Cognito user pool.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("user_pool_domain")
@@ -188,12 +181,10 @@ class AuthenticateCognitoActionProps:
     def authentication_request_extra_params(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
-        """The query parameters (up to 10) to include in the redirect request to the authorization endpoint.
+        """(experimental) The query parameters (up to 10) to include in the redirect request to the authorization endpoint.
 
-        default
         :default: - No extra parameters
 
-        stability
         :stability: experimental
         """
         result = self._values.get("authentication_request_extra_params")
@@ -203,12 +194,10 @@ class AuthenticateCognitoActionProps:
     def on_unauthenticated_request(
         self,
     ) -> typing.Optional[_UnauthenticatedAction_217b7279]:
-        """The behavior if the user is not authenticated.
+        """(experimental) The behavior if the user is not authenticated.
 
-        default
         :default: UnauthenticatedAction.AUTHENTICATE
 
-        stability
         :stability: experimental
         """
         result = self._values.get("on_unauthenticated_request")
@@ -216,14 +205,12 @@ class AuthenticateCognitoActionProps:
 
     @builtins.property
     def scope(self) -> typing.Optional[builtins.str]:
-        """The set of user claims to be requested from the IdP.
+        """(experimental) The set of user claims to be requested from the IdP.
 
         To verify which scope values your IdP supports and how to separate multiple values, see the documentation for your IdP.
 
-        default
         :default: "openid"
 
-        stability
         :stability: experimental
         """
         result = self._values.get("scope")
@@ -231,12 +218,10 @@ class AuthenticateCognitoActionProps:
 
     @builtins.property
     def session_cookie_name(self) -> typing.Optional[builtins.str]:
-        """The name of the cookie used to maintain session information.
+        """(experimental) The name of the cookie used to maintain session information.
 
-        default
         :default: "AWSELBAuthSessionCookie"
 
-        stability
         :stability: experimental
         """
         result = self._values.get("session_cookie_name")
@@ -244,12 +229,10 @@ class AuthenticateCognitoActionProps:
 
     @builtins.property
     def session_timeout(self) -> typing.Optional[_Duration_5170c158]:
-        """The maximum duration of the authentication session.
+        """(experimental) The maximum duration of the authentication session.
 
-        default
         :default: Duration.days(7)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("session_timeout")
