@@ -26,12 +26,11 @@ class InstanceIdTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_elasticloadbalancingv2_targets.InstanceIdTarget",
 ):
-    """An EC2 instance that is the target for load balancing.
+    """(experimental) An EC2 instance that is the target for load balancing.
 
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can connect to the instance.
 
-    stability
     :stability: experimental
     """
 
@@ -40,12 +39,11 @@ class InstanceIdTarget(
         instance_id: builtins.str,
         port: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """Create a new Instance target.
+        """(experimental) Create a new Instance target.
 
         :param instance_id: Instance ID of the instance to register to.
         :param port: Override the default port for the target group.
 
-        stability
         :stability: experimental
         """
         jsii.create(InstanceIdTarget, self, [instance_id, port])
@@ -55,14 +53,13 @@ class InstanceIdTarget(
         self,
         target_group: _IApplicationTargetGroup_1bf77cc5,
     ) -> _LoadBalancerTargetProps_80dbd4a5:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToApplicationTargetGroup", [target_group])
@@ -72,14 +69,13 @@ class InstanceIdTarget(
         self,
         target_group: _INetworkTargetGroup_1183b98f,
     ) -> _LoadBalancerTargetProps_80dbd4a5:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
@@ -91,7 +87,6 @@ class InstanceTarget(
     jsii_type="monocdk-experiment.aws_elasticloadbalancingv2_targets.InstanceTarget",
 ):
     """
-    stability
     :stability: experimental
     """
 
@@ -100,12 +95,11 @@ class InstanceTarget(
         instance: _Instance_024cd2a8,
         port: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """Create a new Instance target.
+        """(experimental) Create a new Instance target.
 
         :param instance: Instance to register to.
         :param port: Override the default port for the target group.
 
-        stability
         :stability: experimental
         """
         jsii.create(InstanceTarget, self, [instance, port])
@@ -116,7 +110,7 @@ class IpTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_elasticloadbalancingv2_targets.IpTarget",
 ):
-    """An IP address that is a target for load balancing.
+    """(experimental) An IP address that is a target for load balancing.
 
     Specify IP addresses from the subnets of the virtual private cloud (VPC) for
     the target group, the RFC 1918 range (10.0.0.0/8, 172.16.0.0/12, and
@@ -126,7 +120,6 @@ class IpTarget(
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can send packets to the IP address.
 
-    stability
     :stability: experimental
     """
 
@@ -136,7 +129,7 @@ class IpTarget(
         port: typing.Optional[jsii.Number] = None,
         availability_zone: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Create a new IPAddress target.
+        """(experimental) Create a new IPAddress target.
 
         The availabilityZone parameter determines whether the target receives
         traffic from the load balancer nodes in the specified Availability Zone
@@ -157,7 +150,6 @@ class IpTarget(
         :param port: Override the group's default port.
         :param availability_zone: Availability zone to send traffic from.
 
-        stability
         :stability: experimental
         """
         jsii.create(IpTarget, self, [ip_address, port, availability_zone])
@@ -167,14 +159,13 @@ class IpTarget(
         self,
         target_group: _IApplicationTargetGroup_1bf77cc5,
     ) -> _LoadBalancerTargetProps_80dbd4a5:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToApplicationTargetGroup", [target_group])
@@ -184,14 +175,13 @@ class IpTarget(
         self,
         target_group: _INetworkTargetGroup_1183b98f,
     ) -> _LoadBalancerTargetProps_80dbd4a5:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
@@ -203,16 +193,14 @@ class LambdaTarget(
     jsii_type="monocdk-experiment.aws_elasticloadbalancingv2_targets.LambdaTarget",
 ):
     """
-    stability
     :stability: experimental
     """
 
     def __init__(self, fn: _IFunction_1c1de0bc) -> None:
-        """Create a new Lambda target.
+        """(experimental) Create a new Lambda target.
 
         :param fn: -
 
-        stability
         :stability: experimental
         """
         jsii.create(LambdaTarget, self, [fn])
@@ -222,14 +210,13 @@ class LambdaTarget(
         self,
         target_group: _IApplicationTargetGroup_1bf77cc5,
     ) -> _LoadBalancerTargetProps_80dbd4a5:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToApplicationTargetGroup", [target_group])
@@ -239,14 +226,13 @@ class LambdaTarget(
         self,
         target_group: _INetworkTargetGroup_1183b98f,
     ) -> _LoadBalancerTargetProps_80dbd4a5:
-        """Register this instance target with a load balancer.
+        """(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
