@@ -27,10 +27,8 @@ class CfnDiscoverer(
 ):
     """A CloudFormation ``AWS::EventSchemas::Discoverer``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::EventSchemas::Discoverer
+    :cloudformationResource: AWS::EventSchemas::Discoverer
     """
 
     def __init__(
@@ -40,7 +38,7 @@ class CfnDiscoverer(
         *,
         source_arn: builtins.str,
         description: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.List["TagsEntryProperty"]] = None,
+        tags: typing.Optional[typing.List["CfnDiscoverer.TagsEntryProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::EventSchemas::Discoverer``.
 
@@ -58,11 +56,10 @@ class CfnDiscoverer(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -87,8 +84,7 @@ class CfnDiscoverer(
     @jsii.member(jsii_name="attrDiscovererArn")
     def attr_discoverer_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: DiscovererArn
+        :cloudformationAttribute: DiscovererArn
         """
         return jsii.get(self, "attrDiscovererArn")
 
@@ -96,8 +92,7 @@ class CfnDiscoverer(
     @jsii.member(jsii_name="attrDiscovererId")
     def attr_discoverer_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: DiscovererId
+        :cloudformationAttribute: DiscovererId
         """
         return jsii.get(self, "attrDiscovererId")
 
@@ -111,7 +106,6 @@ class CfnDiscoverer(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::EventSchemas::Discoverer.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-tags
         """
         return jsii.get(self, "tags")
@@ -121,7 +115,6 @@ class CfnDiscoverer(
     def source_arn(self) -> builtins.str:
         """``AWS::EventSchemas::Discoverer.SourceArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-sourcearn
         """
         return jsii.get(self, "sourceArn")
@@ -135,7 +128,6 @@ class CfnDiscoverer(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Discoverer.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-description
         """
         return jsii.get(self, "description")
@@ -155,7 +147,6 @@ class CfnDiscoverer(
             :param key: ``CfnDiscoverer.TagsEntryProperty.Key``.
             :param value: ``CfnDiscoverer.TagsEntryProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-discoverer-tagsentry.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -167,7 +158,6 @@ class CfnDiscoverer(
         def key(self) -> builtins.str:
             """``CfnDiscoverer.TagsEntryProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-discoverer-tagsentry.html#cfn-eventschemas-discoverer-tagsentry-key
             """
             result = self._values.get("key")
@@ -178,7 +168,6 @@ class CfnDiscoverer(
         def value(self) -> builtins.str:
             """``CfnDiscoverer.TagsEntryProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-discoverer-tagsentry.html#cfn-eventschemas-discoverer-tagsentry-value
             """
             result = self._values.get("value")
@@ -212,7 +201,7 @@ class CfnDiscovererProps:
         *,
         source_arn: builtins.str,
         description: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.List["CfnDiscoverer.TagsEntryProperty"]] = None,
+        tags: typing.Optional[typing.List[CfnDiscoverer.TagsEntryProperty]] = None,
     ) -> None:
         """Properties for defining a ``AWS::EventSchemas::Discoverer``.
 
@@ -220,7 +209,6 @@ class CfnDiscovererProps:
         :param description: ``AWS::EventSchemas::Discoverer.Description``.
         :param tags: ``AWS::EventSchemas::Discoverer.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -235,7 +223,6 @@ class CfnDiscovererProps:
     def source_arn(self) -> builtins.str:
         """``AWS::EventSchemas::Discoverer.SourceArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-sourcearn
         """
         result = self._values.get("source_arn")
@@ -246,17 +233,15 @@ class CfnDiscovererProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Discoverer.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-description
         """
         result = self._values.get("description")
         return result
 
     @builtins.property
-    def tags(self) -> typing.Optional[typing.List["CfnDiscoverer.TagsEntryProperty"]]:
+    def tags(self) -> typing.Optional[typing.List[CfnDiscoverer.TagsEntryProperty]]:
         """``AWS::EventSchemas::Discoverer.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-tags
         """
         result = self._values.get("tags")
@@ -282,10 +267,8 @@ class CfnRegistry(
 ):
     """A CloudFormation ``AWS::EventSchemas::Registry``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::EventSchemas::Registry
+    :cloudformationResource: AWS::EventSchemas::Registry
     """
 
     def __init__(
@@ -295,7 +278,7 @@ class CfnRegistry(
         *,
         description: typing.Optional[builtins.str] = None,
         registry_name: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.List["TagsEntryProperty"]] = None,
+        tags: typing.Optional[typing.List["CfnRegistry.TagsEntryProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::EventSchemas::Registry``.
 
@@ -313,11 +296,10 @@ class CfnRegistry(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -342,8 +324,7 @@ class CfnRegistry(
     @jsii.member(jsii_name="attrRegistryArn")
     def attr_registry_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: RegistryArn
+        :cloudformationAttribute: RegistryArn
         """
         return jsii.get(self, "attrRegistryArn")
 
@@ -351,8 +332,7 @@ class CfnRegistry(
     @jsii.member(jsii_name="attrRegistryName")
     def attr_registry_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: RegistryName
+        :cloudformationAttribute: RegistryName
         """
         return jsii.get(self, "attrRegistryName")
 
@@ -366,7 +346,6 @@ class CfnRegistry(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::EventSchemas::Registry.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-tags
         """
         return jsii.get(self, "tags")
@@ -376,7 +355,6 @@ class CfnRegistry(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Registry.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-description
         """
         return jsii.get(self, "description")
@@ -390,7 +368,6 @@ class CfnRegistry(
     def registry_name(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Registry.RegistryName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-registryname
         """
         return jsii.get(self, "registryName")
@@ -410,7 +387,6 @@ class CfnRegistry(
             :param key: ``CfnRegistry.TagsEntryProperty.Key``.
             :param value: ``CfnRegistry.TagsEntryProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-registry-tagsentry.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -422,7 +398,6 @@ class CfnRegistry(
         def key(self) -> builtins.str:
             """``CfnRegistry.TagsEntryProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-registry-tagsentry.html#cfn-eventschemas-registry-tagsentry-key
             """
             result = self._values.get("key")
@@ -433,7 +408,6 @@ class CfnRegistry(
         def value(self) -> builtins.str:
             """``CfnRegistry.TagsEntryProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-registry-tagsentry.html#cfn-eventschemas-registry-tagsentry-value
             """
             result = self._values.get("value")
@@ -460,10 +434,8 @@ class CfnRegistryPolicy(
 ):
     """A CloudFormation ``AWS::EventSchemas::RegistryPolicy``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::EventSchemas::RegistryPolicy
+    :cloudformationResource: AWS::EventSchemas::RegistryPolicy
     """
 
     def __init__(
@@ -491,11 +463,10 @@ class CfnRegistryPolicy(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -520,8 +491,7 @@ class CfnRegistryPolicy(
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Id
+        :cloudformationAttribute: Id
         """
         return jsii.get(self, "attrId")
 
@@ -535,7 +505,6 @@ class CfnRegistryPolicy(
     def policy(self) -> typing.Any:
         """``AWS::EventSchemas::RegistryPolicy.Policy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-policy
         """
         return jsii.get(self, "policy")
@@ -549,7 +518,6 @@ class CfnRegistryPolicy(
     def registry_name(self) -> builtins.str:
         """``AWS::EventSchemas::RegistryPolicy.RegistryName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-registryname
         """
         return jsii.get(self, "registryName")
@@ -563,7 +531,6 @@ class CfnRegistryPolicy(
     def revision_id(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::RegistryPolicy.RevisionId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-revisionid
         """
         return jsii.get(self, "revisionId")
@@ -596,7 +563,6 @@ class CfnRegistryPolicyProps:
         :param registry_name: ``AWS::EventSchemas::RegistryPolicy.RegistryName``.
         :param revision_id: ``AWS::EventSchemas::RegistryPolicy.RevisionId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -610,7 +576,6 @@ class CfnRegistryPolicyProps:
     def policy(self) -> typing.Any:
         """``AWS::EventSchemas::RegistryPolicy.Policy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-policy
         """
         result = self._values.get("policy")
@@ -621,7 +586,6 @@ class CfnRegistryPolicyProps:
     def registry_name(self) -> builtins.str:
         """``AWS::EventSchemas::RegistryPolicy.RegistryName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-registryname
         """
         result = self._values.get("registry_name")
@@ -632,7 +596,6 @@ class CfnRegistryPolicyProps:
     def revision_id(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::RegistryPolicy.RevisionId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-revisionid
         """
         result = self._values.get("revision_id")
@@ -665,7 +628,7 @@ class CfnRegistryProps:
         *,
         description: typing.Optional[builtins.str] = None,
         registry_name: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.List["CfnRegistry.TagsEntryProperty"]] = None,
+        tags: typing.Optional[typing.List[CfnRegistry.TagsEntryProperty]] = None,
     ) -> None:
         """Properties for defining a ``AWS::EventSchemas::Registry``.
 
@@ -673,7 +636,6 @@ class CfnRegistryProps:
         :param registry_name: ``AWS::EventSchemas::Registry.RegistryName``.
         :param tags: ``AWS::EventSchemas::Registry.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -688,7 +650,6 @@ class CfnRegistryProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Registry.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-description
         """
         result = self._values.get("description")
@@ -698,17 +659,15 @@ class CfnRegistryProps:
     def registry_name(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Registry.RegistryName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-registryname
         """
         result = self._values.get("registry_name")
         return result
 
     @builtins.property
-    def tags(self) -> typing.Optional[typing.List["CfnRegistry.TagsEntryProperty"]]:
+    def tags(self) -> typing.Optional[typing.List[CfnRegistry.TagsEntryProperty]]:
         """``AWS::EventSchemas::Registry.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-tags
         """
         result = self._values.get("tags")
@@ -734,10 +693,8 @@ class CfnSchema(
 ):
     """A CloudFormation ``AWS::EventSchemas::Schema``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::EventSchemas::Schema
+    :cloudformationResource: AWS::EventSchemas::Schema
     """
 
     def __init__(
@@ -750,7 +707,7 @@ class CfnSchema(
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         schema_name: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.List["TagsEntryProperty"]] = None,
+        tags: typing.Optional[typing.List["CfnSchema.TagsEntryProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::EventSchemas::Schema``.
 
@@ -776,11 +733,10 @@ class CfnSchema(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -805,8 +761,7 @@ class CfnSchema(
     @jsii.member(jsii_name="attrSchemaArn")
     def attr_schema_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: SchemaArn
+        :cloudformationAttribute: SchemaArn
         """
         return jsii.get(self, "attrSchemaArn")
 
@@ -814,8 +769,7 @@ class CfnSchema(
     @jsii.member(jsii_name="attrSchemaName")
     def attr_schema_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: SchemaName
+        :cloudformationAttribute: SchemaName
         """
         return jsii.get(self, "attrSchemaName")
 
@@ -823,8 +777,7 @@ class CfnSchema(
     @jsii.member(jsii_name="attrSchemaVersion")
     def attr_schema_version(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: SchemaVersion
+        :cloudformationAttribute: SchemaVersion
         """
         return jsii.get(self, "attrSchemaVersion")
 
@@ -838,7 +791,6 @@ class CfnSchema(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::EventSchemas::Schema.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-tags
         """
         return jsii.get(self, "tags")
@@ -848,7 +800,6 @@ class CfnSchema(
     def content(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.Content``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-content
         """
         return jsii.get(self, "content")
@@ -862,7 +813,6 @@ class CfnSchema(
     def registry_name(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.RegistryName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-registryname
         """
         return jsii.get(self, "registryName")
@@ -876,7 +826,6 @@ class CfnSchema(
     def type(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.Type``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-type
         """
         return jsii.get(self, "type")
@@ -890,7 +839,6 @@ class CfnSchema(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Schema.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-description
         """
         return jsii.get(self, "description")
@@ -904,7 +852,6 @@ class CfnSchema(
     def schema_name(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Schema.SchemaName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-schemaname
         """
         return jsii.get(self, "schemaName")
@@ -924,7 +871,6 @@ class CfnSchema(
             :param key: ``CfnSchema.TagsEntryProperty.Key``.
             :param value: ``CfnSchema.TagsEntryProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-schema-tagsentry.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -936,7 +882,6 @@ class CfnSchema(
         def key(self) -> builtins.str:
             """``CfnSchema.TagsEntryProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-schema-tagsentry.html#cfn-eventschemas-schema-tagsentry-key
             """
             result = self._values.get("key")
@@ -947,7 +892,6 @@ class CfnSchema(
         def value(self) -> builtins.str:
             """``CfnSchema.TagsEntryProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-schema-tagsentry.html#cfn-eventschemas-schema-tagsentry-value
             """
             result = self._values.get("value")
@@ -987,7 +931,7 @@ class CfnSchemaProps:
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         schema_name: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.List["CfnSchema.TagsEntryProperty"]] = None,
+        tags: typing.Optional[typing.List[CfnSchema.TagsEntryProperty]] = None,
     ) -> None:
         """Properties for defining a ``AWS::EventSchemas::Schema``.
 
@@ -998,7 +942,6 @@ class CfnSchemaProps:
         :param schema_name: ``AWS::EventSchemas::Schema.SchemaName``.
         :param tags: ``AWS::EventSchemas::Schema.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1017,7 +960,6 @@ class CfnSchemaProps:
     def content(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.Content``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-content
         """
         result = self._values.get("content")
@@ -1028,7 +970,6 @@ class CfnSchemaProps:
     def registry_name(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.RegistryName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-registryname
         """
         result = self._values.get("registry_name")
@@ -1039,7 +980,6 @@ class CfnSchemaProps:
     def type(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.Type``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-type
         """
         result = self._values.get("type")
@@ -1050,7 +990,6 @@ class CfnSchemaProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Schema.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-description
         """
         result = self._values.get("description")
@@ -1060,17 +999,15 @@ class CfnSchemaProps:
     def schema_name(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Schema.SchemaName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-schemaname
         """
         result = self._values.get("schema_name")
         return result
 
     @builtins.property
-    def tags(self) -> typing.Optional[typing.List["CfnSchema.TagsEntryProperty"]]:
+    def tags(self) -> typing.Optional[typing.List[CfnSchema.TagsEntryProperty]]:
         """``AWS::EventSchemas::Schema.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-tags
         """
         result = self._values.get("tags")
