@@ -27,10 +27,8 @@ class CfnNotificationChannel(
 ):
     """A CloudFormation ``AWS::FMS::NotificationChannel``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::FMS::NotificationChannel
+    :cloudformationResource: AWS::FMS::NotificationChannel
     """
 
     def __init__(
@@ -56,11 +54,10 @@ class CfnNotificationChannel(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -91,7 +88,6 @@ class CfnNotificationChannel(
     def sns_role_name(self) -> builtins.str:
         """``AWS::FMS::NotificationChannel.SnsRoleName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html#cfn-fms-notificationchannel-snsrolename
         """
         return jsii.get(self, "snsRoleName")
@@ -105,7 +101,6 @@ class CfnNotificationChannel(
     def sns_topic_arn(self) -> builtins.str:
         """``AWS::FMS::NotificationChannel.SnsTopicArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html#cfn-fms-notificationchannel-snstopicarn
         """
         return jsii.get(self, "snsTopicArn")
@@ -132,7 +127,6 @@ class CfnNotificationChannelProps:
         :param sns_role_name: ``AWS::FMS::NotificationChannel.SnsRoleName``.
         :param sns_topic_arn: ``AWS::FMS::NotificationChannel.SnsTopicArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -144,7 +138,6 @@ class CfnNotificationChannelProps:
     def sns_role_name(self) -> builtins.str:
         """``AWS::FMS::NotificationChannel.SnsRoleName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html#cfn-fms-notificationchannel-snsrolename
         """
         result = self._values.get("sns_role_name")
@@ -155,7 +148,6 @@ class CfnNotificationChannelProps:
     def sns_topic_arn(self) -> builtins.str:
         """``AWS::FMS::NotificationChannel.SnsTopicArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html#cfn-fms-notificationchannel-snstopicarn
         """
         result = self._values.get("sns_topic_arn")
@@ -182,10 +174,8 @@ class CfnPolicy(
 ):
     """A CloudFormation ``AWS::FMS::Policy``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::FMS::Policy
+    :cloudformationResource: AWS::FMS::Policy
     """
 
     def __init__(
@@ -199,11 +189,11 @@ class CfnPolicy(
         resource_type: builtins.str,
         security_service_policy_data: typing.Any,
         delete_all_policy_resources: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
-        exclude_map: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]] = None,
-        include_map: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]] = None,
-        resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]] = None,
+        exclude_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]] = None,
+        include_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]] = None,
+        resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]] = None,
         resource_type_list: typing.Optional[typing.List[builtins.str]] = None,
-        tags: typing.Optional[typing.List["PolicyTagProperty"]] = None,
+        tags: typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::FMS::Policy``.
 
@@ -239,11 +229,10 @@ class CfnPolicy(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -268,8 +257,7 @@ class CfnPolicy(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -277,8 +265,7 @@ class CfnPolicy(
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Id
+        :cloudformationAttribute: Id
         """
         return jsii.get(self, "attrId")
 
@@ -294,7 +281,6 @@ class CfnPolicy(
     ) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::FMS::Policy.ExcludeResourceTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-excluderesourcetags
         """
         return jsii.get(self, "excludeResourceTags")
@@ -311,7 +297,6 @@ class CfnPolicy(
     def policy_name(self) -> builtins.str:
         """``AWS::FMS::Policy.PolicyName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-policyname
         """
         return jsii.get(self, "policyName")
@@ -325,7 +310,6 @@ class CfnPolicy(
     def remediation_enabled(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::FMS::Policy.RemediationEnabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-remediationenabled
         """
         return jsii.get(self, "remediationEnabled")
@@ -342,7 +326,6 @@ class CfnPolicy(
     def resource_type(self) -> builtins.str:
         """``AWS::FMS::Policy.ResourceType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetype
         """
         return jsii.get(self, "resourceType")
@@ -356,7 +339,6 @@ class CfnPolicy(
     def security_service_policy_data(self) -> typing.Any:
         """``AWS::FMS::Policy.SecurityServicePolicyData``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-securityservicepolicydata
         """
         return jsii.get(self, "securityServicePolicyData")
@@ -372,7 +354,6 @@ class CfnPolicy(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.DeleteAllPolicyResources``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-deleteallpolicyresources
         """
         return jsii.get(self, "deleteAllPolicyResources")
@@ -388,10 +369,9 @@ class CfnPolicy(
     @jsii.member(jsii_name="excludeMap")
     def exclude_map(
         self,
-    ) -> typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.ExcludeMap``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-excludemap
         """
         return jsii.get(self, "excludeMap")
@@ -399,7 +379,7 @@ class CfnPolicy(
     @exclude_map.setter # type: ignore
     def exclude_map(
         self,
-        value: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "excludeMap", value)
 
@@ -407,10 +387,9 @@ class CfnPolicy(
     @jsii.member(jsii_name="includeMap")
     def include_map(
         self,
-    ) -> typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.IncludeMap``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-includemap
         """
         return jsii.get(self, "includeMap")
@@ -418,7 +397,7 @@ class CfnPolicy(
     @include_map.setter # type: ignore
     def include_map(
         self,
-        value: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "includeMap", value)
 
@@ -426,10 +405,9 @@ class CfnPolicy(
     @jsii.member(jsii_name="resourceTags")
     def resource_tags(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::FMS::Policy.ResourceTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetags
         """
         return jsii.get(self, "resourceTags")
@@ -437,7 +415,7 @@ class CfnPolicy(
     @resource_tags.setter # type: ignore
     def resource_tags(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "resourceTags", value)
 
@@ -446,7 +424,6 @@ class CfnPolicy(
     def resource_type_list(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::FMS::Policy.ResourceTypeList``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetypelist
         """
         return jsii.get(self, "resourceTypeList")
@@ -460,22 +437,23 @@ class CfnPolicy(
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
-    def tags(self) -> typing.Optional[typing.List["PolicyTagProperty"]]:
+    def tags(self) -> typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]]:
         """``AWS::FMS::Policy.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-tags
         """
         return jsii.get(self, "tags")
 
     @tags.setter # type: ignore
-    def tags(self, value: typing.Optional[typing.List["PolicyTagProperty"]]) -> None:
+    def tags(
+        self,
+        value: typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]],
+    ) -> None:
         jsii.set(self, "tags", value)
 
     @jsii.interface(jsii_type="monocdk-experiment.aws_fms.CfnPolicy.IEMapProperty")
     class IEMapProperty(typing_extensions.Protocol):
         """
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html
         """
 
@@ -488,7 +466,6 @@ class CfnPolicy(
         def account(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPolicy.IEMapProperty.ACCOUNT``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html#cfn-fms-policy-iemap-account
             """
             ...
@@ -498,7 +475,6 @@ class CfnPolicy(
         def orgunit(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPolicy.IEMapProperty.ORGUNIT``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html#cfn-fms-policy-iemap-orgunit
             """
             ...
@@ -506,7 +482,6 @@ class CfnPolicy(
 
     class _IEMapPropertyProxy:
         """
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html
         """
 
@@ -517,7 +492,6 @@ class CfnPolicy(
         def account(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPolicy.IEMapProperty.ACCOUNT``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html#cfn-fms-policy-iemap-account
             """
             return jsii.get(self, "account")
@@ -527,7 +501,6 @@ class CfnPolicy(
         def orgunit(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPolicy.IEMapProperty.ORGUNIT``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html#cfn-fms-policy-iemap-orgunit
             """
             return jsii.get(self, "orgunit")
@@ -543,7 +516,6 @@ class CfnPolicy(
             :param key: ``CfnPolicy.PolicyTagProperty.Key``.
             :param value: ``CfnPolicy.PolicyTagProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policytag.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -555,7 +527,6 @@ class CfnPolicy(
         def key(self) -> builtins.str:
             """``CfnPolicy.PolicyTagProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policytag.html#cfn-fms-policy-policytag-key
             """
             result = self._values.get("key")
@@ -566,7 +537,6 @@ class CfnPolicy(
         def value(self) -> builtins.str:
             """``CfnPolicy.PolicyTagProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policytag.html#cfn-fms-policy-policytag-value
             """
             result = self._values.get("value")
@@ -600,7 +570,6 @@ class CfnPolicy(
             :param key: ``CfnPolicy.ResourceTagProperty.Key``.
             :param value: ``CfnPolicy.ResourceTagProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-resourcetag.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -613,7 +582,6 @@ class CfnPolicy(
         def key(self) -> builtins.str:
             """``CfnPolicy.ResourceTagProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-resourcetag.html#cfn-fms-policy-resourcetag-key
             """
             result = self._values.get("key")
@@ -624,7 +592,6 @@ class CfnPolicy(
         def value(self) -> typing.Optional[builtins.str]:
             """``CfnPolicy.ResourceTagProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-resourcetag.html#cfn-fms-policy-resourcetag-value
             """
             result = self._values.get("value")
@@ -669,11 +636,11 @@ class CfnPolicyProps:
         resource_type: builtins.str,
         security_service_policy_data: typing.Any,
         delete_all_policy_resources: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
-        exclude_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]] = None,
-        include_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]] = None,
-        resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]] = None,
+        exclude_map: typing.Optional[typing.Union[CfnPolicy.IEMapProperty, _IResolvable_9ceae33e]] = None,
+        include_map: typing.Optional[typing.Union[CfnPolicy.IEMapProperty, _IResolvable_9ceae33e]] = None,
+        resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPolicy.ResourceTagProperty, _IResolvable_9ceae33e]]]] = None,
         resource_type_list: typing.Optional[typing.List[builtins.str]] = None,
-        tags: typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]] = None,
+        tags: typing.Optional[typing.List[CfnPolicy.PolicyTagProperty]] = None,
     ) -> None:
         """Properties for defining a ``AWS::FMS::Policy``.
 
@@ -689,7 +656,6 @@ class CfnPolicyProps:
         :param resource_type_list: ``AWS::FMS::Policy.ResourceTypeList``.
         :param tags: ``AWS::FMS::Policy.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -718,7 +684,6 @@ class CfnPolicyProps:
     ) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::FMS::Policy.ExcludeResourceTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-excluderesourcetags
         """
         result = self._values.get("exclude_resource_tags")
@@ -729,7 +694,6 @@ class CfnPolicyProps:
     def policy_name(self) -> builtins.str:
         """``AWS::FMS::Policy.PolicyName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-policyname
         """
         result = self._values.get("policy_name")
@@ -740,7 +704,6 @@ class CfnPolicyProps:
     def remediation_enabled(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::FMS::Policy.RemediationEnabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-remediationenabled
         """
         result = self._values.get("remediation_enabled")
@@ -751,7 +714,6 @@ class CfnPolicyProps:
     def resource_type(self) -> builtins.str:
         """``AWS::FMS::Policy.ResourceType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetype
         """
         result = self._values.get("resource_type")
@@ -762,7 +724,6 @@ class CfnPolicyProps:
     def security_service_policy_data(self) -> typing.Any:
         """``AWS::FMS::Policy.SecurityServicePolicyData``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-securityservicepolicydata
         """
         result = self._values.get("security_service_policy_data")
@@ -775,7 +736,6 @@ class CfnPolicyProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.DeleteAllPolicyResources``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-deleteallpolicyresources
         """
         result = self._values.get("delete_all_policy_resources")
@@ -784,10 +744,9 @@ class CfnPolicyProps:
     @builtins.property
     def exclude_map(
         self,
-    ) -> typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnPolicy.IEMapProperty, _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.ExcludeMap``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-excludemap
         """
         result = self._values.get("exclude_map")
@@ -796,10 +755,9 @@ class CfnPolicyProps:
     @builtins.property
     def include_map(
         self,
-    ) -> typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnPolicy.IEMapProperty, _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.IncludeMap``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-includemap
         """
         result = self._values.get("include_map")
@@ -808,10 +766,9 @@ class CfnPolicyProps:
     @builtins.property
     def resource_tags(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnPolicy.ResourceTagProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::FMS::Policy.ResourceTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetags
         """
         result = self._values.get("resource_tags")
@@ -821,17 +778,15 @@ class CfnPolicyProps:
     def resource_type_list(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::FMS::Policy.ResourceTypeList``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetypelist
         """
         result = self._values.get("resource_type_list")
         return result
 
     @builtins.property
-    def tags(self) -> typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]]:
+    def tags(self) -> typing.Optional[typing.List[CfnPolicy.PolicyTagProperty]]:
         """``AWS::FMS::Policy.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-tags
         """
         result = self._values.get("tags")
