@@ -27,10 +27,8 @@ class CfnDetector(
 ):
     """A CloudFormation ``AWS::GuardDuty::Detector``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::GuardDuty::Detector
+    :cloudformationResource: AWS::GuardDuty::Detector
     """
 
     def __init__(
@@ -39,7 +37,7 @@ class CfnDetector(
         id: builtins.str,
         *,
         enable: typing.Union[builtins.bool, _IResolvable_9ceae33e],
-        data_sources: typing.Optional[typing.Union["CFNDataSourceConfigurationsProperty", _IResolvable_9ceae33e]] = None,
+        data_sources: typing.Optional[typing.Union["CfnDetector.CFNDataSourceConfigurationsProperty", _IResolvable_9ceae33e]] = None,
         finding_publishing_frequency: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::GuardDuty::Detector``.
@@ -60,11 +58,10 @@ class CfnDetector(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -95,7 +92,6 @@ class CfnDetector(
     def enable(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::GuardDuty::Detector.Enable``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-enable
         """
         return jsii.get(self, "enable")
@@ -108,10 +104,9 @@ class CfnDetector(
     @jsii.member(jsii_name="dataSources")
     def data_sources(
         self,
-    ) -> typing.Optional[typing.Union["CFNDataSourceConfigurationsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnDetector.CFNDataSourceConfigurationsProperty", _IResolvable_9ceae33e]]:
         """``AWS::GuardDuty::Detector.DataSources``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-datasources
         """
         return jsii.get(self, "dataSources")
@@ -119,7 +114,7 @@ class CfnDetector(
     @data_sources.setter # type: ignore
     def data_sources(
         self,
-        value: typing.Optional[typing.Union["CFNDataSourceConfigurationsProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnDetector.CFNDataSourceConfigurationsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "dataSources", value)
 
@@ -128,7 +123,6 @@ class CfnDetector(
     def finding_publishing_frequency(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::Detector.FindingPublishingFrequency``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-findingpublishingfrequency
         """
         return jsii.get(self, "findingPublishingFrequency")
@@ -154,7 +148,6 @@ class CfnDetector(
             """
             :param s3_logs: ``CfnDetector.CFNDataSourceConfigurationsProperty.S3Logs``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-detector-cfndatasourceconfigurations.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -167,7 +160,6 @@ class CfnDetector(
         ) -> typing.Optional[typing.Union["CfnDetector.CFNS3LogsConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnDetector.CFNDataSourceConfigurationsProperty.S3Logs``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-detector-cfndatasourceconfigurations.html#cfn-guardduty-detector-cfndatasourceconfigurations-s3logs
             """
             result = self._values.get("s3_logs")
@@ -198,7 +190,6 @@ class CfnDetector(
             """
             :param enable: ``CfnDetector.CFNS3LogsConfigurationProperty.Enable``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-detector-cfns3logsconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -211,7 +202,6 @@ class CfnDetector(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnDetector.CFNS3LogsConfigurationProperty.Enable``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-detector-cfns3logsconfiguration.html#cfn-guardduty-detector-cfns3logsconfiguration-enable
             """
             result = self._values.get("enable")
@@ -243,7 +233,7 @@ class CfnDetectorProps:
         self,
         *,
         enable: typing.Union[builtins.bool, _IResolvable_9ceae33e],
-        data_sources: typing.Optional[typing.Union["CfnDetector.CFNDataSourceConfigurationsProperty", _IResolvable_9ceae33e]] = None,
+        data_sources: typing.Optional[typing.Union[CfnDetector.CFNDataSourceConfigurationsProperty, _IResolvable_9ceae33e]] = None,
         finding_publishing_frequency: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::GuardDuty::Detector``.
@@ -252,7 +242,6 @@ class CfnDetectorProps:
         :param data_sources: ``AWS::GuardDuty::Detector.DataSources``.
         :param finding_publishing_frequency: ``AWS::GuardDuty::Detector.FindingPublishingFrequency``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -267,7 +256,6 @@ class CfnDetectorProps:
     def enable(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::GuardDuty::Detector.Enable``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-enable
         """
         result = self._values.get("enable")
@@ -277,10 +265,9 @@ class CfnDetectorProps:
     @builtins.property
     def data_sources(
         self,
-    ) -> typing.Optional[typing.Union["CfnDetector.CFNDataSourceConfigurationsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnDetector.CFNDataSourceConfigurationsProperty, _IResolvable_9ceae33e]]:
         """``AWS::GuardDuty::Detector.DataSources``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-datasources
         """
         result = self._values.get("data_sources")
@@ -290,7 +277,6 @@ class CfnDetectorProps:
     def finding_publishing_frequency(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::Detector.FindingPublishingFrequency``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-findingpublishingfrequency
         """
         result = self._values.get("finding_publishing_frequency")
@@ -316,10 +302,8 @@ class CfnFilter(
 ):
     """A CloudFormation ``AWS::GuardDuty::Filter``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::GuardDuty::Filter
+    :cloudformationResource: AWS::GuardDuty::Filter
     """
 
     def __init__(
@@ -330,7 +314,7 @@ class CfnFilter(
         action: builtins.str,
         description: builtins.str,
         detector_id: builtins.str,
-        finding_criteria: typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e],
+        finding_criteria: typing.Union["CfnFilter.FindingCriteriaProperty", _IResolvable_9ceae33e],
         name: builtins.str,
         rank: jsii.Number,
     ) -> None:
@@ -358,11 +342,10 @@ class CfnFilter(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -393,7 +376,6 @@ class CfnFilter(
     def action(self) -> builtins.str:
         """``AWS::GuardDuty::Filter.Action``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-action
         """
         return jsii.get(self, "action")
@@ -407,7 +389,6 @@ class CfnFilter(
     def description(self) -> builtins.str:
         """``AWS::GuardDuty::Filter.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-description
         """
         return jsii.get(self, "description")
@@ -421,7 +402,6 @@ class CfnFilter(
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::Filter.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-detectorid
         """
         return jsii.get(self, "detectorId")
@@ -434,10 +414,9 @@ class CfnFilter(
     @jsii.member(jsii_name="findingCriteria")
     def finding_criteria(
         self,
-    ) -> typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnFilter.FindingCriteriaProperty", _IResolvable_9ceae33e]:
         """``AWS::GuardDuty::Filter.FindingCriteria``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-findingcriteria
         """
         return jsii.get(self, "findingCriteria")
@@ -445,7 +424,7 @@ class CfnFilter(
     @finding_criteria.setter # type: ignore
     def finding_criteria(
         self,
-        value: typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnFilter.FindingCriteriaProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "findingCriteria", value)
 
@@ -454,7 +433,6 @@ class CfnFilter(
     def name(self) -> builtins.str:
         """``AWS::GuardDuty::Filter.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-name
         """
         return jsii.get(self, "name")
@@ -468,7 +446,6 @@ class CfnFilter(
     def rank(self) -> jsii.Number:
         """``AWS::GuardDuty::Filter.Rank``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-rank
         """
         return jsii.get(self, "rank")
@@ -505,7 +482,6 @@ class CfnFilter(
             :param lte: ``CfnFilter.ConditionProperty.Lte``.
             :param neq: ``CfnFilter.ConditionProperty.Neq``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-filter-condition.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -524,7 +500,6 @@ class CfnFilter(
         def eq(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnFilter.ConditionProperty.Eq``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-filter-condition.html#cfn-guardduty-filter-condition-eq
             """
             result = self._values.get("eq")
@@ -534,7 +509,6 @@ class CfnFilter(
         def gte(self) -> typing.Optional[jsii.Number]:
             """``CfnFilter.ConditionProperty.Gte``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-filter-condition.html#cfn-guardduty-filter-condition-gte
             """
             result = self._values.get("gte")
@@ -544,7 +518,6 @@ class CfnFilter(
         def lt(self) -> typing.Optional[jsii.Number]:
             """``CfnFilter.ConditionProperty.Lt``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-filter-condition.html#cfn-guardduty-filter-condition-lt
             """
             result = self._values.get("lt")
@@ -554,7 +527,6 @@ class CfnFilter(
         def lte(self) -> typing.Optional[jsii.Number]:
             """``CfnFilter.ConditionProperty.Lte``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-filter-condition.html#cfn-guardduty-filter-condition-lte
             """
             result = self._values.get("lte")
@@ -564,7 +536,6 @@ class CfnFilter(
         def neq(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnFilter.ConditionProperty.Neq``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-filter-condition.html#cfn-guardduty-filter-condition-neq
             """
             result = self._values.get("neq")
@@ -597,7 +568,6 @@ class CfnFilter(
             :param criterion: ``CfnFilter.FindingCriteriaProperty.Criterion``.
             :param item_type: ``CfnFilter.FindingCriteriaProperty.ItemType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-filter-findingcriteria.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -610,7 +580,6 @@ class CfnFilter(
         def criterion(self) -> typing.Any:
             """``CfnFilter.FindingCriteriaProperty.Criterion``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-filter-findingcriteria.html#cfn-guardduty-filter-findingcriteria-criterion
             """
             result = self._values.get("criterion")
@@ -622,7 +591,6 @@ class CfnFilter(
         ) -> typing.Optional[typing.Union["CfnFilter.ConditionProperty", _IResolvable_9ceae33e]]:
             """``CfnFilter.FindingCriteriaProperty.ItemType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-guardduty-filter-findingcriteria.html#cfn-guardduty-filter-findingcriteria-itemtype
             """
             result = self._values.get("item_type")
@@ -659,7 +627,7 @@ class CfnFilterProps:
         action: builtins.str,
         description: builtins.str,
         detector_id: builtins.str,
-        finding_criteria: typing.Union["CfnFilter.FindingCriteriaProperty", _IResolvable_9ceae33e],
+        finding_criteria: typing.Union[CfnFilter.FindingCriteriaProperty, _IResolvable_9ceae33e],
         name: builtins.str,
         rank: jsii.Number,
     ) -> None:
@@ -672,7 +640,6 @@ class CfnFilterProps:
         :param name: ``AWS::GuardDuty::Filter.Name``.
         :param rank: ``AWS::GuardDuty::Filter.Rank``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -688,7 +655,6 @@ class CfnFilterProps:
     def action(self) -> builtins.str:
         """``AWS::GuardDuty::Filter.Action``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-action
         """
         result = self._values.get("action")
@@ -699,7 +665,6 @@ class CfnFilterProps:
     def description(self) -> builtins.str:
         """``AWS::GuardDuty::Filter.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-description
         """
         result = self._values.get("description")
@@ -710,7 +675,6 @@ class CfnFilterProps:
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::Filter.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-detectorid
         """
         result = self._values.get("detector_id")
@@ -720,10 +684,9 @@ class CfnFilterProps:
     @builtins.property
     def finding_criteria(
         self,
-    ) -> typing.Union["CfnFilter.FindingCriteriaProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnFilter.FindingCriteriaProperty, _IResolvable_9ceae33e]:
         """``AWS::GuardDuty::Filter.FindingCriteria``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-findingcriteria
         """
         result = self._values.get("finding_criteria")
@@ -734,7 +697,6 @@ class CfnFilterProps:
     def name(self) -> builtins.str:
         """``AWS::GuardDuty::Filter.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-name
         """
         result = self._values.get("name")
@@ -745,7 +707,6 @@ class CfnFilterProps:
     def rank(self) -> jsii.Number:
         """``AWS::GuardDuty::Filter.Rank``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-filter.html#cfn-guardduty-filter-rank
         """
         result = self._values.get("rank")
@@ -772,10 +733,8 @@ class CfnIPSet(
 ):
     """A CloudFormation ``AWS::GuardDuty::IPSet``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::GuardDuty::IPSet
+    :cloudformationResource: AWS::GuardDuty::IPSet
     """
 
     def __init__(
@@ -811,11 +770,10 @@ class CfnIPSet(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -846,7 +804,6 @@ class CfnIPSet(
     def activate(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::GuardDuty::IPSet.Activate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-activate
         """
         return jsii.get(self, "activate")
@@ -863,7 +820,6 @@ class CfnIPSet(
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::IPSet.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-detectorid
         """
         return jsii.get(self, "detectorId")
@@ -877,7 +833,6 @@ class CfnIPSet(
     def format(self) -> builtins.str:
         """``AWS::GuardDuty::IPSet.Format``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-format
         """
         return jsii.get(self, "format")
@@ -891,7 +846,6 @@ class CfnIPSet(
     def location(self) -> builtins.str:
         """``AWS::GuardDuty::IPSet.Location``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-location
         """
         return jsii.get(self, "location")
@@ -905,7 +859,6 @@ class CfnIPSet(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::IPSet.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-name
         """
         return jsii.get(self, "name")
@@ -944,7 +897,6 @@ class CfnIPSetProps:
         :param location: ``AWS::GuardDuty::IPSet.Location``.
         :param name: ``AWS::GuardDuty::IPSet.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -960,7 +912,6 @@ class CfnIPSetProps:
     def activate(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::GuardDuty::IPSet.Activate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-activate
         """
         result = self._values.get("activate")
@@ -971,7 +922,6 @@ class CfnIPSetProps:
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::IPSet.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-detectorid
         """
         result = self._values.get("detector_id")
@@ -982,7 +932,6 @@ class CfnIPSetProps:
     def format(self) -> builtins.str:
         """``AWS::GuardDuty::IPSet.Format``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-format
         """
         result = self._values.get("format")
@@ -993,7 +942,6 @@ class CfnIPSetProps:
     def location(self) -> builtins.str:
         """``AWS::GuardDuty::IPSet.Location``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-location
         """
         result = self._values.get("location")
@@ -1004,7 +952,6 @@ class CfnIPSetProps:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::IPSet.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-ipset.html#cfn-guardduty-ipset-name
         """
         result = self._values.get("name")
@@ -1030,10 +977,8 @@ class CfnMaster(
 ):
     """A CloudFormation ``AWS::GuardDuty::Master``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-master.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::GuardDuty::Master
+    :cloudformationResource: AWS::GuardDuty::Master
     """
 
     def __init__(
@@ -1061,11 +1006,10 @@ class CfnMaster(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -1096,7 +1040,6 @@ class CfnMaster(
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::Master.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-master.html#cfn-guardduty-master-detectorid
         """
         return jsii.get(self, "detectorId")
@@ -1110,7 +1053,6 @@ class CfnMaster(
     def master_id(self) -> builtins.str:
         """``AWS::GuardDuty::Master.MasterId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-master.html#cfn-guardduty-master-masterid
         """
         return jsii.get(self, "masterId")
@@ -1124,7 +1066,6 @@ class CfnMaster(
     def invitation_id(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::Master.InvitationId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-master.html#cfn-guardduty-master-invitationid
         """
         return jsii.get(self, "invitationId")
@@ -1157,7 +1098,6 @@ class CfnMasterProps:
         :param master_id: ``AWS::GuardDuty::Master.MasterId``.
         :param invitation_id: ``AWS::GuardDuty::Master.InvitationId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-master.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1171,7 +1111,6 @@ class CfnMasterProps:
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::Master.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-master.html#cfn-guardduty-master-detectorid
         """
         result = self._values.get("detector_id")
@@ -1182,7 +1121,6 @@ class CfnMasterProps:
     def master_id(self) -> builtins.str:
         """``AWS::GuardDuty::Master.MasterId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-master.html#cfn-guardduty-master-masterid
         """
         result = self._values.get("master_id")
@@ -1193,7 +1131,6 @@ class CfnMasterProps:
     def invitation_id(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::Master.InvitationId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-master.html#cfn-guardduty-master-invitationid
         """
         result = self._values.get("invitation_id")
@@ -1219,10 +1156,8 @@ class CfnMember(
 ):
     """A CloudFormation ``AWS::GuardDuty::Member``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::GuardDuty::Member
+    :cloudformationResource: AWS::GuardDuty::Member
     """
 
     def __init__(
@@ -1261,11 +1196,10 @@ class CfnMember(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -1296,7 +1230,6 @@ class CfnMember(
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::Member.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-detectorid
         """
         return jsii.get(self, "detectorId")
@@ -1310,7 +1243,6 @@ class CfnMember(
     def email(self) -> builtins.str:
         """``AWS::GuardDuty::Member.Email``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-email
         """
         return jsii.get(self, "email")
@@ -1324,7 +1256,6 @@ class CfnMember(
     def member_id(self) -> builtins.str:
         """``AWS::GuardDuty::Member.MemberId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-memberid
         """
         return jsii.get(self, "memberId")
@@ -1340,7 +1271,6 @@ class CfnMember(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::GuardDuty::Member.DisableEmailNotification``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-disableemailnotification
         """
         return jsii.get(self, "disableEmailNotification")
@@ -1357,7 +1287,6 @@ class CfnMember(
     def message(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::Member.Message``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-message
         """
         return jsii.get(self, "message")
@@ -1371,7 +1300,6 @@ class CfnMember(
     def status(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::Member.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-status
         """
         return jsii.get(self, "status")
@@ -1413,7 +1341,6 @@ class CfnMemberProps:
         :param message: ``AWS::GuardDuty::Member.Message``.
         :param status: ``AWS::GuardDuty::Member.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1432,7 +1359,6 @@ class CfnMemberProps:
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::Member.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-detectorid
         """
         result = self._values.get("detector_id")
@@ -1443,7 +1369,6 @@ class CfnMemberProps:
     def email(self) -> builtins.str:
         """``AWS::GuardDuty::Member.Email``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-email
         """
         result = self._values.get("email")
@@ -1454,7 +1379,6 @@ class CfnMemberProps:
     def member_id(self) -> builtins.str:
         """``AWS::GuardDuty::Member.MemberId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-memberid
         """
         result = self._values.get("member_id")
@@ -1467,7 +1391,6 @@ class CfnMemberProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::GuardDuty::Member.DisableEmailNotification``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-disableemailnotification
         """
         result = self._values.get("disable_email_notification")
@@ -1477,7 +1400,6 @@ class CfnMemberProps:
     def message(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::Member.Message``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-message
         """
         result = self._values.get("message")
@@ -1487,7 +1409,6 @@ class CfnMemberProps:
     def status(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::Member.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-member.html#cfn-guardduty-member-status
         """
         result = self._values.get("status")
@@ -1513,10 +1434,8 @@ class CfnThreatIntelSet(
 ):
     """A CloudFormation ``AWS::GuardDuty::ThreatIntelSet``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::GuardDuty::ThreatIntelSet
+    :cloudformationResource: AWS::GuardDuty::ThreatIntelSet
     """
 
     def __init__(
@@ -1552,11 +1471,10 @@ class CfnThreatIntelSet(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -1587,7 +1505,6 @@ class CfnThreatIntelSet(
     def activate(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::GuardDuty::ThreatIntelSet.Activate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-activate
         """
         return jsii.get(self, "activate")
@@ -1604,7 +1521,6 @@ class CfnThreatIntelSet(
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::ThreatIntelSet.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-detectorid
         """
         return jsii.get(self, "detectorId")
@@ -1618,7 +1534,6 @@ class CfnThreatIntelSet(
     def format(self) -> builtins.str:
         """``AWS::GuardDuty::ThreatIntelSet.Format``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-format
         """
         return jsii.get(self, "format")
@@ -1632,7 +1547,6 @@ class CfnThreatIntelSet(
     def location(self) -> builtins.str:
         """``AWS::GuardDuty::ThreatIntelSet.Location``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-location
         """
         return jsii.get(self, "location")
@@ -1646,7 +1560,6 @@ class CfnThreatIntelSet(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::ThreatIntelSet.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-name
         """
         return jsii.get(self, "name")
@@ -1685,7 +1598,6 @@ class CfnThreatIntelSetProps:
         :param location: ``AWS::GuardDuty::ThreatIntelSet.Location``.
         :param name: ``AWS::GuardDuty::ThreatIntelSet.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1701,7 +1613,6 @@ class CfnThreatIntelSetProps:
     def activate(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::GuardDuty::ThreatIntelSet.Activate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-activate
         """
         result = self._values.get("activate")
@@ -1712,7 +1623,6 @@ class CfnThreatIntelSetProps:
     def detector_id(self) -> builtins.str:
         """``AWS::GuardDuty::ThreatIntelSet.DetectorId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-detectorid
         """
         result = self._values.get("detector_id")
@@ -1723,7 +1633,6 @@ class CfnThreatIntelSetProps:
     def format(self) -> builtins.str:
         """``AWS::GuardDuty::ThreatIntelSet.Format``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-format
         """
         result = self._values.get("format")
@@ -1734,7 +1643,6 @@ class CfnThreatIntelSetProps:
     def location(self) -> builtins.str:
         """``AWS::GuardDuty::ThreatIntelSet.Location``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-location
         """
         result = self._values.get("location")
@@ -1745,7 +1653,6 @@ class CfnThreatIntelSetProps:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::GuardDuty::ThreatIntelSet.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-threatintelset.html#cfn-guardduty-threatintelset-name
         """
         result = self._values.get("name")
