@@ -28,10 +28,8 @@ class CfnAssessmentTarget(
 ):
     """A CloudFormation ``AWS::Inspector::AssessmentTarget``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Inspector::AssessmentTarget
+    :cloudformationResource: AWS::Inspector::AssessmentTarget
     """
 
     def __init__(
@@ -58,11 +56,10 @@ class CfnAssessmentTarget(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -87,8 +84,7 @@ class CfnAssessmentTarget(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -102,7 +98,6 @@ class CfnAssessmentTarget(
     def assessment_target_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
         """
         return jsii.get(self, "assessmentTargetName")
@@ -116,7 +111,6 @@ class CfnAssessmentTarget(
     def resource_group_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
         """
         return jsii.get(self, "resourceGroupArn")
@@ -146,7 +140,6 @@ class CfnAssessmentTargetProps:
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
         :param resource_group_arn: ``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -159,7 +152,6 @@ class CfnAssessmentTargetProps:
     def assessment_target_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
         """
         result = self._values.get("assessment_target_name")
@@ -169,7 +161,6 @@ class CfnAssessmentTargetProps:
     def resource_group_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
         """
         result = self._values.get("resource_group_arn")
@@ -195,10 +186,8 @@ class CfnAssessmentTemplate(
 ):
     """A CloudFormation ``AWS::Inspector::AssessmentTemplate``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Inspector::AssessmentTemplate
+    :cloudformationResource: AWS::Inspector::AssessmentTemplate
     """
 
     def __init__(
@@ -234,11 +223,10 @@ class CfnAssessmentTemplate(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -263,8 +251,7 @@ class CfnAssessmentTemplate(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -278,7 +265,6 @@ class CfnAssessmentTemplate(
     def assessment_target_arn(self) -> builtins.str:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
         """
         return jsii.get(self, "assessmentTargetArn")
@@ -292,7 +278,6 @@ class CfnAssessmentTemplate(
     def duration_in_seconds(self) -> jsii.Number:
         """``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
         """
         return jsii.get(self, "durationInSeconds")
@@ -306,7 +291,6 @@ class CfnAssessmentTemplate(
     def rules_package_arns(self) -> typing.List[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
         """
         return jsii.get(self, "rulesPackageArns")
@@ -320,7 +304,6 @@ class CfnAssessmentTemplate(
     def assessment_template_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
         """
         return jsii.get(self, "assessmentTemplateName")
@@ -336,7 +319,6 @@ class CfnAssessmentTemplate(
     ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
         """
         return jsii.get(self, "userAttributesForFindings")
@@ -378,7 +360,6 @@ class CfnAssessmentTemplateProps:
         :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param user_attributes_for_findings: ``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -395,7 +376,6 @@ class CfnAssessmentTemplateProps:
     def assessment_target_arn(self) -> builtins.str:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
         """
         result = self._values.get("assessment_target_arn")
@@ -406,7 +386,6 @@ class CfnAssessmentTemplateProps:
     def duration_in_seconds(self) -> jsii.Number:
         """``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
         """
         result = self._values.get("duration_in_seconds")
@@ -417,7 +396,6 @@ class CfnAssessmentTemplateProps:
     def rules_package_arns(self) -> typing.List[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
         """
         result = self._values.get("rules_package_arns")
@@ -428,7 +406,6 @@ class CfnAssessmentTemplateProps:
     def assessment_template_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
         """
         result = self._values.get("assessment_template_name")
@@ -440,7 +417,6 @@ class CfnAssessmentTemplateProps:
     ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
         """
         result = self._values.get("user_attributes_for_findings")
@@ -466,10 +442,8 @@ class CfnResourceGroup(
 ):
     """A CloudFormation ``AWS::Inspector::ResourceGroup``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Inspector::ResourceGroup
+    :cloudformationResource: AWS::Inspector::ResourceGroup
     """
 
     def __init__(
@@ -491,11 +465,10 @@ class CfnResourceGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -520,8 +493,7 @@ class CfnResourceGroup(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -537,7 +509,6 @@ class CfnResourceGroup(
     ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
         """
         return jsii.get(self, "resourceGroupTags")
@@ -565,7 +536,6 @@ class CfnResourceGroupProps:
 
         :param resource_group_tags: ``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -578,7 +548,6 @@ class CfnResourceGroupProps:
     ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
         """
         result = self._values.get("resource_group_tags")
