@@ -27,10 +27,8 @@ class CfnDevice(
 ):
     """A CloudFormation ``AWS::IoT1Click::Device``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::IoT1Click::Device
+    :cloudformationResource: AWS::IoT1Click::Device
     """
 
     def __init__(
@@ -54,11 +52,10 @@ class CfnDevice(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -83,8 +80,7 @@ class CfnDevice(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -92,8 +88,7 @@ class CfnDevice(
     @jsii.member(jsii_name="attrDeviceId")
     def attr_device_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: DeviceId
+        :cloudformationAttribute: DeviceId
         """
         return jsii.get(self, "attrDeviceId")
 
@@ -101,8 +96,7 @@ class CfnDevice(
     @jsii.member(jsii_name="attrEnabled")
     def attr_enabled(self) -> _IResolvable_9ceae33e:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Enabled
+        :cloudformationAttribute: Enabled
         """
         return jsii.get(self, "attrEnabled")
 
@@ -116,7 +110,6 @@ class CfnDevice(
     def device_id(self) -> builtins.str:
         """``AWS::IoT1Click::Device.DeviceId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html#cfn-iot1click-device-deviceid
         """
         return jsii.get(self, "deviceId")
@@ -130,7 +123,6 @@ class CfnDevice(
     def enabled(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::IoT1Click::Device.Enabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html#cfn-iot1click-device-enabled
         """
         return jsii.get(self, "enabled")
@@ -160,7 +152,6 @@ class CfnDeviceProps:
         :param device_id: ``AWS::IoT1Click::Device.DeviceId``.
         :param enabled: ``AWS::IoT1Click::Device.Enabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -172,7 +163,6 @@ class CfnDeviceProps:
     def device_id(self) -> builtins.str:
         """``AWS::IoT1Click::Device.DeviceId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html#cfn-iot1click-device-deviceid
         """
         result = self._values.get("device_id")
@@ -183,7 +173,6 @@ class CfnDeviceProps:
     def enabled(self) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::IoT1Click::Device.Enabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-device.html#cfn-iot1click-device-enabled
         """
         result = self._values.get("enabled")
@@ -210,10 +199,8 @@ class CfnPlacement(
 ):
     """A CloudFormation ``AWS::IoT1Click::Placement``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::IoT1Click::Placement
+    :cloudformationResource: AWS::IoT1Click::Placement
     """
 
     def __init__(
@@ -246,11 +233,10 @@ class CfnPlacement(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -275,8 +261,7 @@ class CfnPlacement(
     @jsii.member(jsii_name="attrPlacementName")
     def attr_placement_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: PlacementName
+        :cloudformationAttribute: PlacementName
         """
         return jsii.get(self, "attrPlacementName")
 
@@ -284,8 +269,7 @@ class CfnPlacement(
     @jsii.member(jsii_name="attrProjectName")
     def attr_project_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ProjectName
+        :cloudformationAttribute: ProjectName
         """
         return jsii.get(self, "attrProjectName")
 
@@ -299,7 +283,6 @@ class CfnPlacement(
     def associated_devices(self) -> typing.Any:
         """``AWS::IoT1Click::Placement.AssociatedDevices``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-associateddevices
         """
         return jsii.get(self, "associatedDevices")
@@ -313,7 +296,6 @@ class CfnPlacement(
     def attributes(self) -> typing.Any:
         """``AWS::IoT1Click::Placement.Attributes``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-attributes
         """
         return jsii.get(self, "attributes")
@@ -327,7 +309,6 @@ class CfnPlacement(
     def project_name(self) -> builtins.str:
         """``AWS::IoT1Click::Placement.ProjectName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-projectname
         """
         return jsii.get(self, "projectName")
@@ -341,7 +322,6 @@ class CfnPlacement(
     def placement_name(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Placement.PlacementName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-placementname
         """
         return jsii.get(self, "placementName")
@@ -377,7 +357,6 @@ class CfnPlacementProps:
         :param attributes: ``AWS::IoT1Click::Placement.Attributes``.
         :param placement_name: ``AWS::IoT1Click::Placement.PlacementName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -394,7 +373,6 @@ class CfnPlacementProps:
     def project_name(self) -> builtins.str:
         """``AWS::IoT1Click::Placement.ProjectName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-projectname
         """
         result = self._values.get("project_name")
@@ -405,7 +383,6 @@ class CfnPlacementProps:
     def associated_devices(self) -> typing.Any:
         """``AWS::IoT1Click::Placement.AssociatedDevices``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-associateddevices
         """
         result = self._values.get("associated_devices")
@@ -415,7 +392,6 @@ class CfnPlacementProps:
     def attributes(self) -> typing.Any:
         """``AWS::IoT1Click::Placement.Attributes``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-attributes
         """
         result = self._values.get("attributes")
@@ -425,7 +401,6 @@ class CfnPlacementProps:
     def placement_name(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Placement.PlacementName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-placement.html#cfn-iot1click-placement-placementname
         """
         result = self._values.get("placement_name")
@@ -451,10 +426,8 @@ class CfnProject(
 ):
     """A CloudFormation ``AWS::IoT1Click::Project``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::IoT1Click::Project
+    :cloudformationResource: AWS::IoT1Click::Project
     """
 
     def __init__(
@@ -462,7 +435,7 @@ class CfnProject(
         scope: _Construct_f50a3f53,
         id: builtins.str,
         *,
-        placement_template: typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e],
+        placement_template: typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e],
         description: typing.Optional[builtins.str] = None,
         project_name: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -484,11 +457,10 @@ class CfnProject(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -513,8 +485,7 @@ class CfnProject(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -522,8 +493,7 @@ class CfnProject(
     @jsii.member(jsii_name="attrProjectName")
     def attr_project_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ProjectName
+        :cloudformationAttribute: ProjectName
         """
         return jsii.get(self, "attrProjectName")
 
@@ -536,10 +506,9 @@ class CfnProject(
     @jsii.member(jsii_name="placementTemplate")
     def placement_template(
         self,
-    ) -> typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e]:
         """``AWS::IoT1Click::Project.PlacementTemplate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-placementtemplate
         """
         return jsii.get(self, "placementTemplate")
@@ -547,7 +516,7 @@ class CfnProject(
     @placement_template.setter # type: ignore
     def placement_template(
         self,
-        value: typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "placementTemplate", value)
 
@@ -556,7 +525,6 @@ class CfnProject(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Project.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-description
         """
         return jsii.get(self, "description")
@@ -570,7 +538,6 @@ class CfnProject(
     def project_name(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Project.ProjectName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-projectname
         """
         return jsii.get(self, "projectName")
@@ -598,7 +565,6 @@ class CfnProject(
             :param callback_overrides: ``CfnProject.DeviceTemplateProperty.CallbackOverrides``.
             :param device_type: ``CfnProject.DeviceTemplateProperty.DeviceType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-devicetemplate.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -611,7 +577,6 @@ class CfnProject(
         def callback_overrides(self) -> typing.Any:
             """``CfnProject.DeviceTemplateProperty.CallbackOverrides``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-devicetemplate.html#cfn-iot1click-project-devicetemplate-callbackoverrides
             """
             result = self._values.get("callback_overrides")
@@ -621,7 +586,6 @@ class CfnProject(
         def device_type(self) -> typing.Optional[builtins.str]:
             """``CfnProject.DeviceTemplateProperty.DeviceType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-devicetemplate.html#cfn-iot1click-project-devicetemplate-devicetype
             """
             result = self._values.get("device_type")
@@ -657,7 +621,6 @@ class CfnProject(
             :param default_attributes: ``CfnProject.PlacementTemplateProperty.DefaultAttributes``.
             :param device_templates: ``CfnProject.PlacementTemplateProperty.DeviceTemplates``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-placementtemplate.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -670,7 +633,6 @@ class CfnProject(
         def default_attributes(self) -> typing.Any:
             """``CfnProject.PlacementTemplateProperty.DefaultAttributes``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-placementtemplate.html#cfn-iot1click-project-placementtemplate-defaultattributes
             """
             result = self._values.get("default_attributes")
@@ -682,7 +644,6 @@ class CfnProject(
         ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, typing.Union["CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e]]]]:
             """``CfnProject.PlacementTemplateProperty.DeviceTemplates``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iot1click-project-placementtemplate.html#cfn-iot1click-project-placementtemplate-devicetemplates
             """
             result = self._values.get("device_templates")
@@ -713,7 +674,7 @@ class CfnProjectProps:
     def __init__(
         self,
         *,
-        placement_template: typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e],
+        placement_template: typing.Union[CfnProject.PlacementTemplateProperty, _IResolvable_9ceae33e],
         description: typing.Optional[builtins.str] = None,
         project_name: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -723,7 +684,6 @@ class CfnProjectProps:
         :param description: ``AWS::IoT1Click::Project.Description``.
         :param project_name: ``AWS::IoT1Click::Project.ProjectName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -737,10 +697,9 @@ class CfnProjectProps:
     @builtins.property
     def placement_template(
         self,
-    ) -> typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnProject.PlacementTemplateProperty, _IResolvable_9ceae33e]:
         """``AWS::IoT1Click::Project.PlacementTemplate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-placementtemplate
         """
         result = self._values.get("placement_template")
@@ -751,7 +710,6 @@ class CfnProjectProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Project.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-description
         """
         result = self._values.get("description")
@@ -761,7 +719,6 @@ class CfnProjectProps:
     def project_name(self) -> typing.Optional[builtins.str]:
         """``AWS::IoT1Click::Project.ProjectName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iot1click-project.html#cfn-iot1click-project-projectname
         """
         result = self._values.get("project_name")
