@@ -35,10 +35,8 @@ class CfnStream(
 ):
     """A CloudFormation ``AWS::Kinesis::Stream``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Kinesis::Stream
+    :cloudformationResource: AWS::Kinesis::Stream
     """
 
     def __init__(
@@ -49,7 +47,7 @@ class CfnStream(
         shard_count: jsii.Number,
         name: typing.Optional[builtins.str] = None,
         retention_period_hours: typing.Optional[jsii.Number] = None,
-        stream_encryption: typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]] = None,
+        stream_encryption: typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::Kinesis::Stream``.
@@ -74,11 +72,10 @@ class CfnStream(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -103,8 +100,7 @@ class CfnStream(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -118,7 +114,6 @@ class CfnStream(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::Kinesis::Stream.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-tags
         """
         return jsii.get(self, "tags")
@@ -128,7 +123,6 @@ class CfnStream(
     def shard_count(self) -> jsii.Number:
         """``AWS::Kinesis::Stream.ShardCount``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-shardcount
         """
         return jsii.get(self, "shardCount")
@@ -142,7 +136,6 @@ class CfnStream(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Kinesis::Stream.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-name
         """
         return jsii.get(self, "name")
@@ -156,7 +149,6 @@ class CfnStream(
     def retention_period_hours(self) -> typing.Optional[jsii.Number]:
         """``AWS::Kinesis::Stream.RetentionPeriodHours``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-retentionperiodhours
         """
         return jsii.get(self, "retentionPeriodHours")
@@ -169,10 +161,9 @@ class CfnStream(
     @jsii.member(jsii_name="streamEncryption")
     def stream_encryption(
         self,
-    ) -> typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]]:
         """``AWS::Kinesis::Stream.StreamEncryption``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-streamencryption
         """
         return jsii.get(self, "streamEncryption")
@@ -180,7 +171,7 @@ class CfnStream(
     @stream_encryption.setter # type: ignore
     def stream_encryption(
         self,
-        value: typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "streamEncryption", value)
 
@@ -200,7 +191,6 @@ class CfnStream(
             :param encryption_type: ``CfnStream.StreamEncryptionProperty.EncryptionType``.
             :param key_id: ``CfnStream.StreamEncryptionProperty.KeyId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesis-stream-streamencryption.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -212,7 +202,6 @@ class CfnStream(
         def encryption_type(self) -> builtins.str:
             """``CfnStream.StreamEncryptionProperty.EncryptionType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesis-stream-streamencryption.html#cfn-kinesis-stream-streamencryption-encryptiontype
             """
             result = self._values.get("encryption_type")
@@ -223,7 +212,6 @@ class CfnStream(
         def key_id(self) -> builtins.str:
             """``CfnStream.StreamEncryptionProperty.KeyId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesis-stream-streamencryption.html#cfn-kinesis-stream-streamencryption-keyid
             """
             result = self._values.get("key_id")
@@ -250,10 +238,8 @@ class CfnStreamConsumer(
 ):
     """A CloudFormation ``AWS::Kinesis::StreamConsumer``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Kinesis::StreamConsumer
+    :cloudformationResource: AWS::Kinesis::StreamConsumer
     """
 
     def __init__(
@@ -279,11 +265,10 @@ class CfnStreamConsumer(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -308,8 +293,7 @@ class CfnStreamConsumer(
     @jsii.member(jsii_name="attrConsumerArn")
     def attr_consumer_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ConsumerARN
+        :cloudformationAttribute: ConsumerARN
         """
         return jsii.get(self, "attrConsumerArn")
 
@@ -317,8 +301,7 @@ class CfnStreamConsumer(
     @jsii.member(jsii_name="attrConsumerCreationTimestamp")
     def attr_consumer_creation_timestamp(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ConsumerCreationTimestamp
+        :cloudformationAttribute: ConsumerCreationTimestamp
         """
         return jsii.get(self, "attrConsumerCreationTimestamp")
 
@@ -326,8 +309,7 @@ class CfnStreamConsumer(
     @jsii.member(jsii_name="attrConsumerName")
     def attr_consumer_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ConsumerName
+        :cloudformationAttribute: ConsumerName
         """
         return jsii.get(self, "attrConsumerName")
 
@@ -335,8 +317,7 @@ class CfnStreamConsumer(
     @jsii.member(jsii_name="attrConsumerStatus")
     def attr_consumer_status(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ConsumerStatus
+        :cloudformationAttribute: ConsumerStatus
         """
         return jsii.get(self, "attrConsumerStatus")
 
@@ -344,8 +325,7 @@ class CfnStreamConsumer(
     @jsii.member(jsii_name="attrStreamArn")
     def attr_stream_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: StreamARN
+        :cloudformationAttribute: StreamARN
         """
         return jsii.get(self, "attrStreamArn")
 
@@ -359,7 +339,6 @@ class CfnStreamConsumer(
     def consumer_name(self) -> builtins.str:
         """``AWS::Kinesis::StreamConsumer.ConsumerName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html#cfn-kinesis-streamconsumer-consumername
         """
         return jsii.get(self, "consumerName")
@@ -373,7 +352,6 @@ class CfnStreamConsumer(
     def stream_arn(self) -> builtins.str:
         """``AWS::Kinesis::StreamConsumer.StreamARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html#cfn-kinesis-streamconsumer-streamarn
         """
         return jsii.get(self, "streamArn")
@@ -400,7 +378,6 @@ class CfnStreamConsumerProps:
         :param consumer_name: ``AWS::Kinesis::StreamConsumer.ConsumerName``.
         :param stream_arn: ``AWS::Kinesis::StreamConsumer.StreamARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -412,7 +389,6 @@ class CfnStreamConsumerProps:
     def consumer_name(self) -> builtins.str:
         """``AWS::Kinesis::StreamConsumer.ConsumerName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html#cfn-kinesis-streamconsumer-consumername
         """
         result = self._values.get("consumer_name")
@@ -423,7 +399,6 @@ class CfnStreamConsumerProps:
     def stream_arn(self) -> builtins.str:
         """``AWS::Kinesis::StreamConsumer.StreamARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html#cfn-kinesis-streamconsumer-streamarn
         """
         result = self._values.get("stream_arn")
@@ -460,7 +435,7 @@ class CfnStreamProps:
         shard_count: jsii.Number,
         name: typing.Optional[builtins.str] = None,
         retention_period_hours: typing.Optional[jsii.Number] = None,
-        stream_encryption: typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]] = None,
+        stream_encryption: typing.Optional[typing.Union[CfnStream.StreamEncryptionProperty, _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Kinesis::Stream``.
@@ -471,7 +446,6 @@ class CfnStreamProps:
         :param stream_encryption: ``AWS::Kinesis::Stream.StreamEncryption``.
         :param tags: ``AWS::Kinesis::Stream.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -490,7 +464,6 @@ class CfnStreamProps:
     def shard_count(self) -> jsii.Number:
         """``AWS::Kinesis::Stream.ShardCount``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-shardcount
         """
         result = self._values.get("shard_count")
@@ -501,7 +474,6 @@ class CfnStreamProps:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Kinesis::Stream.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-name
         """
         result = self._values.get("name")
@@ -511,7 +483,6 @@ class CfnStreamProps:
     def retention_period_hours(self) -> typing.Optional[jsii.Number]:
         """``AWS::Kinesis::Stream.RetentionPeriodHours``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-retentionperiodhours
         """
         result = self._values.get("retention_period_hours")
@@ -520,10 +491,9 @@ class CfnStreamProps:
     @builtins.property
     def stream_encryption(
         self,
-    ) -> typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnStream.StreamEncryptionProperty, _IResolvable_9ceae33e]]:
         """``AWS::Kinesis::Stream.StreamEncryption``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-streamencryption
         """
         result = self._values.get("stream_encryption")
@@ -533,7 +503,6 @@ class CfnStreamProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::Kinesis::Stream.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-tags
         """
         result = self._values.get("tags")
@@ -553,9 +522,8 @@ class CfnStreamProps:
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_kinesis.IStream")
 class IStream(_IResource_72f7ee7e, typing_extensions.Protocol):
-    """A Kinesis Stream.
+    """(experimental) A Kinesis Stream.
 
-    stability
     :stability: experimental
     """
 
@@ -566,33 +534,28 @@ class IStream(_IResource_72f7ee7e, typing_extensions.Protocol):
     @builtins.property # type: ignore
     @jsii.member(jsii_name="streamArn")
     def stream_arn(self) -> builtins.str:
-        """The ARN of the stream.
+        """(experimental) The ARN of the stream.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         ...
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="streamName")
     def stream_name(self) -> builtins.str:
-        """The name of the stream.
+        """(experimental) The name of the stream.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         ...
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
-        """Optional KMS encryption key associated with this stream.
+        """(experimental) Optional KMS encryption key associated with this stream.
 
-        stability
         :stability: experimental
         """
         ...
@@ -603,54 +566,50 @@ class IStream(_IResource_72f7ee7e, typing_extensions.Protocol):
         grantee: _IGrantable_0fcfc53a,
         *actions: builtins.str,
     ) -> _Grant_96af6d2d:
-        """Grant the indicated permissions on this stream to the provided IAM principal.
+        """(experimental) Grant the indicated permissions on this stream to the provided IAM principal.
 
         :param grantee: -
         :param actions: -
 
-        stability
         :stability: experimental
         """
         ...
 
     @jsii.member(jsii_name="grantRead")
     def grant_read(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant read permissions for this stream and its contents to an IAM principal (Role/Group/User).
+        """(experimental) Grant read permissions for this stream and its contents to an IAM principal (Role/Group/User).
 
         If an encryption key is used, permission to ues the key to decrypt the
         contents of the stream will also be granted.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         ...
 
     @jsii.member(jsii_name="grantReadWrite")
     def grant_read_write(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grants read/write permissions for this stream and its contents to an IAM principal (Role/Group/User).
+        """(experimental) Grants read/write permissions for this stream and its contents to an IAM principal (Role/Group/User).
 
         If an encryption key is used, permission to use the key for
         encrypt/decrypt will also be granted.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         ...
 
     @jsii.member(jsii_name="grantWrite")
     def grant_write(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant write permissions for this stream and its contents to an IAM principal (Role/Group/User).
+        """(experimental) Grant write permissions for this stream and its contents to an IAM principal (Role/Group/User).
 
         If an encryption key is used, permission to ues the key to encrypt the
         contents of the stream will also be granted.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         ...
@@ -659,9 +618,8 @@ class IStream(_IResource_72f7ee7e, typing_extensions.Protocol):
 class _IStreamProxy(
     jsii.proxy_for(_IResource_72f7ee7e) # type: ignore
 ):
-    """A Kinesis Stream.
+    """(experimental) A Kinesis Stream.
 
-    stability
     :stability: experimental
     """
 
@@ -670,33 +628,28 @@ class _IStreamProxy(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="streamArn")
     def stream_arn(self) -> builtins.str:
-        """The ARN of the stream.
+        """(experimental) The ARN of the stream.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         return jsii.get(self, "streamArn")
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="streamName")
     def stream_name(self) -> builtins.str:
-        """The name of the stream.
+        """(experimental) The name of the stream.
 
-        stability
         :stability: experimental
-        attribute:
-        :attribute:: true
+        :attribute: true
         """
         return jsii.get(self, "streamName")
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
-        """Optional KMS encryption key associated with this stream.
+        """(experimental) Optional KMS encryption key associated with this stream.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "encryptionKey")
@@ -707,54 +660,50 @@ class _IStreamProxy(
         grantee: _IGrantable_0fcfc53a,
         *actions: builtins.str,
     ) -> _Grant_96af6d2d:
-        """Grant the indicated permissions on this stream to the provided IAM principal.
+        """(experimental) Grant the indicated permissions on this stream to the provided IAM principal.
 
         :param grantee: -
         :param actions: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grant", [grantee, *actions])
 
     @jsii.member(jsii_name="grantRead")
     def grant_read(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant read permissions for this stream and its contents to an IAM principal (Role/Group/User).
+        """(experimental) Grant read permissions for this stream and its contents to an IAM principal (Role/Group/User).
 
         If an encryption key is used, permission to ues the key to decrypt the
         contents of the stream will also be granted.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantRead", [grantee])
 
     @jsii.member(jsii_name="grantReadWrite")
     def grant_read_write(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grants read/write permissions for this stream and its contents to an IAM principal (Role/Group/User).
+        """(experimental) Grants read/write permissions for this stream and its contents to an IAM principal (Role/Group/User).
 
         If an encryption key is used, permission to use the key for
         encrypt/decrypt will also be granted.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantReadWrite", [grantee])
 
     @jsii.member(jsii_name="grantWrite")
     def grant_write(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant write permissions for this stream and its contents to an IAM principal (Role/Group/User).
+        """(experimental) Grant write permissions for this stream and its contents to an IAM principal (Role/Group/User).
 
         If an encryption key is used, permission to ues the key to encrypt the
         contents of the stream will also be granted.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantWrite", [grantee])
@@ -766,11 +715,10 @@ class Stream(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_kinesis.Stream",
 ):
-    """A Kinesis stream.
+    """(experimental) A Kinesis stream.
 
     Can be encrypted with a KMS key.
 
-    stability
     :stability: experimental
     """
 
@@ -788,13 +736,12 @@ class Stream(
         """
         :param scope: -
         :param id: -
-        :param encryption: The kind of server-side encryption to apply to this stream. If you choose KMS, you can specify a KMS key via ``encryptionKey``. If encryption key is not specified, a key will automatically be created. Default: - StreamEncryption.KMS if encrypted Streams are supported in the region or StreamEncryption.UNENCRYPTED otherwise. StreamEncryption.KMS if an encryption key is supplied through the encryptionKey property
-        :param encryption_key: External KMS key to use for stream encryption. The 'encryption' property must be set to "Kms". Default: - Kinesis Data Streams master key ('/alias/aws/kinesis'). If encryption is set to StreamEncryption.KMS and this property is undefined, a new KMS key will be created and associated with this stream.
-        :param retention_period: The number of hours for the data records that are stored in shards to remain accessible. Default: Duration.hours(24)
-        :param shard_count: The number of shards for the stream. Default: 1
-        :param stream_name: Enforces a particular physical stream name. Default: 
+        :param encryption: (experimental) The kind of server-side encryption to apply to this stream. If you choose KMS, you can specify a KMS key via ``encryptionKey``. If encryption key is not specified, a key will automatically be created. Default: - StreamEncryption.KMS if encrypted Streams are supported in the region or StreamEncryption.UNENCRYPTED otherwise. StreamEncryption.KMS if an encryption key is supplied through the encryptionKey property
+        :param encryption_key: (experimental) External KMS key to use for stream encryption. The 'encryption' property must be set to "Kms". Default: - Kinesis Data Streams master key ('/alias/aws/kinesis'). If encryption is set to StreamEncryption.KMS and this property is undefined, a new KMS key will be created and associated with this stream.
+        :param retention_period: (experimental) The number of hours for the data records that are stored in shards to remain accessible. Default: Duration.hours(24)
+        :param shard_count: (experimental) The number of shards for the stream. Default: 1
+        :param stream_name: (experimental) Enforces a particular physical stream name. Default: 
 
-        stability
         :stability: experimental
         """
         props = StreamProps(
@@ -814,14 +761,13 @@ class Stream(
         scope: constructs.Construct,
         id: builtins.str,
         stream_arn: builtins.str,
-    ) -> "IStream":
-        """Import an existing Kinesis Stream provided an ARN.
+    ) -> IStream:
+        """(experimental) Import an existing Kinesis Stream provided an ARN.
 
         :param scope: The parent creating construct (usually ``this``).
         :param id: The construct's name.
         :param stream_arn: Stream ARN (i.e. arn:aws:kinesis:::stream/Foo).
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "fromStreamArn", [scope, id, stream_arn])
@@ -835,15 +781,14 @@ class Stream(
         *,
         stream_arn: builtins.str,
         encryption_key: typing.Optional[_IKey_3336c79d] = None,
-    ) -> "IStream":
-        """Creates a Stream construct that represents an external stream.
+    ) -> IStream:
+        """(experimental) Creates a Stream construct that represents an external stream.
 
         :param scope: The parent creating construct (usually ``this``).
         :param id: The construct's name.
-        :param stream_arn: The ARN of the stream.
-        :param encryption_key: The KMS key securing the contents of the stream if encryption is enabled. Default: - No encryption
+        :param stream_arn: (experimental) The ARN of the stream.
+        :param encryption_key: (experimental) The KMS key securing the contents of the stream if encryption is enabled. Default: - No encryption
 
-        stability
         :stability: experimental
         """
         attrs = StreamAttributes(stream_arn=stream_arn, encryption_key=encryption_key)
@@ -856,54 +801,50 @@ class Stream(
         grantee: _IGrantable_0fcfc53a,
         *actions: builtins.str,
     ) -> _Grant_96af6d2d:
-        """Grant the indicated permissions on this stream to the given IAM principal (Role/Group/User).
+        """(experimental) Grant the indicated permissions on this stream to the given IAM principal (Role/Group/User).
 
         :param grantee: -
         :param actions: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grant", [grantee, *actions])
 
     @jsii.member(jsii_name="grantRead")
     def grant_read(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant write permissions for this stream and its contents to an IAM principal (Role/Group/User).
+        """(experimental) Grant write permissions for this stream and its contents to an IAM principal (Role/Group/User).
 
         If an encryption key is used, permission to ues the key to decrypt the
         contents of the stream will also be granted.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantRead", [grantee])
 
     @jsii.member(jsii_name="grantReadWrite")
     def grant_read_write(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grants read/write permissions for this stream and its contents to an IAM principal (Role/Group/User).
+        """(experimental) Grants read/write permissions for this stream and its contents to an IAM principal (Role/Group/User).
 
         If an encryption key is used, permission to use the key for
         encrypt/decrypt will also be granted.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantReadWrite", [grantee])
 
     @jsii.member(jsii_name="grantWrite")
     def grant_write(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
-        """Grant read permissions for this stream and its contents to an IAM principal (Role/Group/User).
+        """(experimental) Grant read permissions for this stream and its contents to an IAM principal (Role/Group/User).
 
         If an encryption key is used, permission to ues the key to decrypt the
         contents of the stream will also be granted.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantWrite", [grantee])
@@ -911,9 +852,8 @@ class Stream(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="streamArn")
     def stream_arn(self) -> builtins.str:
-        """The ARN of the stream.
+        """(experimental) The ARN of the stream.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "streamArn")
@@ -921,9 +861,8 @@ class Stream(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="streamName")
     def stream_name(self) -> builtins.str:
-        """The name of the stream.
+        """(experimental) The name of the stream.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "streamName")
@@ -931,9 +870,8 @@ class Stream(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
-        """Optional KMS encryption key associated with this stream.
+        """(experimental) Optional KMS encryption key associated with this stream.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "encryptionKey")
@@ -951,16 +889,15 @@ class StreamAttributes:
         stream_arn: builtins.str,
         encryption_key: typing.Optional[_IKey_3336c79d] = None,
     ) -> None:
-        """A reference to a stream.
+        """(experimental) A reference to a stream.
 
         The easiest way to instantiate is to call
         ``stream.export()``. Then, the consumer can use ``Stream.import(this, ref)`` and
         get a ``Stream``.
 
-        :param stream_arn: The ARN of the stream.
-        :param encryption_key: The KMS key securing the contents of the stream if encryption is enabled. Default: - No encryption
+        :param stream_arn: (experimental) The ARN of the stream.
+        :param encryption_key: (experimental) The KMS key securing the contents of the stream if encryption is enabled. Default: - No encryption
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -971,9 +908,8 @@ class StreamAttributes:
 
     @builtins.property
     def stream_arn(self) -> builtins.str:
-        """The ARN of the stream.
+        """(experimental) The ARN of the stream.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("stream_arn")
@@ -982,12 +918,10 @@ class StreamAttributes:
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
-        """The KMS key securing the contents of the stream if encryption is enabled.
+        """(experimental) The KMS key securing the contents of the stream if encryption is enabled.
 
-        default
         :default: - No encryption
 
-        stability
         :stability: experimental
         """
         result = self._values.get("encryption_key")
@@ -1007,30 +941,26 @@ class StreamAttributes:
 
 @jsii.enum(jsii_type="monocdk-experiment.aws_kinesis.StreamEncryption")
 class StreamEncryption(enum.Enum):
-    """What kind of server-side encryption to apply to this stream.
+    """(experimental) What kind of server-side encryption to apply to this stream.
 
-    stability
     :stability: experimental
     """
 
     UNENCRYPTED = "UNENCRYPTED"
-    """Records in the stream are not encrypted.
+    """(experimental) Records in the stream are not encrypted.
 
-    stability
     :stability: experimental
     """
     KMS = "KMS"
-    """Server-side encryption with a KMS key managed by the user.
+    """(experimental) Server-side encryption with a KMS key managed by the user.
 
     If ``encryptionKey`` is specified, this key will be used, otherwise, one will be defined.
 
-    stability
     :stability: experimental
     """
     MANAGED = "MANAGED"
-    """Server-side encryption with a master key managed by Amazon Kinesis.
+    """(experimental) Server-side encryption with a master key managed by Amazon Kinesis.
 
-    stability
     :stability: experimental
     """
 
@@ -1050,21 +980,20 @@ class StreamProps:
     def __init__(
         self,
         *,
-        encryption: typing.Optional["StreamEncryption"] = None,
+        encryption: typing.Optional[StreamEncryption] = None,
         encryption_key: typing.Optional[_IKey_3336c79d] = None,
         retention_period: typing.Optional[_Duration_5170c158] = None,
         shard_count: typing.Optional[jsii.Number] = None,
         stream_name: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Properties for a Kinesis Stream.
+        """(experimental) Properties for a Kinesis Stream.
 
-        :param encryption: The kind of server-side encryption to apply to this stream. If you choose KMS, you can specify a KMS key via ``encryptionKey``. If encryption key is not specified, a key will automatically be created. Default: - StreamEncryption.KMS if encrypted Streams are supported in the region or StreamEncryption.UNENCRYPTED otherwise. StreamEncryption.KMS if an encryption key is supplied through the encryptionKey property
-        :param encryption_key: External KMS key to use for stream encryption. The 'encryption' property must be set to "Kms". Default: - Kinesis Data Streams master key ('/alias/aws/kinesis'). If encryption is set to StreamEncryption.KMS and this property is undefined, a new KMS key will be created and associated with this stream.
-        :param retention_period: The number of hours for the data records that are stored in shards to remain accessible. Default: Duration.hours(24)
-        :param shard_count: The number of shards for the stream. Default: 1
-        :param stream_name: Enforces a particular physical stream name. Default: 
+        :param encryption: (experimental) The kind of server-side encryption to apply to this stream. If you choose KMS, you can specify a KMS key via ``encryptionKey``. If encryption key is not specified, a key will automatically be created. Default: - StreamEncryption.KMS if encrypted Streams are supported in the region or StreamEncryption.UNENCRYPTED otherwise. StreamEncryption.KMS if an encryption key is supplied through the encryptionKey property
+        :param encryption_key: (experimental) External KMS key to use for stream encryption. The 'encryption' property must be set to "Kms". Default: - Kinesis Data Streams master key ('/alias/aws/kinesis'). If encryption is set to StreamEncryption.KMS and this property is undefined, a new KMS key will be created and associated with this stream.
+        :param retention_period: (experimental) The number of hours for the data records that are stored in shards to remain accessible. Default: Duration.hours(24)
+        :param shard_count: (experimental) The number of shards for the stream. Default: 1
+        :param stream_name: (experimental) Enforces a particular physical stream name. Default: 
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -1080,20 +1009,18 @@ class StreamProps:
             self._values["stream_name"] = stream_name
 
     @builtins.property
-    def encryption(self) -> typing.Optional["StreamEncryption"]:
-        """The kind of server-side encryption to apply to this stream.
+    def encryption(self) -> typing.Optional[StreamEncryption]:
+        """(experimental) The kind of server-side encryption to apply to this stream.
 
         If you choose KMS, you can specify a KMS key via ``encryptionKey``. If
         encryption key is not specified, a key will automatically be created.
 
-        default
         :default:
 
         - StreamEncryption.KMS if encrypted Streams are supported in the region
-          or StreamEncryption.UNENCRYPTED otherwise.
-          StreamEncryption.KMS if an encryption key is supplied through the encryptionKey property
+        or StreamEncryption.UNENCRYPTED otherwise.
+        StreamEncryption.KMS if an encryption key is supplied through the encryptionKey property
 
-        stability
         :stability: experimental
         """
         result = self._values.get("encryption")
@@ -1101,18 +1028,16 @@ class StreamProps:
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
-        """External KMS key to use for stream encryption.
+        """(experimental) External KMS key to use for stream encryption.
 
         The 'encryption' property must be set to "Kms".
 
-        default
         :default:
 
         - Kinesis Data Streams master key ('/alias/aws/kinesis').
-          If encryption is set to StreamEncryption.KMS and this property is undefined, a new KMS key
-          will be created and associated with this stream.
+        If encryption is set to StreamEncryption.KMS and this property is undefined, a new KMS key
+        will be created and associated with this stream.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("encryption_key")
@@ -1120,12 +1045,10 @@ class StreamProps:
 
     @builtins.property
     def retention_period(self) -> typing.Optional[_Duration_5170c158]:
-        """The number of hours for the data records that are stored in shards to remain accessible.
+        """(experimental) The number of hours for the data records that are stored in shards to remain accessible.
 
-        default
         :default: Duration.hours(24)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("retention_period")
@@ -1133,12 +1056,10 @@ class StreamProps:
 
     @builtins.property
     def shard_count(self) -> typing.Optional[jsii.Number]:
-        """The number of shards for the stream.
+        """(experimental) The number of shards for the stream.
 
-        default
         :default: 1
 
-        stability
         :stability: experimental
         """
         result = self._values.get("shard_count")
@@ -1146,12 +1067,10 @@ class StreamProps:
 
     @builtins.property
     def stream_name(self) -> typing.Optional[builtins.str]:
-        """Enforces a particular physical stream name.
+        """(experimental) Enforces a particular physical stream name.
 
-        default
-        :default: 
+        :default:
 
-        stability
         :stability: experimental
         """
         result = self._values.get("stream_name")
