@@ -27,10 +27,8 @@ class CfnDataLakeSettings(
 ):
     """A CloudFormation ``AWS::LakeFormation::DataLakeSettings``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-datalakesettings.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::LakeFormation::DataLakeSettings
+    :cloudformationResource: AWS::LakeFormation::DataLakeSettings
     """
 
     def __init__(
@@ -38,7 +36,7 @@ class CfnDataLakeSettings(
         scope: _Construct_f50a3f53,
         id: builtins.str,
         *,
-        admins: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]]]] = None,
+        admins: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnDataLakeSettings.DataLakePrincipalProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::LakeFormation::DataLakeSettings``.
 
@@ -52,11 +50,10 @@ class CfnDataLakeSettings(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -86,10 +83,9 @@ class CfnDataLakeSettings(
     @jsii.member(jsii_name="admins")
     def admins(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnDataLakeSettings.DataLakePrincipalProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::LakeFormation::DataLakeSettings.Admins``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-datalakesettings.html#cfn-lakeformation-datalakesettings-admins
         """
         return jsii.get(self, "admins")
@@ -97,7 +93,7 @@ class CfnDataLakeSettings(
     @admins.setter # type: ignore
     def admins(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnDataLakeSettings.DataLakePrincipalProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "admins", value)
 
@@ -115,7 +111,6 @@ class CfnDataLakeSettings(
             """
             :param data_lake_principal_identifier: ``CfnDataLakeSettings.DataLakePrincipalProperty.DataLakePrincipalIdentifier``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-datalakesettings-datalakeprincipal.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -126,7 +121,6 @@ class CfnDataLakeSettings(
         def data_lake_principal_identifier(self) -> typing.Optional[builtins.str]:
             """``CfnDataLakeSettings.DataLakePrincipalProperty.DataLakePrincipalIdentifier``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-datalakesettings-datalakeprincipal.html#cfn-lakeformation-datalakesettings-datalakeprincipal-datalakeprincipalidentifier
             """
             result = self._values.get("data_lake_principal_identifier")
@@ -153,13 +147,12 @@ class CfnDataLakeSettingsProps:
     def __init__(
         self,
         *,
-        admins: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnDataLakeSettings.DataLakePrincipalProperty", _IResolvable_9ceae33e]]]] = None,
+        admins: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnDataLakeSettings.DataLakePrincipalProperty, _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::LakeFormation::DataLakeSettings``.
 
         :param admins: ``AWS::LakeFormation::DataLakeSettings.Admins``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-datalakesettings.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -169,10 +162,9 @@ class CfnDataLakeSettingsProps:
     @builtins.property
     def admins(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnDataLakeSettings.DataLakePrincipalProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnDataLakeSettings.DataLakePrincipalProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::LakeFormation::DataLakeSettings.Admins``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-datalakesettings.html#cfn-lakeformation-datalakesettings-admins
         """
         result = self._values.get("admins")
@@ -198,10 +190,8 @@ class CfnPermissions(
 ):
     """A CloudFormation ``AWS::LakeFormation::Permissions``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::LakeFormation::Permissions
+    :cloudformationResource: AWS::LakeFormation::Permissions
     """
 
     def __init__(
@@ -209,8 +199,8 @@ class CfnPermissions(
         scope: _Construct_f50a3f53,
         id: builtins.str,
         *,
-        data_lake_principal: typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e],
-        resource: typing.Union["ResourceProperty", _IResolvable_9ceae33e],
+        data_lake_principal: typing.Union["CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e],
+        resource: typing.Union["CfnPermissions.ResourceProperty", _IResolvable_9ceae33e],
         permissions: typing.Optional[typing.List[builtins.str]] = None,
         permissions_with_grant_option: typing.Optional[typing.List[builtins.str]] = None,
     ) -> None:
@@ -234,11 +224,10 @@ class CfnPermissions(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -268,10 +257,9 @@ class CfnPermissions(
     @jsii.member(jsii_name="dataLakePrincipal")
     def data_lake_principal(
         self,
-    ) -> typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Permissions.DataLakePrincipal``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-datalakeprincipal
         """
         return jsii.get(self, "dataLakePrincipal")
@@ -279,16 +267,17 @@ class CfnPermissions(
     @data_lake_principal.setter # type: ignore
     def data_lake_principal(
         self,
-        value: typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "dataLakePrincipal", value)
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="resource")
-    def resource(self) -> typing.Union["ResourceProperty", _IResolvable_9ceae33e]:
+    def resource(
+        self,
+    ) -> typing.Union["CfnPermissions.ResourceProperty", _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Permissions.Resource``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-resource
         """
         return jsii.get(self, "resource")
@@ -296,7 +285,7 @@ class CfnPermissions(
     @resource.setter # type: ignore
     def resource(
         self,
-        value: typing.Union["ResourceProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnPermissions.ResourceProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "resource", value)
 
@@ -305,7 +294,6 @@ class CfnPermissions(
     def permissions(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::LakeFormation::Permissions.Permissions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-permissions
         """
         return jsii.get(self, "permissions")
@@ -321,7 +309,6 @@ class CfnPermissions(
     ) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::LakeFormation::Permissions.PermissionsWithGrantOption``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-permissionswithgrantoption
         """
         return jsii.get(self, "permissionsWithGrantOption")
@@ -347,7 +334,6 @@ class CfnPermissions(
             """
             :param excluded_column_names: ``CfnPermissions.ColumnWildcardProperty.ExcludedColumnNames``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-columnwildcard.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -358,7 +344,6 @@ class CfnPermissions(
         def excluded_column_names(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPermissions.ColumnWildcardProperty.ExcludedColumnNames``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-columnwildcard.html#cfn-lakeformation-permissions-columnwildcard-excludedcolumnnames
             """
             result = self._values.get("excluded_column_names")
@@ -389,7 +374,6 @@ class CfnPermissions(
             """
             :param data_lake_principal_identifier: ``CfnPermissions.DataLakePrincipalProperty.DataLakePrincipalIdentifier``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalakeprincipal.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -400,7 +384,6 @@ class CfnPermissions(
         def data_lake_principal_identifier(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.DataLakePrincipalProperty.DataLakePrincipalIdentifier``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalakeprincipal.html#cfn-lakeformation-permissions-datalakeprincipal-datalakeprincipalidentifier
             """
             result = self._values.get("data_lake_principal_identifier")
@@ -420,29 +403,40 @@ class CfnPermissions(
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_lakeformation.CfnPermissions.DataLocationResourceProperty",
         jsii_struct_bases=[],
-        name_mapping={"s3_resource": "s3Resource"},
+        name_mapping={"catalog_id": "catalogId", "s3_resource": "s3Resource"},
     )
     class DataLocationResourceProperty:
         def __init__(
             self,
             *,
+            catalog_id: typing.Optional[builtins.str] = None,
             s3_resource: typing.Optional[builtins.str] = None,
         ) -> None:
             """
+            :param catalog_id: ``CfnPermissions.DataLocationResourceProperty.CatalogId``.
             :param s3_resource: ``CfnPermissions.DataLocationResourceProperty.S3Resource``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalocationresource.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
+            if catalog_id is not None:
+                self._values["catalog_id"] = catalog_id
             if s3_resource is not None:
                 self._values["s3_resource"] = s3_resource
 
+        @builtins.property
+        def catalog_id(self) -> typing.Optional[builtins.str]:
+            """``CfnPermissions.DataLocationResourceProperty.CatalogId``.
+
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalocationresource.html#cfn-lakeformation-permissions-datalocationresource-catalogid
+            """
+            result = self._values.get("catalog_id")
+            return result
+
         @builtins.property
         def s3_resource(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.DataLocationResourceProperty.S3Resource``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalocationresource.html#cfn-lakeformation-permissions-datalocationresource-s3resource
             """
             result = self._values.get("s3_resource")
@@ -462,25 +456,40 @@ class CfnPermissions(
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_lakeformation.CfnPermissions.DatabaseResourceProperty",
         jsii_struct_bases=[],
-        name_mapping={"name": "name"},
+        name_mapping={"catalog_id": "catalogId", "name": "name"},
     )
     class DatabaseResourceProperty:
-        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
+        def __init__(
+            self,
+            *,
+            catalog_id: typing.Optional[builtins.str] = None,
+            name: typing.Optional[builtins.str] = None,
+        ) -> None:
             """
+            :param catalog_id: ``CfnPermissions.DatabaseResourceProperty.CatalogId``.
             :param name: ``CfnPermissions.DatabaseResourceProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-databaseresource.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
+            if catalog_id is not None:
+                self._values["catalog_id"] = catalog_id
             if name is not None:
                 self._values["name"] = name
 
+        @builtins.property
+        def catalog_id(self) -> typing.Optional[builtins.str]:
+            """``CfnPermissions.DatabaseResourceProperty.CatalogId``.
+
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-databaseresource.html#cfn-lakeformation-permissions-databaseresource-catalogid
+            """
+            result = self._values.get("catalog_id")
+            return result
+
         @builtins.property
         def name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.DatabaseResourceProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-databaseresource.html#cfn-lakeformation-permissions-databaseresource-name
             """
             result = self._values.get("name")
@@ -522,7 +531,6 @@ class CfnPermissions(
             :param table_resource: ``CfnPermissions.ResourceProperty.TableResource``.
             :param table_with_columns_resource: ``CfnPermissions.ResourceProperty.TableWithColumnsResource``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -541,7 +549,6 @@ class CfnPermissions(
         ) -> typing.Optional[typing.Union["CfnPermissions.DatabaseResourceProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.ResourceProperty.DatabaseResource``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html#cfn-lakeformation-permissions-resource-databaseresource
             """
             result = self._values.get("database_resource")
@@ -553,7 +560,6 @@ class CfnPermissions(
         ) -> typing.Optional[typing.Union["CfnPermissions.DataLocationResourceProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.ResourceProperty.DataLocationResource``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html#cfn-lakeformation-permissions-resource-datalocationresource
             """
             result = self._values.get("data_location_resource")
@@ -565,7 +571,6 @@ class CfnPermissions(
         ) -> typing.Optional[typing.Union["CfnPermissions.TableResourceProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.ResourceProperty.TableResource``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html#cfn-lakeformation-permissions-resource-tableresource
             """
             result = self._values.get("table_resource")
@@ -577,7 +582,6 @@ class CfnPermissions(
         ) -> typing.Optional[typing.Union["CfnPermissions.TableWithColumnsResourceProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.ResourceProperty.TableWithColumnsResource``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html#cfn-lakeformation-permissions-resource-tablewithcolumnsresource
             """
             result = self._values.get("table_with_columns_resource")
@@ -597,33 +601,53 @@ class CfnPermissions(
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_lakeformation.CfnPermissions.TableResourceProperty",
         jsii_struct_bases=[],
-        name_mapping={"database_name": "databaseName", "name": "name"},
+        name_mapping={
+            "catalog_id": "catalogId",
+            "database_name": "databaseName",
+            "name": "name",
+            "table_wildcard": "tableWildcard",
+        },
     )
     class TableResourceProperty:
         def __init__(
             self,
             *,
+            catalog_id: typing.Optional[builtins.str] = None,
             database_name: typing.Optional[builtins.str] = None,
             name: typing.Optional[builtins.str] = None,
+            table_wildcard: typing.Optional[typing.Union["CfnPermissions.TableWildcardProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
+            :param catalog_id: ``CfnPermissions.TableResourceProperty.CatalogId``.
             :param database_name: ``CfnPermissions.TableResourceProperty.DatabaseName``.
             :param name: ``CfnPermissions.TableResourceProperty.Name``.
+            :param table_wildcard: ``CfnPermissions.TableResourceProperty.TableWildcard``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tableresource.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
+            if catalog_id is not None:
+                self._values["catalog_id"] = catalog_id
             if database_name is not None:
                 self._values["database_name"] = database_name
             if name is not None:
                 self._values["name"] = name
+            if table_wildcard is not None:
+                self._values["table_wildcard"] = table_wildcard
+
+        @builtins.property
+        def catalog_id(self) -> typing.Optional[builtins.str]:
+            """``CfnPermissions.TableResourceProperty.CatalogId``.
+
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tableresource.html#cfn-lakeformation-permissions-tableresource-catalogid
+            """
+            result = self._values.get("catalog_id")
+            return result
 
         @builtins.property
         def database_name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.TableResourceProperty.DatabaseName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tableresource.html#cfn-lakeformation-permissions-tableresource-databasename
             """
             result = self._values.get("database_name")
@@ -633,12 +657,22 @@ class CfnPermissions(
         def name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.TableResourceProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tableresource.html#cfn-lakeformation-permissions-tableresource-name
             """
             result = self._values.get("name")
             return result
 
+        @builtins.property
+        def table_wildcard(
+            self,
+        ) -> typing.Optional[typing.Union["CfnPermissions.TableWildcardProperty", _IResolvable_9ceae33e]]:
+            """``CfnPermissions.TableResourceProperty.TableWildcard``.
+
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tableresource.html#cfn-lakeformation-permissions-tableresource-tablewildcard
+            """
+            result = self._values.get("table_wildcard")
+            return result
+
         def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -650,10 +684,34 @@ class CfnPermissions(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_lakeformation.CfnPermissions.TableWildcardProperty",
+        jsii_struct_bases=[],
+        name_mapping={},
+    )
+    class TableWildcardProperty:
+        def __init__(self) -> None:
+            """
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewildcard.html
+            """
+            self._values: typing.Dict[str, typing.Any] = {}
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "TableWildcardProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_lakeformation.CfnPermissions.TableWithColumnsResourceProperty",
         jsii_struct_bases=[],
         name_mapping={
+            "catalog_id": "catalogId",
             "column_names": "columnNames",
             "column_wildcard": "columnWildcard",
             "database_name": "databaseName",
@@ -664,21 +722,24 @@ class CfnPermissions(
         def __init__(
             self,
             *,
+            catalog_id: typing.Optional[builtins.str] = None,
             column_names: typing.Optional[typing.List[builtins.str]] = None,
             column_wildcard: typing.Optional[typing.Union["CfnPermissions.ColumnWildcardProperty", _IResolvable_9ceae33e]] = None,
             database_name: typing.Optional[builtins.str] = None,
             name: typing.Optional[builtins.str] = None,
         ) -> None:
             """
+            :param catalog_id: ``CfnPermissions.TableWithColumnsResourceProperty.CatalogId``.
             :param column_names: ``CfnPermissions.TableWithColumnsResourceProperty.ColumnNames``.
             :param column_wildcard: ``CfnPermissions.TableWithColumnsResourceProperty.ColumnWildcard``.
             :param database_name: ``CfnPermissions.TableWithColumnsResourceProperty.DatabaseName``.
             :param name: ``CfnPermissions.TableWithColumnsResourceProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
+            if catalog_id is not None:
+                self._values["catalog_id"] = catalog_id
             if column_names is not None:
                 self._values["column_names"] = column_names
             if column_wildcard is not None:
@@ -688,11 +749,19 @@ class CfnPermissions(
             if name is not None:
                 self._values["name"] = name
 
+        @builtins.property
+        def catalog_id(self) -> typing.Optional[builtins.str]:
+            """``CfnPermissions.TableWithColumnsResourceProperty.CatalogId``.
+
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html#cfn-lakeformation-permissions-tablewithcolumnsresource-catalogid
+            """
+            result = self._values.get("catalog_id")
+            return result
+
         @builtins.property
         def column_names(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnPermissions.TableWithColumnsResourceProperty.ColumnNames``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html#cfn-lakeformation-permissions-tablewithcolumnsresource-columnnames
             """
             result = self._values.get("column_names")
@@ -704,7 +773,6 @@ class CfnPermissions(
         ) -> typing.Optional[typing.Union["CfnPermissions.ColumnWildcardProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.TableWithColumnsResourceProperty.ColumnWildcard``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html#cfn-lakeformation-permissions-tablewithcolumnsresource-columnwildcard
             """
             result = self._values.get("column_wildcard")
@@ -714,7 +782,6 @@ class CfnPermissions(
         def database_name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.TableWithColumnsResourceProperty.DatabaseName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html#cfn-lakeformation-permissions-tablewithcolumnsresource-databasename
             """
             result = self._values.get("database_name")
@@ -724,7 +791,6 @@ class CfnPermissions(
         def name(self) -> typing.Optional[builtins.str]:
             """``CfnPermissions.TableWithColumnsResourceProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewithcolumnsresource.html#cfn-lakeformation-permissions-tablewithcolumnsresource-name
             """
             result = self._values.get("name")
@@ -756,8 +822,8 @@ class CfnPermissionsProps:
     def __init__(
         self,
         *,
-        data_lake_principal: typing.Union["CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e],
-        resource: typing.Union["CfnPermissions.ResourceProperty", _IResolvable_9ceae33e],
+        data_lake_principal: typing.Union[CfnPermissions.DataLakePrincipalProperty, _IResolvable_9ceae33e],
+        resource: typing.Union[CfnPermissions.ResourceProperty, _IResolvable_9ceae33e],
         permissions: typing.Optional[typing.List[builtins.str]] = None,
         permissions_with_grant_option: typing.Optional[typing.List[builtins.str]] = None,
     ) -> None:
@@ -768,7 +834,6 @@ class CfnPermissionsProps:
         :param permissions: ``AWS::LakeFormation::Permissions.Permissions``.
         :param permissions_with_grant_option: ``AWS::LakeFormation::Permissions.PermissionsWithGrantOption``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -783,10 +848,9 @@ class CfnPermissionsProps:
     @builtins.property
     def data_lake_principal(
         self,
-    ) -> typing.Union["CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnPermissions.DataLakePrincipalProperty, _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Permissions.DataLakePrincipal``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-datalakeprincipal
         """
         result = self._values.get("data_lake_principal")
@@ -796,10 +860,9 @@ class CfnPermissionsProps:
     @builtins.property
     def resource(
         self,
-    ) -> typing.Union["CfnPermissions.ResourceProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnPermissions.ResourceProperty, _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Permissions.Resource``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-resource
         """
         result = self._values.get("resource")
@@ -810,7 +873,6 @@ class CfnPermissionsProps:
     def permissions(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::LakeFormation::Permissions.Permissions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-permissions
         """
         result = self._values.get("permissions")
@@ -822,7 +884,6 @@ class CfnPermissionsProps:
     ) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::LakeFormation::Permissions.PermissionsWithGrantOption``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html#cfn-lakeformation-permissions-permissionswithgrantoption
         """
         result = self._values.get("permissions_with_grant_option")
@@ -848,10 +909,8 @@ class CfnResource(
 ):
     """A CloudFormation ``AWS::LakeFormation::Resource``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::LakeFormation::Resource
+    :cloudformationResource: AWS::LakeFormation::Resource
     """
 
     def __init__(
@@ -881,11 +940,10 @@ class CfnResource(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -916,7 +974,6 @@ class CfnResource(
     def resource_arn(self) -> builtins.str:
         """``AWS::LakeFormation::Resource.ResourceArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html#cfn-lakeformation-resource-resourcearn
         """
         return jsii.get(self, "resourceArn")
@@ -932,7 +989,6 @@ class CfnResource(
     ) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Resource.UseServiceLinkedRole``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html#cfn-lakeformation-resource-useservicelinkedrole
         """
         return jsii.get(self, "useServiceLinkedRole")
@@ -949,7 +1005,6 @@ class CfnResource(
     def role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::LakeFormation::Resource.RoleArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html#cfn-lakeformation-resource-rolearn
         """
         return jsii.get(self, "roleArn")
@@ -982,7 +1037,6 @@ class CfnResourceProps:
         :param use_service_linked_role: ``AWS::LakeFormation::Resource.UseServiceLinkedRole``.
         :param role_arn: ``AWS::LakeFormation::Resource.RoleArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -996,7 +1050,6 @@ class CfnResourceProps:
     def resource_arn(self) -> builtins.str:
         """``AWS::LakeFormation::Resource.ResourceArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html#cfn-lakeformation-resource-resourcearn
         """
         result = self._values.get("resource_arn")
@@ -1009,7 +1062,6 @@ class CfnResourceProps:
     ) -> typing.Union[builtins.bool, _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Resource.UseServiceLinkedRole``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html#cfn-lakeformation-resource-useservicelinkedrole
         """
         result = self._values.get("use_service_linked_role")
@@ -1020,7 +1072,6 @@ class CfnResourceProps:
     def role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::LakeFormation::Resource.RoleArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html#cfn-lakeformation-resource-rolearn
         """
         result = self._values.get("role_arn")
