@@ -28,11 +28,10 @@ class EventBridgeDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_lambda_destinations.EventBridgeDestination",
 ):
-    """Use an Event Bridge event bus as a Lambda destination.
+    """(experimental) Use an Event Bridge event bus as a Lambda destination.
 
     If no event bus is specified, the default event bus is used.
 
-    stability
     :stability: experimental
     """
 
@@ -40,10 +39,8 @@ class EventBridgeDestination(
         """
         :param event_bus: -
 
-        default
         :default: - use the default event bus
 
-        stability
         :stability: experimental
         """
         jsii.create(EventBridgeDestination, self, [event_bus])
@@ -56,13 +53,12 @@ class EventBridgeDestination(
         *,
         type: _DestinationType_644824de,
     ) -> _DestinationConfig_ab93b607:
-        """Returns a destination configuration.
+        """(experimental) Returns a destination configuration.
 
         :param _scope: -
         :param fn: -
-        :param type: The destination type.
+        :param type: (experimental) The destination type.
 
-        stability
         :stability: experimental
         """
         _options = _DestinationOptions_4bc6a3c7(type=type)
@@ -75,9 +71,8 @@ class LambdaDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_lambda_destinations.LambdaDestination",
 ):
-    """Use a Lambda function as a Lambda destination.
+    """(experimental) Use a Lambda function as a Lambda destination.
 
-    stability
     :stability: experimental
     """
 
@@ -89,9 +84,8 @@ class LambdaDestination(
     ) -> None:
         """
         :param fn: -
-        :param response_only: Whether the destination function receives only the ``responsePayload`` of the source function. When set to ``true`` and used as ``onSuccess`` destination, the destination function will be invoked with the payload returned by the source function. When set to ``true`` and used as ``onFailure`` destination, the destination function will be invoked with the error object returned by source function. See the README of this module to see a full explanation of this option. Default: false The destination function receives the full invocation record.
+        :param response_only: (experimental) Whether the destination function receives only the ``responsePayload`` of the source function. When set to ``true`` and used as ``onSuccess`` destination, the destination function will be invoked with the payload returned by the source function. When set to ``true`` and used as ``onFailure`` destination, the destination function will be invoked with the error object returned by source function. See the README of this module to see a full explanation of this option. Default: false The destination function receives the full invocation record.
 
-        stability
         :stability: experimental
         """
         options = LambdaDestinationOptions(response_only=response_only)
@@ -106,13 +100,12 @@ class LambdaDestination(
         *,
         type: _DestinationType_644824de,
     ) -> _DestinationConfig_ab93b607:
-        """Returns a destination configuration.
+        """(experimental) Returns a destination configuration.
 
         :param scope: -
         :param fn: -
-        :param type: The destination type.
+        :param type: (experimental) The destination type.
 
-        stability
         :stability: experimental
         """
         options = _DestinationOptions_4bc6a3c7(type=type)
@@ -127,11 +120,10 @@ class LambdaDestination(
 )
 class LambdaDestinationOptions:
     def __init__(self, *, response_only: typing.Optional[builtins.bool] = None) -> None:
-        """Options for a Lambda destination.
+        """(experimental) Options for a Lambda destination.
 
-        :param response_only: Whether the destination function receives only the ``responsePayload`` of the source function. When set to ``true`` and used as ``onSuccess`` destination, the destination function will be invoked with the payload returned by the source function. When set to ``true`` and used as ``onFailure`` destination, the destination function will be invoked with the error object returned by source function. See the README of this module to see a full explanation of this option. Default: false The destination function receives the full invocation record.
+        :param response_only: (experimental) Whether the destination function receives only the ``responsePayload`` of the source function. When set to ``true`` and used as ``onSuccess`` destination, the destination function will be invoked with the payload returned by the source function. When set to ``true`` and used as ``onFailure`` destination, the destination function will be invoked with the error object returned by source function. See the README of this module to see a full explanation of this option. Default: false The destination function receives the full invocation record.
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -140,7 +132,7 @@ class LambdaDestinationOptions:
 
     @builtins.property
     def response_only(self) -> typing.Optional[builtins.bool]:
-        """Whether the destination function receives only the ``responsePayload`` of the source function.
+        """(experimental) Whether the destination function receives only the ``responsePayload`` of the source function.
 
         When set to ``true`` and used as ``onSuccess`` destination, the destination
         function will be invoked with the payload returned by the source function.
@@ -150,10 +142,8 @@ class LambdaDestinationOptions:
 
         See the README of this module to see a full explanation of this option.
 
-        default
         :default: false The destination function receives the full invocation record.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("response_only")
@@ -176,9 +166,8 @@ class SnsDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_lambda_destinations.SnsDestination",
 ):
-    """Use a SNS topic as a Lambda destination.
+    """(experimental) Use a SNS topic as a Lambda destination.
 
-    stability
     :stability: experimental
     """
 
@@ -186,7 +175,6 @@ class SnsDestination(
         """
         :param topic: -
 
-        stability
         :stability: experimental
         """
         jsii.create(SnsDestination, self, [topic])
@@ -199,13 +187,12 @@ class SnsDestination(
         *,
         type: _DestinationType_644824de,
     ) -> _DestinationConfig_ab93b607:
-        """Returns a destination configuration.
+        """(experimental) Returns a destination configuration.
 
         :param _scope: -
         :param fn: -
-        :param type: The destination type.
+        :param type: (experimental) The destination type.
 
-        stability
         :stability: experimental
         """
         _options = _DestinationOptions_4bc6a3c7(type=type)
@@ -218,9 +205,8 @@ class SqsDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_lambda_destinations.SqsDestination",
 ):
-    """Use a SQS queue as a Lambda destination.
+    """(experimental) Use a SQS queue as a Lambda destination.
 
-    stability
     :stability: experimental
     """
 
@@ -228,7 +214,6 @@ class SqsDestination(
         """
         :param queue: -
 
-        stability
         :stability: experimental
         """
         jsii.create(SqsDestination, self, [queue])
@@ -241,13 +226,12 @@ class SqsDestination(
         *,
         type: _DestinationType_644824de,
     ) -> _DestinationConfig_ab93b607:
-        """Returns a destination configuration.
+        """(experimental) Returns a destination configuration.
 
         :param _scope: -
         :param fn: -
-        :param type: The destination type.
+        :param type: (experimental) The destination type.
 
-        stability
         :stability: experimental
         """
         _options = _DestinationOptions_4bc6a3c7(type=type)
