@@ -25,9 +25,8 @@ class KinesisDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_logs_destinations.KinesisDestination",
 ):
-    """Use a Kinesis stream as the destination for a log subscription.
+    """(experimental) Use a Kinesis stream as the destination for a log subscription.
 
-    stability
     :stability: experimental
     """
 
@@ -35,7 +34,6 @@ class KinesisDestination(
         """
         :param stream: -
 
-        stability
         :stability: experimental
         """
         jsii.create(KinesisDestination, self, [stream])
@@ -46,7 +44,7 @@ class KinesisDestination(
         scope: _Construct_f50a3f53,
         _source_log_group: _ILogGroup_6b54c8e1,
     ) -> _LogSubscriptionDestinationConfig_1075ffd8:
-        """Return the properties required to send subscription events to this destination.
+        """(experimental) Return the properties required to send subscription events to this destination.
 
         If necessary, the destination can use the properties of the SubscriptionFilter
         object itself to configure its permissions to allow the subscription to write
@@ -58,7 +56,6 @@ class KinesisDestination(
         :param scope: -
         :param _source_log_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [scope, _source_log_group])
@@ -69,9 +66,8 @@ class LambdaDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_logs_destinations.LambdaDestination",
 ):
-    """Use a Lamda Function as the destination for a log subscription.
+    """(experimental) Use a Lamda Function as the destination for a log subscription.
 
-    stability
     :stability: experimental
     """
 
@@ -79,7 +75,6 @@ class LambdaDestination(
         """
         :param fn: -
 
-        stability
         :stability: experimental
         """
         jsii.create(LambdaDestination, self, [fn])
@@ -90,7 +85,7 @@ class LambdaDestination(
         scope: _Construct_f50a3f53,
         log_group: _ILogGroup_6b54c8e1,
     ) -> _LogSubscriptionDestinationConfig_1075ffd8:
-        """Return the properties required to send subscription events to this destination.
+        """(experimental) Return the properties required to send subscription events to this destination.
 
         If necessary, the destination can use the properties of the SubscriptionFilter
         object itself to configure its permissions to allow the subscription to write
@@ -102,7 +97,6 @@ class LambdaDestination(
         :param scope: -
         :param log_group: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [scope, log_group])
