@@ -27,10 +27,8 @@ class CfnCustomDataIdentifier(
 ):
     """A CloudFormation ``AWS::Macie::CustomDataIdentifier``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Macie::CustomDataIdentifier
+    :cloudformationResource: AWS::Macie::CustomDataIdentifier
     """
 
     def __init__(
@@ -69,11 +67,10 @@ class CfnCustomDataIdentifier(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -98,8 +95,7 @@ class CfnCustomDataIdentifier(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -107,8 +103,7 @@ class CfnCustomDataIdentifier(
     @jsii.member(jsii_name="attrCreatedAt")
     def attr_created_at(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: CreatedAt
+        :cloudformationAttribute: CreatedAt
         """
         return jsii.get(self, "attrCreatedAt")
 
@@ -116,8 +111,7 @@ class CfnCustomDataIdentifier(
     @jsii.member(jsii_name="attrDeleted")
     def attr_deleted(self) -> _IResolvable_9ceae33e:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Deleted
+        :cloudformationAttribute: Deleted
         """
         return jsii.get(self, "attrDeleted")
 
@@ -125,8 +119,7 @@ class CfnCustomDataIdentifier(
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Id
+        :cloudformationAttribute: Id
         """
         return jsii.get(self, "attrId")
 
@@ -140,7 +133,6 @@ class CfnCustomDataIdentifier(
     def name(self) -> builtins.str:
         """``AWS::Macie::CustomDataIdentifier.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-name
         """
         return jsii.get(self, "name")
@@ -154,7 +146,6 @@ class CfnCustomDataIdentifier(
     def regex(self) -> builtins.str:
         """``AWS::Macie::CustomDataIdentifier.Regex``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-regex
         """
         return jsii.get(self, "regex")
@@ -168,7 +159,6 @@ class CfnCustomDataIdentifier(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::CustomDataIdentifier.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-description
         """
         return jsii.get(self, "description")
@@ -182,7 +172,6 @@ class CfnCustomDataIdentifier(
     def ignore_words(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Macie::CustomDataIdentifier.IgnoreWords``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-ignorewords
         """
         return jsii.get(self, "ignoreWords")
@@ -196,7 +185,6 @@ class CfnCustomDataIdentifier(
     def keywords(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Macie::CustomDataIdentifier.Keywords``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-keywords
         """
         return jsii.get(self, "keywords")
@@ -210,7 +198,6 @@ class CfnCustomDataIdentifier(
     def maximum_match_distance(self) -> typing.Optional[jsii.Number]:
         """``AWS::Macie::CustomDataIdentifier.MaximumMatchDistance``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-maximummatchdistance
         """
         return jsii.get(self, "maximumMatchDistance")
@@ -252,7 +239,6 @@ class CfnCustomDataIdentifierProps:
         :param keywords: ``AWS::Macie::CustomDataIdentifier.Keywords``.
         :param maximum_match_distance: ``AWS::Macie::CustomDataIdentifier.MaximumMatchDistance``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -272,7 +258,6 @@ class CfnCustomDataIdentifierProps:
     def name(self) -> builtins.str:
         """``AWS::Macie::CustomDataIdentifier.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-name
         """
         result = self._values.get("name")
@@ -283,7 +268,6 @@ class CfnCustomDataIdentifierProps:
     def regex(self) -> builtins.str:
         """``AWS::Macie::CustomDataIdentifier.Regex``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-regex
         """
         result = self._values.get("regex")
@@ -294,7 +278,6 @@ class CfnCustomDataIdentifierProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::CustomDataIdentifier.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-description
         """
         result = self._values.get("description")
@@ -304,7 +287,6 @@ class CfnCustomDataIdentifierProps:
     def ignore_words(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Macie::CustomDataIdentifier.IgnoreWords``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-ignorewords
         """
         result = self._values.get("ignore_words")
@@ -314,7 +296,6 @@ class CfnCustomDataIdentifierProps:
     def keywords(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Macie::CustomDataIdentifier.Keywords``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-keywords
         """
         result = self._values.get("keywords")
@@ -324,7 +305,6 @@ class CfnCustomDataIdentifierProps:
     def maximum_match_distance(self) -> typing.Optional[jsii.Number]:
         """``AWS::Macie::CustomDataIdentifier.MaximumMatchDistance``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html#cfn-macie-customdataidentifier-maximummatchdistance
         """
         result = self._values.get("maximum_match_distance")
@@ -350,10 +330,8 @@ class CfnFindingsFilter(
 ):
     """A CloudFormation ``AWS::Macie::FindingsFilter``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Macie::FindingsFilter
+    :cloudformationResource: AWS::Macie::FindingsFilter
     """
 
     def __init__(
@@ -361,7 +339,7 @@ class CfnFindingsFilter(
         scope: _Construct_f50a3f53,
         id: builtins.str,
         *,
-        finding_criteria: typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e],
+        finding_criteria: typing.Union["CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e],
         name: builtins.str,
         action: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
@@ -389,11 +367,10 @@ class CfnFindingsFilter(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -418,8 +395,7 @@ class CfnFindingsFilter(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -427,8 +403,7 @@ class CfnFindingsFilter(
     @jsii.member(jsii_name="attrFindingsFilterListItems")
     def attr_findings_filter_list_items(self) -> _IResolvable_9ceae33e:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: FindingsFilterListItems
+        :cloudformationAttribute: FindingsFilterListItems
         """
         return jsii.get(self, "attrFindingsFilterListItems")
 
@@ -436,8 +411,7 @@ class CfnFindingsFilter(
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Id
+        :cloudformationAttribute: Id
         """
         return jsii.get(self, "attrId")
 
@@ -450,10 +424,9 @@ class CfnFindingsFilter(
     @jsii.member(jsii_name="findingCriteria")
     def finding_criteria(
         self,
-    ) -> typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e]:
         """``AWS::Macie::FindingsFilter.FindingCriteria``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-findingcriteria
         """
         return jsii.get(self, "findingCriteria")
@@ -461,7 +434,7 @@ class CfnFindingsFilter(
     @finding_criteria.setter # type: ignore
     def finding_criteria(
         self,
-        value: typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "findingCriteria", value)
 
@@ -470,7 +443,6 @@ class CfnFindingsFilter(
     def name(self) -> builtins.str:
         """``AWS::Macie::FindingsFilter.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-name
         """
         return jsii.get(self, "name")
@@ -484,7 +456,6 @@ class CfnFindingsFilter(
     def action(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::FindingsFilter.Action``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-action
         """
         return jsii.get(self, "action")
@@ -498,7 +469,6 @@ class CfnFindingsFilter(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::FindingsFilter.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-description
         """
         return jsii.get(self, "description")
@@ -512,7 +482,6 @@ class CfnFindingsFilter(
     def position(self) -> typing.Optional[jsii.Number]:
         """``AWS::Macie::FindingsFilter.Position``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-position
         """
         return jsii.get(self, "position")
@@ -529,7 +498,6 @@ class CfnFindingsFilter(
     class CriterionProperty:
         def __init__(self) -> None:
             """
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-criterion.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -559,7 +527,6 @@ class CfnFindingsFilter(
             """
             :param criterion: ``CfnFindingsFilter.FindingCriteriaProperty.Criterion``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingcriteria.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -572,7 +539,6 @@ class CfnFindingsFilter(
         ) -> typing.Optional[typing.Union["CfnFindingsFilter.CriterionProperty", _IResolvable_9ceae33e]]:
             """``CfnFindingsFilter.FindingCriteriaProperty.Criterion``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingcriteria.html#cfn-macie-findingsfilter-findingcriteria-criterion
             """
             result = self._values.get("criterion")
@@ -605,7 +571,6 @@ class CfnFindingsFilter(
             :param id: ``CfnFindingsFilter.FindingsFilterListItemProperty.Id``.
             :param name: ``CfnFindingsFilter.FindingsFilterListItemProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingsfilterlistitem.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -618,7 +583,6 @@ class CfnFindingsFilter(
         def id(self) -> typing.Optional[builtins.str]:
             """``CfnFindingsFilter.FindingsFilterListItemProperty.Id``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingsfilterlistitem.html#cfn-macie-findingsfilter-findingsfilterlistitem-id
             """
             result = self._values.get("id")
@@ -628,7 +592,6 @@ class CfnFindingsFilter(
         def name(self) -> typing.Optional[builtins.str]:
             """``CfnFindingsFilter.FindingsFilterListItemProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingsfilterlistitem.html#cfn-macie-findingsfilter-findingsfilterlistitem-name
             """
             result = self._values.get("name")
@@ -661,7 +624,7 @@ class CfnFindingsFilterProps:
     def __init__(
         self,
         *,
-        finding_criteria: typing.Union["CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e],
+        finding_criteria: typing.Union[CfnFindingsFilter.FindingCriteriaProperty, _IResolvable_9ceae33e],
         name: builtins.str,
         action: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
@@ -675,7 +638,6 @@ class CfnFindingsFilterProps:
         :param description: ``AWS::Macie::FindingsFilter.Description``.
         :param position: ``AWS::Macie::FindingsFilter.Position``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -692,10 +654,9 @@ class CfnFindingsFilterProps:
     @builtins.property
     def finding_criteria(
         self,
-    ) -> typing.Union["CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnFindingsFilter.FindingCriteriaProperty, _IResolvable_9ceae33e]:
         """``AWS::Macie::FindingsFilter.FindingCriteria``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-findingcriteria
         """
         result = self._values.get("finding_criteria")
@@ -706,7 +667,6 @@ class CfnFindingsFilterProps:
     def name(self) -> builtins.str:
         """``AWS::Macie::FindingsFilter.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-name
         """
         result = self._values.get("name")
@@ -717,7 +677,6 @@ class CfnFindingsFilterProps:
     def action(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::FindingsFilter.Action``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-action
         """
         result = self._values.get("action")
@@ -727,7 +686,6 @@ class CfnFindingsFilterProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::FindingsFilter.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-description
         """
         result = self._values.get("description")
@@ -737,7 +695,6 @@ class CfnFindingsFilterProps:
     def position(self) -> typing.Optional[jsii.Number]:
         """``AWS::Macie::FindingsFilter.Position``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html#cfn-macie-findingsfilter-position
         """
         result = self._values.get("position")
@@ -763,10 +720,8 @@ class CfnSession(
 ):
     """A CloudFormation ``AWS::Macie::Session``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Macie::Session
+    :cloudformationResource: AWS::Macie::Session
     """
 
     def __init__(
@@ -792,11 +747,10 @@ class CfnSession(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -821,8 +775,7 @@ class CfnSession(
     @jsii.member(jsii_name="attrAwsAccountId")
     def attr_aws_account_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: AwsAccountId
+        :cloudformationAttribute: AwsAccountId
         """
         return jsii.get(self, "attrAwsAccountId")
 
@@ -830,8 +783,7 @@ class CfnSession(
     @jsii.member(jsii_name="attrServiceRole")
     def attr_service_role(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ServiceRole
+        :cloudformationAttribute: ServiceRole
         """
         return jsii.get(self, "attrServiceRole")
 
@@ -845,7 +797,6 @@ class CfnSession(
     def finding_publishing_frequency(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::Session.FindingPublishingFrequency``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-findingpublishingfrequency
         """
         return jsii.get(self, "findingPublishingFrequency")
@@ -862,7 +813,6 @@ class CfnSession(
     def status(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::Session.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-status
         """
         return jsii.get(self, "status")
@@ -892,7 +842,6 @@ class CfnSessionProps:
         :param finding_publishing_frequency: ``AWS::Macie::Session.FindingPublishingFrequency``.
         :param status: ``AWS::Macie::Session.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -905,7 +854,6 @@ class CfnSessionProps:
     def finding_publishing_frequency(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::Session.FindingPublishingFrequency``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-findingpublishingfrequency
         """
         result = self._values.get("finding_publishing_frequency")
@@ -915,7 +863,6 @@ class CfnSessionProps:
     def status(self) -> typing.Optional[builtins.str]:
         """``AWS::Macie::Session.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-status
         """
         result = self._values.get("status")
