@@ -27,10 +27,8 @@ class CfnMember(
 ):
     """A CloudFormation ``AWS::ManagedBlockchain::Member``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::ManagedBlockchain::Member
+    :cloudformationResource: AWS::ManagedBlockchain::Member
     """
 
     def __init__(
@@ -38,9 +36,9 @@ class CfnMember(
         scope: _Construct_f50a3f53,
         id: builtins.str,
         *,
-        member_configuration: typing.Union["MemberConfigurationProperty", _IResolvable_9ceae33e],
+        member_configuration: typing.Union["CfnMember.MemberConfigurationProperty", _IResolvable_9ceae33e],
         invitation_id: typing.Optional[builtins.str] = None,
-        network_configuration: typing.Optional[typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
+        network_configuration: typing.Optional[typing.Union["CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
         network_id: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::ManagedBlockchain::Member``.
@@ -63,11 +61,10 @@ class CfnMember(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -92,8 +89,7 @@ class CfnMember(
     @jsii.member(jsii_name="attrMemberId")
     def attr_member_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: MemberId
+        :cloudformationAttribute: MemberId
         """
         return jsii.get(self, "attrMemberId")
 
@@ -101,8 +97,7 @@ class CfnMember(
     @jsii.member(jsii_name="attrNetworkId")
     def attr_network_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: NetworkId
+        :cloudformationAttribute: NetworkId
         """
         return jsii.get(self, "attrNetworkId")
 
@@ -115,10 +110,9 @@ class CfnMember(
     @jsii.member(jsii_name="memberConfiguration")
     def member_configuration(
         self,
-    ) -> typing.Union["MemberConfigurationProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnMember.MemberConfigurationProperty", _IResolvable_9ceae33e]:
         """``AWS::ManagedBlockchain::Member.MemberConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-memberconfiguration
         """
         return jsii.get(self, "memberConfiguration")
@@ -126,7 +120,7 @@ class CfnMember(
     @member_configuration.setter # type: ignore
     def member_configuration(
         self,
-        value: typing.Union["MemberConfigurationProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnMember.MemberConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "memberConfiguration", value)
 
@@ -135,7 +129,6 @@ class CfnMember(
     def invitation_id(self) -> typing.Optional[builtins.str]:
         """``AWS::ManagedBlockchain::Member.InvitationId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-invitationid
         """
         return jsii.get(self, "invitationId")
@@ -148,10 +141,9 @@ class CfnMember(
     @jsii.member(jsii_name="networkConfiguration")
     def network_configuration(
         self,
-    ) -> typing.Optional[typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::ManagedBlockchain::Member.NetworkConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkconfiguration
         """
         return jsii.get(self, "networkConfiguration")
@@ -159,7 +151,7 @@ class CfnMember(
     @network_configuration.setter # type: ignore
     def network_configuration(
         self,
-        value: typing.Optional[typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "networkConfiguration", value)
 
@@ -168,7 +160,6 @@ class CfnMember(
     def network_id(self) -> typing.Optional[builtins.str]:
         """``AWS::ManagedBlockchain::Member.NetworkId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkid
         """
         return jsii.get(self, "networkId")
@@ -199,7 +190,6 @@ class CfnMember(
             :param threshold_comparator: ``CfnMember.ApprovalThresholdPolicyProperty.ThresholdComparator``.
             :param threshold_percentage: ``CfnMember.ApprovalThresholdPolicyProperty.ThresholdPercentage``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-approvalthresholdpolicy.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -214,7 +204,6 @@ class CfnMember(
         def proposal_duration_in_hours(self) -> typing.Optional[jsii.Number]:
             """``CfnMember.ApprovalThresholdPolicyProperty.ProposalDurationInHours``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-approvalthresholdpolicy.html#cfn-managedblockchain-member-approvalthresholdpolicy-proposaldurationinhours
             """
             result = self._values.get("proposal_duration_in_hours")
@@ -224,7 +213,6 @@ class CfnMember(
         def threshold_comparator(self) -> typing.Optional[builtins.str]:
             """``CfnMember.ApprovalThresholdPolicyProperty.ThresholdComparator``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-approvalthresholdpolicy.html#cfn-managedblockchain-member-approvalthresholdpolicy-thresholdcomparator
             """
             result = self._values.get("threshold_comparator")
@@ -234,7 +222,6 @@ class CfnMember(
         def threshold_percentage(self) -> typing.Optional[jsii.Number]:
             """``CfnMember.ApprovalThresholdPolicyProperty.ThresholdPercentage``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-approvalthresholdpolicy.html#cfn-managedblockchain-member-approvalthresholdpolicy-thresholdpercentage
             """
             result = self._values.get("threshold_percentage")
@@ -273,7 +260,6 @@ class CfnMember(
             :param description: ``CfnMember.MemberConfigurationProperty.Description``.
             :param member_framework_configuration: ``CfnMember.MemberConfigurationProperty.MemberFrameworkConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -288,7 +274,6 @@ class CfnMember(
         def name(self) -> builtins.str:
             """``CfnMember.MemberConfigurationProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberconfiguration.html#cfn-managedblockchain-member-memberconfiguration-name
             """
             result = self._values.get("name")
@@ -299,7 +284,6 @@ class CfnMember(
         def description(self) -> typing.Optional[builtins.str]:
             """``CfnMember.MemberConfigurationProperty.Description``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberconfiguration.html#cfn-managedblockchain-member-memberconfiguration-description
             """
             result = self._values.get("description")
@@ -311,7 +295,6 @@ class CfnMember(
         ) -> typing.Optional[typing.Union["CfnMember.MemberFrameworkConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.MemberConfigurationProperty.MemberFrameworkConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberconfiguration.html#cfn-managedblockchain-member-memberconfiguration-memberframeworkconfiguration
             """
             result = self._values.get("member_framework_configuration")
@@ -347,7 +330,6 @@ class CfnMember(
             :param admin_password: ``CfnMember.MemberFabricConfigurationProperty.AdminPassword``.
             :param admin_username: ``CfnMember.MemberFabricConfigurationProperty.AdminUsername``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberfabricconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -359,7 +341,6 @@ class CfnMember(
         def admin_password(self) -> builtins.str:
             """``CfnMember.MemberFabricConfigurationProperty.AdminPassword``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberfabricconfiguration.html#cfn-managedblockchain-member-memberfabricconfiguration-adminpassword
             """
             result = self._values.get("admin_password")
@@ -370,7 +351,6 @@ class CfnMember(
         def admin_username(self) -> builtins.str:
             """``CfnMember.MemberFabricConfigurationProperty.AdminUsername``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberfabricconfiguration.html#cfn-managedblockchain-member-memberfabricconfiguration-adminusername
             """
             result = self._values.get("admin_username")
@@ -402,7 +382,6 @@ class CfnMember(
             """
             :param member_fabric_configuration: ``CfnMember.MemberFrameworkConfigurationProperty.MemberFabricConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberframeworkconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -415,7 +394,6 @@ class CfnMember(
         ) -> typing.Optional[typing.Union["CfnMember.MemberFabricConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.MemberFrameworkConfigurationProperty.MemberFabricConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-memberframeworkconfiguration.html#cfn-managedblockchain-member-memberframeworkconfiguration-memberfabricconfiguration
             """
             result = self._values.get("member_fabric_configuration")
@@ -463,7 +441,6 @@ class CfnMember(
             :param description: ``CfnMember.NetworkConfigurationProperty.Description``.
             :param network_framework_configuration: ``CfnMember.NetworkConfigurationProperty.NetworkFrameworkConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -481,7 +458,6 @@ class CfnMember(
         def framework(self) -> builtins.str:
             """``CfnMember.NetworkConfigurationProperty.Framework``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-framework
             """
             result = self._values.get("framework")
@@ -492,7 +468,6 @@ class CfnMember(
         def framework_version(self) -> builtins.str:
             """``CfnMember.NetworkConfigurationProperty.FrameworkVersion``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-frameworkversion
             """
             result = self._values.get("framework_version")
@@ -503,7 +478,6 @@ class CfnMember(
         def name(self) -> builtins.str:
             """``CfnMember.NetworkConfigurationProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-name
             """
             result = self._values.get("name")
@@ -516,7 +490,6 @@ class CfnMember(
         ) -> typing.Union["CfnMember.VotingPolicyProperty", _IResolvable_9ceae33e]:
             """``CfnMember.NetworkConfigurationProperty.VotingPolicy``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-votingpolicy
             """
             result = self._values.get("voting_policy")
@@ -527,7 +500,6 @@ class CfnMember(
         def description(self) -> typing.Optional[builtins.str]:
             """``CfnMember.NetworkConfigurationProperty.Description``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-description
             """
             result = self._values.get("description")
@@ -539,7 +511,6 @@ class CfnMember(
         ) -> typing.Optional[typing.Union["CfnMember.NetworkFrameworkConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.NetworkConfigurationProperty.NetworkFrameworkConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkconfiguration.html#cfn-managedblockchain-member-networkconfiguration-networkframeworkconfiguration
             """
             result = self._values.get("network_framework_configuration")
@@ -566,7 +537,6 @@ class CfnMember(
             """
             :param edition: ``CfnMember.NetworkFabricConfigurationProperty.Edition``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkfabricconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -577,7 +547,6 @@ class CfnMember(
         def edition(self) -> builtins.str:
             """``CfnMember.NetworkFabricConfigurationProperty.Edition``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkfabricconfiguration.html#cfn-managedblockchain-member-networkfabricconfiguration-edition
             """
             result = self._values.get("edition")
@@ -609,7 +578,6 @@ class CfnMember(
             """
             :param network_fabric_configuration: ``CfnMember.NetworkFrameworkConfigurationProperty.NetworkFabricConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkframeworkconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -622,7 +590,6 @@ class CfnMember(
         ) -> typing.Optional[typing.Union["CfnMember.NetworkFabricConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.NetworkFrameworkConfigurationProperty.NetworkFabricConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-networkframeworkconfiguration.html#cfn-managedblockchain-member-networkframeworkconfiguration-networkfabricconfiguration
             """
             result = self._values.get("network_fabric_configuration")
@@ -653,7 +620,6 @@ class CfnMember(
             """
             :param approval_threshold_policy: ``CfnMember.VotingPolicyProperty.ApprovalThresholdPolicy``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-votingpolicy.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -666,7 +632,6 @@ class CfnMember(
         ) -> typing.Optional[typing.Union["CfnMember.ApprovalThresholdPolicyProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.VotingPolicyProperty.ApprovalThresholdPolicy``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-member-votingpolicy.html#cfn-managedblockchain-member-votingpolicy-approvalthresholdpolicy
             """
             result = self._values.get("approval_threshold_policy")
@@ -698,9 +663,9 @@ class CfnMemberProps:
     def __init__(
         self,
         *,
-        member_configuration: typing.Union["CfnMember.MemberConfigurationProperty", _IResolvable_9ceae33e],
+        member_configuration: typing.Union[CfnMember.MemberConfigurationProperty, _IResolvable_9ceae33e],
         invitation_id: typing.Optional[builtins.str] = None,
-        network_configuration: typing.Optional[typing.Union["CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
+        network_configuration: typing.Optional[typing.Union[CfnMember.NetworkConfigurationProperty, _IResolvable_9ceae33e]] = None,
         network_id: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::ManagedBlockchain::Member``.
@@ -710,7 +675,6 @@ class CfnMemberProps:
         :param network_configuration: ``AWS::ManagedBlockchain::Member.NetworkConfiguration``.
         :param network_id: ``AWS::ManagedBlockchain::Member.NetworkId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -726,10 +690,9 @@ class CfnMemberProps:
     @builtins.property
     def member_configuration(
         self,
-    ) -> typing.Union["CfnMember.MemberConfigurationProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnMember.MemberConfigurationProperty, _IResolvable_9ceae33e]:
         """``AWS::ManagedBlockchain::Member.MemberConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-memberconfiguration
         """
         result = self._values.get("member_configuration")
@@ -740,7 +703,6 @@ class CfnMemberProps:
     def invitation_id(self) -> typing.Optional[builtins.str]:
         """``AWS::ManagedBlockchain::Member.InvitationId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-invitationid
         """
         result = self._values.get("invitation_id")
@@ -749,10 +711,9 @@ class CfnMemberProps:
     @builtins.property
     def network_configuration(
         self,
-    ) -> typing.Optional[typing.Union["CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnMember.NetworkConfigurationProperty, _IResolvable_9ceae33e]]:
         """``AWS::ManagedBlockchain::Member.NetworkConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkconfiguration
         """
         result = self._values.get("network_configuration")
@@ -762,7 +723,6 @@ class CfnMemberProps:
     def network_id(self) -> typing.Optional[builtins.str]:
         """``AWS::ManagedBlockchain::Member.NetworkId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkid
         """
         result = self._values.get("network_id")
@@ -788,10 +748,8 @@ class CfnNode(
 ):
     """A CloudFormation ``AWS::ManagedBlockchain::Node``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::ManagedBlockchain::Node
+    :cloudformationResource: AWS::ManagedBlockchain::Node
     """
 
     def __init__(
@@ -801,7 +759,7 @@ class CfnNode(
         *,
         member_id: builtins.str,
         network_id: builtins.str,
-        node_configuration: typing.Union["NodeConfigurationProperty", _IResolvable_9ceae33e],
+        node_configuration: typing.Union["CfnNode.NodeConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         """Create a new ``AWS::ManagedBlockchain::Node``.
 
@@ -821,11 +779,10 @@ class CfnNode(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -850,8 +807,7 @@ class CfnNode(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -859,8 +815,7 @@ class CfnNode(
     @jsii.member(jsii_name="attrMemberId")
     def attr_member_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: MemberId
+        :cloudformationAttribute: MemberId
         """
         return jsii.get(self, "attrMemberId")
 
@@ -868,8 +823,7 @@ class CfnNode(
     @jsii.member(jsii_name="attrNetworkId")
     def attr_network_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: NetworkId
+        :cloudformationAttribute: NetworkId
         """
         return jsii.get(self, "attrNetworkId")
 
@@ -877,8 +831,7 @@ class CfnNode(
     @jsii.member(jsii_name="attrNodeId")
     def attr_node_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: NodeId
+        :cloudformationAttribute: NodeId
         """
         return jsii.get(self, "attrNodeId")
 
@@ -892,7 +845,6 @@ class CfnNode(
     def member_id(self) -> builtins.str:
         """``AWS::ManagedBlockchain::Node.MemberId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-memberid
         """
         return jsii.get(self, "memberId")
@@ -906,7 +858,6 @@ class CfnNode(
     def network_id(self) -> builtins.str:
         """``AWS::ManagedBlockchain::Node.NetworkId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-networkid
         """
         return jsii.get(self, "networkId")
@@ -919,10 +870,9 @@ class CfnNode(
     @jsii.member(jsii_name="nodeConfiguration")
     def node_configuration(
         self,
-    ) -> typing.Union["NodeConfigurationProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnNode.NodeConfigurationProperty", _IResolvable_9ceae33e]:
         """``AWS::ManagedBlockchain::Node.NodeConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-nodeconfiguration
         """
         return jsii.get(self, "nodeConfiguration")
@@ -930,7 +880,7 @@ class CfnNode(
     @node_configuration.setter # type: ignore
     def node_configuration(
         self,
-        value: typing.Union["NodeConfigurationProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnNode.NodeConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "nodeConfiguration", value)
 
@@ -953,7 +903,6 @@ class CfnNode(
             :param availability_zone: ``CfnNode.NodeConfigurationProperty.AvailabilityZone``.
             :param instance_type: ``CfnNode.NodeConfigurationProperty.InstanceType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-node-nodeconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -965,7 +914,6 @@ class CfnNode(
         def availability_zone(self) -> builtins.str:
             """``CfnNode.NodeConfigurationProperty.AvailabilityZone``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-node-nodeconfiguration.html#cfn-managedblockchain-node-nodeconfiguration-availabilityzone
             """
             result = self._values.get("availability_zone")
@@ -976,7 +924,6 @@ class CfnNode(
         def instance_type(self) -> builtins.str:
             """``CfnNode.NodeConfigurationProperty.InstanceType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-managedblockchain-node-nodeconfiguration.html#cfn-managedblockchain-node-nodeconfiguration-instancetype
             """
             result = self._values.get("instance_type")
@@ -1010,7 +957,7 @@ class CfnNodeProps:
         *,
         member_id: builtins.str,
         network_id: builtins.str,
-        node_configuration: typing.Union["CfnNode.NodeConfigurationProperty", _IResolvable_9ceae33e],
+        node_configuration: typing.Union[CfnNode.NodeConfigurationProperty, _IResolvable_9ceae33e],
     ) -> None:
         """Properties for defining a ``AWS::ManagedBlockchain::Node``.
 
@@ -1018,7 +965,6 @@ class CfnNodeProps:
         :param network_id: ``AWS::ManagedBlockchain::Node.NetworkId``.
         :param node_configuration: ``AWS::ManagedBlockchain::Node.NodeConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1031,7 +977,6 @@ class CfnNodeProps:
     def member_id(self) -> builtins.str:
         """``AWS::ManagedBlockchain::Node.MemberId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-memberid
         """
         result = self._values.get("member_id")
@@ -1042,7 +987,6 @@ class CfnNodeProps:
     def network_id(self) -> builtins.str:
         """``AWS::ManagedBlockchain::Node.NetworkId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-networkid
         """
         result = self._values.get("network_id")
@@ -1052,10 +996,9 @@ class CfnNodeProps:
     @builtins.property
     def node_configuration(
         self,
-    ) -> typing.Union["CfnNode.NodeConfigurationProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnNode.NodeConfigurationProperty, _IResolvable_9ceae33e]:
         """``AWS::ManagedBlockchain::Node.NodeConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-nodeconfiguration
         """
         result = self._values.get("node_configuration")
