@@ -28,10 +28,8 @@ class CfnJobTemplate(
 ):
     """A CloudFormation ``AWS::MediaConvert::JobTemplate``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::MediaConvert::JobTemplate
+    :cloudformationResource: AWS::MediaConvert::JobTemplate
     """
 
     def __init__(
@@ -40,10 +38,10 @@ class CfnJobTemplate(
         id: builtins.str,
         *,
         settings_json: typing.Any,
-        acceleration_settings: typing.Optional[typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]] = None,
+        acceleration_settings: typing.Optional[typing.Union["CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e]] = None,
         category: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
-        hop_destinations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]]]] = None,
+        hop_destinations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e]]]] = None,
         name: typing.Optional[builtins.str] = None,
         priority: typing.Optional[jsii.Number] = None,
         queue: typing.Optional[builtins.str] = None,
@@ -82,11 +80,10 @@ class CfnJobTemplate(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -111,8 +108,7 @@ class CfnJobTemplate(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -120,8 +116,7 @@ class CfnJobTemplate(
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Name
+        :cloudformationAttribute: Name
         """
         return jsii.get(self, "attrName")
 
@@ -135,7 +130,6 @@ class CfnJobTemplate(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::MediaConvert::JobTemplate.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-tags
         """
         return jsii.get(self, "tags")
@@ -145,7 +139,6 @@ class CfnJobTemplate(
     def settings_json(self) -> typing.Any:
         """``AWS::MediaConvert::JobTemplate.SettingsJson``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-settingsjson
         """
         return jsii.get(self, "settingsJson")
@@ -158,10 +151,9 @@ class CfnJobTemplate(
     @jsii.member(jsii_name="accelerationSettings")
     def acceleration_settings(
         self,
-    ) -> typing.Optional[typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e]]:
         """``AWS::MediaConvert::JobTemplate.AccelerationSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-accelerationsettings
         """
         return jsii.get(self, "accelerationSettings")
@@ -169,7 +161,7 @@ class CfnJobTemplate(
     @acceleration_settings.setter # type: ignore
     def acceleration_settings(
         self,
-        value: typing.Optional[typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "accelerationSettings", value)
 
@@ -178,7 +170,6 @@ class CfnJobTemplate(
     def category(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Category``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-category
         """
         return jsii.get(self, "category")
@@ -192,7 +183,6 @@ class CfnJobTemplate(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-description
         """
         return jsii.get(self, "description")
@@ -205,10 +195,9 @@ class CfnJobTemplate(
     @jsii.member(jsii_name="hopDestinations")
     def hop_destinations(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::MediaConvert::JobTemplate.HopDestinations``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-hopdestinations
         """
         return jsii.get(self, "hopDestinations")
@@ -216,7 +205,7 @@ class CfnJobTemplate(
     @hop_destinations.setter # type: ignore
     def hop_destinations(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "hopDestinations", value)
 
@@ -225,7 +214,6 @@ class CfnJobTemplate(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-name
         """
         return jsii.get(self, "name")
@@ -239,7 +227,6 @@ class CfnJobTemplate(
     def priority(self) -> typing.Optional[jsii.Number]:
         """``AWS::MediaConvert::JobTemplate.Priority``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-priority
         """
         return jsii.get(self, "priority")
@@ -253,7 +240,6 @@ class CfnJobTemplate(
     def queue(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Queue``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-queue
         """
         return jsii.get(self, "queue")
@@ -267,7 +253,6 @@ class CfnJobTemplate(
     def status_update_interval(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.StatusUpdateInterval``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-statusupdateinterval
         """
         return jsii.get(self, "statusUpdateInterval")
@@ -286,7 +271,6 @@ class CfnJobTemplate(
             """
             :param mode: ``CfnJobTemplate.AccelerationSettingsProperty.Mode``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-accelerationsettings.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -297,7 +281,6 @@ class CfnJobTemplate(
         def mode(self) -> builtins.str:
             """``CfnJobTemplate.AccelerationSettingsProperty.Mode``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-accelerationsettings.html#cfn-mediaconvert-jobtemplate-accelerationsettings-mode
             """
             result = self._values.get("mode")
@@ -337,7 +320,6 @@ class CfnJobTemplate(
             :param queue: ``CfnJobTemplate.HopDestinationProperty.Queue``.
             :param wait_minutes: ``CfnJobTemplate.HopDestinationProperty.WaitMinutes``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-hopdestination.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -352,7 +334,6 @@ class CfnJobTemplate(
         def priority(self) -> typing.Optional[jsii.Number]:
             """``CfnJobTemplate.HopDestinationProperty.Priority``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-hopdestination.html#cfn-mediaconvert-jobtemplate-hopdestination-priority
             """
             result = self._values.get("priority")
@@ -362,7 +343,6 @@ class CfnJobTemplate(
         def queue(self) -> typing.Optional[builtins.str]:
             """``CfnJobTemplate.HopDestinationProperty.Queue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-hopdestination.html#cfn-mediaconvert-jobtemplate-hopdestination-queue
             """
             result = self._values.get("queue")
@@ -372,7 +352,6 @@ class CfnJobTemplate(
         def wait_minutes(self) -> typing.Optional[jsii.Number]:
             """``CfnJobTemplate.HopDestinationProperty.WaitMinutes``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-hopdestination.html#cfn-mediaconvert-jobtemplate-hopdestination-waitminutes
             """
             result = self._values.get("wait_minutes")
@@ -411,10 +390,10 @@ class CfnJobTemplateProps:
         self,
         *,
         settings_json: typing.Any,
-        acceleration_settings: typing.Optional[typing.Union["CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e]] = None,
+        acceleration_settings: typing.Optional[typing.Union[CfnJobTemplate.AccelerationSettingsProperty, _IResolvable_9ceae33e]] = None,
         category: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
-        hop_destinations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e]]]] = None,
+        hop_destinations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnJobTemplate.HopDestinationProperty, _IResolvable_9ceae33e]]]] = None,
         name: typing.Optional[builtins.str] = None,
         priority: typing.Optional[jsii.Number] = None,
         queue: typing.Optional[builtins.str] = None,
@@ -434,7 +413,6 @@ class CfnJobTemplateProps:
         :param status_update_interval: ``AWS::MediaConvert::JobTemplate.StatusUpdateInterval``.
         :param tags: ``AWS::MediaConvert::JobTemplate.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -463,7 +441,6 @@ class CfnJobTemplateProps:
     def settings_json(self) -> typing.Any:
         """``AWS::MediaConvert::JobTemplate.SettingsJson``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-settingsjson
         """
         result = self._values.get("settings_json")
@@ -473,10 +450,9 @@ class CfnJobTemplateProps:
     @builtins.property
     def acceleration_settings(
         self,
-    ) -> typing.Optional[typing.Union["CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnJobTemplate.AccelerationSettingsProperty, _IResolvable_9ceae33e]]:
         """``AWS::MediaConvert::JobTemplate.AccelerationSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-accelerationsettings
         """
         result = self._values.get("acceleration_settings")
@@ -486,7 +462,6 @@ class CfnJobTemplateProps:
     def category(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Category``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-category
         """
         result = self._values.get("category")
@@ -496,7 +471,6 @@ class CfnJobTemplateProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-description
         """
         result = self._values.get("description")
@@ -505,10 +479,9 @@ class CfnJobTemplateProps:
     @builtins.property
     def hop_destinations(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnJobTemplate.HopDestinationProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::MediaConvert::JobTemplate.HopDestinations``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-hopdestinations
         """
         result = self._values.get("hop_destinations")
@@ -518,7 +491,6 @@ class CfnJobTemplateProps:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-name
         """
         result = self._values.get("name")
@@ -528,7 +500,6 @@ class CfnJobTemplateProps:
     def priority(self) -> typing.Optional[jsii.Number]:
         """``AWS::MediaConvert::JobTemplate.Priority``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-priority
         """
         result = self._values.get("priority")
@@ -538,7 +509,6 @@ class CfnJobTemplateProps:
     def queue(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Queue``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-queue
         """
         result = self._values.get("queue")
@@ -548,7 +518,6 @@ class CfnJobTemplateProps:
     def status_update_interval(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.StatusUpdateInterval``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-statusupdateinterval
         """
         result = self._values.get("status_update_interval")
@@ -558,7 +527,6 @@ class CfnJobTemplateProps:
     def tags(self) -> typing.Any:
         """``AWS::MediaConvert::JobTemplate.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-tags
         """
         result = self._values.get("tags")
@@ -584,10 +552,8 @@ class CfnPreset(
 ):
     """A CloudFormation ``AWS::MediaConvert::Preset``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::MediaConvert::Preset
+    :cloudformationResource: AWS::MediaConvert::Preset
     """
 
     def __init__(
@@ -623,11 +589,10 @@ class CfnPreset(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -652,8 +617,7 @@ class CfnPreset(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -661,8 +625,7 @@ class CfnPreset(
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Name
+        :cloudformationAttribute: Name
         """
         return jsii.get(self, "attrName")
 
@@ -676,7 +639,6 @@ class CfnPreset(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::MediaConvert::Preset.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-tags
         """
         return jsii.get(self, "tags")
@@ -686,7 +648,6 @@ class CfnPreset(
     def settings_json(self) -> typing.Any:
         """``AWS::MediaConvert::Preset.SettingsJson``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-settingsjson
         """
         return jsii.get(self, "settingsJson")
@@ -700,7 +661,6 @@ class CfnPreset(
     def category(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Category``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-category
         """
         return jsii.get(self, "category")
@@ -714,7 +674,6 @@ class CfnPreset(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-description
         """
         return jsii.get(self, "description")
@@ -728,7 +687,6 @@ class CfnPreset(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-name
         """
         return jsii.get(self, "name")
@@ -767,7 +725,6 @@ class CfnPresetProps:
         :param name: ``AWS::MediaConvert::Preset.Name``.
         :param tags: ``AWS::MediaConvert::Preset.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -786,7 +743,6 @@ class CfnPresetProps:
     def settings_json(self) -> typing.Any:
         """``AWS::MediaConvert::Preset.SettingsJson``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-settingsjson
         """
         result = self._values.get("settings_json")
@@ -797,7 +753,6 @@ class CfnPresetProps:
     def category(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Category``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-category
         """
         result = self._values.get("category")
@@ -807,7 +762,6 @@ class CfnPresetProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-description
         """
         result = self._values.get("description")
@@ -817,7 +771,6 @@ class CfnPresetProps:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-name
         """
         result = self._values.get("name")
@@ -827,7 +780,6 @@ class CfnPresetProps:
     def tags(self) -> typing.Any:
         """``AWS::MediaConvert::Preset.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-tags
         """
         result = self._values.get("tags")
@@ -853,10 +805,8 @@ class CfnQueue(
 ):
     """A CloudFormation ``AWS::MediaConvert::Queue``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::MediaConvert::Queue
+    :cloudformationResource: AWS::MediaConvert::Queue
     """
 
     def __init__(
@@ -892,11 +842,10 @@ class CfnQueue(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -921,8 +870,7 @@ class CfnQueue(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -930,8 +878,7 @@ class CfnQueue(
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Name
+        :cloudformationAttribute: Name
         """
         return jsii.get(self, "attrName")
 
@@ -945,7 +892,6 @@ class CfnQueue(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::MediaConvert::Queue.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-tags
         """
         return jsii.get(self, "tags")
@@ -955,7 +901,6 @@ class CfnQueue(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-description
         """
         return jsii.get(self, "description")
@@ -969,7 +914,6 @@ class CfnQueue(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-name
         """
         return jsii.get(self, "name")
@@ -983,7 +927,6 @@ class CfnQueue(
     def pricing_plan(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.PricingPlan``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-pricingplan
         """
         return jsii.get(self, "pricingPlan")
@@ -997,7 +940,6 @@ class CfnQueue(
     def status(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-status
         """
         return jsii.get(self, "status")
@@ -1036,7 +978,6 @@ class CfnQueueProps:
         :param status: ``AWS::MediaConvert::Queue.Status``.
         :param tags: ``AWS::MediaConvert::Queue.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -1055,7 +996,6 @@ class CfnQueueProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-description
         """
         result = self._values.get("description")
@@ -1065,7 +1005,6 @@ class CfnQueueProps:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-name
         """
         result = self._values.get("name")
@@ -1075,7 +1014,6 @@ class CfnQueueProps:
     def pricing_plan(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.PricingPlan``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-pricingplan
         """
         result = self._values.get("pricing_plan")
@@ -1085,7 +1023,6 @@ class CfnQueueProps:
     def status(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Status``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-status
         """
         result = self._values.get("status")
@@ -1095,7 +1032,6 @@ class CfnQueueProps:
     def tags(self) -> typing.Any:
         """``AWS::MediaConvert::Queue.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-tags
         """
         result = self._values.get("tags")
