@@ -29,10 +29,8 @@ class CfnContainer(
 ):
     """A CloudFormation ``AWS::MediaStore::Container``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::MediaStore::Container
+    :cloudformationResource: AWS::MediaStore::Container
     """
 
     def __init__(
@@ -42,9 +40,9 @@ class CfnContainer(
         *,
         container_name: builtins.str,
         access_logging_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
-        cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]] = None,
+        cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]] = None,
         lifecycle_policy: typing.Optional[builtins.str] = None,
-        metric_policy: typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]] = None,
+        metric_policy: typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]] = None,
         policy: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -74,11 +72,10 @@ class CfnContainer(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -103,8 +100,7 @@ class CfnContainer(
     @jsii.member(jsii_name="attrEndpoint")
     def attr_endpoint(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Endpoint
+        :cloudformationAttribute: Endpoint
         """
         return jsii.get(self, "attrEndpoint")
 
@@ -118,7 +114,6 @@ class CfnContainer(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::MediaStore::Container.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-tags
         """
         return jsii.get(self, "tags")
@@ -128,7 +123,6 @@ class CfnContainer(
     def container_name(self) -> builtins.str:
         """``AWS::MediaStore::Container.ContainerName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-containername
         """
         return jsii.get(self, "containerName")
@@ -144,7 +138,6 @@ class CfnContainer(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.AccessLoggingEnabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-accessloggingenabled
         """
         return jsii.get(self, "accessLoggingEnabled")
@@ -160,10 +153,9 @@ class CfnContainer(
     @jsii.member(jsii_name="corsPolicy")
     def cors_policy(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::MediaStore::Container.CorsPolicy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-corspolicy
         """
         return jsii.get(self, "corsPolicy")
@@ -171,7 +163,7 @@ class CfnContainer(
     @cors_policy.setter # type: ignore
     def cors_policy(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "corsPolicy", value)
 
@@ -180,7 +172,6 @@ class CfnContainer(
     def lifecycle_policy(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaStore::Container.LifecyclePolicy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-lifecyclepolicy
         """
         return jsii.get(self, "lifecyclePolicy")
@@ -193,10 +184,9 @@ class CfnContainer(
     @jsii.member(jsii_name="metricPolicy")
     def metric_policy(
         self,
-    ) -> typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.MetricPolicy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-metricpolicy
         """
         return jsii.get(self, "metricPolicy")
@@ -204,7 +194,7 @@ class CfnContainer(
     @metric_policy.setter # type: ignore
     def metric_policy(
         self,
-        value: typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "metricPolicy", value)
 
@@ -213,7 +203,6 @@ class CfnContainer(
     def policy(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaStore::Container.Policy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-policy
         """
         return jsii.get(self, "policy")
@@ -250,7 +239,6 @@ class CfnContainer(
             :param expose_headers: ``CfnContainer.CorsRuleProperty.ExposeHeaders``.
             :param max_age_seconds: ``CfnContainer.CorsRuleProperty.MaxAgeSeconds``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -269,7 +257,6 @@ class CfnContainer(
         def allowed_headers(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnContainer.CorsRuleProperty.AllowedHeaders``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-allowedheaders
             """
             result = self._values.get("allowed_headers")
@@ -279,7 +266,6 @@ class CfnContainer(
         def allowed_methods(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnContainer.CorsRuleProperty.AllowedMethods``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-allowedmethods
             """
             result = self._values.get("allowed_methods")
@@ -289,7 +275,6 @@ class CfnContainer(
         def allowed_origins(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnContainer.CorsRuleProperty.AllowedOrigins``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-allowedorigins
             """
             result = self._values.get("allowed_origins")
@@ -299,7 +284,6 @@ class CfnContainer(
         def expose_headers(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnContainer.CorsRuleProperty.ExposeHeaders``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-exposeheaders
             """
             result = self._values.get("expose_headers")
@@ -309,7 +293,6 @@ class CfnContainer(
         def max_age_seconds(self) -> typing.Optional[jsii.Number]:
             """``CfnContainer.CorsRuleProperty.MaxAgeSeconds``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-maxageseconds
             """
             result = self._values.get("max_age_seconds")
@@ -345,7 +328,6 @@ class CfnContainer(
             :param container_level_metrics: ``CfnContainer.MetricPolicyProperty.ContainerLevelMetrics``.
             :param metric_policy_rules: ``CfnContainer.MetricPolicyProperty.MetricPolicyRules``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicy.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -358,7 +340,6 @@ class CfnContainer(
         def container_level_metrics(self) -> builtins.str:
             """``CfnContainer.MetricPolicyProperty.ContainerLevelMetrics``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicy.html#cfn-mediastore-container-metricpolicy-containerlevelmetrics
             """
             result = self._values.get("container_level_metrics")
@@ -371,7 +352,6 @@ class CfnContainer(
         ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.MetricPolicyRuleProperty", _IResolvable_9ceae33e]]]]:
             """``CfnContainer.MetricPolicyProperty.MetricPolicyRules``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicy.html#cfn-mediastore-container-metricpolicy-metricpolicyrules
             """
             result = self._values.get("metric_policy_rules")
@@ -407,7 +387,6 @@ class CfnContainer(
             :param object_group: ``CfnContainer.MetricPolicyRuleProperty.ObjectGroup``.
             :param object_group_name: ``CfnContainer.MetricPolicyRuleProperty.ObjectGroupName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicyrule.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -419,7 +398,6 @@ class CfnContainer(
         def object_group(self) -> builtins.str:
             """``CfnContainer.MetricPolicyRuleProperty.ObjectGroup``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicyrule.html#cfn-mediastore-container-metricpolicyrule-objectgroup
             """
             result = self._values.get("object_group")
@@ -430,7 +408,6 @@ class CfnContainer(
         def object_group_name(self) -> builtins.str:
             """``CfnContainer.MetricPolicyRuleProperty.ObjectGroupName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicyrule.html#cfn-mediastore-container-metricpolicyrule-objectgroupname
             """
             result = self._values.get("object_group_name")
@@ -468,9 +445,9 @@ class CfnContainerProps:
         *,
         container_name: builtins.str,
         access_logging_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
-        cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]] = None,
+        cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnContainer.CorsRuleProperty, _IResolvable_9ceae33e]]]] = None,
         lifecycle_policy: typing.Optional[builtins.str] = None,
-        metric_policy: typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]] = None,
+        metric_policy: typing.Optional[typing.Union[CfnContainer.MetricPolicyProperty, _IResolvable_9ceae33e]] = None,
         policy: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -484,7 +461,6 @@ class CfnContainerProps:
         :param policy: ``AWS::MediaStore::Container.Policy``.
         :param tags: ``AWS::MediaStore::Container.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -507,7 +483,6 @@ class CfnContainerProps:
     def container_name(self) -> builtins.str:
         """``AWS::MediaStore::Container.ContainerName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-containername
         """
         result = self._values.get("container_name")
@@ -520,7 +495,6 @@ class CfnContainerProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.AccessLoggingEnabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-accessloggingenabled
         """
         result = self._values.get("access_logging_enabled")
@@ -529,10 +503,9 @@ class CfnContainerProps:
     @builtins.property
     def cors_policy(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnContainer.CorsRuleProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::MediaStore::Container.CorsPolicy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-corspolicy
         """
         result = self._values.get("cors_policy")
@@ -542,7 +515,6 @@ class CfnContainerProps:
     def lifecycle_policy(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaStore::Container.LifecyclePolicy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-lifecyclepolicy
         """
         result = self._values.get("lifecycle_policy")
@@ -551,10 +523,9 @@ class CfnContainerProps:
     @builtins.property
     def metric_policy(
         self,
-    ) -> typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnContainer.MetricPolicyProperty, _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.MetricPolicy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-metricpolicy
         """
         result = self._values.get("metric_policy")
@@ -564,7 +535,6 @@ class CfnContainerProps:
     def policy(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaStore::Container.Policy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-policy
         """
         result = self._values.get("policy")
@@ -574,7 +544,6 @@ class CfnContainerProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::MediaStore::Container.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-tags
         """
         result = self._values.get("tags")
