@@ -29,10 +29,8 @@ class CfnServer(
 ):
     """A CloudFormation ``AWS::OpsWorksCM::Server``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::OpsWorksCM::Server
+    :cloudformationResource: AWS::OpsWorksCM::Server
     """
 
     def __init__(
@@ -51,7 +49,7 @@ class CfnServer(
         custom_private_key: typing.Optional[builtins.str] = None,
         disable_automated_backup: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         engine: typing.Optional[builtins.str] = None,
-        engine_attributes: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]]]] = None,
+        engine_attributes: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e]]]] = None,
         engine_model: typing.Optional[builtins.str] = None,
         engine_version: typing.Optional[builtins.str] = None,
         key_pair: typing.Optional[builtins.str] = None,
@@ -116,11 +114,10 @@ class CfnServer(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -145,8 +142,7 @@ class CfnServer(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -154,8 +150,7 @@ class CfnServer(
     @jsii.member(jsii_name="attrEndpoint")
     def attr_endpoint(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Endpoint
+        :cloudformationAttribute: Endpoint
         """
         return jsii.get(self, "attrEndpoint")
 
@@ -163,8 +158,7 @@ class CfnServer(
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Id
+        :cloudformationAttribute: Id
         """
         return jsii.get(self, "attrId")
 
@@ -178,7 +172,6 @@ class CfnServer(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::OpsWorksCM::Server.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-tags
         """
         return jsii.get(self, "tags")
@@ -188,7 +181,6 @@ class CfnServer(
     def instance_profile_arn(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.InstanceProfileArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-instanceprofilearn
         """
         return jsii.get(self, "instanceProfileArn")
@@ -202,7 +194,6 @@ class CfnServer(
     def instance_type(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.InstanceType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-instancetype
         """
         return jsii.get(self, "instanceType")
@@ -216,7 +207,6 @@ class CfnServer(
     def service_role_arn(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.ServiceRoleArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-servicerolearn
         """
         return jsii.get(self, "serviceRoleArn")
@@ -232,7 +222,6 @@ class CfnServer(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::OpsWorksCM::Server.AssociatePublicIpAddress``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-associatepublicipaddress
         """
         return jsii.get(self, "associatePublicIpAddress")
@@ -249,7 +238,6 @@ class CfnServer(
     def backup_id(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.BackupId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-backupid
         """
         return jsii.get(self, "backupId")
@@ -263,7 +251,6 @@ class CfnServer(
     def backup_retention_count(self) -> typing.Optional[jsii.Number]:
         """``AWS::OpsWorksCM::Server.BackupRetentionCount``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-backupretentioncount
         """
         return jsii.get(self, "backupRetentionCount")
@@ -277,7 +264,6 @@ class CfnServer(
     def custom_certificate(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomCertificate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-customcertificate
         """
         return jsii.get(self, "customCertificate")
@@ -291,7 +277,6 @@ class CfnServer(
     def custom_domain(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomDomain``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-customdomain
         """
         return jsii.get(self, "customDomain")
@@ -305,7 +290,6 @@ class CfnServer(
     def custom_private_key(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomPrivateKey``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-customprivatekey
         """
         return jsii.get(self, "customPrivateKey")
@@ -321,7 +305,6 @@ class CfnServer(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::OpsWorksCM::Server.DisableAutomatedBackup``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-disableautomatedbackup
         """
         return jsii.get(self, "disableAutomatedBackup")
@@ -338,7 +321,6 @@ class CfnServer(
     def engine(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.Engine``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-engine
         """
         return jsii.get(self, "engine")
@@ -351,10 +333,9 @@ class CfnServer(
     @jsii.member(jsii_name="engineAttributes")
     def engine_attributes(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::OpsWorksCM::Server.EngineAttributes``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-engineattributes
         """
         return jsii.get(self, "engineAttributes")
@@ -362,7 +343,7 @@ class CfnServer(
     @engine_attributes.setter # type: ignore
     def engine_attributes(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "engineAttributes", value)
 
@@ -371,7 +352,6 @@ class CfnServer(
     def engine_model(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.EngineModel``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-enginemodel
         """
         return jsii.get(self, "engineModel")
@@ -385,7 +365,6 @@ class CfnServer(
     def engine_version(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.EngineVersion``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-engineversion
         """
         return jsii.get(self, "engineVersion")
@@ -399,7 +378,6 @@ class CfnServer(
     def key_pair(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.KeyPair``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-keypair
         """
         return jsii.get(self, "keyPair")
@@ -413,7 +391,6 @@ class CfnServer(
     def preferred_backup_window(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.PreferredBackupWindow``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-preferredbackupwindow
         """
         return jsii.get(self, "preferredBackupWindow")
@@ -427,7 +404,6 @@ class CfnServer(
     def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.PreferredMaintenanceWindow``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-preferredmaintenancewindow
         """
         return jsii.get(self, "preferredMaintenanceWindow")
@@ -444,7 +420,6 @@ class CfnServer(
     def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::OpsWorksCM::Server.SecurityGroupIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-securitygroupids
         """
         return jsii.get(self, "securityGroupIds")
@@ -461,7 +436,6 @@ class CfnServer(
     def server_name(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.ServerName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-servername
         """
         return jsii.get(self, "serverName")
@@ -475,7 +449,6 @@ class CfnServer(
     def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::OpsWorksCM::Server.SubnetIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-subnetids
         """
         return jsii.get(self, "subnetIds")
@@ -500,7 +473,6 @@ class CfnServer(
             :param name: ``CfnServer.EngineAttributeProperty.Name``.
             :param value: ``CfnServer.EngineAttributeProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opsworkscm-server-engineattribute.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -513,7 +485,6 @@ class CfnServer(
         def name(self) -> typing.Optional[builtins.str]:
             """``CfnServer.EngineAttributeProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opsworkscm-server-engineattribute.html#cfn-opsworkscm-server-engineattribute-name
             """
             result = self._values.get("name")
@@ -523,7 +494,6 @@ class CfnServer(
         def value(self) -> typing.Optional[builtins.str]:
             """``CfnServer.EngineAttributeProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opsworkscm-server-engineattribute.html#cfn-opsworkscm-server-engineattribute-value
             """
             result = self._values.get("value")
@@ -583,7 +553,7 @@ class CfnServerProps:
         custom_private_key: typing.Optional[builtins.str] = None,
         disable_automated_backup: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         engine: typing.Optional[builtins.str] = None,
-        engine_attributes: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e]]]] = None,
+        engine_attributes: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnServer.EngineAttributeProperty, _IResolvable_9ceae33e]]]] = None,
         engine_model: typing.Optional[builtins.str] = None,
         engine_version: typing.Optional[builtins.str] = None,
         key_pair: typing.Optional[builtins.str] = None,
@@ -618,7 +588,6 @@ class CfnServerProps:
         :param subnet_ids: ``AWS::OpsWorksCM::Server.SubnetIds``.
         :param tags: ``AWS::OpsWorksCM::Server.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -667,7 +636,6 @@ class CfnServerProps:
     def instance_profile_arn(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.InstanceProfileArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-instanceprofilearn
         """
         result = self._values.get("instance_profile_arn")
@@ -678,7 +646,6 @@ class CfnServerProps:
     def instance_type(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.InstanceType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-instancetype
         """
         result = self._values.get("instance_type")
@@ -689,7 +656,6 @@ class CfnServerProps:
     def service_role_arn(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.ServiceRoleArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-servicerolearn
         """
         result = self._values.get("service_role_arn")
@@ -702,7 +668,6 @@ class CfnServerProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::OpsWorksCM::Server.AssociatePublicIpAddress``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-associatepublicipaddress
         """
         result = self._values.get("associate_public_ip_address")
@@ -712,7 +677,6 @@ class CfnServerProps:
     def backup_id(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.BackupId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-backupid
         """
         result = self._values.get("backup_id")
@@ -722,7 +686,6 @@ class CfnServerProps:
     def backup_retention_count(self) -> typing.Optional[jsii.Number]:
         """``AWS::OpsWorksCM::Server.BackupRetentionCount``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-backupretentioncount
         """
         result = self._values.get("backup_retention_count")
@@ -732,7 +695,6 @@ class CfnServerProps:
     def custom_certificate(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomCertificate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-customcertificate
         """
         result = self._values.get("custom_certificate")
@@ -742,7 +704,6 @@ class CfnServerProps:
     def custom_domain(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomDomain``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-customdomain
         """
         result = self._values.get("custom_domain")
@@ -752,7 +713,6 @@ class CfnServerProps:
     def custom_private_key(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomPrivateKey``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-customprivatekey
         """
         result = self._values.get("custom_private_key")
@@ -764,7 +724,6 @@ class CfnServerProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::OpsWorksCM::Server.DisableAutomatedBackup``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-disableautomatedbackup
         """
         result = self._values.get("disable_automated_backup")
@@ -774,7 +733,6 @@ class CfnServerProps:
     def engine(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.Engine``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-engine
         """
         result = self._values.get("engine")
@@ -783,10 +741,9 @@ class CfnServerProps:
     @builtins.property
     def engine_attributes(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnServer.EngineAttributeProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::OpsWorksCM::Server.EngineAttributes``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-engineattributes
         """
         result = self._values.get("engine_attributes")
@@ -796,7 +753,6 @@ class CfnServerProps:
     def engine_model(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.EngineModel``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-enginemodel
         """
         result = self._values.get("engine_model")
@@ -806,7 +762,6 @@ class CfnServerProps:
     def engine_version(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.EngineVersion``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-engineversion
         """
         result = self._values.get("engine_version")
@@ -816,7 +771,6 @@ class CfnServerProps:
     def key_pair(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.KeyPair``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-keypair
         """
         result = self._values.get("key_pair")
@@ -826,7 +780,6 @@ class CfnServerProps:
     def preferred_backup_window(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.PreferredBackupWindow``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-preferredbackupwindow
         """
         result = self._values.get("preferred_backup_window")
@@ -836,7 +789,6 @@ class CfnServerProps:
     def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.PreferredMaintenanceWindow``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-preferredmaintenancewindow
         """
         result = self._values.get("preferred_maintenance_window")
@@ -846,7 +798,6 @@ class CfnServerProps:
     def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::OpsWorksCM::Server.SecurityGroupIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-securitygroupids
         """
         result = self._values.get("security_group_ids")
@@ -856,7 +807,6 @@ class CfnServerProps:
     def server_name(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.ServerName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-servername
         """
         result = self._values.get("server_name")
@@ -866,7 +816,6 @@ class CfnServerProps:
     def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::OpsWorksCM::Server.SubnetIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-subnetids
         """
         result = self._values.get("subnet_ids")
@@ -876,7 +825,6 @@ class CfnServerProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::OpsWorksCM::Server.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-tags
         """
         result = self._values.get("tags")
