@@ -29,10 +29,8 @@ class CfnLedger(
 ):
     """A CloudFormation ``AWS::QLDB::Ledger``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::QLDB::Ledger
+    :cloudformationResource: AWS::QLDB::Ledger
     """
 
     def __init__(
@@ -65,11 +63,10 @@ class CfnLedger(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -100,7 +97,6 @@ class CfnLedger(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::QLDB::Ledger.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-tags
         """
         return jsii.get(self, "tags")
@@ -110,7 +106,6 @@ class CfnLedger(
     def permissions_mode(self) -> builtins.str:
         """``AWS::QLDB::Ledger.PermissionsMode``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-permissionsmode
         """
         return jsii.get(self, "permissionsMode")
@@ -126,7 +121,6 @@ class CfnLedger(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::QLDB::Ledger.DeletionProtection``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-deletionprotection
         """
         return jsii.get(self, "deletionProtection")
@@ -143,7 +137,6 @@ class CfnLedger(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::QLDB::Ledger.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-name
         """
         return jsii.get(self, "name")
@@ -179,7 +172,6 @@ class CfnLedgerProps:
         :param name: ``AWS::QLDB::Ledger.Name``.
         :param tags: ``AWS::QLDB::Ledger.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -196,7 +188,6 @@ class CfnLedgerProps:
     def permissions_mode(self) -> builtins.str:
         """``AWS::QLDB::Ledger.PermissionsMode``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-permissionsmode
         """
         result = self._values.get("permissions_mode")
@@ -209,7 +200,6 @@ class CfnLedgerProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::QLDB::Ledger.DeletionProtection``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-deletionprotection
         """
         result = self._values.get("deletion_protection")
@@ -219,7 +209,6 @@ class CfnLedgerProps:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::QLDB::Ledger.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-name
         """
         result = self._values.get("name")
@@ -229,7 +218,6 @@ class CfnLedgerProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::QLDB::Ledger.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-ledger.html#cfn-qldb-ledger-tags
         """
         result = self._values.get("tags")
@@ -255,10 +243,8 @@ class CfnStream(
 ):
     """A CloudFormation ``AWS::QLDB::Stream``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::QLDB::Stream
+    :cloudformationResource: AWS::QLDB::Stream
     """
 
     def __init__(
@@ -267,7 +253,7 @@ class CfnStream(
         id: builtins.str,
         *,
         inclusive_start_time: builtins.str,
-        kinesis_configuration: typing.Union["KinesisConfigurationProperty", _IResolvable_9ceae33e],
+        kinesis_configuration: typing.Union["CfnStream.KinesisConfigurationProperty", _IResolvable_9ceae33e],
         ledger_name: builtins.str,
         role_arn: builtins.str,
         stream_name: builtins.str,
@@ -300,11 +286,10 @@ class CfnStream(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -329,8 +314,7 @@ class CfnStream(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -338,8 +322,7 @@ class CfnStream(
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Id
+        :cloudformationAttribute: Id
         """
         return jsii.get(self, "attrId")
 
@@ -353,7 +336,6 @@ class CfnStream(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::QLDB::Stream.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-tags
         """
         return jsii.get(self, "tags")
@@ -363,7 +345,6 @@ class CfnStream(
     def inclusive_start_time(self) -> builtins.str:
         """``AWS::QLDB::Stream.InclusiveStartTime``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-inclusivestarttime
         """
         return jsii.get(self, "inclusiveStartTime")
@@ -376,10 +357,9 @@ class CfnStream(
     @jsii.member(jsii_name="kinesisConfiguration")
     def kinesis_configuration(
         self,
-    ) -> typing.Union["KinesisConfigurationProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union["CfnStream.KinesisConfigurationProperty", _IResolvable_9ceae33e]:
         """``AWS::QLDB::Stream.KinesisConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-kinesisconfiguration
         """
         return jsii.get(self, "kinesisConfiguration")
@@ -387,7 +367,7 @@ class CfnStream(
     @kinesis_configuration.setter # type: ignore
     def kinesis_configuration(
         self,
-        value: typing.Union["KinesisConfigurationProperty", _IResolvable_9ceae33e],
+        value: typing.Union["CfnStream.KinesisConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "kinesisConfiguration", value)
 
@@ -396,7 +376,6 @@ class CfnStream(
     def ledger_name(self) -> builtins.str:
         """``AWS::QLDB::Stream.LedgerName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-ledgername
         """
         return jsii.get(self, "ledgerName")
@@ -410,7 +389,6 @@ class CfnStream(
     def role_arn(self) -> builtins.str:
         """``AWS::QLDB::Stream.RoleArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-rolearn
         """
         return jsii.get(self, "roleArn")
@@ -424,7 +402,6 @@ class CfnStream(
     def stream_name(self) -> builtins.str:
         """``AWS::QLDB::Stream.StreamName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-streamname
         """
         return jsii.get(self, "streamName")
@@ -438,7 +415,6 @@ class CfnStream(
     def exclusive_end_time(self) -> typing.Optional[builtins.str]:
         """``AWS::QLDB::Stream.ExclusiveEndTime``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-exclusiveendtime
         """
         return jsii.get(self, "exclusiveEndTime")
@@ -466,7 +442,6 @@ class CfnStream(
             :param aggregation_enabled: ``CfnStream.KinesisConfigurationProperty.AggregationEnabled``.
             :param stream_arn: ``CfnStream.KinesisConfigurationProperty.StreamArn``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qldb-stream-kinesisconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -481,7 +456,6 @@ class CfnStream(
         ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnStream.KinesisConfigurationProperty.AggregationEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qldb-stream-kinesisconfiguration.html#cfn-qldb-stream-kinesisconfiguration-aggregationenabled
             """
             result = self._values.get("aggregation_enabled")
@@ -491,7 +465,6 @@ class CfnStream(
         def stream_arn(self) -> typing.Optional[builtins.str]:
             """``CfnStream.KinesisConfigurationProperty.StreamArn``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qldb-stream-kinesisconfiguration.html#cfn-qldb-stream-kinesisconfiguration-streamarn
             """
             result = self._values.get("stream_arn")
@@ -527,7 +500,7 @@ class CfnStreamProps:
         self,
         *,
         inclusive_start_time: builtins.str,
-        kinesis_configuration: typing.Union["CfnStream.KinesisConfigurationProperty", _IResolvable_9ceae33e],
+        kinesis_configuration: typing.Union[CfnStream.KinesisConfigurationProperty, _IResolvable_9ceae33e],
         ledger_name: builtins.str,
         role_arn: builtins.str,
         stream_name: builtins.str,
@@ -544,7 +517,6 @@ class CfnStreamProps:
         :param exclusive_end_time: ``AWS::QLDB::Stream.ExclusiveEndTime``.
         :param tags: ``AWS::QLDB::Stream.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -563,7 +535,6 @@ class CfnStreamProps:
     def inclusive_start_time(self) -> builtins.str:
         """``AWS::QLDB::Stream.InclusiveStartTime``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-inclusivestarttime
         """
         result = self._values.get("inclusive_start_time")
@@ -573,10 +544,9 @@ class CfnStreamProps:
     @builtins.property
     def kinesis_configuration(
         self,
-    ) -> typing.Union["CfnStream.KinesisConfigurationProperty", _IResolvable_9ceae33e]:
+    ) -> typing.Union[CfnStream.KinesisConfigurationProperty, _IResolvable_9ceae33e]:
         """``AWS::QLDB::Stream.KinesisConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-kinesisconfiguration
         """
         result = self._values.get("kinesis_configuration")
@@ -587,7 +557,6 @@ class CfnStreamProps:
     def ledger_name(self) -> builtins.str:
         """``AWS::QLDB::Stream.LedgerName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-ledgername
         """
         result = self._values.get("ledger_name")
@@ -598,7 +567,6 @@ class CfnStreamProps:
     def role_arn(self) -> builtins.str:
         """``AWS::QLDB::Stream.RoleArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-rolearn
         """
         result = self._values.get("role_arn")
@@ -609,7 +577,6 @@ class CfnStreamProps:
     def stream_name(self) -> builtins.str:
         """``AWS::QLDB::Stream.StreamName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-streamname
         """
         result = self._values.get("stream_name")
@@ -620,7 +587,6 @@ class CfnStreamProps:
     def exclusive_end_time(self) -> typing.Optional[builtins.str]:
         """``AWS::QLDB::Stream.ExclusiveEndTime``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-exclusiveendtime
         """
         result = self._values.get("exclusive_end_time")
@@ -630,7 +596,6 @@ class CfnStreamProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::QLDB::Stream.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qldb-stream.html#cfn-qldb-stream-tags
         """
         result = self._values.get("tags")
