@@ -10,6 +10,7 @@ import typing_extensions
 
 from .._jsii import *
 
+import constructs
 from .. import Construct as _Construct_f50a3f53
 from ..aws_certificatemanager import ICertificate as _ICertificate_8f3d4c96
 from ..aws_route53 import IHostedZone as _IHostedZone_59ffab76
@@ -20,17 +21,16 @@ class HttpsRedirect(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_route53_patterns.HttpsRedirect",
 ):
-    """Allows creating a domainA -> domainB redirect using CloudFront and S3.
+    """(experimental) Allows creating a domainA -> domainB redirect using CloudFront and S3.
 
     You can specify multiple domains to be redirected.
 
-    stability
     :stability: experimental
     """
 
     def __init__(
         self,
-        scope: _Construct_f50a3f53,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         target_domain: builtins.str,
@@ -41,12 +41,11 @@ class HttpsRedirect(
         """
         :param scope: -
         :param id: -
-        :param target_domain: The redirect target fully qualified domain name (FQDN). An alias record will be created that points to your CloudFront distribution. Root domain or sub-domain can be supplied.
-        :param zone: Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain. The hosted zone must contain entries for the domain name(s) supplied through ``recordNames`` that will redirect to the target domain. Domain names in the hosted zone can include a specific domain (example.com) and its subdomains (acme.example.com, zenith.example.com).
-        :param certificate: The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created. If provided, the certificate must be stored in us-east-1 (N. Virginia) Default: - A new certificate is created in us-east-1 (N. Virginia)
-        :param record_names: The domain names that will redirect to ``targetDomain``. Default: - the domain name of the hosted zone
+        :param target_domain: (experimental) The redirect target fully qualified domain name (FQDN). An alias record will be created that points to your CloudFront distribution. Root domain or sub-domain can be supplied.
+        :param zone: (experimental) Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain. The hosted zone must contain entries for the domain name(s) supplied through ``recordNames`` that will redirect to the target domain. Domain names in the hosted zone can include a specific domain (example.com) and its subdomains (acme.example.com, zenith.example.com).
+        :param certificate: (experimental) The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created. If provided, the certificate must be stored in us-east-1 (N. Virginia) Default: - A new certificate is created in us-east-1 (N. Virginia)
+        :param record_names: (experimental) The domain names that will redirect to ``targetDomain``. Default: - the domain name of the hosted zone
 
-        stability
         :stability: experimental
         """
         props = HttpsRedirectProps(
@@ -78,14 +77,13 @@ class HttpsRedirectProps:
         certificate: typing.Optional[_ICertificate_8f3d4c96] = None,
         record_names: typing.Optional[typing.List[builtins.str]] = None,
     ) -> None:
-        """Properties to configure an HTTPS Redirect.
+        """(experimental) Properties to configure an HTTPS Redirect.
 
-        :param target_domain: The redirect target fully qualified domain name (FQDN). An alias record will be created that points to your CloudFront distribution. Root domain or sub-domain can be supplied.
-        :param zone: Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain. The hosted zone must contain entries for the domain name(s) supplied through ``recordNames`` that will redirect to the target domain. Domain names in the hosted zone can include a specific domain (example.com) and its subdomains (acme.example.com, zenith.example.com).
-        :param certificate: The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created. If provided, the certificate must be stored in us-east-1 (N. Virginia) Default: - A new certificate is created in us-east-1 (N. Virginia)
-        :param record_names: The domain names that will redirect to ``targetDomain``. Default: - the domain name of the hosted zone
+        :param target_domain: (experimental) The redirect target fully qualified domain name (FQDN). An alias record will be created that points to your CloudFront distribution. Root domain or sub-domain can be supplied.
+        :param zone: (experimental) Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain. The hosted zone must contain entries for the domain name(s) supplied through ``recordNames`` that will redirect to the target domain. Domain names in the hosted zone can include a specific domain (example.com) and its subdomains (acme.example.com, zenith.example.com).
+        :param certificate: (experimental) The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created. If provided, the certificate must be stored in us-east-1 (N. Virginia) Default: - A new certificate is created in us-east-1 (N. Virginia)
+        :param record_names: (experimental) The domain names that will redirect to ``targetDomain``. Default: - the domain name of the hosted zone
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -99,13 +97,12 @@ class HttpsRedirectProps:
 
     @builtins.property
     def target_domain(self) -> builtins.str:
-        """The redirect target fully qualified domain name (FQDN).
+        """(experimental) The redirect target fully qualified domain name (FQDN).
 
         An alias record
         will be created that points to your CloudFront distribution. Root domain
         or sub-domain can be supplied.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("target_domain")
@@ -114,7 +111,7 @@ class HttpsRedirectProps:
 
     @builtins.property
     def zone(self) -> _IHostedZone_59ffab76:
-        """Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain.
+        """(experimental) Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain.
 
         The hosted zone must
         contain entries for the domain name(s) supplied through ``recordNames`` that
@@ -123,7 +120,6 @@ class HttpsRedirectProps:
         Domain names in the hosted zone can include a specific domain (example.com)
         and its subdomains (acme.example.com, zenith.example.com).
 
-        stability
         :stability: experimental
         """
         result = self._values.get("zone")
@@ -132,15 +128,13 @@ class HttpsRedirectProps:
 
     @builtins.property
     def certificate(self) -> typing.Optional[_ICertificate_8f3d4c96]:
-        """The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created.
+        """(experimental) The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created.
 
         If provided, the certificate must be
         stored in us-east-1 (N. Virginia)
 
-        default
         :default: - A new certificate is created in us-east-1 (N. Virginia)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("certificate")
@@ -148,12 +142,10 @@ class HttpsRedirectProps:
 
     @builtins.property
     def record_names(self) -> typing.Optional[typing.List[builtins.str]]:
-        """The domain names that will redirect to ``targetDomain``.
+        """(experimental) The domain names that will redirect to ``targetDomain``.
 
-        default
         :default: - the domain name of the hosted zone
 
-        stability
         :stability: experimental
         """
         result = self._values.get("record_names")
