@@ -32,12 +32,11 @@ class ApiGatewayDomain(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_route53_targets.ApiGatewayDomain",
 ):
-    """Defines an API Gateway domain name as the alias target.
+    """(experimental) Defines an API Gateway domain name as the alias target.
 
     Use the ``ApiGateway`` class if you wish to map the alias to an REST API with a
     domain name defined throug the ``RestApiProps.domainName`` prop.
 
-    stability
     :stability: experimental
     """
 
@@ -45,18 +44,16 @@ class ApiGatewayDomain(
         """
         :param domain_name: -
 
-        stability
         :stability: experimental
         """
         jsii.create(ApiGatewayDomain, self, [domain_name])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _record: _IRecordSet_4a72cb59) -> _AliasRecordTargetConfig_193313da:
-        """Return hosted zone ID and DNS name, usable for Route53 alias targets.
+        """(experimental) Return hosted zone ID and DNS name, usable for Route53 alias targets.
 
         :param _record: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_record])
@@ -67,9 +64,8 @@ class BucketWebsiteTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_route53_targets.BucketWebsiteTarget",
 ):
-    """Use a S3 as an alias record target.
+    """(experimental) Use a S3 as an alias record target.
 
-    stability
     :stability: experimental
     """
 
@@ -77,18 +73,16 @@ class BucketWebsiteTarget(
         """
         :param bucket: -
 
-        stability
         :stability: experimental
         """
         jsii.create(BucketWebsiteTarget, self, [bucket])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _record: _IRecordSet_4a72cb59) -> _AliasRecordTargetConfig_193313da:
-        """Return hosted zone ID and DNS name, usable for Route53 alias targets.
+        """(experimental) Return hosted zone ID and DNS name, usable for Route53 alias targets.
 
         :param _record: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_record])
@@ -99,9 +93,8 @@ class ClassicLoadBalancerTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_route53_targets.ClassicLoadBalancerTarget",
 ):
-    """Use a classic ELB as an alias record target.
+    """(experimental) Use a classic ELB as an alias record target.
 
-    stability
     :stability: experimental
     """
 
@@ -109,18 +102,16 @@ class ClassicLoadBalancerTarget(
         """
         :param load_balancer: -
 
-        stability
         :stability: experimental
         """
         jsii.create(ClassicLoadBalancerTarget, self, [load_balancer])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _record: _IRecordSet_4a72cb59) -> _AliasRecordTargetConfig_193313da:
-        """Return hosted zone ID and DNS name, usable for Route53 alias targets.
+        """(experimental) Return hosted zone ID and DNS name, usable for Route53 alias targets.
 
         :param _record: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_record])
@@ -131,9 +122,8 @@ class CloudFrontTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_route53_targets.CloudFrontTarget",
 ):
-    """Use a CloudFront Distribution as an alias record target.
+    """(experimental) Use a CloudFront Distribution as an alias record target.
 
-    stability
     :stability: experimental
     """
 
@@ -141,7 +131,6 @@ class CloudFrontTarget(
         """
         :param distribution: -
 
-        stability
         :stability: experimental
         """
         jsii.create(CloudFrontTarget, self, [distribution])
@@ -149,22 +138,20 @@ class CloudFrontTarget(
     @jsii.member(jsii_name="getHostedZoneId")
     @builtins.classmethod
     def get_hosted_zone_id(cls, scope: _IConstruct_db0cc7e3) -> builtins.str:
-        """Get the hosted zone id for the current scope.
+        """(experimental) Get the hosted zone id for the current scope.
 
         :param scope: - scope in which this resource is defined.
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "getHostedZoneId", [scope])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _record: _IRecordSet_4a72cb59) -> _AliasRecordTargetConfig_193313da:
-        """Return hosted zone ID and DNS name, usable for Route53 alias targets.
+        """(experimental) Return hosted zone ID and DNS name, usable for Route53 alias targets.
 
         :param _record: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_record])
@@ -172,11 +159,10 @@ class CloudFrontTarget(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CLOUDFRONT_ZONE_ID")
     def CLOUDFRONT_ZONE_ID(cls) -> builtins.str:
-        """The hosted zone Id if using an alias record in Route53.
+        """(experimental) The hosted zone Id if using an alias record in Route53.
 
         This value never changes.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "CLOUDFRONT_ZONE_ID")
@@ -187,9 +173,8 @@ class InterfaceVpcEndpointTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_route53_targets.InterfaceVpcEndpointTarget",
 ):
-    """Set an InterfaceVpcEndpoint as a target for an ARecord.
+    """(experimental) Set an InterfaceVpcEndpoint as a target for an ARecord.
 
-    stability
     :stability: experimental
     """
 
@@ -197,18 +182,16 @@ class InterfaceVpcEndpointTarget(
         """
         :param vpc_endpoint: -
 
-        stability
         :stability: experimental
         """
         jsii.create(InterfaceVpcEndpointTarget, self, [vpc_endpoint])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _record: _IRecordSet_4a72cb59) -> _AliasRecordTargetConfig_193313da:
-        """Return hosted zone ID and DNS name, usable for Route53 alias targets.
+        """(experimental) Return hosted zone ID and DNS name, usable for Route53 alias targets.
 
         :param _record: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_record])
@@ -219,9 +202,8 @@ class LoadBalancerTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_route53_targets.LoadBalancerTarget",
 ):
-    """Use an ELBv2 as an alias record target.
+    """(experimental) Use an ELBv2 as an alias record target.
 
-    stability
     :stability: experimental
     """
 
@@ -229,18 +211,16 @@ class LoadBalancerTarget(
         """
         :param load_balancer: -
 
-        stability
         :stability: experimental
         """
         jsii.create(LoadBalancerTarget, self, [load_balancer])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _record: _IRecordSet_4a72cb59) -> _AliasRecordTargetConfig_193313da:
-        """Return hosted zone ID and DNS name, usable for Route53 alias targets.
+        """(experimental) Return hosted zone ID and DNS name, usable for Route53 alias targets.
 
         :param _record: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_record])
@@ -251,9 +231,8 @@ class UserPoolDomainTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_route53_targets.UserPoolDomainTarget",
 ):
-    """Use a user pool domain as an alias record target.
+    """(experimental) Use a user pool domain as an alias record target.
 
-    stability
     :stability: experimental
     """
 
@@ -261,18 +240,16 @@ class UserPoolDomainTarget(
         """
         :param domain: -
 
-        stability
         :stability: experimental
         """
         jsii.create(UserPoolDomainTarget, self, [domain])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _record: _IRecordSet_4a72cb59) -> _AliasRecordTargetConfig_193313da:
-        """Return hosted zone ID and DNS name, usable for Route53 alias targets.
+        """(experimental) Return hosted zone ID and DNS name, usable for Route53 alias targets.
 
         :param _record: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_record])
@@ -283,12 +260,11 @@ class ApiGateway(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_route53_targets.ApiGateway",
 ):
-    """Defines an API Gateway REST API as the alias target. Requires that the domain name will be defined through ``RestApiProps.domainName``.
+    """(experimental) Defines an API Gateway REST API as the alias target. Requires that the domain name will be defined through ``RestApiProps.domainName``.
 
     You can direct the alias to any ``apigateway.DomainName`` resource through the
     ``ApiGatewayDomain`` class.
 
-    stability
     :stability: experimental
     """
 
@@ -296,7 +272,6 @@ class ApiGateway(
         """
         :param api: -
 
-        stability
         :stability: experimental
         """
         jsii.create(ApiGateway, self, [api])
