@@ -32,9 +32,8 @@ class Asset(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_s3_assets.Asset",
 ):
-    """An asset represents a local file or directory, which is automatically uploaded to S3 and then can be referenced within a CDK application.
+    """(experimental) An asset represents a local file or directory, which is automatically uploaded to S3 and then can be referenced within a CDK application.
 
-    stability
     :stability: experimental
     """
 
@@ -55,16 +54,15 @@ class Asset(
         """
         :param scope: -
         :param id: -
-        :param path: The disk location of the asset. The path should refer to one of the following: - A regular file or a .zip file, in which case the file will be uploaded as-is to S3. - A directory, in which case it will be archived into a .zip file and uploaded to S3.
-        :param readers: A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
-        :param source_hash: Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
-        :param asset_hash: Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
-        :param asset_hash_type: Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
-        :param bundling: Bundle the asset by executing a command in a Docker container. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
+        :param path: (experimental) The disk location of the asset. The path should refer to one of the following: - A regular file or a .zip file, in which case the file will be uploaded as-is to S3. - A directory, in which case it will be archived into a .zip file and uploaded to S3.
+        :param readers: (experimental) A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
+        :param source_hash: (deprecated) Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
+        :param asset_hash: (experimental) Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
+        :param asset_hash_type: (experimental) Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
+        :param bundling: (experimental) Bundle the asset by executing a command in a Docker container. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
 
-        stability
         :stability: experimental
         """
         props = AssetProps(
@@ -86,7 +84,7 @@ class Asset(
         resource: _CfnResource_7760e8e4,
         resource_property: builtins.str,
     ) -> None:
-        """Adds CloudFormation template metadata to the specified resource with information that indicates which resource property is mapped to this local asset.
+        """(experimental) Adds CloudFormation template metadata to the specified resource with information that indicates which resource property is mapped to this local asset.
 
         This can be used by tools such as SAM CLI to provide local
         experience such as local invocation and debugging of Lambda functions.
@@ -98,20 +96,17 @@ class Asset(
         :param resource: The CloudFormation resource which is using this asset [disable-awslint:ref-via-interface].
         :param resource_property: The property name where this asset is referenced (e.g. "Code" for AWS::Lambda::Function).
 
-        see
         :see: https://github.com/aws/aws-cdk/issues/1432
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "addResourceMetadata", [resource, resource_property])
 
     @jsii.member(jsii_name="grantRead")
     def grant_read(self, grantee: _IGrantable_0fcfc53a) -> None:
-        """Grants read permissions to the principal on the assets bucket.
+        """(experimental) Grants read permissions to the principal on the assets bucket.
 
         :param grantee: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "grantRead", [grantee])
@@ -119,13 +114,12 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="assetHash")
     def asset_hash(self) -> builtins.str:
-        """A hash of this asset, which is available at construction time.
+        """(experimental) A hash of this asset, which is available at construction time.
 
         As this is a plain string, it
         can be used in construct IDs in order to enforce creation of a new resource when the content
         hash has changed.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "assetHash")
@@ -133,12 +127,11 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="assetPath")
     def asset_path(self) -> builtins.str:
-        """The path to the asset (stringinfied token).
+        """(experimental) The path to the asset (stringinfied token).
 
         If asset staging is disabled, this will just be the original path.
         If asset staging is enabled it will be the staged path.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "assetPath")
@@ -146,9 +139,8 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="bucket")
     def bucket(self) -> _IBucket_25bad983:
-        """The S3 bucket in which this asset resides.
+        """(experimental) The S3 bucket in which this asset resides.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "bucket")
@@ -156,9 +148,8 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="httpUrl")
     def http_url(self) -> builtins.str:
-        """Attribute which represents the S3 HTTP URL of this asset.
+        """(experimental) Attribute which represents the S3 HTTP URL of this asset.
 
-        stability
         :stability: experimental
 
         Example::
@@ -171,12 +162,11 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="isZipArchive")
     def is_zip_archive(self) -> builtins.bool:
-        """Indicates if this asset is a zip archive.
+        """(experimental) Indicates if this asset is a zip archive.
 
         Allows constructs to ensure that the
         correct file type was used.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "isZipArchive")
@@ -184,9 +174,8 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="s3BucketName")
     def s3_bucket_name(self) -> builtins.str:
-        """Attribute that represents the name of the bucket this asset exists in.
+        """(experimental) Attribute that represents the name of the bucket this asset exists in.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "s3BucketName")
@@ -194,9 +183,8 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="s3ObjectKey")
     def s3_object_key(self) -> builtins.str:
-        """Attribute which represents the S3 object key of this asset.
+        """(experimental) Attribute which represents the S3 object key of this asset.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "s3ObjectKey")
@@ -204,9 +192,8 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="s3ObjectUrl")
     def s3_object_url(self) -> builtins.str:
-        """Attribute which represents the S3 URL of this asset.
+        """(experimental) Attribute which represents the S3 URL of this asset.
 
-        stability
         :stability: experimental
 
         Example::
@@ -219,12 +206,10 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="s3Url")
     def s3_url(self) -> builtins.str:
-        """Attribute which represents the S3 URL of this asset.
+        """(deprecated) Attribute which represents the S3 URL of this asset.
 
-        deprecated
         :deprecated: use ``httpUrl``
 
-        stability
         :stability: deprecated
         """
         return jsii.get(self, "s3Url")
@@ -232,12 +217,10 @@ class Asset(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
-        """A cryptographic hash of the asset.
+        """(deprecated) A cryptographic hash of the asset.
 
-        deprecated
         :deprecated: see ``assetHash``
 
-        stability
         :stability: deprecated
         """
         return jsii.get(self, "sourceHash")
@@ -269,15 +252,14 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         source_hash: typing.Optional[builtins.str] = None,
     ) -> None:
         """
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
-        :param asset_hash: Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
-        :param asset_hash_type: Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
-        :param bundling: Bundle the asset by executing a command in a Docker container. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
-        :param readers: A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
-        :param source_hash: Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
+        :param asset_hash: (experimental) Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
+        :param asset_hash_type: (experimental) Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
+        :param bundling: (experimental) Bundle the asset by executing a command in a Docker container. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
+        :param readers: (experimental) A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
+        :param source_hash: (deprecated) Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
 
-        stability
         :stability: experimental
         """
         if isinstance(bundling, dict):
@@ -300,12 +282,10 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
 
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
-        """Glob patterns to exclude from the copy.
+        """(deprecated) Glob patterns to exclude from the copy.
 
-        default
         :default: nothing is excluded
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("exclude")
@@ -313,12 +293,10 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
 
     @builtins.property
     def follow(self) -> typing.Optional[_FollowMode_f74e7125]:
-        """A strategy for how to handle symlinks.
+        """(deprecated) A strategy for how to handle symlinks.
 
-        default
         :default: Never
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("follow")
@@ -326,7 +304,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
 
     @builtins.property
     def asset_hash(self) -> typing.Optional[builtins.str]:
-        """Specify a custom hash for this asset.
+        """(experimental) Specify a custom hash for this asset.
 
         If ``assetHashType`` is set it must
         be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will
@@ -339,10 +317,8 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         need to make sure it is updated every time the asset changes, or otherwise it is
         possible that some deployments will not be invalidated.
 
-        default
         :default: - based on ``assetHashType``
 
-        stability
         :stability: experimental
         """
         result = self._values.get("asset_hash")
@@ -350,18 +326,16 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
 
     @builtins.property
     def asset_hash_type(self) -> typing.Optional[_AssetHashType_16f7047a]:
-        """Specifies the type of hash to calculate for this asset.
+        """(experimental) Specifies the type of hash to calculate for this asset.
 
         If ``assetHash`` is configured, this option must be ``undefined`` or
         ``AssetHashType.CUSTOM``.
 
-        default
         :default:
 
         - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is
-          explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
+        explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("asset_hash_type")
@@ -369,20 +343,18 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
 
     @builtins.property
     def bundling(self) -> typing.Optional[_BundlingOptions_0cab5223]:
-        """Bundle the asset by executing a command in a Docker container.
+        """(experimental) Bundle the asset by executing a command in a Docker container.
 
         The asset path will be mounted at ``/asset-input``. The Docker
         container is responsible for putting content at ``/asset-output``.
         The content at ``/asset-output`` will be zipped and used as the
         final asset.
 
-        default
         :default:
 
         - uploaded as-is to S3 if the asset is a regular file or a .zip file,
-          archived into a .zip file and uploaded to S3 otherwise
+        archived into a .zip file and uploaded to S3 otherwise
 
-        stability
         :stability: experimental
         """
         result = self._values.get("bundling")
@@ -390,14 +362,12 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
 
     @builtins.property
     def readers(self) -> typing.Optional[typing.List[_IGrantable_0fcfc53a]]:
-        """A list of principals that should be able to read this asset from S3.
+        """(experimental) A list of principals that should be able to read this asset from S3.
 
         You can use ``asset.grantRead(principal)`` to grant read permissions later.
 
-        default
         :default: - No principals that can read file asset.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("readers")
@@ -405,7 +375,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
 
     @builtins.property
     def source_hash(self) -> typing.Optional[builtins.str]:
-        """Custom hash to use when identifying the specific version of the asset.
+        """(deprecated) Custom hash to use when identifying the specific version of the asset.
 
         For consistency,
         this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be
@@ -417,16 +387,13 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         you will need to make sure it is updated every time the source changes, or otherwise
         it is possible that some deployments will not be invalidated.
 
-        default
         :default:
 
         - automatically calculate source hash based on the contents
-          of the source file or directory.
+        of the source file or directory.
 
-        deprecated
         :deprecated: see ``assetHash`` and ``assetHashType``
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("source_hash")
@@ -472,16 +439,15 @@ class AssetProps(AssetOptions):
         path: builtins.str,
     ) -> None:
         """
-        :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: A strategy for how to handle symlinks. Default: Never
-        :param asset_hash: Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
-        :param asset_hash_type: Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
-        :param bundling: Bundle the asset by executing a command in a Docker container. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
-        :param readers: A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
-        :param source_hash: Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
-        :param path: The disk location of the asset. The path should refer to one of the following: - A regular file or a .zip file, in which case the file will be uploaded as-is to S3. - A directory, in which case it will be archived into a .zip file and uploaded to S3.
+        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
+        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
+        :param asset_hash: (experimental) Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
+        :param asset_hash_type: (experimental) Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
+        :param bundling: (experimental) Bundle the asset by executing a command in a Docker container. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
+        :param readers: (experimental) A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
+        :param source_hash: (deprecated) Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
+        :param path: (experimental) The disk location of the asset. The path should refer to one of the following: - A regular file or a .zip file, in which case the file will be uploaded as-is to S3. - A directory, in which case it will be archived into a .zip file and uploaded to S3.
 
-        stability
         :stability: experimental
         """
         if isinstance(bundling, dict):
@@ -506,12 +472,10 @@ class AssetProps(AssetOptions):
 
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
-        """Glob patterns to exclude from the copy.
+        """(deprecated) Glob patterns to exclude from the copy.
 
-        default
         :default: nothing is excluded
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("exclude")
@@ -519,12 +483,10 @@ class AssetProps(AssetOptions):
 
     @builtins.property
     def follow(self) -> typing.Optional[_FollowMode_f74e7125]:
-        """A strategy for how to handle symlinks.
+        """(deprecated) A strategy for how to handle symlinks.
 
-        default
         :default: Never
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("follow")
@@ -532,7 +494,7 @@ class AssetProps(AssetOptions):
 
     @builtins.property
     def asset_hash(self) -> typing.Optional[builtins.str]:
-        """Specify a custom hash for this asset.
+        """(experimental) Specify a custom hash for this asset.
 
         If ``assetHashType`` is set it must
         be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will
@@ -545,10 +507,8 @@ class AssetProps(AssetOptions):
         need to make sure it is updated every time the asset changes, or otherwise it is
         possible that some deployments will not be invalidated.
 
-        default
         :default: - based on ``assetHashType``
 
-        stability
         :stability: experimental
         """
         result = self._values.get("asset_hash")
@@ -556,18 +516,16 @@ class AssetProps(AssetOptions):
 
     @builtins.property
     def asset_hash_type(self) -> typing.Optional[_AssetHashType_16f7047a]:
-        """Specifies the type of hash to calculate for this asset.
+        """(experimental) Specifies the type of hash to calculate for this asset.
 
         If ``assetHash`` is configured, this option must be ``undefined`` or
         ``AssetHashType.CUSTOM``.
 
-        default
         :default:
 
         - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is
-          explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
+        explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("asset_hash_type")
@@ -575,20 +533,18 @@ class AssetProps(AssetOptions):
 
     @builtins.property
     def bundling(self) -> typing.Optional[_BundlingOptions_0cab5223]:
-        """Bundle the asset by executing a command in a Docker container.
+        """(experimental) Bundle the asset by executing a command in a Docker container.
 
         The asset path will be mounted at ``/asset-input``. The Docker
         container is responsible for putting content at ``/asset-output``.
         The content at ``/asset-output`` will be zipped and used as the
         final asset.
 
-        default
         :default:
 
         - uploaded as-is to S3 if the asset is a regular file or a .zip file,
-          archived into a .zip file and uploaded to S3 otherwise
+        archived into a .zip file and uploaded to S3 otherwise
 
-        stability
         :stability: experimental
         """
         result = self._values.get("bundling")
@@ -596,14 +552,12 @@ class AssetProps(AssetOptions):
 
     @builtins.property
     def readers(self) -> typing.Optional[typing.List[_IGrantable_0fcfc53a]]:
-        """A list of principals that should be able to read this asset from S3.
+        """(experimental) A list of principals that should be able to read this asset from S3.
 
         You can use ``asset.grantRead(principal)`` to grant read permissions later.
 
-        default
         :default: - No principals that can read file asset.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("readers")
@@ -611,7 +565,7 @@ class AssetProps(AssetOptions):
 
     @builtins.property
     def source_hash(self) -> typing.Optional[builtins.str]:
-        """Custom hash to use when identifying the specific version of the asset.
+        """(deprecated) Custom hash to use when identifying the specific version of the asset.
 
         For consistency,
         this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be
@@ -623,16 +577,13 @@ class AssetProps(AssetOptions):
         you will need to make sure it is updated every time the source changes, or otherwise
         it is possible that some deployments will not be invalidated.
 
-        default
         :default:
 
         - automatically calculate source hash based on the contents
-          of the source file or directory.
+        of the source file or directory.
 
-        deprecated
         :deprecated: see ``assetHash`` and ``assetHashType``
 
-        stability
         :stability: deprecated
         """
         result = self._values.get("source_hash")
@@ -640,14 +591,13 @@ class AssetProps(AssetOptions):
 
     @builtins.property
     def path(self) -> builtins.str:
-        """The disk location of the asset.
+        """(experimental) The disk location of the asset.
 
         The path should refer to one of the following:
 
         - A regular file or a .zip file, in which case the file will be uploaded as-is to S3.
         - A directory, in which case it will be archived into a .zip file and uploaded to S3.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("path")
