@@ -26,18 +26,16 @@ class AddHeader(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_ses_actions.AddHeader",
 ):
-    """Adds a header to the received email.
+    """(experimental) Adds a header to the received email.
 
-    stability
     :stability: experimental
     """
 
     def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
         """
-        :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
-        :param value: The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
+        :param name: (experimental) The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
+        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
 
-        stability
         :stability: experimental
         """
         props = AddHeaderProps(name=name, value=value)
@@ -46,11 +44,10 @@ class AddHeader(
 
     @jsii.member(jsii_name="bind")
     def bind(self, _rule: _IReceiptRule_fc1cf2e3) -> _ReceiptRuleActionConfig_2ed15321:
-        """Returns the receipt rule action specification.
+        """(experimental) Returns the receipt rule action specification.
 
         :param _rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_rule])
@@ -63,12 +60,11 @@ class AddHeader(
 )
 class AddHeaderProps:
     def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
-        """Construction properties for a add header action.
+        """(experimental) Construction properties for a add header action.
 
-        :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
-        :param value: The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
+        :param name: (experimental) The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
+        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -78,13 +74,12 @@ class AddHeaderProps:
 
     @builtins.property
     def name(self) -> builtins.str:
-        """The name of the header to add.
+        """(experimental) The name of the header to add.
 
         Must be between 1 and 50 characters,
         inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters
         and dashes only.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("name")
@@ -93,12 +88,11 @@ class AddHeaderProps:
 
     @builtins.property
     def value(self) -> builtins.str:
-        """The value of the header to add.
+        """(experimental) The value of the header to add.
 
         Must be less than 2048 characters,
         and must not contain newline characters ("\r" or "\n").
 
-        stability
         :stability: experimental
         """
         result = self._values.get("value")
@@ -122,9 +116,8 @@ class Bounce(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_ses_actions.Bounce",
 ):
-    """Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
+    """(experimental) Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
@@ -136,11 +129,10 @@ class Bounce(
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
         """
-        :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
-        :param template: The template containing the message, reply code and status code.
-        :param topic: The SNS topic to notify when the bounce action is taken. Default: no notification
+        :param sender: (experimental) The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
+        :param template: (experimental) The template containing the message, reply code and status code.
+        :param topic: (experimental) The SNS topic to notify when the bounce action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
         props = BounceProps(sender=sender, template=template, topic=topic)
@@ -149,11 +141,10 @@ class Bounce(
 
     @jsii.member(jsii_name="bind")
     def bind(self, _rule: _IReceiptRule_fc1cf2e3) -> _ReceiptRuleActionConfig_2ed15321:
-        """Returns the receipt rule action specification.
+        """(experimental) Returns the receipt rule action specification.
 
         :param _rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_rule])
@@ -172,13 +163,12 @@ class BounceProps:
         template: "BounceTemplate",
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
-        """Construction properties for a bounce action.
+        """(experimental) Construction properties for a bounce action.
 
-        :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
-        :param template: The template containing the message, reply code and status code.
-        :param topic: The SNS topic to notify when the bounce action is taken. Default: no notification
+        :param sender: (experimental) The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
+        :param template: (experimental) The template containing the message, reply code and status code.
+        :param topic: (experimental) The SNS topic to notify when the bounce action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -190,12 +180,11 @@ class BounceProps:
 
     @builtins.property
     def sender(self) -> builtins.str:
-        """The email address of the sender of the bounced email.
+        """(experimental) The email address of the sender of the bounced email.
 
         This is the address
         from which the bounce message will be sent.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("sender")
@@ -204,9 +193,8 @@ class BounceProps:
 
     @builtins.property
     def template(self) -> "BounceTemplate":
-        """The template containing the message, reply code and status code.
+        """(experimental) The template containing the message, reply code and status code.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("template")
@@ -215,12 +203,10 @@ class BounceProps:
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
-        """The SNS topic to notify when the bounce action is taken.
+        """(experimental) The SNS topic to notify when the bounce action is taken.
 
-        default
         :default: no notification
 
-        stability
         :stability: experimental
         """
         result = self._values.get("topic")
@@ -242,9 +228,8 @@ class BounceTemplate(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_ses_actions.BounceTemplate",
 ):
-    """A bounce template.
+    """(experimental) A bounce template.
 
-    stability
     :stability: experimental
     """
 
@@ -256,11 +241,10 @@ class BounceTemplate(
         status_code: typing.Optional[builtins.str] = None,
     ) -> None:
         """
-        :param message: Human-readable text to include in the bounce message.
-        :param smtp_reply_code: The SMTP reply code, as defined by RFC 5321.
-        :param status_code: The SMTP enhanced status code, as defined by RFC 3463.
+        :param message: (experimental) Human-readable text to include in the bounce message.
+        :param smtp_reply_code: (experimental) The SMTP reply code, as defined by RFC 5321.
+        :param status_code: (experimental) The SMTP enhanced status code, as defined by RFC 3463.
 
-        stability
         :stability: experimental
         """
         props = BounceTemplateProps(
@@ -273,7 +257,6 @@ class BounceTemplate(
     @jsii.member(jsii_name="MAILBOX_DOES_NOT_EXIST")
     def MAILBOX_DOES_NOT_EXIST(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "MAILBOX_DOES_NOT_EXIST")
@@ -282,7 +265,6 @@ class BounceTemplate(
     @jsii.member(jsii_name="MAILBOX_FULL")
     def MAILBOX_FULL(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "MAILBOX_FULL")
@@ -291,7 +273,6 @@ class BounceTemplate(
     @jsii.member(jsii_name="MESSAGE_CONTENT_REJECTED")
     def MESSAGE_CONTENT_REJECTED(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "MESSAGE_CONTENT_REJECTED")
@@ -300,7 +281,6 @@ class BounceTemplate(
     @jsii.member(jsii_name="MESSAGE_TOO_LARGE")
     def MESSAGE_TOO_LARGE(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "MESSAGE_TOO_LARGE")
@@ -309,7 +289,6 @@ class BounceTemplate(
     @jsii.member(jsii_name="TEMPORARY_FAILURE")
     def TEMPORARY_FAILURE(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "TEMPORARY_FAILURE")
@@ -318,7 +297,6 @@ class BounceTemplate(
     @jsii.member(jsii_name="props")
     def props(self) -> "BounceTemplateProps":
         """
-        stability
         :stability: experimental
         """
         return jsii.get(self, "props")
@@ -341,13 +319,12 @@ class BounceTemplateProps:
         smtp_reply_code: builtins.str,
         status_code: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Construction properties for a BounceTemplate.
+        """(experimental) Construction properties for a BounceTemplate.
 
-        :param message: Human-readable text to include in the bounce message.
-        :param smtp_reply_code: The SMTP reply code, as defined by RFC 5321.
-        :param status_code: The SMTP enhanced status code, as defined by RFC 3463.
+        :param message: (experimental) Human-readable text to include in the bounce message.
+        :param smtp_reply_code: (experimental) The SMTP reply code, as defined by RFC 5321.
+        :param status_code: (experimental) The SMTP enhanced status code, as defined by RFC 3463.
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -359,9 +336,8 @@ class BounceTemplateProps:
 
     @builtins.property
     def message(self) -> builtins.str:
-        """Human-readable text to include in the bounce message.
+        """(experimental) Human-readable text to include in the bounce message.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("message")
@@ -370,11 +346,9 @@ class BounceTemplateProps:
 
     @builtins.property
     def smtp_reply_code(self) -> builtins.str:
-        """The SMTP reply code, as defined by RFC 5321.
+        """(experimental) The SMTP reply code, as defined by RFC 5321.
 
-        see
         :see: https://tools.ietf.org/html/rfc5321
-        stability
         :stability: experimental
         """
         result = self._values.get("smtp_reply_code")
@@ -383,11 +357,9 @@ class BounceTemplateProps:
 
     @builtins.property
     def status_code(self) -> typing.Optional[builtins.str]:
-        """The SMTP enhanced status code, as defined by RFC 3463.
+        """(experimental) The SMTP enhanced status code, as defined by RFC 3463.
 
-        see
         :see: https://tools.ietf.org/html/rfc3463
-        stability
         :stability: experimental
         """
         result = self._values.get("status_code")
@@ -407,22 +379,19 @@ class BounceTemplateProps:
 
 @jsii.enum(jsii_type="monocdk-experiment.aws_ses_actions.EmailEncoding")
 class EmailEncoding(enum.Enum):
-    """The type of email encoding to use for a SNS action.
+    """(experimental) The type of email encoding to use for a SNS action.
 
-    stability
     :stability: experimental
     """
 
     BASE64 = "BASE64"
-    """Base 64.
+    """(experimental) Base 64.
 
-    stability
     :stability: experimental
     """
     UTF8 = "UTF8"
-    """UTF-8.
+    """(experimental) UTF-8.
 
-    stability
     :stability: experimental
     """
 
@@ -432,9 +401,8 @@ class Lambda(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_ses_actions.Lambda",
 ):
-    """Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
+    """(experimental) Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
@@ -446,11 +414,10 @@ class Lambda(
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
         """
-        :param function: The Lambda function to invoke.
-        :param invocation_type: The invocation type of the Lambda function. Default: Event
-        :param topic: The SNS topic to notify when the Lambda action is taken. Default: no notification
+        :param function: (experimental) The Lambda function to invoke.
+        :param invocation_type: (experimental) The invocation type of the Lambda function. Default: Event
+        :param topic: (experimental) The SNS topic to notify when the Lambda action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
         props = LambdaProps(
@@ -461,11 +428,10 @@ class Lambda(
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: _IReceiptRule_fc1cf2e3) -> _ReceiptRuleActionConfig_2ed15321:
-        """Returns the receipt rule action specification.
+        """(experimental) Returns the receipt rule action specification.
 
         :param rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [rule])
@@ -473,26 +439,23 @@ class Lambda(
 
 @jsii.enum(jsii_type="monocdk-experiment.aws_ses_actions.LambdaInvocationType")
 class LambdaInvocationType(enum.Enum):
-    """The type of invocation to use for a Lambda Action.
+    """(experimental) The type of invocation to use for a Lambda Action.
 
-    stability
     :stability: experimental
     """
 
     EVENT = "EVENT"
-    """The function will be invoked asynchronously.
+    """(experimental) The function will be invoked asynchronously.
 
-    stability
     :stability: experimental
     """
     REQUEST_RESPONSE = "REQUEST_RESPONSE"
-    """The function will be invoked sychronously.
+    """(experimental) The function will be invoked sychronously.
 
     Use RequestResponse only when
     you want to make a mail flow decision, such as whether to stop the receipt
     rule or the receipt rule set.
 
-    stability
     :stability: experimental
     """
 
@@ -511,16 +474,15 @@ class LambdaProps:
         self,
         *,
         function: _IFunction_1c1de0bc,
-        invocation_type: typing.Optional["LambdaInvocationType"] = None,
+        invocation_type: typing.Optional[LambdaInvocationType] = None,
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
-        """Construction properties for a Lambda action.
+        """(experimental) Construction properties for a Lambda action.
 
-        :param function: The Lambda function to invoke.
-        :param invocation_type: The invocation type of the Lambda function. Default: Event
-        :param topic: The SNS topic to notify when the Lambda action is taken. Default: no notification
+        :param function: (experimental) The Lambda function to invoke.
+        :param invocation_type: (experimental) The invocation type of the Lambda function. Default: Event
+        :param topic: (experimental) The SNS topic to notify when the Lambda action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -533,9 +495,8 @@ class LambdaProps:
 
     @builtins.property
     def function(self) -> _IFunction_1c1de0bc:
-        """The Lambda function to invoke.
+        """(experimental) The Lambda function to invoke.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("function")
@@ -543,13 +504,11 @@ class LambdaProps:
         return result
 
     @builtins.property
-    def invocation_type(self) -> typing.Optional["LambdaInvocationType"]:
-        """The invocation type of the Lambda function.
+    def invocation_type(self) -> typing.Optional[LambdaInvocationType]:
+        """(experimental) The invocation type of the Lambda function.
 
-        default
         :default: Event
 
-        stability
         :stability: experimental
         """
         result = self._values.get("invocation_type")
@@ -557,12 +516,10 @@ class LambdaProps:
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
-        """The SNS topic to notify when the Lambda action is taken.
+        """(experimental) The SNS topic to notify when the Lambda action is taken.
 
-        default
         :default: no notification
 
-        stability
         :stability: experimental
         """
         result = self._values.get("topic")
@@ -582,9 +539,8 @@ class LambdaProps:
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
 class S3(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.S3"):
-    """Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.
+    """(experimental) Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
@@ -597,12 +553,11 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
         """
-        :param bucket: The S3 bucket that incoming email will be saved to.
-        :param kms_key: The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
-        :param object_key_prefix: The key prefix of the S3 bucket. Default: no prefix
-        :param topic: The SNS topic to notify when the S3 action is taken. Default: no notification
+        :param bucket: (experimental) The S3 bucket that incoming email will be saved to.
+        :param kms_key: (experimental) The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
+        :param object_key_prefix: (experimental) The key prefix of the S3 bucket. Default: no prefix
+        :param topic: (experimental) The SNS topic to notify when the S3 action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
         props = S3Props(
@@ -616,11 +571,10 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: _IReceiptRule_fc1cf2e3) -> _ReceiptRuleActionConfig_2ed15321:
-        """Returns the receipt rule action specification.
+        """(experimental) Returns the receipt rule action specification.
 
         :param rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [rule])
@@ -645,14 +599,13 @@ class S3Props:
         object_key_prefix: typing.Optional[builtins.str] = None,
         topic: typing.Optional[_ITopic_ef0ebe0e] = None,
     ) -> None:
-        """Construction properties for a S3 action.
+        """(experimental) Construction properties for a S3 action.
 
-        :param bucket: The S3 bucket that incoming email will be saved to.
-        :param kms_key: The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
-        :param object_key_prefix: The key prefix of the S3 bucket. Default: no prefix
-        :param topic: The SNS topic to notify when the S3 action is taken. Default: no notification
+        :param bucket: (experimental) The S3 bucket that incoming email will be saved to.
+        :param kms_key: (experimental) The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
+        :param object_key_prefix: (experimental) The key prefix of the S3 bucket. Default: no prefix
+        :param topic: (experimental) The SNS topic to notify when the S3 action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -667,9 +620,8 @@ class S3Props:
 
     @builtins.property
     def bucket(self) -> _IBucket_25bad983:
-        """The S3 bucket that incoming email will be saved to.
+        """(experimental) The S3 bucket that incoming email will be saved to.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("bucket")
@@ -678,12 +630,10 @@ class S3Props:
 
     @builtins.property
     def kms_key(self) -> typing.Optional[_IKey_3336c79d]:
-        """The master key that SES should use to encrypt your emails before saving them to the S3 bucket.
+        """(experimental) The master key that SES should use to encrypt your emails before saving them to the S3 bucket.
 
-        default
         :default: no encryption
 
-        stability
         :stability: experimental
         """
         result = self._values.get("kms_key")
@@ -691,12 +641,10 @@ class S3Props:
 
     @builtins.property
     def object_key_prefix(self) -> typing.Optional[builtins.str]:
-        """The key prefix of the S3 bucket.
+        """(experimental) The key prefix of the S3 bucket.
 
-        default
         :default: no prefix
 
-        stability
         :stability: experimental
         """
         result = self._values.get("object_key_prefix")
@@ -704,12 +652,10 @@ class S3Props:
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
-        """The SNS topic to notify when the S3 action is taken.
+        """(experimental) The SNS topic to notify when the S3 action is taken.
 
-        default
         :default: no notification
 
-        stability
         :stability: experimental
         """
         result = self._values.get("topic")
@@ -729,9 +675,8 @@ class S3Props:
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
 class Sns(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Sns"):
-    """Publishes the email content within a notification to Amazon SNS.
+    """(experimental) Publishes the email content within a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
@@ -739,13 +684,12 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions
         self,
         *,
         topic: _ITopic_ef0ebe0e,
-        encoding: typing.Optional["EmailEncoding"] = None,
+        encoding: typing.Optional[EmailEncoding] = None,
     ) -> None:
         """
-        :param topic: The SNS topic to notify.
-        :param encoding: The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
+        :param topic: (experimental) The SNS topic to notify.
+        :param encoding: (experimental) The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
 
-        stability
         :stability: experimental
         """
         props = SnsProps(topic=topic, encoding=encoding)
@@ -754,11 +698,10 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions
 
     @jsii.member(jsii_name="bind")
     def bind(self, _rule: _IReceiptRule_fc1cf2e3) -> _ReceiptRuleActionConfig_2ed15321:
-        """Returns the receipt rule action specification.
+        """(experimental) Returns the receipt rule action specification.
 
         :param _rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_rule])
@@ -774,14 +717,13 @@ class SnsProps:
         self,
         *,
         topic: _ITopic_ef0ebe0e,
-        encoding: typing.Optional["EmailEncoding"] = None,
+        encoding: typing.Optional[EmailEncoding] = None,
     ) -> None:
-        """Construction properties for a SNS action.
+        """(experimental) Construction properties for a SNS action.
 
-        :param topic: The SNS topic to notify.
-        :param encoding: The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
+        :param topic: (experimental) The SNS topic to notify.
+        :param encoding: (experimental) The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -792,9 +734,8 @@ class SnsProps:
 
     @builtins.property
     def topic(self) -> _ITopic_ef0ebe0e:
-        """The SNS topic to notify.
+        """(experimental) The SNS topic to notify.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("topic")
@@ -802,13 +743,11 @@ class SnsProps:
         return result
 
     @builtins.property
-    def encoding(self) -> typing.Optional["EmailEncoding"]:
-        """The encoding to use for the email within the Amazon SNS notification.
+    def encoding(self) -> typing.Optional[EmailEncoding]:
+        """(experimental) The encoding to use for the email within the Amazon SNS notification.
 
-        default
         :default: UTF-8
 
-        stability
         :stability: experimental
         """
         result = self._values.get("encoding")
@@ -831,17 +770,15 @@ class Stop(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_ses_actions.Stop",
 ):
-    """Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
+    """(experimental) Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
     def __init__(self, *, topic: typing.Optional[_ITopic_ef0ebe0e] = None) -> None:
         """
-        :param topic: The SNS topic to notify when the stop action is taken.
+        :param topic: (experimental) The SNS topic to notify when the stop action is taken.
 
-        stability
         :stability: experimental
         """
         props = StopProps(topic=topic)
@@ -850,11 +787,10 @@ class Stop(
 
     @jsii.member(jsii_name="bind")
     def bind(self, _rule: _IReceiptRule_fc1cf2e3) -> _ReceiptRuleActionConfig_2ed15321:
-        """Returns the receipt rule action specification.
+        """(experimental) Returns the receipt rule action specification.
 
         :param _rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_rule])
@@ -867,11 +803,10 @@ class Stop(
 )
 class StopProps:
     def __init__(self, *, topic: typing.Optional[_ITopic_ef0ebe0e] = None) -> None:
-        """Construction properties for a stop action.
+        """(experimental) Construction properties for a stop action.
 
-        :param topic: The SNS topic to notify when the stop action is taken.
+        :param topic: (experimental) The SNS topic to notify when the stop action is taken.
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -880,9 +815,8 @@ class StopProps:
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
-        """The SNS topic to notify when the stop action is taken.
+        """(experimental) The SNS topic to notify when the stop action is taken.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("topic")
