@@ -26,11 +26,10 @@ class EmailSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_sns_subscriptions.EmailSubscription",
 ):
-    """Use an email address as a subscription target.
+    """(experimental) Use an email address as a subscription target.
 
     Email subscriptions require confirmation.
 
-    stability
     :stability: experimental
     """
 
@@ -44,11 +43,10 @@ class EmailSubscription(
     ) -> None:
         """
         :param email_address: -
-        :param json: Indicates if the full notification JSON should be sent to the email address or just the message text. Default: false (Message text)
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
+        :param json: (experimental) Indicates if the full notification JSON should be sent to the email address or just the message text. Default: false (Message text)
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         props = EmailSubscriptionProps(
@@ -59,11 +57,10 @@ class EmailSubscription(
 
     @jsii.member(jsii_name="bind")
     def bind(self, _topic: _ITopic_ef0ebe0e) -> _TopicSubscriptionConfig_2ddb92c9:
-        """Returns a configuration for an email address to subscribe to an SNS topic.
+        """(experimental) Returns a configuration for an email address to subscribe to an SNS topic.
 
         :param _topic: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_topic])
@@ -74,9 +71,8 @@ class LambdaSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_sns_subscriptions.LambdaSubscription",
 ):
-    """Use a Lambda function as a subscription target.
+    """(experimental) Use a Lambda function as a subscription target.
 
-    stability
     :stability: experimental
     """
 
@@ -89,10 +85,9 @@ class LambdaSubscription(
     ) -> None:
         """
         :param fn: -
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         props = LambdaSubscriptionProps(
@@ -103,11 +98,10 @@ class LambdaSubscription(
 
     @jsii.member(jsii_name="bind")
     def bind(self, topic: _ITopic_ef0ebe0e) -> _TopicSubscriptionConfig_2ddb92c9:
-        """Returns a configuration for a Lambda function to subscribe to an SNS topic.
+        """(experimental) Returns a configuration for a Lambda function to subscribe to an SNS topic.
 
         :param topic: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [topic])
@@ -118,9 +112,8 @@ class SmsSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_sns_subscriptions.SmsSubscription",
 ):
-    """Use an sms address as a subscription target.
+    """(experimental) Use an sms address as a subscription target.
 
-    stability
     :stability: experimental
     """
 
@@ -133,10 +126,9 @@ class SmsSubscription(
     ) -> None:
         """
         :param phone_number: -
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         props = SmsSubscriptionProps(
@@ -147,11 +139,10 @@ class SmsSubscription(
 
     @jsii.member(jsii_name="bind")
     def bind(self, _topic: _ITopic_ef0ebe0e) -> _TopicSubscriptionConfig_2ddb92c9:
-        """Returns a configuration used to subscribe to an SNS topic.
+        """(experimental) Returns a configuration used to subscribe to an SNS topic.
 
         :param _topic: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_topic])
@@ -162,9 +153,8 @@ class SqsSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_sns_subscriptions.SqsSubscription",
 ):
-    """Use an SQS queue as a subscription target.
+    """(experimental) Use an SQS queue as a subscription target.
 
-    stability
     :stability: experimental
     """
 
@@ -178,11 +168,10 @@ class SqsSubscription(
     ) -> None:
         """
         :param queue: -
-        :param raw_message_delivery: The message to the queue is the same as it was sent to the topic. If false, the message will be wrapped in an SNS envelope. Default: false
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
+        :param raw_message_delivery: (experimental) The message to the queue is the same as it was sent to the topic. If false, the message will be wrapped in an SNS envelope. Default: false
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         props = SqsSubscriptionProps(
@@ -195,11 +184,10 @@ class SqsSubscription(
 
     @jsii.member(jsii_name="bind")
     def bind(self, topic: _ITopic_ef0ebe0e) -> _TopicSubscriptionConfig_2ddb92c9:
-        """Returns a configuration for an SQS queue to subscribe to an SNS topic.
+        """(experimental) Returns a configuration for an SQS queue to subscribe to an SNS topic.
 
         :param topic: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [topic])
@@ -220,12 +208,11 @@ class SubscriptionProps:
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
         filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
-        """Options to subscribing to an SNS topic.
+        """(experimental) Options to subscribing to an SNS topic.
 
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -236,14 +223,12 @@ class SubscriptionProps:
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
-        """Queue to be used as dead letter queue.
+        """(experimental) Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
 
-        default
         :default: - No dead letter queue enabled.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("dead_letter_queue")
@@ -253,12 +238,10 @@ class SubscriptionProps:
     def filter_policy(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
-        """The filter policy.
+        """(experimental) The filter policy.
 
-        default
         :default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         result = self._values.get("filter_policy")
@@ -281,13 +264,11 @@ class UrlSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.aws_sns_subscriptions.UrlSubscription",
 ):
-    """Use a URL as a subscription target.
+    """(experimental) Use a URL as a subscription target.
 
     The message will be POSTed to the given URL.
 
-    see
     :see: https://docs.aws.amazon.com/sns/latest/dg/sns-http-https-endpoint-as-subscriber.html
-    stability
     :stability: experimental
     """
 
@@ -302,12 +283,11 @@ class UrlSubscription(
     ) -> None:
         """
         :param url: -
-        :param protocol: The subscription's protocol. Default: - Protocol is derived from url
-        :param raw_message_delivery: The message to the queue is the same as it was sent to the topic. If false, the message will be wrapped in an SNS envelope. Default: false
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
+        :param protocol: (experimental) The subscription's protocol. Default: - Protocol is derived from url
+        :param raw_message_delivery: (experimental) The message to the queue is the same as it was sent to the topic. If false, the message will be wrapped in an SNS envelope. Default: false
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         props = UrlSubscriptionProps(
@@ -321,11 +301,10 @@ class UrlSubscription(
 
     @jsii.member(jsii_name="bind")
     def bind(self, _topic: _ITopic_ef0ebe0e) -> _TopicSubscriptionConfig_2ddb92c9:
-        """Returns a configuration for a URL to subscribe to an SNS topic.
+        """(experimental) Returns a configuration for a URL to subscribe to an SNS topic.
 
         :param _topic: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_topic])
@@ -350,14 +329,13 @@ class UrlSubscriptionProps(SubscriptionProps):
         protocol: typing.Optional[_SubscriptionProtocol_3d1a4bcf] = None,
         raw_message_delivery: typing.Optional[builtins.bool] = None,
     ) -> None:
-        """Options for URL subscriptions.
+        """(experimental) Options for URL subscriptions.
 
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
-        :param protocol: The subscription's protocol. Default: - Protocol is derived from url
-        :param raw_message_delivery: The message to the queue is the same as it was sent to the topic. If false, the message will be wrapped in an SNS envelope. Default: false
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
+        :param protocol: (experimental) The subscription's protocol. Default: - Protocol is derived from url
+        :param raw_message_delivery: (experimental) The message to the queue is the same as it was sent to the topic. If false, the message will be wrapped in an SNS envelope. Default: false
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -372,14 +350,12 @@ class UrlSubscriptionProps(SubscriptionProps):
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
-        """Queue to be used as dead letter queue.
+        """(experimental) Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
 
-        default
         :default: - No dead letter queue enabled.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("dead_letter_queue")
@@ -389,12 +365,10 @@ class UrlSubscriptionProps(SubscriptionProps):
     def filter_policy(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
-        """The filter policy.
+        """(experimental) The filter policy.
 
-        default
         :default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         result = self._values.get("filter_policy")
@@ -402,12 +376,10 @@ class UrlSubscriptionProps(SubscriptionProps):
 
     @builtins.property
     def protocol(self) -> typing.Optional[_SubscriptionProtocol_3d1a4bcf]:
-        """The subscription's protocol.
+        """(experimental) The subscription's protocol.
 
-        default
         :default: - Protocol is derived from url
 
-        stability
         :stability: experimental
         """
         result = self._values.get("protocol")
@@ -415,14 +387,12 @@ class UrlSubscriptionProps(SubscriptionProps):
 
     @builtins.property
     def raw_message_delivery(self) -> typing.Optional[builtins.bool]:
-        """The message to the queue is the same as it was sent to the topic.
+        """(experimental) The message to the queue is the same as it was sent to the topic.
 
         If false, the message will be wrapped in an SNS envelope.
 
-        default
         :default: false
 
-        stability
         :stability: experimental
         """
         result = self._values.get("raw_message_delivery")
@@ -457,13 +427,12 @@ class EmailSubscriptionProps(SubscriptionProps):
         filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
         json: typing.Optional[builtins.bool] = None,
     ) -> None:
-        """Options for email subscriptions.
+        """(experimental) Options for email subscriptions.
 
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
-        :param json: Indicates if the full notification JSON should be sent to the email address or just the message text. Default: false (Message text)
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
+        :param json: (experimental) Indicates if the full notification JSON should be sent to the email address or just the message text. Default: false (Message text)
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -476,14 +445,12 @@ class EmailSubscriptionProps(SubscriptionProps):
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
-        """Queue to be used as dead letter queue.
+        """(experimental) Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
 
-        default
         :default: - No dead letter queue enabled.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("dead_letter_queue")
@@ -493,12 +460,10 @@ class EmailSubscriptionProps(SubscriptionProps):
     def filter_policy(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
-        """The filter policy.
+        """(experimental) The filter policy.
 
-        default
         :default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         result = self._values.get("filter_policy")
@@ -506,12 +471,10 @@ class EmailSubscriptionProps(SubscriptionProps):
 
     @builtins.property
     def json(self) -> typing.Optional[builtins.bool]:
-        """Indicates if the full notification JSON should be sent to the email address or just the message text.
+        """(experimental) Indicates if the full notification JSON should be sent to the email address or just the message text.
 
-        default
         :default: false (Message text)
 
-        stability
         :stability: experimental
         """
         result = self._values.get("json")
@@ -544,12 +507,11 @@ class LambdaSubscriptionProps(SubscriptionProps):
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
         filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
-        """Properties for a Lambda subscription.
+        """(experimental) Properties for a Lambda subscription.
 
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -560,14 +522,12 @@ class LambdaSubscriptionProps(SubscriptionProps):
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
-        """Queue to be used as dead letter queue.
+        """(experimental) Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
 
-        default
         :default: - No dead letter queue enabled.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("dead_letter_queue")
@@ -577,12 +537,10 @@ class LambdaSubscriptionProps(SubscriptionProps):
     def filter_policy(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
-        """The filter policy.
+        """(experimental) The filter policy.
 
-        default
         :default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         result = self._values.get("filter_policy")
@@ -615,12 +573,11 @@ class SmsSubscriptionProps(SubscriptionProps):
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
         filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
-        """Options for SMS subscriptions.
+        """(experimental) Options for SMS subscriptions.
 
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -631,14 +588,12 @@ class SmsSubscriptionProps(SubscriptionProps):
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
-        """Queue to be used as dead letter queue.
+        """(experimental) Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
 
-        default
         :default: - No dead letter queue enabled.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("dead_letter_queue")
@@ -648,12 +603,10 @@ class SmsSubscriptionProps(SubscriptionProps):
     def filter_policy(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
-        """The filter policy.
+        """(experimental) The filter policy.
 
-        default
         :default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         result = self._values.get("filter_policy")
@@ -688,13 +641,12 @@ class SqsSubscriptionProps(SubscriptionProps):
         filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
         raw_message_delivery: typing.Optional[builtins.bool] = None,
     ) -> None:
-        """Properties for an SQS subscription.
+        """(experimental) Properties for an SQS subscription.
 
-        :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
-        :param filter_policy: The filter policy. Default: - all messages are delivered
-        :param raw_message_delivery: The message to the queue is the same as it was sent to the topic. If false, the message will be wrapped in an SNS envelope. Default: false
+        :param dead_letter_queue: (experimental) Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
+        :param filter_policy: (experimental) The filter policy. Default: - all messages are delivered
+        :param raw_message_delivery: (experimental) The message to the queue is the same as it was sent to the topic. If false, the message will be wrapped in an SNS envelope. Default: false
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -707,14 +659,12 @@ class SqsSubscriptionProps(SubscriptionProps):
 
     @builtins.property
     def dead_letter_queue(self) -> typing.Optional[_IQueue_b743f559]:
-        """Queue to be used as dead letter queue.
+        """(experimental) Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
 
-        default
         :default: - No dead letter queue enabled.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("dead_letter_queue")
@@ -724,12 +674,10 @@ class SqsSubscriptionProps(SubscriptionProps):
     def filter_policy(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
-        """The filter policy.
+        """(experimental) The filter policy.
 
-        default
         :default: - all messages are delivered
 
-        stability
         :stability: experimental
         """
         result = self._values.get("filter_policy")
@@ -737,14 +685,12 @@ class SqsSubscriptionProps(SubscriptionProps):
 
     @builtins.property
     def raw_message_delivery(self) -> typing.Optional[builtins.bool]:
-        """The message to the queue is the same as it was sent to the topic.
+        """(experimental) The message to the queue is the same as it was sent to the topic.
 
         If false, the message will be wrapped in an SNS envelope.
 
-        default
         :default: false
 
-        stability
         :stability: experimental
         """
         result = self._values.get("raw_message_delivery")
