@@ -28,10 +28,8 @@ class CfnAssignment(
 ):
     """A CloudFormation ``AWS::SSO::Assignment``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::SSO::Assignment
+    :cloudformationResource: AWS::SSO::Assignment
     """
 
     def __init__(
@@ -70,11 +68,10 @@ class CfnAssignment(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -105,7 +102,6 @@ class CfnAssignment(
     def instance_arn(self) -> builtins.str:
         """``AWS::SSO::Assignment.InstanceArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-instancearn
         """
         return jsii.get(self, "instanceArn")
@@ -119,7 +115,6 @@ class CfnAssignment(
     def permission_set_arn(self) -> builtins.str:
         """``AWS::SSO::Assignment.PermissionSetArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-permissionsetarn
         """
         return jsii.get(self, "permissionSetArn")
@@ -133,7 +128,6 @@ class CfnAssignment(
     def principal_id(self) -> builtins.str:
         """``AWS::SSO::Assignment.PrincipalId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-principalid
         """
         return jsii.get(self, "principalId")
@@ -147,7 +141,6 @@ class CfnAssignment(
     def principal_type(self) -> builtins.str:
         """``AWS::SSO::Assignment.PrincipalType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-principaltype
         """
         return jsii.get(self, "principalType")
@@ -161,7 +154,6 @@ class CfnAssignment(
     def target_id(self) -> builtins.str:
         """``AWS::SSO::Assignment.TargetId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-targetid
         """
         return jsii.get(self, "targetId")
@@ -175,7 +167,6 @@ class CfnAssignment(
     def target_type(self) -> builtins.str:
         """``AWS::SSO::Assignment.TargetType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-targettype
         """
         return jsii.get(self, "targetType")
@@ -217,7 +208,6 @@ class CfnAssignmentProps:
         :param target_id: ``AWS::SSO::Assignment.TargetId``.
         :param target_type: ``AWS::SSO::Assignment.TargetType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -233,7 +223,6 @@ class CfnAssignmentProps:
     def instance_arn(self) -> builtins.str:
         """``AWS::SSO::Assignment.InstanceArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-instancearn
         """
         result = self._values.get("instance_arn")
@@ -244,7 +233,6 @@ class CfnAssignmentProps:
     def permission_set_arn(self) -> builtins.str:
         """``AWS::SSO::Assignment.PermissionSetArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-permissionsetarn
         """
         result = self._values.get("permission_set_arn")
@@ -255,7 +243,6 @@ class CfnAssignmentProps:
     def principal_id(self) -> builtins.str:
         """``AWS::SSO::Assignment.PrincipalId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-principalid
         """
         result = self._values.get("principal_id")
@@ -266,7 +253,6 @@ class CfnAssignmentProps:
     def principal_type(self) -> builtins.str:
         """``AWS::SSO::Assignment.PrincipalType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-principaltype
         """
         result = self._values.get("principal_type")
@@ -277,7 +263,6 @@ class CfnAssignmentProps:
     def target_id(self) -> builtins.str:
         """``AWS::SSO::Assignment.TargetId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-targetid
         """
         result = self._values.get("target_id")
@@ -288,7 +273,6 @@ class CfnAssignmentProps:
     def target_type(self) -> builtins.str:
         """``AWS::SSO::Assignment.TargetType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-assignment.html#cfn-sso-assignment-targettype
         """
         result = self._values.get("target_type")
@@ -315,10 +299,8 @@ class CfnPermissionSet(
 ):
     """A CloudFormation ``AWS::SSO::PermissionSet``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::SSO::PermissionSet
+    :cloudformationResource: AWS::SSO::PermissionSet
     """
 
     def __init__(
@@ -363,11 +345,10 @@ class CfnPermissionSet(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -392,8 +373,7 @@ class CfnPermissionSet(
     @jsii.member(jsii_name="attrPermissionSetArn")
     def attr_permission_set_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: PermissionSetArn
+        :cloudformationAttribute: PermissionSetArn
         """
         return jsii.get(self, "attrPermissionSetArn")
 
@@ -407,7 +387,6 @@ class CfnPermissionSet(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::SSO::PermissionSet.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-tags
         """
         return jsii.get(self, "tags")
@@ -417,7 +396,6 @@ class CfnPermissionSet(
     def instance_arn(self) -> builtins.str:
         """``AWS::SSO::PermissionSet.InstanceArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-instancearn
         """
         return jsii.get(self, "instanceArn")
@@ -431,7 +409,6 @@ class CfnPermissionSet(
     def name(self) -> builtins.str:
         """``AWS::SSO::PermissionSet.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-name
         """
         return jsii.get(self, "name")
@@ -445,7 +422,6 @@ class CfnPermissionSet(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::SSO::PermissionSet.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-description
         """
         return jsii.get(self, "description")
@@ -459,7 +435,6 @@ class CfnPermissionSet(
     def inline_policy(self) -> typing.Optional[builtins.str]:
         """``AWS::SSO::PermissionSet.InlinePolicy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-inlinepolicy
         """
         return jsii.get(self, "inlinePolicy")
@@ -473,7 +448,6 @@ class CfnPermissionSet(
     def managed_policies(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::SSO::PermissionSet.ManagedPolicies``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-managedpolicies
         """
         return jsii.get(self, "managedPolicies")
@@ -490,7 +464,6 @@ class CfnPermissionSet(
     def relay_state_type(self) -> typing.Optional[builtins.str]:
         """``AWS::SSO::PermissionSet.RelayStateType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-relaystatetype
         """
         return jsii.get(self, "relayStateType")
@@ -504,7 +477,6 @@ class CfnPermissionSet(
     def session_duration(self) -> typing.Optional[builtins.str]:
         """``AWS::SSO::PermissionSet.SessionDuration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-sessionduration
         """
         return jsii.get(self, "sessionDuration")
@@ -552,7 +524,6 @@ class CfnPermissionSetProps:
         :param session_duration: ``AWS::SSO::PermissionSet.SessionDuration``.
         :param tags: ``AWS::SSO::PermissionSet.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -576,7 +547,6 @@ class CfnPermissionSetProps:
     def instance_arn(self) -> builtins.str:
         """``AWS::SSO::PermissionSet.InstanceArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-instancearn
         """
         result = self._values.get("instance_arn")
@@ -587,7 +557,6 @@ class CfnPermissionSetProps:
     def name(self) -> builtins.str:
         """``AWS::SSO::PermissionSet.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-name
         """
         result = self._values.get("name")
@@ -598,7 +567,6 @@ class CfnPermissionSetProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::SSO::PermissionSet.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-description
         """
         result = self._values.get("description")
@@ -608,7 +576,6 @@ class CfnPermissionSetProps:
     def inline_policy(self) -> typing.Optional[builtins.str]:
         """``AWS::SSO::PermissionSet.InlinePolicy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-inlinepolicy
         """
         result = self._values.get("inline_policy")
@@ -618,7 +585,6 @@ class CfnPermissionSetProps:
     def managed_policies(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::SSO::PermissionSet.ManagedPolicies``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-managedpolicies
         """
         result = self._values.get("managed_policies")
@@ -628,7 +594,6 @@ class CfnPermissionSetProps:
     def relay_state_type(self) -> typing.Optional[builtins.str]:
         """``AWS::SSO::PermissionSet.RelayStateType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-relaystatetype
         """
         result = self._values.get("relay_state_type")
@@ -638,7 +603,6 @@ class CfnPermissionSetProps:
     def session_duration(self) -> typing.Optional[builtins.str]:
         """``AWS::SSO::PermissionSet.SessionDuration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-sessionduration
         """
         result = self._values.get("session_duration")
@@ -648,7 +612,6 @@ class CfnPermissionSetProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::SSO::PermissionSet.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sso-permissionset.html#cfn-sso-permissionset-tags
         """
         result = self._values.get("tags")
