@@ -29,10 +29,8 @@ class CfnServer(
 ):
     """A CloudFormation ``AWS::Transfer::Server``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Transfer::Server
+    :cloudformationResource: AWS::Transfer::Server
     """
 
     def __init__(
@@ -41,9 +39,9 @@ class CfnServer(
         id: builtins.str,
         *,
         certificate: typing.Optional[builtins.str] = None,
-        endpoint_details: typing.Optional[typing.Union["EndpointDetailsProperty", _IResolvable_9ceae33e]] = None,
+        endpoint_details: typing.Optional[typing.Union["CfnServer.EndpointDetailsProperty", _IResolvable_9ceae33e]] = None,
         endpoint_type: typing.Optional[builtins.str] = None,
-        identity_provider_details: typing.Optional[typing.Union["IdentityProviderDetailsProperty", _IResolvable_9ceae33e]] = None,
+        identity_provider_details: typing.Optional[typing.Union["CfnServer.IdentityProviderDetailsProperty", _IResolvable_9ceae33e]] = None,
         identity_provider_type: typing.Optional[builtins.str] = None,
         logging_role: typing.Optional[builtins.str] = None,
         protocols: typing.Optional[typing.List[builtins.str]] = None,
@@ -80,11 +78,10 @@ class CfnServer(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -109,8 +106,7 @@ class CfnServer(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -118,8 +114,7 @@ class CfnServer(
     @jsii.member(jsii_name="attrServerId")
     def attr_server_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ServerId
+        :cloudformationAttribute: ServerId
         """
         return jsii.get(self, "attrServerId")
 
@@ -133,7 +128,6 @@ class CfnServer(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::Transfer::Server.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-tags
         """
         return jsii.get(self, "tags")
@@ -143,7 +137,6 @@ class CfnServer(
     def certificate(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.Certificate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-certificate
         """
         return jsii.get(self, "certificate")
@@ -156,10 +149,9 @@ class CfnServer(
     @jsii.member(jsii_name="endpointDetails")
     def endpoint_details(
         self,
-    ) -> typing.Optional[typing.Union["EndpointDetailsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnServer.EndpointDetailsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Transfer::Server.EndpointDetails``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-endpointdetails
         """
         return jsii.get(self, "endpointDetails")
@@ -167,7 +159,7 @@ class CfnServer(
     @endpoint_details.setter # type: ignore
     def endpoint_details(
         self,
-        value: typing.Optional[typing.Union["EndpointDetailsProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnServer.EndpointDetailsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "endpointDetails", value)
 
@@ -176,7 +168,6 @@ class CfnServer(
     def endpoint_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.EndpointType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-endpointtype
         """
         return jsii.get(self, "endpointType")
@@ -189,10 +180,9 @@ class CfnServer(
     @jsii.member(jsii_name="identityProviderDetails")
     def identity_provider_details(
         self,
-    ) -> typing.Optional[typing.Union["IdentityProviderDetailsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnServer.IdentityProviderDetailsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Transfer::Server.IdentityProviderDetails``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-identityproviderdetails
         """
         return jsii.get(self, "identityProviderDetails")
@@ -200,7 +190,7 @@ class CfnServer(
     @identity_provider_details.setter # type: ignore
     def identity_provider_details(
         self,
-        value: typing.Optional[typing.Union["IdentityProviderDetailsProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnServer.IdentityProviderDetailsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "identityProviderDetails", value)
 
@@ -209,7 +199,6 @@ class CfnServer(
     def identity_provider_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.IdentityProviderType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-identityprovidertype
         """
         return jsii.get(self, "identityProviderType")
@@ -223,7 +212,6 @@ class CfnServer(
     def logging_role(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.LoggingRole``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-loggingrole
         """
         return jsii.get(self, "loggingRole")
@@ -237,7 +225,6 @@ class CfnServer(
     def protocols(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Transfer::Server.Protocols``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-protocols
         """
         return jsii.get(self, "protocols")
@@ -251,7 +238,6 @@ class CfnServer(
     def security_policy_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.SecurityPolicyName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-securitypolicyname
         """
         return jsii.get(self, "securityPolicyName")
@@ -285,7 +271,6 @@ class CfnServer(
             :param vpc_endpoint_id: ``CfnServer.EndpointDetailsProperty.VpcEndpointId``.
             :param vpc_id: ``CfnServer.EndpointDetailsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-endpointdetails.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -302,7 +287,6 @@ class CfnServer(
         def address_allocation_ids(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnServer.EndpointDetailsProperty.AddressAllocationIds``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-endpointdetails.html#cfn-transfer-server-endpointdetails-addressallocationids
             """
             result = self._values.get("address_allocation_ids")
@@ -312,7 +296,6 @@ class CfnServer(
         def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnServer.EndpointDetailsProperty.SubnetIds``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-endpointdetails.html#cfn-transfer-server-endpointdetails-subnetids
             """
             result = self._values.get("subnet_ids")
@@ -322,7 +305,6 @@ class CfnServer(
         def vpc_endpoint_id(self) -> typing.Optional[builtins.str]:
             """``CfnServer.EndpointDetailsProperty.VpcEndpointId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-endpointdetails.html#cfn-transfer-server-endpointdetails-vpcendpointid
             """
             result = self._values.get("vpc_endpoint_id")
@@ -332,7 +314,6 @@ class CfnServer(
         def vpc_id(self) -> typing.Optional[builtins.str]:
             """``CfnServer.EndpointDetailsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-endpointdetails.html#cfn-transfer-server-endpointdetails-vpcid
             """
             result = self._values.get("vpc_id")
@@ -360,7 +341,6 @@ class CfnServer(
             :param invocation_role: ``CfnServer.IdentityProviderDetailsProperty.InvocationRole``.
             :param url: ``CfnServer.IdentityProviderDetailsProperty.Url``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-identityproviderdetails.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -372,7 +352,6 @@ class CfnServer(
         def invocation_role(self) -> builtins.str:
             """``CfnServer.IdentityProviderDetailsProperty.InvocationRole``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-identityproviderdetails.html#cfn-transfer-server-identityproviderdetails-invocationrole
             """
             result = self._values.get("invocation_role")
@@ -383,7 +362,6 @@ class CfnServer(
         def url(self) -> builtins.str:
             """``CfnServer.IdentityProviderDetailsProperty.Url``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-server-identityproviderdetails.html#cfn-transfer-server-identityproviderdetails-url
             """
             result = self._values.get("url")
@@ -422,9 +400,9 @@ class CfnServerProps:
         self,
         *,
         certificate: typing.Optional[builtins.str] = None,
-        endpoint_details: typing.Optional[typing.Union["CfnServer.EndpointDetailsProperty", _IResolvable_9ceae33e]] = None,
+        endpoint_details: typing.Optional[typing.Union[CfnServer.EndpointDetailsProperty, _IResolvable_9ceae33e]] = None,
         endpoint_type: typing.Optional[builtins.str] = None,
-        identity_provider_details: typing.Optional[typing.Union["CfnServer.IdentityProviderDetailsProperty", _IResolvable_9ceae33e]] = None,
+        identity_provider_details: typing.Optional[typing.Union[CfnServer.IdentityProviderDetailsProperty, _IResolvable_9ceae33e]] = None,
         identity_provider_type: typing.Optional[builtins.str] = None,
         logging_role: typing.Optional[builtins.str] = None,
         protocols: typing.Optional[typing.List[builtins.str]] = None,
@@ -443,7 +421,6 @@ class CfnServerProps:
         :param security_policy_name: ``AWS::Transfer::Server.SecurityPolicyName``.
         :param tags: ``AWS::Transfer::Server.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -470,7 +447,6 @@ class CfnServerProps:
     def certificate(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.Certificate``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-certificate
         """
         result = self._values.get("certificate")
@@ -479,10 +455,9 @@ class CfnServerProps:
     @builtins.property
     def endpoint_details(
         self,
-    ) -> typing.Optional[typing.Union["CfnServer.EndpointDetailsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnServer.EndpointDetailsProperty, _IResolvable_9ceae33e]]:
         """``AWS::Transfer::Server.EndpointDetails``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-endpointdetails
         """
         result = self._values.get("endpoint_details")
@@ -492,7 +467,6 @@ class CfnServerProps:
     def endpoint_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.EndpointType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-endpointtype
         """
         result = self._values.get("endpoint_type")
@@ -501,10 +475,9 @@ class CfnServerProps:
     @builtins.property
     def identity_provider_details(
         self,
-    ) -> typing.Optional[typing.Union["CfnServer.IdentityProviderDetailsProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnServer.IdentityProviderDetailsProperty, _IResolvable_9ceae33e]]:
         """``AWS::Transfer::Server.IdentityProviderDetails``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-identityproviderdetails
         """
         result = self._values.get("identity_provider_details")
@@ -514,7 +487,6 @@ class CfnServerProps:
     def identity_provider_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.IdentityProviderType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-identityprovidertype
         """
         result = self._values.get("identity_provider_type")
@@ -524,7 +496,6 @@ class CfnServerProps:
     def logging_role(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.LoggingRole``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-loggingrole
         """
         result = self._values.get("logging_role")
@@ -534,7 +505,6 @@ class CfnServerProps:
     def protocols(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Transfer::Server.Protocols``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-protocols
         """
         result = self._values.get("protocols")
@@ -544,7 +514,6 @@ class CfnServerProps:
     def security_policy_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::Server.SecurityPolicyName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-securitypolicyname
         """
         result = self._values.get("security_policy_name")
@@ -554,7 +523,6 @@ class CfnServerProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::Transfer::Server.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-server.html#cfn-transfer-server-tags
         """
         result = self._values.get("tags")
@@ -580,10 +548,8 @@ class CfnUser(
 ):
     """A CloudFormation ``AWS::Transfer::User``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Transfer::User
+    :cloudformationResource: AWS::Transfer::User
     """
 
     def __init__(
@@ -595,7 +561,7 @@ class CfnUser(
         server_id: builtins.str,
         user_name: builtins.str,
         home_directory: typing.Optional[builtins.str] = None,
-        home_directory_mappings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HomeDirectoryMapEntryProperty", _IResolvable_9ceae33e]]]] = None,
+        home_directory_mappings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnUser.HomeDirectoryMapEntryProperty", _IResolvable_9ceae33e]]]] = None,
         home_directory_type: typing.Optional[builtins.str] = None,
         policy: typing.Optional[builtins.str] = None,
         ssh_public_keys: typing.Optional[typing.List[builtins.str]] = None,
@@ -631,11 +597,10 @@ class CfnUser(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -660,8 +625,7 @@ class CfnUser(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -669,8 +633,7 @@ class CfnUser(
     @jsii.member(jsii_name="attrServerId")
     def attr_server_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ServerId
+        :cloudformationAttribute: ServerId
         """
         return jsii.get(self, "attrServerId")
 
@@ -678,8 +641,7 @@ class CfnUser(
     @jsii.member(jsii_name="attrUserName")
     def attr_user_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: UserName
+        :cloudformationAttribute: UserName
         """
         return jsii.get(self, "attrUserName")
 
@@ -693,7 +655,6 @@ class CfnUser(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::Transfer::User.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-tags
         """
         return jsii.get(self, "tags")
@@ -703,7 +664,6 @@ class CfnUser(
     def role(self) -> builtins.str:
         """``AWS::Transfer::User.Role``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-role
         """
         return jsii.get(self, "role")
@@ -717,7 +677,6 @@ class CfnUser(
     def server_id(self) -> builtins.str:
         """``AWS::Transfer::User.ServerId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-serverid
         """
         return jsii.get(self, "serverId")
@@ -731,7 +690,6 @@ class CfnUser(
     def user_name(self) -> builtins.str:
         """``AWS::Transfer::User.UserName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-username
         """
         return jsii.get(self, "userName")
@@ -745,7 +703,6 @@ class CfnUser(
     def home_directory(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::User.HomeDirectory``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-homedirectory
         """
         return jsii.get(self, "homeDirectory")
@@ -758,10 +715,9 @@ class CfnUser(
     @jsii.member(jsii_name="homeDirectoryMappings")
     def home_directory_mappings(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HomeDirectoryMapEntryProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnUser.HomeDirectoryMapEntryProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Transfer::User.HomeDirectoryMappings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-homedirectorymappings
         """
         return jsii.get(self, "homeDirectoryMappings")
@@ -769,7 +725,7 @@ class CfnUser(
     @home_directory_mappings.setter # type: ignore
     def home_directory_mappings(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HomeDirectoryMapEntryProperty", _IResolvable_9ceae33e]]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnUser.HomeDirectoryMapEntryProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "homeDirectoryMappings", value)
 
@@ -778,7 +734,6 @@ class CfnUser(
     def home_directory_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::User.HomeDirectoryType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-homedirectorytype
         """
         return jsii.get(self, "homeDirectoryType")
@@ -792,7 +747,6 @@ class CfnUser(
     def policy(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::User.Policy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-policy
         """
         return jsii.get(self, "policy")
@@ -806,7 +760,6 @@ class CfnUser(
     def ssh_public_keys(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Transfer::User.SshPublicKeys``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-sshpublickeys
         """
         return jsii.get(self, "sshPublicKeys")
@@ -829,7 +782,6 @@ class CfnUser(
             :param entry: ``CfnUser.HomeDirectoryMapEntryProperty.Entry``.
             :param target: ``CfnUser.HomeDirectoryMapEntryProperty.Target``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-user-homedirectorymapentry.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -841,7 +793,6 @@ class CfnUser(
         def entry(self) -> builtins.str:
             """``CfnUser.HomeDirectoryMapEntryProperty.Entry``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-user-homedirectorymapentry.html#cfn-transfer-user-homedirectorymapentry-entry
             """
             result = self._values.get("entry")
@@ -852,7 +803,6 @@ class CfnUser(
         def target(self) -> builtins.str:
             """``CfnUser.HomeDirectoryMapEntryProperty.Target``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-transfer-user-homedirectorymapentry.html#cfn-transfer-user-homedirectorymapentry-target
             """
             result = self._values.get("target")
@@ -894,7 +844,7 @@ class CfnUserProps:
         server_id: builtins.str,
         user_name: builtins.str,
         home_directory: typing.Optional[builtins.str] = None,
-        home_directory_mappings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnUser.HomeDirectoryMapEntryProperty", _IResolvable_9ceae33e]]]] = None,
+        home_directory_mappings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnUser.HomeDirectoryMapEntryProperty, _IResolvable_9ceae33e]]]] = None,
         home_directory_type: typing.Optional[builtins.str] = None,
         policy: typing.Optional[builtins.str] = None,
         ssh_public_keys: typing.Optional[typing.List[builtins.str]] = None,
@@ -912,7 +862,6 @@ class CfnUserProps:
         :param ssh_public_keys: ``AWS::Transfer::User.SshPublicKeys``.
         :param tags: ``AWS::Transfer::User.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -937,7 +886,6 @@ class CfnUserProps:
     def role(self) -> builtins.str:
         """``AWS::Transfer::User.Role``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-role
         """
         result = self._values.get("role")
@@ -948,7 +896,6 @@ class CfnUserProps:
     def server_id(self) -> builtins.str:
         """``AWS::Transfer::User.ServerId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-serverid
         """
         result = self._values.get("server_id")
@@ -959,7 +906,6 @@ class CfnUserProps:
     def user_name(self) -> builtins.str:
         """``AWS::Transfer::User.UserName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-username
         """
         result = self._values.get("user_name")
@@ -970,7 +916,6 @@ class CfnUserProps:
     def home_directory(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::User.HomeDirectory``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-homedirectory
         """
         result = self._values.get("home_directory")
@@ -979,10 +924,9 @@ class CfnUserProps:
     @builtins.property
     def home_directory_mappings(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnUser.HomeDirectoryMapEntryProperty", _IResolvable_9ceae33e]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[CfnUser.HomeDirectoryMapEntryProperty, _IResolvable_9ceae33e]]]]:
         """``AWS::Transfer::User.HomeDirectoryMappings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-homedirectorymappings
         """
         result = self._values.get("home_directory_mappings")
@@ -992,7 +936,6 @@ class CfnUserProps:
     def home_directory_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::User.HomeDirectoryType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-homedirectorytype
         """
         result = self._values.get("home_directory_type")
@@ -1002,7 +945,6 @@ class CfnUserProps:
     def policy(self) -> typing.Optional[builtins.str]:
         """``AWS::Transfer::User.Policy``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-policy
         """
         result = self._values.get("policy")
@@ -1012,7 +954,6 @@ class CfnUserProps:
     def ssh_public_keys(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Transfer::User.SshPublicKeys``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-sshpublickeys
         """
         result = self._values.get("ssh_public_keys")
@@ -1022,7 +963,6 @@ class CfnUserProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::Transfer::User.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-transfer-user.html#cfn-transfer-user-tags
         """
         result = self._values.get("tags")
