@@ -29,10 +29,8 @@ class CfnWorkspace(
 ):
     """A CloudFormation ``AWS::WorkSpaces::Workspace``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::WorkSpaces::Workspace
+    :cloudformationResource: AWS::WorkSpaces::Workspace
     """
 
     def __init__(
@@ -47,7 +45,7 @@ class CfnWorkspace(
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         user_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         volume_encryption_key: typing.Optional[builtins.str] = None,
-        workspace_properties: typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]] = None,
+        workspace_properties: typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::WorkSpaces::Workspace``.
 
@@ -77,11 +75,10 @@ class CfnWorkspace(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -112,7 +109,6 @@ class CfnWorkspace(
     def tags(self) -> _TagManager_2508893f:
         """``AWS::WorkSpaces::Workspace.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-tags
         """
         return jsii.get(self, "tags")
@@ -122,7 +118,6 @@ class CfnWorkspace(
     def bundle_id(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.BundleId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-bundleid
         """
         return jsii.get(self, "bundleId")
@@ -136,7 +131,6 @@ class CfnWorkspace(
     def directory_id(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.DirectoryId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-directoryid
         """
         return jsii.get(self, "directoryId")
@@ -150,7 +144,6 @@ class CfnWorkspace(
     def user_name(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.UserName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-username
         """
         return jsii.get(self, "userName")
@@ -166,7 +159,6 @@ class CfnWorkspace(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-rootvolumeencryptionenabled
         """
         return jsii.get(self, "rootVolumeEncryptionEnabled")
@@ -185,7 +177,6 @@ class CfnWorkspace(
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-uservolumeencryptionenabled
         """
         return jsii.get(self, "userVolumeEncryptionEnabled")
@@ -202,7 +193,6 @@ class CfnWorkspace(
     def volume_encryption_key(self) -> typing.Optional[builtins.str]:
         """``AWS::WorkSpaces::Workspace.VolumeEncryptionKey``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-volumeencryptionkey
         """
         return jsii.get(self, "volumeEncryptionKey")
@@ -215,10 +205,9 @@ class CfnWorkspace(
     @jsii.member(jsii_name="workspaceProperties")
     def workspace_properties(
         self,
-    ) -> typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-workspaceproperties
         """
         return jsii.get(self, "workspaceProperties")
@@ -226,7 +215,7 @@ class CfnWorkspace(
     @workspace_properties.setter # type: ignore
     def workspace_properties(
         self,
-        value: typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]],
+        value: typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "workspaceProperties", value)
 
@@ -258,7 +247,6 @@ class CfnWorkspace(
             :param running_mode_auto_stop_timeout_in_minutes: ``CfnWorkspace.WorkspacePropertiesProperty.RunningModeAutoStopTimeoutInMinutes``.
             :param user_volume_size_gib: ``CfnWorkspace.WorkspacePropertiesProperty.UserVolumeSizeGib``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -277,7 +265,6 @@ class CfnWorkspace(
         def compute_type_name(self) -> typing.Optional[builtins.str]:
             """``CfnWorkspace.WorkspacePropertiesProperty.ComputeTypeName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-computetypename
             """
             result = self._values.get("compute_type_name")
@@ -287,7 +274,6 @@ class CfnWorkspace(
         def root_volume_size_gib(self) -> typing.Optional[jsii.Number]:
             """``CfnWorkspace.WorkspacePropertiesProperty.RootVolumeSizeGib``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-rootvolumesizegib
             """
             result = self._values.get("root_volume_size_gib")
@@ -297,7 +283,6 @@ class CfnWorkspace(
         def running_mode(self) -> typing.Optional[builtins.str]:
             """``CfnWorkspace.WorkspacePropertiesProperty.RunningMode``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-runningmode
             """
             result = self._values.get("running_mode")
@@ -309,7 +294,6 @@ class CfnWorkspace(
         ) -> typing.Optional[jsii.Number]:
             """``CfnWorkspace.WorkspacePropertiesProperty.RunningModeAutoStopTimeoutInMinutes``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-runningmodeautostoptimeoutinminutes
             """
             result = self._values.get("running_mode_auto_stop_timeout_in_minutes")
@@ -319,7 +303,6 @@ class CfnWorkspace(
         def user_volume_size_gib(self) -> typing.Optional[jsii.Number]:
             """``CfnWorkspace.WorkspacePropertiesProperty.UserVolumeSizeGib``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-uservolumesizegib
             """
             result = self._values.get("user_volume_size_gib")
@@ -362,7 +345,7 @@ class CfnWorkspaceProps:
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         user_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         volume_encryption_key: typing.Optional[builtins.str] = None,
-        workspace_properties: typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]] = None,
+        workspace_properties: typing.Optional[typing.Union[CfnWorkspace.WorkspacePropertiesProperty, _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WorkSpaces::Workspace``.
 
@@ -375,7 +358,6 @@ class CfnWorkspaceProps:
         :param volume_encryption_key: ``AWS::WorkSpaces::Workspace.VolumeEncryptionKey``.
         :param workspace_properties: ``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -398,7 +380,6 @@ class CfnWorkspaceProps:
     def bundle_id(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.BundleId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-bundleid
         """
         result = self._values.get("bundle_id")
@@ -409,7 +390,6 @@ class CfnWorkspaceProps:
     def directory_id(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.DirectoryId``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-directoryid
         """
         result = self._values.get("directory_id")
@@ -420,7 +400,6 @@ class CfnWorkspaceProps:
     def user_name(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.UserName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-username
         """
         result = self._values.get("user_name")
@@ -433,7 +412,6 @@ class CfnWorkspaceProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-rootvolumeencryptionenabled
         """
         result = self._values.get("root_volume_encryption_enabled")
@@ -443,7 +421,6 @@ class CfnWorkspaceProps:
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
         """``AWS::WorkSpaces::Workspace.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-tags
         """
         result = self._values.get("tags")
@@ -455,7 +432,6 @@ class CfnWorkspaceProps:
     ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-uservolumeencryptionenabled
         """
         result = self._values.get("user_volume_encryption_enabled")
@@ -465,7 +441,6 @@ class CfnWorkspaceProps:
     def volume_encryption_key(self) -> typing.Optional[builtins.str]:
         """``AWS::WorkSpaces::Workspace.VolumeEncryptionKey``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-volumeencryptionkey
         """
         result = self._values.get("volume_encryption_key")
@@ -474,10 +449,9 @@ class CfnWorkspaceProps:
     @builtins.property
     def workspace_properties(
         self,
-    ) -> typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[CfnWorkspace.WorkspacePropertiesProperty, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-workspaceproperties
         """
         result = self._values.get("workspace_properties")
