@@ -29,12 +29,11 @@ class CfnInclude(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.cloudformation_include.CfnInclude",
 ):
-    """Construct to import an existing CloudFormation template file into a CDK application.
+    """(experimental) Construct to import an existing CloudFormation template file into a CDK application.
 
     All resources defined in the template file can be retrieved by calling the {@link getResource} method.
     Any modifications made on the returned resource objects will be reflected in the resulting CDK template.
 
-    stability
     :stability: experimental
     """
 
@@ -51,12 +50,11 @@ class CfnInclude(
         """
         :param scope: -
         :param id: -
-        :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
-        :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
-        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
+        :param template_file: (experimental) Path to the template file. Both JSON and YAML template formats are supported.
+        :param load_nested_stacks: (experimental) Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param parameters: (experimental) Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
+        :param preserve_logical_ids: (experimental) Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
 
-        stability
         :stability: experimental
         """
         props = CfnIncludeProps(
@@ -70,7 +68,7 @@ class CfnInclude(
 
     @jsii.member(jsii_name="getCondition")
     def get_condition(self, condition_name: builtins.str) -> _CfnCondition_548166d0:
-        """Returns the CfnCondition object from the 'Conditions' section of the CloudFormation template with the given name.
+        """(experimental) Returns the CfnCondition object from the 'Conditions' section of the CloudFormation template with the given name.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
 
@@ -79,14 +77,13 @@ class CfnInclude(
 
         :param condition_name: the name of the Condition in the CloudFormation template file.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "getCondition", [condition_name])
 
     @jsii.member(jsii_name="getHook")
     def get_hook(self, hook_logical_id: builtins.str) -> _CfnHook_ca75538d:
-        """Returns the CfnHook object from the 'Hooks' section of the included CloudFormation template with the given logical ID.
+        """(experimental) Returns the CfnHook object from the 'Hooks' section of the included CloudFormation template with the given logical ID.
 
         Any modifications performed on the returned object will be reflected in the resulting CDK template.
 
@@ -95,14 +92,13 @@ class CfnInclude(
 
         :param hook_logical_id: the logical ID of the Hook in the included CloudFormation template's 'Hooks' section.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "getHook", [hook_logical_id])
 
     @jsii.member(jsii_name="getMapping")
     def get_mapping(self, mapping_name: builtins.str) -> _CfnMapping_b46343a2:
-        """Returns the CfnMapping object from the 'Mappings' section of the included template.
+        """(experimental) Returns the CfnMapping object from the 'Mappings' section of the included template.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
 
@@ -111,14 +107,13 @@ class CfnInclude(
 
         :param mapping_name: the name of the Mapping in the template to retrieve.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "getMapping", [mapping_name])
 
     @jsii.member(jsii_name="getNestedStack")
     def get_nested_stack(self, logical_id: builtins.str) -> "IncludedNestedStack":
-        """Returns a loaded NestedStack with name logicalId.
+        """(experimental) Returns a loaded NestedStack with name logicalId.
 
         For a nested stack to be returned by this method,
         it must be specified either in the {@link CfnIncludeProps.loadNestedStacks} property,
@@ -126,14 +121,13 @@ class CfnInclude(
 
         :param logical_id: the ID of the stack to retrieve, as it appears in the template.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "getNestedStack", [logical_id])
 
     @jsii.member(jsii_name="getOutput")
     def get_output(self, logical_id: builtins.str) -> _CfnOutput_1185605a:
-        """Returns the CfnOutput object from the 'Outputs' section of the included template.
+        """(experimental) Returns the CfnOutput object from the 'Outputs' section of the included template.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
 
@@ -142,14 +136,13 @@ class CfnInclude(
 
         :param logical_id: the name of the output to retrieve.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "getOutput", [logical_id])
 
     @jsii.member(jsii_name="getParameter")
     def get_parameter(self, parameter_name: builtins.str) -> _CfnParameter_90f1d0df:
-        """Returns the CfnParameter object from the 'Parameters' section of the included template.
+        """(experimental) Returns the CfnParameter object from the 'Parameters' section of the included template.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
 
@@ -158,14 +151,13 @@ class CfnInclude(
 
         :param parameter_name: the name of the parameter to retrieve.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "getParameter", [parameter_name])
 
     @jsii.member(jsii_name="getResource")
     def get_resource(self, logical_id: builtins.str) -> _CfnResource_7760e8e4:
-        """Returns the low-level CfnResource from the template with the given logical ID.
+        """(experimental) Returns the low-level CfnResource from the template with the given logical ID.
 
         Any modifications performed on that resource will be reflected in the resulting CDK template.
 
@@ -181,14 +173,13 @@ class CfnInclude(
 
         :param logical_id: the logical ID of the resource in the CloudFormation template file.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "getResource", [logical_id])
 
     @jsii.member(jsii_name="getRule")
     def get_rule(self, rule_name: builtins.str) -> _CfnRule_a373f272:
-        """Returns the CfnRule object from the 'Rules' section of the CloudFormation template with the given name.
+        """(experimental) Returns the CfnRule object from the 'Rules' section of the CloudFormation template with the given name.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
 
@@ -197,7 +188,6 @@ class CfnInclude(
 
         :param rule_name: the name of the Rule in the CloudFormation template.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "getRule", [rule_name])
@@ -212,7 +202,7 @@ class CfnInclude(
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> "IncludedNestedStack":
-        """Includes a template for a child stack inside of this parent template.
+        """(experimental) Includes a template for a child stack inside of this parent template.
 
         A child with this logical ID must exist in the template,
         and be of type AWS::CloudFormation::Stack.
@@ -220,15 +210,13 @@ class CfnInclude(
         property on object construction.
 
         :param logical_id: the ID of the stack to retrieve, as it appears in the template.
-        :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
-        :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
-        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
+        :param template_file: (experimental) Path to the template file. Both JSON and YAML template formats are supported.
+        :param load_nested_stacks: (experimental) Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param parameters: (experimental) Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
+        :param preserve_logical_ids: (experimental) Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
 
-        return
         :return: the same {@link IncludedNestedStack} object that {@link getNestedStack} returns for this logical ID
 
-        stability
         :stability: experimental
         """
         nested_stack_props = CfnIncludeProps(
@@ -260,14 +248,13 @@ class CfnIncludeProps:
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> None:
-        """Construction properties of {@link CfnInclude}.
+        """(experimental) Construction properties of {@link CfnInclude}.
 
-        :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
-        :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
-        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
+        :param template_file: (experimental) Path to the template file. Both JSON and YAML template formats are supported.
+        :param load_nested_stacks: (experimental) Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param parameters: (experimental) Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
+        :param preserve_logical_ids: (experimental) Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -282,11 +269,10 @@ class CfnIncludeProps:
 
     @builtins.property
     def template_file(self) -> builtins.str:
-        """Path to the template file.
+        """(experimental) Path to the template file.
 
         Both JSON and YAML template formats are supported.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("template_file")
@@ -297,7 +283,7 @@ class CfnIncludeProps:
     def load_nested_stacks(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, "CfnIncludeProps"]]:
-        """Specifies the template files that define nested stacks that should be included.
+        """(experimental) Specifies the template files that define nested stacks that should be included.
 
         If your template specifies a stack that isn't included here, it won't be created as a NestedStack
         resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method
@@ -307,10 +293,8 @@ class CfnIncludeProps:
         or is in the template but is not a nested stack,
         template creation will fail and an error will be thrown.
 
-        default
         :default: - no nested stacks will be included
 
-        stability
         :stability: experimental
         """
         result = self._values.get("load_nested_stacks")
@@ -318,16 +302,14 @@ class CfnIncludeProps:
 
     @builtins.property
     def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
-        """Specifies parameters to be replaced by the values in this mapping.
+        """(experimental) Specifies parameters to be replaced by the values in this mapping.
 
         Any parameters in the template that aren't specified here will be left unmodified.
         If you include a parameter here with an ID that isn't in the template,
         template creation will fail and an error will be thrown.
 
-        default
         :default: - no parameters will be replaced
 
-        stability
         :stability: experimental
         """
         result = self._values.get("parameters")
@@ -335,7 +317,7 @@ class CfnIncludeProps:
 
     @builtins.property
     def preserve_logical_ids(self) -> typing.Optional[builtins.bool]:
-        """Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file.
+        """(experimental) Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file.
 
         If you're vending a Construct using an existing CloudFormation template,
         make sure to pass this as ``false``.
@@ -344,10 +326,8 @@ class CfnIncludeProps:
         the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element,
         as specified in the template file.
 
-        default
         :default: true
 
-        stability
         :stability: experimental
         """
         result = self._values.get("preserve_logical_ids")
@@ -374,15 +354,14 @@ class IncludedNestedStack:
     def __init__(
         self,
         *,
-        included_template: "CfnInclude",
+        included_template: CfnInclude,
         stack: _NestedStack_e205561c,
     ) -> None:
-        """The type returned from {@link CfnInclude.getNestedStack}. Contains both the NestedStack object and CfnInclude representations of the child stack.
+        """(experimental) The type returned from {@link CfnInclude.getNestedStack}. Contains both the NestedStack object and CfnInclude representations of the child stack.
 
-        :param included_template: The CfnInclude that represents the template, which can be used to access Resources and other template elements.
-        :param stack: The NestedStack object which represents the scope of the template.
+        :param included_template: (experimental) The CfnInclude that represents the template, which can be used to access Resources and other template elements.
+        :param stack: (experimental) The NestedStack object which represents the scope of the template.
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -391,10 +370,9 @@ class IncludedNestedStack:
         }
 
     @builtins.property
-    def included_template(self) -> "CfnInclude":
-        """The CfnInclude that represents the template, which can be used to access Resources and other template elements.
+    def included_template(self) -> CfnInclude:
+        """(experimental) The CfnInclude that represents the template, which can be used to access Resources and other template elements.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("included_template")
@@ -403,9 +381,8 @@ class IncludedNestedStack:
 
     @builtins.property
     def stack(self) -> _NestedStack_e205561c:
-        """The NestedStack object which represents the scope of the template.
+        """(experimental) The NestedStack object which represents the scope of the template.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("stack")
