@@ -15,9 +15,8 @@ class Default(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.region_info.Default",
 ):
-    """Provides default values for certain regional information points.
+    """(experimental) Provides default values for certain regional information points.
 
-    stability
     :stability: experimental
     """
 
@@ -29,7 +28,7 @@ class Default(
         region: builtins.str,
         url_suffix: builtins.str,
     ) -> builtins.str:
-        """Computes a "standard" AWS Service principal for a given service, region and suffix.
+        """(experimental) Computes a "standard" AWS Service principal for a given service, region and suffix.
 
         This is useful for example when
         you need to compute a service principal name, but you do not have a synthesize-time region literal available (so
@@ -40,7 +39,6 @@ class Default(
         :param region: the region in which the service principal is needed.
         :param url_suffix: the URL suffix for the partition in which the region is located.
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "servicePrincipal", [service, region, url_suffix])
@@ -48,18 +46,16 @@ class Default(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="VPC_ENDPOINT_SERVICE_NAME_PREFIX")
     def VPC_ENDPOINT_SERVICE_NAME_PREFIX(cls) -> builtins.str:
-        """The default value for a VPC Endpoint Service name prefix, useful if you do not have a synthesize-time region literal available (all you have is ``{ "Ref": "AWS::Region" }``).
+        """(experimental) The default value for a VPC Endpoint Service name prefix, useful if you do not have a synthesize-time region literal available (all you have is ``{ "Ref": "AWS::Region" }``).
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "VPC_ENDPOINT_SERVICE_NAME_PREFIX")
 
 
 class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fact"):
-    """A database of regional information.
+    """(experimental) A database of regional information.
 
-    stability
     :stability: experimental
     """
 
@@ -70,15 +66,13 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
         region: builtins.str,
         name: builtins.str,
     ) -> typing.Optional[builtins.str]:
-        """Retrieves a fact from this Fact database.
+        """(experimental) Retrieves a fact from this Fact database.
 
         :param region: the name of the region (e.g: ``us-east-1``).
         :param name: the name of the fact being looked up (see the ``FactName`` class for details).
 
-        return
         :return: the fact value if it is known, and ``undefined`` otherwise.
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "find", [region, name])
@@ -90,12 +84,11 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
         fact: "IFact",
         allow_replacing: typing.Optional[builtins.bool] = None,
     ) -> None:
-        """Registers a new fact in this Fact database.
+        """(experimental) Registers a new fact in this Fact database.
 
         :param fact: the new fact to be registered.
         :param allow_replacing: whether new facts can replace existing facts or not.
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "register", [fact, allow_replacing])
@@ -103,7 +96,7 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
     @jsii.member(jsii_name="requireFact")
     @builtins.classmethod
     def require_fact(cls, region: builtins.str, name: builtins.str) -> builtins.str:
-        """Retrieve a fact from the Fact database.
+        """(experimental) Retrieve a fact from the Fact database.
 
         (retrieval will fail if the specified region or
         fact name does not exist.)
@@ -111,7 +104,6 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
         :param region: the name of the region (e.g: ``us-east-1``).
         :param name: the name of the fact being looked up (see the ``FactName`` class for details).
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "requireFact", [region, name])
@@ -124,13 +116,12 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
         name: builtins.str,
         value: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Removes a fact from the database.
+        """(experimental) Removes a fact from the database.
 
         :param region: the region for which the fact is to be removed.
         :param name: the name of the fact to remove.
         :param value: the value that should be removed (removal will fail if the value is specified, but does not match the current stored value).
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "unregister", [region, name, value])
@@ -139,13 +130,11 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
     @jsii.member(jsii_name="regions")
     def regions(cls) -> typing.List[builtins.str]:
         """
-        return
         :return:
 
         the list of names of AWS regions for which there is at least one registered fact. This
         may not be an exhaustive list of all available AWS regions.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "regions")
@@ -155,15 +144,13 @@ class FactName(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.region_info.FactName",
 ):
-    """All standardized fact names.
+    """(experimental) All standardized fact names.
 
-    stability
     :stability: experimental
     """
 
     def __init__(self) -> None:
         """
-        stability
         :stability: experimental
         """
         jsii.create(FactName, self, [])
@@ -171,11 +158,10 @@ class FactName(
     @jsii.member(jsii_name="servicePrincipal")
     @builtins.classmethod
     def service_principal(cls, service: builtins.str) -> builtins.str:
-        """The name of the regional service principal for a given service.
+        """(experimental) The name of the regional service principal for a given service.
 
         :param service: the service name, either simple (e.g: ``s3``, ``codedeploy``) or qualified (e.g: ``s3.amazonaws.com``). The ``.amazonaws.com`` and ``.amazonaws.com.cn`` domains are stripped from service names, so they are canonicalized in that respect.
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "servicePrincipal", [service])
@@ -183,9 +169,8 @@ class FactName(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="APPMESH_ECR_ACCOUNT")
     def APPMESH_ECR_ACCOUNT(cls) -> builtins.str:
-        """The ID of the AWS account that owns the public ECR repository that contains the AWS App Mesh Envoy Proxy images in a given region.
+        """(experimental) The ID of the AWS account that owns the public ECR repository that contains the AWS App Mesh Envoy Proxy images in a given region.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "APPMESH_ECR_ACCOUNT")
@@ -193,12 +178,11 @@ class FactName(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CDK_METADATA_RESOURCE_AVAILABLE")
     def CDK_METADATA_RESOURCE_AVAILABLE(cls) -> builtins.str:
-        """Whether the AWS::CDK::Metadata CloudFormation Resource is available in-region or not.
+        """(experimental) Whether the AWS::CDK::Metadata CloudFormation Resource is available in-region or not.
 
         The value is a boolean
         modelled as ``YES`` or ``NO``.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "CDK_METADATA_RESOURCE_AVAILABLE")
@@ -206,9 +190,8 @@ class FactName(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="DLC_REPOSITORY_ACCOUNT")
     def DLC_REPOSITORY_ACCOUNT(cls) -> builtins.str:
-        """The ID of the AWS account that owns the public ECR repository that contains the AWS Deep Learning Containers images in a given region.
+        """(experimental) The ID of the AWS account that owns the public ECR repository that contains the AWS Deep Learning Containers images in a given region.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "DLC_REPOSITORY_ACCOUNT")
@@ -216,9 +199,8 @@ class FactName(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="DOMAIN_SUFFIX")
     def DOMAIN_SUFFIX(cls) -> builtins.str:
-        """The domain suffix for a region (e.g: 'amazonaws.com`).
+        """(experimental) The domain suffix for a region (e.g: 'amazonaws.com`).
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "DOMAIN_SUFFIX")
@@ -226,9 +208,8 @@ class FactName(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="ELBV2_ACCOUNT")
     def ELBV2_ACCOUNT(cls) -> builtins.str:
-        """The account for ELBv2 in this region.
+        """(experimental) The account for ELBv2 in this region.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "ELBV2_ACCOUNT")
@@ -236,9 +217,8 @@ class FactName(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="PARTITION")
     def PARTITION(cls) -> builtins.str:
-        """The name of the partition for a region (e.g: 'aws', 'aws-cn', ...).
+        """(experimental) The name of the partition for a region (e.g: 'aws', 'aws-cn', ...).
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "PARTITION")
@@ -246,9 +226,8 @@ class FactName(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="S3_STATIC_WEBSITE_ENDPOINT")
     def S3_STATIC_WEBSITE_ENDPOINT(cls) -> builtins.str:
-        """The endpoint used for hosting S3 static websites.
+        """(experimental) The endpoint used for hosting S3 static websites.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "S3_STATIC_WEBSITE_ENDPOINT")
@@ -256,9 +235,8 @@ class FactName(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID")
     def S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID(cls) -> builtins.str:
-        """The endpoint used for aliasing S3 static websites in Route 53.
+        """(experimental) The endpoint used for aliasing S3 static websites in Route 53.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID")
@@ -266,9 +244,8 @@ class FactName(
     @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="VPC_ENDPOINT_SERVICE_NAME_PREFIX")
     def VPC_ENDPOINT_SERVICE_NAME_PREFIX(cls) -> builtins.str:
-        """The prefix for VPC Endpoint Service names, cn.com.amazonaws.vpce for China regions, com.amazonaws.vpce otherwise.
+        """(experimental) The prefix for VPC Endpoint Service names, cn.com.amazonaws.vpce for China regions, com.amazonaws.vpce otherwise.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "VPC_ENDPOINT_SERVICE_NAME_PREFIX")
@@ -276,9 +253,8 @@ class FactName(
 
 @jsii.interface(jsii_type="monocdk-experiment.region_info.IFact")
 class IFact(typing_extensions.Protocol):
-    """A fact that can be registered about a particular region.
+    """(experimental) A fact that can be registered about a particular region.
 
-    stability
     :stability: experimental
     """
 
@@ -289,11 +265,10 @@ class IFact(typing_extensions.Protocol):
     @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
-        """The name of this fact.
+        """(experimental) The name of this fact.
 
         Standardized values are provided by the ``Facts`` class.
 
-        stability
         :stability: experimental
         """
         ...
@@ -301,9 +276,8 @@ class IFact(typing_extensions.Protocol):
     @builtins.property # type: ignore
     @jsii.member(jsii_name="region")
     def region(self) -> builtins.str:
-        """The region for which this fact applies.
+        """(experimental) The region for which this fact applies.
 
-        stability
         :stability: experimental
         """
         ...
@@ -311,18 +285,16 @@ class IFact(typing_extensions.Protocol):
     @builtins.property # type: ignore
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Optional[builtins.str]:
-        """The value of this fact.
+        """(experimental) The value of this fact.
 
-        stability
         :stability: experimental
         """
         ...
 
 
 class _IFactProxy:
-    """A fact that can be registered about a particular region.
+    """(experimental) A fact that can be registered about a particular region.
 
-    stability
     :stability: experimental
     """
 
@@ -331,11 +303,10 @@ class _IFactProxy:
     @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
-        """The name of this fact.
+        """(experimental) The name of this fact.
 
         Standardized values are provided by the ``Facts`` class.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "name")
@@ -343,9 +314,8 @@ class _IFactProxy:
     @builtins.property # type: ignore
     @jsii.member(jsii_name="region")
     def region(self) -> builtins.str:
-        """The region for which this fact applies.
+        """(experimental) The region for which this fact applies.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "region")
@@ -353,9 +323,8 @@ class _IFactProxy:
     @builtins.property # type: ignore
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Optional[builtins.str]:
-        """The value of this fact.
+        """(experimental) The value of this fact.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "value")
@@ -365,20 +334,18 @@ class RegionInfo(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk-experiment.region_info.RegionInfo",
 ):
-    """Information pertaining to an AWS region.
+    """(experimental) Information pertaining to an AWS region.
 
-    stability
     :stability: experimental
     """
 
     @jsii.member(jsii_name="get")
     @builtins.classmethod
     def get(cls, name: builtins.str) -> "RegionInfo":
-        """Obtain region info for a given region name.
+        """(experimental) Obtain region info for a given region name.
 
         :param name: the name of the region (e.g: us-east-1).
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "get", [name])
@@ -389,28 +356,25 @@ class RegionInfo(
         cls,
         fact_name: builtins.str,
     ) -> typing.Mapping[builtins.str, builtins.str]:
-        """Retrieves a collection of all fact values for all regions that fact is defined in.
+        """(experimental) Retrieves a collection of all fact values for all regions that fact is defined in.
 
         :param fact_name: the name of the fact to retrieve values for. For a list of common fact names, see the FactName class
 
-        return
         :return:
 
         a mapping with AWS region codes as the keys,
         and the fact in the given region as the value for that key
 
-        stability
         :stability: experimental
         """
         return jsii.sinvoke(cls, "regionMap", [fact_name])
 
     @jsii.member(jsii_name="servicePrincipal")
     def service_principal(self, service: builtins.str) -> typing.Optional[builtins.str]:
-        """The name of the service principal for a given service in this region.
+        """(experimental) The name of the service principal for a given service in this region.
 
         :param service: the service name (e.g: s3.amazonaws.com).
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "servicePrincipal", [service])
@@ -419,13 +383,11 @@ class RegionInfo(
     @jsii.member(jsii_name="regions")
     def regions(cls) -> typing.List["RegionInfo"]:
         """
-        return
         :return:
 
         the list of names of AWS regions for which there is at least one registered fact. This
         may not be an exaustive list of all available AWS regions.
 
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "regions")
@@ -433,9 +395,8 @@ class RegionInfo(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="cdkMetadataResourceAvailable")
     def cdk_metadata_resource_available(self) -> builtins.bool:
-        """Whether the ``AWS::CDK::Metadata`` CloudFormation Resource is available in this region or not.
+        """(experimental) Whether the ``AWS::CDK::Metadata`` CloudFormation Resource is available in this region or not.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "cdkMetadataResourceAvailable")
@@ -444,7 +405,6 @@ class RegionInfo(
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         """
-        stability
         :stability: experimental
         """
         return jsii.get(self, "name")
@@ -452,9 +412,8 @@ class RegionInfo(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="appMeshRepositoryAccount")
     def app_mesh_repository_account(self) -> typing.Optional[builtins.str]:
-        """The ID of the AWS account that owns the public ECR repository that contains the AWS App Mesh Envoy Proxy images in a given region.
+        """(experimental) The ID of the AWS account that owns the public ECR repository that contains the AWS App Mesh Envoy Proxy images in a given region.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "appMeshRepositoryAccount")
@@ -462,9 +421,8 @@ class RegionInfo(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="dlcRepositoryAccount")
     def dlc_repository_account(self) -> typing.Optional[builtins.str]:
-        """The ID of the AWS account that owns the public ECR repository containing the AWS Deep Learning Containers images in this region.
+        """(experimental) The ID of the AWS account that owns the public ECR repository containing the AWS Deep Learning Containers images in this region.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "dlcRepositoryAccount")
@@ -472,9 +430,8 @@ class RegionInfo(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="domainSuffix")
     def domain_suffix(self) -> typing.Optional[builtins.str]:
-        """The domain name suffix (e.g: amazonaws.com) for this region.
+        """(experimental) The domain name suffix (e.g: amazonaws.com) for this region.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "domainSuffix")
@@ -482,9 +439,8 @@ class RegionInfo(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="elbv2Account")
     def elbv2_account(self) -> typing.Optional[builtins.str]:
-        """The account ID for ELBv2 in this region.
+        """(experimental) The account ID for ELBv2 in this region.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "elbv2Account")
@@ -492,9 +448,8 @@ class RegionInfo(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="partition")
     def partition(self) -> typing.Optional[builtins.str]:
-        """The name of the ARN partition for this region (e.g: aws).
+        """(experimental) The name of the ARN partition for this region (e.g: aws).
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "partition")
@@ -502,9 +457,8 @@ class RegionInfo(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="s3StaticWebsiteEndpoint")
     def s3_static_website_endpoint(self) -> typing.Optional[builtins.str]:
-        """The endpoint used by S3 static website hosting in this region (e.g: s3-static-website-us-east-1.amazonaws.com).
+        """(experimental) The endpoint used by S3 static website hosting in this region (e.g: s3-static-website-us-east-1.amazonaws.com).
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "s3StaticWebsiteEndpoint")
@@ -512,9 +466,8 @@ class RegionInfo(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="s3StaticWebsiteHostedZoneId")
     def s3_static_website_hosted_zone_id(self) -> typing.Optional[builtins.str]:
-        """The hosted zone ID used by Route 53 to alias a S3 static website in this region (e.g: Z2O1EMRO9K5GLX).
+        """(experimental) The hosted zone ID used by Route 53 to alias a S3 static website in this region (e.g: Z2O1EMRO9K5GLX).
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "s3StaticWebsiteHostedZoneId")
@@ -522,9 +475,8 @@ class RegionInfo(
     @builtins.property # type: ignore
     @jsii.member(jsii_name="vpcEndpointServiceNamePrefix")
     def vpc_endpoint_service_name_prefix(self) -> typing.Optional[builtins.str]:
-        """The prefix for VPC Endpoint Service names, cn.com.amazonaws.vpce for China regions, com.amazonaws.vpce otherwise.
+        """(experimental) The prefix for VPC Endpoint Service names, cn.com.amazonaws.vpce for China regions, com.amazonaws.vpce otherwise.
 
-        stability
         :stability: experimental
         """
         return jsii.get(self, "vpcEndpointServiceNamePrefix")
